""" Cisco_IOS_XR_ipv4_igmp_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-igmp package operational data.

This module contains definitions
for the following management objects\:
  mld\: MLD operational data
  igmp\: igmp

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class IgmpAfi(Enum):
    """
    IgmpAfi

    Address family

    .. data:: ipv4_unicast = 0

    	IP v4 unicast

    .. data:: ipv6_unicast = 1

    	IP v6 unicast

    """

    ipv4_unicast = Enum.YLeaf(0, "ipv4-unicast")

    ipv6_unicast = Enum.YLeaf(1, "ipv6-unicast")


class IgmpEdmProtocol(Enum):
    """
    IgmpEdmProtocol

    IGMP Protocol

    .. data:: no_route = 0

    	no route

    .. data:: sm = 1

    	sm

    .. data:: dm = 2

    	dm

    .. data:: bidir = 3

    	bidir

    .. data:: ssm = 4

    	ssm

    .. data:: any = 6

    	any

    """

    no_route = Enum.YLeaf(0, "no-route")

    sm = Enum.YLeaf(1, "sm")

    dm = Enum.YLeaf(2, "dm")

    bidir = Enum.YLeaf(3, "bidir")

    ssm = Enum.YLeaf(4, "ssm")

    any = Enum.YLeaf(6, "any")


class IgmpssmMap(Enum):
    """
    IgmpssmMap

    Igmpssm map

    .. data:: static = 0

    	Static

    .. data:: dns = 1

    	Dns

    .. data:: all = 2

    	All

    """

    static = Enum.YLeaf(0, "static")

    dns = Enum.YLeaf(1, "dns")

    all = Enum.YLeaf(2, "all")



class Mld(Entity):
    """
    MLD operational data
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby>`
    
    

    """

    _prefix = 'ipv4-igmp-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Mld, self).__init__()
        self._top_entity = None

        self.yang_name = "mld"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-igmp-oper"

        self.active = Mld.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = Mld.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-igmp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Mld.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "mld"

            self.default_context = Mld.Standby.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Mld.Standby.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Mld.Standby.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF table Names
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Standby.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "standby"

                self.vrf = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Mld.Standby.Vrfs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Mld.Standby.Vrfs, self).__setattr__(name, value)


            class Vrf(Entity):
                """
                VRF table Names
                
                .. attribute:: vrf_name  <key>
                
                	VRF name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: detail_groups
                
                	IGMP Detail Group Database
                	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups>`
                
                .. attribute:: explicit_groups
                
                	IGMP Explicit Group Database
                	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups>`
                
                .. attribute:: global_interface_table
                
                	IGMP Global Interface 
                	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable>`
                
                .. attribute:: group_summary
                
                	IGMP Groups Summary
                	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GroupSummary>`
                
                .. attribute:: groups
                
                	IGMP Group Database Table
                	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Groups>`
                
                .. attribute:: ifrs_interface_summary
                
                	IGMP IFRS Interface summary
                	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary>`
                
                .. attribute:: ifrs_interfaces
                
                	IGMP Interface specific
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: interface_state_offs
                
                	IGMP Interface state off
                	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOffs>`
                
                .. attribute:: interface_state_ons
                
                	IGMP Interface state on
                	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOns>`
                
                .. attribute:: interface_table
                
                	IGMP Interface specific Table
                	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceTable>`
                
                .. attribute:: interface_unicast_qos_adjusts
                
                	IGMP Interface Unicast\-Qos\-Adjust
                	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts>`
                
                .. attribute:: non_active_groups
                
                	IGMP Non\-Active Groups Information
                	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.NonActiveGroups>`
                
                .. attribute:: ranges
                
                	Range table
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: ssm_map_details
                
                	SSM Map Detail
                	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMapDetails>`
                
                .. attribute:: ssm_maps
                
                	SSM Map Table
                	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMaps>`
                
                .. attribute:: summary
                
                	IGMP Summary Information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: traffic_counters
                
                	IGMP Message Traffic Counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.TrafficCounters>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.detail_groups = Mld.Standby.Vrfs.Vrf.DetailGroups()
                    self.detail_groups.parent = self
                    self._children_name_map["detail_groups"] = "detail-groups"
                    self._children_yang_names.add("detail-groups")

                    self.explicit_groups = Mld.Standby.Vrfs.Vrf.ExplicitGroups()
                    self.explicit_groups.parent = self
                    self._children_name_map["explicit_groups"] = "explicit-groups"
                    self._children_yang_names.add("explicit-groups")

                    self.global_interface_table = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable()
                    self.global_interface_table.parent = self
                    self._children_name_map["global_interface_table"] = "global-interface-table"
                    self._children_yang_names.add("global-interface-table")

                    self.group_summary = Mld.Standby.Vrfs.Vrf.GroupSummary()
                    self.group_summary.parent = self
                    self._children_name_map["group_summary"] = "group-summary"
                    self._children_yang_names.add("group-summary")

                    self.groups = Mld.Standby.Vrfs.Vrf.Groups()
                    self.groups.parent = self
                    self._children_name_map["groups"] = "groups"
                    self._children_yang_names.add("groups")

                    self.ifrs_interface_summary = Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary()
                    self.ifrs_interface_summary.parent = self
                    self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    self._children_yang_names.add("ifrs-interface-summary")

                    self.ifrs_interfaces = Mld.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.interface_state_offs = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs()
                    self.interface_state_offs.parent = self
                    self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    self._children_yang_names.add("interface-state-offs")

                    self.interface_state_ons = Mld.Standby.Vrfs.Vrf.InterfaceStateOns()
                    self.interface_state_ons.parent = self
                    self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    self._children_yang_names.add("interface-state-ons")

                    self.interface_table = Mld.Standby.Vrfs.Vrf.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                    self._children_yang_names.add("interface-table")

                    self.interface_unicast_qos_adjusts = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                    self.interface_unicast_qos_adjusts.parent = self
                    self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    self._children_yang_names.add("interface-unicast-qos-adjusts")

                    self.non_active_groups = Mld.Standby.Vrfs.Vrf.NonActiveGroups()
                    self.non_active_groups.parent = self
                    self._children_name_map["non_active_groups"] = "non-active-groups"
                    self._children_yang_names.add("non-active-groups")

                    self.ranges = Mld.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.ssm_map_details = Mld.Standby.Vrfs.Vrf.SsmMapDetails()
                    self.ssm_map_details.parent = self
                    self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    self._children_yang_names.add("ssm-map-details")

                    self.ssm_maps = Mld.Standby.Vrfs.Vrf.SsmMaps()
                    self.ssm_maps.parent = self
                    self._children_name_map["ssm_maps"] = "ssm-maps"
                    self._children_yang_names.add("ssm-maps")

                    self.summary = Mld.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.traffic_counters = Mld.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vrf_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.Vrfs.Vrf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.Vrfs.Vrf, self).__setattr__(name, value)


                class Summary(Entity):
                    """
                    IGMP Summary Information
                    
                    .. attribute:: disabled_interface_count
                    
                    	No. of disabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: enabled_interface_count
                    
                    	No. of enabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Maximum and current groups accepted for each interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Summary.Interface>`
                    
                    .. attribute:: is_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: robustness
                    
                    	Robustness variable
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: supported_interfaces
                    
                    	No. of supported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_mte_config_count
                    
                    	No. of static group commands
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsupported_interfaces
                    
                    	No. of unsupported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"

                        self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                        self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                        self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                        self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                        self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("disabled_interface_count",
                                        "enabled_interface_count",
                                        "group_count",
                                        "group_limit",
                                        "is_disabled",
                                        "node_low_memory",
                                        "robustness",
                                        "supported_interfaces",
                                        "tunnel_mte_config_count",
                                        "unsupported_interfaces") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.Summary, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Maximum and current groups accepted for each
                        interface
                        
                        .. attribute:: group_count
                        
                        	Current groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_limit
                        
                        	Maximum groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: on_off
                        
                        	Enabled/Disabled
                        	**type**\:  bool
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent if handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Time elapsed since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.group_limit = YLeaf(YType.uint32, "group-limit")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.on_off = YLeaf(YType.boolean, "on-off")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_count",
                                            "group_limit",
                                            "interface_name",
                                            "on_off",
                                            "parent_ifhandle",
                                            "router_uptime_in_seconds",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.Summary.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.Summary.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.group_count.is_set or
                                self.group_limit.is_set or
                                self.interface_name.is_set or
                                self.on_off.is_set or
                                self.parent_ifhandle.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.group_limit.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.on_off.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_limit.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.on_off.is_set or self.on_off.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.on_off.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-count" or name == "group-limit" or name == "interface-name" or name == "on-off" or name == "parent-ifhandle" or name == "router-uptime-in-seconds" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-limit"):
                                self.group_limit = value
                                self.group_limit.value_namespace = name_space
                                self.group_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "on-off"):
                                self.on_off = value
                                self.on_off.value_namespace = name_space
                                self.on_off.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.disabled_interface_count.is_set or
                            self.enabled_interface_count.is_set or
                            self.group_count.is_set or
                            self.group_limit.is_set or
                            self.is_disabled.is_set or
                            self.node_low_memory.is_set or
                            self.robustness.is_set or
                            self.supported_interfaces.is_set or
                            self.tunnel_mte_config_count.is_set or
                            self.unsupported_interfaces.is_set)

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.disabled_interface_count.yfilter != YFilter.not_set or
                            self.enabled_interface_count.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.group_limit.yfilter != YFilter.not_set or
                            self.is_disabled.yfilter != YFilter.not_set or
                            self.node_low_memory.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.supported_interfaces.yfilter != YFilter.not_set or
                            self.tunnel_mte_config_count.yfilter != YFilter.not_set or
                            self.unsupported_interfaces.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.disabled_interface_count.is_set or self.disabled_interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disabled_interface_count.get_name_leafdata())
                        if (self.enabled_interface_count.is_set or self.enabled_interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enabled_interface_count.get_name_leafdata())
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_limit.get_name_leafdata())
                        if (self.is_disabled.is_set or self.is_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_disabled.get_name_leafdata())
                        if (self.node_low_memory.is_set or self.node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_low_memory.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.supported_interfaces.is_set or self.supported_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.supported_interfaces.get_name_leafdata())
                        if (self.tunnel_mte_config_count.is_set or self.tunnel_mte_config_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_mte_config_count.get_name_leafdata())
                        if (self.unsupported_interfaces.is_set or self.unsupported_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unsupported_interfaces.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.Summary.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "disabled-interface-count" or name == "enabled-interface-count" or name == "group-count" or name == "group-limit" or name == "is-disabled" or name == "node-low-memory" or name == "robustness" or name == "supported-interfaces" or name == "tunnel-mte-config-count" or name == "unsupported-interfaces"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "disabled-interface-count"):
                            self.disabled_interface_count = value
                            self.disabled_interface_count.value_namespace = name_space
                            self.disabled_interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "enabled-interface-count"):
                            self.enabled_interface_count = value
                            self.enabled_interface_count.value_namespace = name_space
                            self.enabled_interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-limit"):
                            self.group_limit = value
                            self.group_limit.value_namespace = name_space
                            self.group_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-disabled"):
                            self.is_disabled = value
                            self.is_disabled.value_namespace = name_space
                            self.is_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-low-memory"):
                            self.node_low_memory = value
                            self.node_low_memory.value_namespace = name_space
                            self.node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "supported-interfaces"):
                            self.supported_interfaces = value
                            self.supported_interfaces.value_namespace = name_space
                            self.supported_interfaces.value_namespace_prefix = name_space_prefix
                        if(value_path == "tunnel-mte-config-count"):
                            self.tunnel_mte_config_count = value
                            self.tunnel_mte_config_count.value_namespace = name_space
                            self.tunnel_mte_config_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "unsupported-interfaces"):
                            self.unsupported_interfaces = value
                            self.unsupported_interfaces.value_namespace = name_space
                            self.unsupported_interfaces.value_namespace_prefix = name_space_prefix


                class InterfaceStateOns(Entity):
                    """
                    IGMP Interface state on
                    
                    .. attribute:: interface_state_on
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns, self).__init__()

                        self.yang_name = "interface-state-ons"
                        self.yang_parent_name = "vrf"

                        self.interface_state_on = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns, self).__setattr__(name, value)


                    class InterfaceStateOn(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__init__()

                            self.yang_name = "interface-state-on"
                            self.yang_parent_name = "interface-state-ons"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_state_on:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_state_on:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-ons" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-state-on"):
                            for c in self.interface_state_on:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_state_on.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-state-on"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class DetailGroups(Entity):
                    """
                    IGMP Detail Group Database
                    
                    .. attribute:: detail_group
                    
                    	IGMP Detail Group Entry Information
                    	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.DetailGroups, self).__init__()

                        self.yang_name = "detail-groups"
                        self.yang_parent_name = "vrf"

                        self.detail_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.DetailGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.DetailGroups, self).__setattr__(name, value)


                    class DetailGroup(Entity):
                        """
                        IGMP Detail Group Entry Information
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_host_exclude_mode
                        
                        	Group host filter mode
                        	**type**\:  bool
                        
                        .. attribute:: is_router_exclude_mode
                        
                        	Group router filter mode
                        	**type**\:  bool
                        
                        .. attribute:: source
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup, self).__init__()

                            self.yang_name = "detail-group"
                            self.yang_parent_name = "detail-groups"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                            self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.source = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "interface_name",
                                            "is_host_exclude_mode",
                                            "is_router_exclude_mode",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup, self).__setattr__(name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "detail-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "explicit_tracking_enabled",
                                                "interface_name_xr",
                                                "is_added",
                                                "is_low_memory",
                                                "is_self_join",
                                                "is_suppressed",
                                                "older_host_version1_timer",
                                                "older_host_version2_timer",
                                                "router_filter_mode",
                                                "row_status",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "last-reporter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.explicit_tracking_enabled.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_added.is_set or
                                    self.is_low_memory.is_set or
                                    self.is_self_join.is_set or
                                    self.is_suppressed.is_set or
                                    self.older_host_version1_timer.is_set or
                                    self.older_host_version2_timer.is_set or
                                    self.router_filter_mode.is_set or
                                    self.row_status.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.last_reporter is not None and self.last_reporter.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_low_memory.yfilter != YFilter.not_set or
                                    self.is_self_join.yfilter != YFilter.not_set or
                                    self.is_suppressed.yfilter != YFilter.not_set or
                                    self.older_host_version1_timer.yfilter != YFilter.not_set or
                                    self.older_host_version2_timer.yfilter != YFilter.not_set or
                                    self.router_filter_mode.yfilter != YFilter.not_set or
                                    self.row_status.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                                if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_self_join.get_name_leafdata())
                                if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                                if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                                if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                                if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                                if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.row_status.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "last-reporter"):
                                    if (self.last_reporter is None):
                                        self.last_reporter = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                        self.last_reporter.parent = self
                                        self._children_name_map["last_reporter"] = "last-reporter"
                                    return self.last_reporter

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "explicit-tracking-enabled"):
                                    self.explicit_tracking_enabled = value
                                    self.explicit_tracking_enabled.value_namespace = name_space
                                    self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-low-memory"):
                                    self.is_low_memory = value
                                    self.is_low_memory.value_namespace = name_space
                                    self.is_low_memory.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-self-join"):
                                    self.is_self_join = value
                                    self.is_self_join.value_namespace = name_space
                                    self.is_self_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-suppressed"):
                                    self.is_suppressed = value
                                    self.is_suppressed.value_namespace = name_space
                                    self.is_suppressed.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version1-timer"):
                                    self.older_host_version1_timer = value
                                    self.older_host_version1_timer.value_namespace = name_space
                                    self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version2-timer"):
                                    self.older_host_version2_timer = value
                                    self.older_host_version2_timer.value_namespace = name_space
                                    self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-filter-mode"):
                                    self.router_filter_mode = value
                                    self.router_filter_mode.value_namespace = name_space
                                    self.router_filter_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "row-status"):
                                    self.row_status = value
                                    self.row_status.value_namespace = name_space
                                    self.row_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix


                        class Source(Entity):
                            """
                            List of sources
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: flags
                            
                            	Source flags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_forward
                            
                            	Should we forward on this entry
                            	**type**\:  bool
                            
                            .. attribute:: is_local
                            
                            	Is this a local source
                            	**type**\:  bool
                            
                            .. attribute:: is_remote
                            
                            	Is this a remote source
                            	**type**\:  bool
                            
                            .. attribute:: is_we_report
                            
                            	Should we report the source
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "detail-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.flags = YLeaf(YType.int32, "flags")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_forward = YLeaf(YType.boolean, "is-forward")

                                self.is_local = YLeaf(YType.boolean, "is-local")

                                self.is_remote = YLeaf(YType.boolean, "is-remote")

                                self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.source_address = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "flags",
                                                "is_added",
                                                "is_forward",
                                                "is_local",
                                                "is_remote",
                                                "is_we_report",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.flags.is_set or
                                    self.is_added.is_set or
                                    self.is_forward.is_set or
                                    self.is_local.is_set or
                                    self.is_remote.is_set or
                                    self.is_we_report.is_set or
                                    self.uptime.is_set or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.flags.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_forward.yfilter != YFilter.not_set or
                                    self.is_local.yfilter != YFilter.not_set or
                                    self.is_remote.yfilter != YFilter.not_set or
                                    self.is_we_report.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_forward.is_set or self.is_forward.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_forward.get_name_leafdata())
                                if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_local.get_name_leafdata())
                                if (self.is_remote.is_set or self.is_remote.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_remote.get_name_leafdata())
                                if (self.is_we_report.is_set or self.is_we_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_we_report.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "source-address" or name == "expiration-time" or name == "flags" or name == "is-added" or name == "is-forward" or name == "is-local" or name == "is-remote" or name == "is-we-report" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "flags"):
                                    self.flags = value
                                    self.flags.value_namespace = name_space
                                    self.flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-forward"):
                                    self.is_forward = value
                                    self.is_forward.value_namespace = name_space
                                    self.is_forward.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-local"):
                                    self.is_local = value
                                    self.is_local.value_namespace = name_space
                                    self.is_local.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-remote"):
                                    self.is_remote = value
                                    self.is_remote.value_namespace = name_space
                                    self.is_remote.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-we-report"):
                                    self.is_we_report = value
                                    self.is_we_report.value_namespace = name_space
                                    self.is_we_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.source:
                                if (c.has_data()):
                                    return True
                            return (
                                self.group_address.is_set or
                                self.interface_name.is_set or
                                self.is_host_exclude_mode.is_set or
                                self.is_router_exclude_mode.is_set or
                                self.source_address.is_set or
                                (self.group_info is not None and self.group_info.has_data()))

                        def has_operation(self):
                            for c in self.source:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_host_exclude_mode.yfilter != YFilter.not_set or
                                self.is_router_exclude_mode.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group_info is not None and self.group_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "detail-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_host_exclude_mode.is_set or self.is_host_exclude_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_host_exclude_mode.get_name_leafdata())
                            if (self.is_router_exclude_mode.is_set or self.is_router_exclude_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_exclude_mode.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-info"):
                                if (self.group_info is None):
                                    self.group_info = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                                    self.group_info.parent = self
                                    self._children_name_map["group_info"] = "group-info"
                                return self.group_info

                            if (child_yang_name == "source"):
                                for c in self.source:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.source.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-info" or name == "source" or name == "group-address" or name == "interface-name" or name == "is-host-exclude-mode" or name == "is-router-exclude-mode" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-host-exclude-mode"):
                                self.is_host_exclude_mode = value
                                self.is_host_exclude_mode.value_namespace = name_space
                                self.is_host_exclude_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-exclude-mode"):
                                self.is_router_exclude_mode = value
                                self.is_router_exclude_mode.value_namespace = name_space
                                self.is_router_exclude_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.detail_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.detail_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "detail-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "detail-group"):
                            for c in self.detail_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.detail_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "detail-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NonActiveGroups(Entity):
                    """
                    IGMP Non\-Active Groups Information
                    
                    .. attribute:: non_active_groups
                    
                    	List of non\-active groups
                    	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "vrf"

                        self.non_active_groups = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.NonActiveGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.NonActiveGroups, self).__setattr__(name, value)


                    class NonActiveGroups(Entity):
                        """
                        List of non\-active groups
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress>`
                        
                        .. attribute:: interface
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: reason_for_non_activity
                        
                        	Reason for group join not being processed
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__init__()

                            self.yang_name = "non-active-groups"
                            self.yang_parent_name = "non-active-groups"

                            self.interface = YLeaf(YType.str, "interface")

                            self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                            self.group_address = Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface",
                                            "reason_for_non_activity") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "non-active-groups"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "non-active-groups"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface.is_set or
                                self.reason_for_non_activity.is_set or
                                (self.group_address is not None and self.group_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface.yfilter != YFilter.not_set or
                                self.reason_for_non_activity.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "non-active-groups" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface.get_name_leafdata())
                            if (self.reason_for_non_activity.is_set or self.reason_for_non_activity.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reason_for_non_activity.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "source-address" or name == "interface" or name == "reason-for-non-activity"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface"):
                                self.interface = value
                                self.interface.value_namespace = name_space
                                self.interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "reason-for-non-activity"):
                                self.reason_for_non_activity = value
                                self.reason_for_non_activity.value_namespace = name_space
                                self.reason_for_non_activity.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.non_active_groups:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.non_active_groups:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "non-active-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "non-active-groups"):
                            for c in self.non_active_groups:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.non_active_groups.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "non-active-groups"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SsmMaps(Entity):
                    """
                    SSM Map Table
                    
                    .. attribute:: ssm_map
                    
                    	SSM Map information
                    	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.SsmMaps, self).__init__()

                        self.yang_name = "ssm-maps"
                        self.yang_parent_name = "vrf"

                        self.ssm_map = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.SsmMaps, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.SsmMaps, self).__setattr__(name, value)


                    class SsmMap(Entity):
                        """
                        SSM Map information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap, self).__init__()

                            self.yang_name = "ssm-map"
                            self.yang_parent_name = "ssm-maps"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.group_address_xr = Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "map_type",
                                            "source_counts",
                                            "ssm_map_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "ssm-map"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.map_type.is_set or
                                self.source_counts.is_set or
                                self.ssm_map_type.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.map_type.yfilter != YFilter.not_set or
                                self.source_counts.yfilter != YFilter.not_set or
                                self.ssm_map_type.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ssm-map" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.map_type.get_name_leafdata())
                            if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_counts.get_name_leafdata())
                            if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "group-address" or name == "map-type" or name == "source-counts" or name == "ssm-map-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "map-type"):
                                self.map_type = value
                                self.map_type.value_namespace = name_space
                                self.map_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-counts"):
                                self.source_counts = value
                                self.source_counts.value_namespace = name_space
                                self.source_counts.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssm-map-type"):
                                self.ssm_map_type = value
                                self.ssm_map_type.value_namespace = name_space
                                self.ssm_map_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ssm_map:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ssm_map:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-maps" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ssm-map"):
                            for c in self.ssm_map:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ssm_map.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ssm-map"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class ExplicitGroups(Entity):
                    """
                    IGMP Explicit Group Database
                    
                    .. attribute:: explicit_group
                    
                    	IGMP Explicit Group Entry Information
                    	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.ExplicitGroups, self).__init__()

                        self.yang_name = "explicit-groups"
                        self.yang_parent_name = "vrf"

                        self.explicit_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.ExplicitGroups, self).__setattr__(name, value)


                    class ExplicitGroup(Entity):
                        """
                        IGMP Explicit Group Entry Information
                        
                        .. attribute:: exclude_hosts
                        
                        	No. of hosts who are excluded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo>`
                        
                        .. attribute:: host
                        
                        	List of hosts
                        	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host>`
                        
                        .. attribute:: include_hosts
                        
                        	No. of hosts who are included
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__init__()

                            self.yang_name = "explicit-group"
                            self.yang_parent_name = "explicit-groups"

                            self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.host = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("exclude_hosts",
                                            "group_address",
                                            "include_hosts",
                                            "interface_name",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "explicit-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "explicit_tracking_enabled",
                                                "interface_name_xr",
                                                "is_added",
                                                "is_low_memory",
                                                "is_self_join",
                                                "is_suppressed",
                                                "older_host_version1_timer",
                                                "older_host_version2_timer",
                                                "router_filter_mode",
                                                "row_status",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "last-reporter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.explicit_tracking_enabled.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_added.is_set or
                                    self.is_low_memory.is_set or
                                    self.is_self_join.is_set or
                                    self.is_suppressed.is_set or
                                    self.older_host_version1_timer.is_set or
                                    self.older_host_version2_timer.is_set or
                                    self.router_filter_mode.is_set or
                                    self.row_status.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.last_reporter is not None and self.last_reporter.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_low_memory.yfilter != YFilter.not_set or
                                    self.is_self_join.yfilter != YFilter.not_set or
                                    self.is_suppressed.yfilter != YFilter.not_set or
                                    self.older_host_version1_timer.yfilter != YFilter.not_set or
                                    self.older_host_version2_timer.yfilter != YFilter.not_set or
                                    self.router_filter_mode.yfilter != YFilter.not_set or
                                    self.row_status.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                                if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_self_join.get_name_leafdata())
                                if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                                if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                                if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                                if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                                if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.row_status.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "last-reporter"):
                                    if (self.last_reporter is None):
                                        self.last_reporter = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                        self.last_reporter.parent = self
                                        self._children_name_map["last_reporter"] = "last-reporter"
                                    return self.last_reporter

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "explicit-tracking-enabled"):
                                    self.explicit_tracking_enabled = value
                                    self.explicit_tracking_enabled.value_namespace = name_space
                                    self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-low-memory"):
                                    self.is_low_memory = value
                                    self.is_low_memory.value_namespace = name_space
                                    self.is_low_memory.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-self-join"):
                                    self.is_self_join = value
                                    self.is_self_join.value_namespace = name_space
                                    self.is_self_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-suppressed"):
                                    self.is_suppressed = value
                                    self.is_suppressed.value_namespace = name_space
                                    self.is_suppressed.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version1-timer"):
                                    self.older_host_version1_timer = value
                                    self.older_host_version1_timer.value_namespace = name_space
                                    self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version2-timer"):
                                    self.older_host_version2_timer = value
                                    self.older_host_version2_timer.value_namespace = name_space
                                    self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-filter-mode"):
                                    self.router_filter_mode = value
                                    self.router_filter_mode.value_namespace = name_space
                                    self.router_filter_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "row-status"):
                                    self.row_status = value
                                    self.row_status.value_namespace = name_space
                                    self.row_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix


                        class Host(Entity):
                            """
                            List of hosts
                            
                            .. attribute:: address
                            
                            	Host Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address>`
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_exclude
                            
                            	Exclude flag set
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	First 3 source addresses
                            	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                            
                            .. attribute:: source_count
                            
                            	No. of sources in entry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "explicit-group"

                                self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                                self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                                self.source_count = YLeaf(YType.uint32, "source-count")

                                self.uptime = YLeaf(YType.uint32, "uptime")

                                self.address = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.source_address = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "is_exclude",
                                                "source_count",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)


                            class Address(Entity):
                                """
                                Host Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "host"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                First 3 source addresses
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "host"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.source_address:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.expiration_time.is_set or
                                    self.is_exclude.is_set or
                                    self.source_count.is_set or
                                    self.uptime.is_set or
                                    (self.address is not None and self.address.has_data()))

                            def has_operation(self):
                                for c in self.source_address:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.is_exclude.yfilter != YFilter.not_set or
                                    self.source_count.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.address is not None and self.address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "host" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.is_exclude.is_set or self.is_exclude.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_exclude.get_name_leafdata())
                                if (self.source_count.is_set or self.source_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_count.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "address"):
                                    if (self.address is None):
                                        self.address = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                    return self.address

                                if (child_yang_name == "source-address"):
                                    for c in self.source_address:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.source_address.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "source-address" or name == "expiration-time" or name == "is-exclude" or name == "source-count" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-exclude"):
                                    self.is_exclude = value
                                    self.is_exclude.value_namespace = name_space
                                    self.is_exclude.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-count"):
                                    self.source_count = value
                                    self.source_count.value_namespace = name_space
                                    self.source_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.host:
                                if (c.has_data()):
                                    return True
                            return (
                                self.exclude_hosts.is_set or
                                self.group_address.is_set or
                                self.include_hosts.is_set or
                                self.interface_name.is_set or
                                self.source_address.is_set or
                                (self.group_info is not None and self.group_info.has_data()))

                        def has_operation(self):
                            for c in self.host:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.exclude_hosts.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.include_hosts.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group_info is not None and self.group_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "explicit-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.exclude_hosts.is_set or self.exclude_hosts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.exclude_hosts.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.include_hosts.is_set or self.include_hosts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.include_hosts.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-info"):
                                if (self.group_info is None):
                                    self.group_info = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                                    self.group_info.parent = self
                                    self._children_name_map["group_info"] = "group-info"
                                return self.group_info

                            if (child_yang_name == "host"):
                                for c in self.host:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.host.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-info" or name == "host" or name == "exclude-hosts" or name == "group-address" or name == "include-hosts" or name == "interface-name" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "exclude-hosts"):
                                self.exclude_hosts = value
                                self.exclude_hosts.value_namespace = name_space
                                self.exclude_hosts.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "include-hosts"):
                                self.include_hosts = value
                                self.include_hosts.value_namespace = name_space
                                self.include_hosts.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.explicit_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.explicit_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "explicit-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "explicit-group"):
                            for c in self.explicit_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.explicit_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "explicit-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceTable(Entity):
                    """
                    IGMP Interface specific Table
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.InterfaceTable, self).__init__()

                        self.yang_name = "interface-table"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.InterfaceTable, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-table"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceUnicastQosAdjusts(Entity):
                    """
                    IGMP Interface Unicast\-Qos\-Adjust
                    
                    .. attribute:: interface_unicast_qos_adjust
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjusts"
                        self.yang_parent_name = "vrf"

                        self.interface_unicast_qos_adjust = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)


                    class InterfaceUnicastQosAdjust(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_virtual_access
                        
                        	Is VirtualAccess Interface
                        	**type**\:  bool
                        
                        .. attribute:: rate
                        
                        	Overall rate in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: rate_decrements
                        
                        	Count of rate decrements
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rate_increments
                        
                        	Count of rate increments
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update
                        
                        	List of updates
                        	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                            self.yang_name = "interface-unicast-qos-adjust"
                            self.yang_parent_name = "interface-unicast-qos-adjusts"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                            self.rate = YLeaf(YType.uint32, "rate")

                            self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                            self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                            self.update = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "is_virtual_access",
                                            "rate",
                                            "rate_decrements",
                                            "rate_increments") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)


                        class Update(Entity):
                            """
                            List of updates
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                            
                            .. attribute:: is_add
                            
                            	Is this a rate increment
                            	**type**\:  bool
                            
                            .. attribute:: received_time
                            
                            	Time this update is received
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                            
                            .. attribute:: weight
                            
                            	Weight from policy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                                self.yang_name = "update"
                                self.yang_parent_name = "interface-unicast-qos-adjust"

                                self.is_add = YLeaf(YType.boolean, "is-add")

                                self.received_time = YLeaf(YType.uint64, "received-time")

                                self.weight = YLeaf(YType.uint32, "weight")

                                self.group_address = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                                self._children_yang_names.add("group-address")

                                self.source_address = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_add",
                                                "received_time",
                                                "weight") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)


                            class SourceAddress(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "update"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GroupAddress(Entity):
                                """
                                Group address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                    self.yang_name = "group-address"
                                    self.yang_parent_name = "update"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.is_add.is_set or
                                    self.received_time.is_set or
                                    self.weight.is_set or
                                    (self.group_address is not None and self.group_address.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_add.yfilter != YFilter.not_set or
                                    self.received_time.yfilter != YFilter.not_set or
                                    self.weight.yfilter != YFilter.not_set or
                                    (self.group_address is not None and self.group_address.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "update" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_add.is_set or self.is_add.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_add.get_name_leafdata())
                                if (self.received_time.is_set or self.received_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_time.get_name_leafdata())
                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address"):
                                    if (self.group_address is None):
                                        self.group_address = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                        self.group_address.parent = self
                                        self._children_name_map["group_address"] = "group-address"
                                    return self.group_address

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address" or name == "source-address" or name == "is-add" or name == "received-time" or name == "weight"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-add"):
                                    self.is_add = value
                                    self.is_add.value_namespace = name_space
                                    self.is_add.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-time"):
                                    self.received_time = value
                                    self.received_time.value_namespace = name_space
                                    self.received_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "weight"):
                                    self.weight = value
                                    self.weight.value_namespace = name_space
                                    self.weight.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.update:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.is_virtual_access.is_set or
                                self.rate.is_set or
                                self.rate_decrements.is_set or
                                self.rate_increments.is_set)

                        def has_operation(self):
                            for c in self.update:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_virtual_access.yfilter != YFilter.not_set or
                                self.rate.yfilter != YFilter.not_set or
                                self.rate_decrements.yfilter != YFilter.not_set or
                                self.rate_increments.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_virtual_access.is_set or self.is_virtual_access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_virtual_access.get_name_leafdata())
                            if (self.rate.is_set or self.rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate.get_name_leafdata())
                            if (self.rate_decrements.is_set or self.rate_decrements.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate_decrements.get_name_leafdata())
                            if (self.rate_increments.is_set or self.rate_increments.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate_increments.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "update"):
                                for c in self.update:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.update.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "update" or name == "interface-name" or name == "is-virtual-access" or name == "rate" or name == "rate-decrements" or name == "rate-increments"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-virtual-access"):
                                self.is_virtual_access = value
                                self.is_virtual_access.value_namespace = name_space
                                self.is_virtual_access.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate"):
                                self.rate = value
                                self.rate.value_namespace = name_space
                                self.rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate-decrements"):
                                self.rate_decrements = value
                                self.rate_decrements.value_namespace = name_space
                                self.rate_decrements.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate-increments"):
                                self.rate_increments = value
                                self.rate_increments.value_namespace = name_space
                                self.rate_increments.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_unicast_qos_adjust:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_unicast_qos_adjust:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-unicast-qos-adjusts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-unicast-qos-adjust"):
                            for c in self.interface_unicast_qos_adjust:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_unicast_qos_adjust.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-unicast-qos-adjust"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Ranges(Entity):
                    """
                    Range table
                    
                    .. attribute:: range
                    
                    	Range information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"

                        self.range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.Ranges, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.Ranges, self).__setattr__(name, value)


                    class Range(Entity):
                        """
                        Range information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr>`
                        
                        .. attribute:: group_mask
                        
                        	Group Mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_stale
                        
                        	Is the entry stale
                        	**type**\:  bool
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.group_mask = YLeaf(YType.int32, "group-mask")

                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.group_address_xr = Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "group_mask",
                                            "is_stale",
                                            "prefix_length",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.group_mask.is_set or
                                self.is_stale.is_set or
                                self.prefix_length.is_set or
                                self.protocol.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.group_mask.yfilter != YFilter.not_set or
                                self.is_stale.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.group_mask.is_set or self.group_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_mask.get_name_leafdata())
                            if (self.is_stale.is_set or self.is_stale.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_stale.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "group-address" or name == "group-mask" or name == "is-stale" or name == "prefix-length" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-mask"):
                                self.group_mask = value
                                self.group_mask.value_namespace = name_space
                                self.group_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-stale"):
                                self.is_stale = value
                                self.is_stale.value_namespace = name_space
                                self.is_stale.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.range:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.range:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ranges" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "range"):
                            for c in self.range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.Ranges.Range()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.range.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "range"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class IfrsInterfaces(Entity):
                    """
                    IGMP Interface specific
                    
                    .. attribute:: ifrs_interface
                    
                    	IGMP IFRS Interface
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"

                        self.ifrs_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)


                    class IfrsInterface(Entity):
                        """
                        IGMP IFRS Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	IFRS Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: igmp_interface_entry
                        
                        	IGMP interface entry
                        	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                        
                        .. attribute:: join_group_count
                        
                        	Join group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                            self.igmp_interface_entry = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                            self.igmp_interface_entry.parent = self
                            self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            self._children_yang_names.add("igmp-interface-entry")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "join_group_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                        class IgmpInterfaceEntry(Entity):
                            """
                            IGMP interface entry
                            
                            .. attribute:: address
                            
                            	IP address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                            
                            .. attribute:: configuration_mcast_vrf_error
                            
                            	Is mcast error
                            	**type**\:  bool
                            
                            .. attribute:: configuration_mcast_vrf_set
                            
                            	Is mcast set
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_error
                            
                            	CFG vrf error
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_set
                            
                            	CFG vrf set
                            	**type**\:  bool
                            
                            .. attribute:: group_joins
                            
                            	No. of group joins
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_leaves
                            
                            	No. of group leaves
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: host_version
                            
                            	IGMP Host version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: igmp_version
                            
                            	IGMP Router version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_configurationverify
                            
                            	CFG verify
                            	**type**\:  bool
                            
                            .. attribute:: is_identity_present
                            
                            	Subscriber ID or Address available from AAA
                            	**type**\:  bool
                            
                            .. attribute:: is_im_state_registered
                            
                            	Im state registered
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_up
                            
                            	Is interface up
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_enabled
                            
                            	Is IP enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_las_registered
                            
                            	LAS registered
                            	**type**\:  bool
                            
                            .. attribute:: is_las_request
                            
                            	LAS req
                            	**type**\:  bool
                            
                            .. attribute:: is_querier
                            
                            	Are we querier
                            	**type**\:  bool
                            
                            .. attribute:: is_router_enabled
                            
                            	Is Router functionality enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_subscriber
                            
                            	Subscriber interface
                            	**type**\:  bool
                            
                            .. attribute:: las_get_address_count
                            
                            	LAS get addr count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_add_update_count
                            
                            	LAS LL add update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_registration_count
                            
                            	LAS reg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_remove_update_count
                            
                            	LAS LL remove update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_null_update_count
                            
                            	LAS Null update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_unregistration_count
                            
                            	LAS unreg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_update_count
                            
                            	LAS Update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_member_query_interval
                            
                            	Last Member Query Interval
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: location
                            
                            	Location
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_tuple_count
                            
                            	MTE Tuple count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_vrf_id
                            
                            	MTE VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_ifhandle
                            
                            	Parent If Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: proxy_interface
                            
                            	Proxy interface index
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: querier_address
                            
                            	Address of the Querier
                            	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                            
                            .. attribute:: querier_uptime
                            
                            	Time since the last querier took over
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_interval
                            
                            	Query Interval value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: query_maximum_response_time
                            
                            	Max Response Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_timeout
                            
                            	Query Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: robustness
                            
                            	Robustness Variable value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_uptime_in_seconds
                            
                            	Uptime since router enabled event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	Interface state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: subscriber_address
                            
                            	Address of subscriber
                            	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                            
                            .. attribute:: subscriber_id
                            
                            	ID string of subscriber
                            	**type**\:  str
                            
                            	**length:** 0..257
                            
                            .. attribute:: subscriber_mode
                            
                            	Subscriber mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_query_in_seconds
                            
                            	Time elapsed since last query
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_report_in_seconds
                            
                            	Time elapsed since last report
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_active_groups
                            
                            	Actual number of groups on interface
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_id
                            
                            	VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_state
                            
                            	Vrf State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                                self.yang_name = "igmp-interface-entry"
                                self.yang_parent_name = "ifrs-interface"

                                self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                                self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                                self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                                self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                                self.group_joins = YLeaf(YType.uint32, "group-joins")

                                self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                                self.host_version = YLeaf(YType.uint8, "host-version")

                                self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                                self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                                self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                                self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                                self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                                self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                                self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                                self.is_querier = YLeaf(YType.boolean, "is-querier")

                                self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                                self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                                self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                                self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                                self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                                self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                                self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                                self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                                self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                                self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                                self.location = YLeaf(YType.uint32, "location")

                                self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                                self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                                self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                                self.query_interval = YLeaf(YType.uint16, "query-interval")

                                self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                                self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                                self.robustness = YLeaf(YType.uint32, "robustness")

                                self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                                self.state = YLeaf(YType.uint32, "state")

                                self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                                self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                                self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                                self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                                self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                                self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                                self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                                self.address = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.querier_address = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                                self._children_yang_names.add("querier-address")

                                self.subscriber_address = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                                self._children_yang_names.add("subscriber-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configuration_mcast_vrf_error",
                                                "configuration_mcast_vrf_set",
                                                "configurationvrf_error",
                                                "configurationvrf_set",
                                                "group_joins",
                                                "group_leaves",
                                                "host_version",
                                                "igmp_version",
                                                "interface_name_xr",
                                                "is_configurationverify",
                                                "is_identity_present",
                                                "is_im_state_registered",
                                                "is_interface_up",
                                                "is_ip_enabled",
                                                "is_las_registered",
                                                "is_las_request",
                                                "is_querier",
                                                "is_router_enabled",
                                                "is_subscriber",
                                                "las_get_address_count",
                                                "las_ll_add_update_count",
                                                "las_ll_registration_count",
                                                "las_ll_remove_update_count",
                                                "las_null_update_count",
                                                "las_unregistration_count",
                                                "las_update_count",
                                                "last_member_query_interval",
                                                "location",
                                                "mte_tuple_count",
                                                "mte_vrf_id",
                                                "mtu",
                                                "parent_ifhandle",
                                                "prefix_length",
                                                "proxy_interface",
                                                "querier_uptime",
                                                "query_interval",
                                                "query_maximum_response_time",
                                                "query_timeout",
                                                "robustness",
                                                "router_uptime_in_seconds",
                                                "state",
                                                "subscriber_id",
                                                "subscriber_mode",
                                                "time_since_last_query_in_seconds",
                                                "time_since_last_report_in_seconds",
                                                "total_active_groups",
                                                "vrf_id",
                                                "vrf_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)


                            class Address(Entity):
                                """
                                IP address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class QuerierAddress(Entity):
                                """
                                Address of the Querier
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                    self.yang_name = "querier-address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "querier-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SubscriberAddress(Entity):
                                """
                                Address of subscriber
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                    self.yang_name = "subscriber-address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.configuration_mcast_vrf_error.is_set or
                                    self.configuration_mcast_vrf_set.is_set or
                                    self.configurationvrf_error.is_set or
                                    self.configurationvrf_set.is_set or
                                    self.group_joins.is_set or
                                    self.group_leaves.is_set or
                                    self.host_version.is_set or
                                    self.igmp_version.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_configurationverify.is_set or
                                    self.is_identity_present.is_set or
                                    self.is_im_state_registered.is_set or
                                    self.is_interface_up.is_set or
                                    self.is_ip_enabled.is_set or
                                    self.is_las_registered.is_set or
                                    self.is_las_request.is_set or
                                    self.is_querier.is_set or
                                    self.is_router_enabled.is_set or
                                    self.is_subscriber.is_set or
                                    self.las_get_address_count.is_set or
                                    self.las_ll_add_update_count.is_set or
                                    self.las_ll_registration_count.is_set or
                                    self.las_ll_remove_update_count.is_set or
                                    self.las_null_update_count.is_set or
                                    self.las_unregistration_count.is_set or
                                    self.las_update_count.is_set or
                                    self.last_member_query_interval.is_set or
                                    self.location.is_set or
                                    self.mte_tuple_count.is_set or
                                    self.mte_vrf_id.is_set or
                                    self.mtu.is_set or
                                    self.parent_ifhandle.is_set or
                                    self.prefix_length.is_set or
                                    self.proxy_interface.is_set or
                                    self.querier_uptime.is_set or
                                    self.query_interval.is_set or
                                    self.query_maximum_response_time.is_set or
                                    self.query_timeout.is_set or
                                    self.robustness.is_set or
                                    self.router_uptime_in_seconds.is_set or
                                    self.state.is_set or
                                    self.subscriber_id.is_set or
                                    self.subscriber_mode.is_set or
                                    self.time_since_last_query_in_seconds.is_set or
                                    self.time_since_last_report_in_seconds.is_set or
                                    self.total_active_groups.is_set or
                                    self.vrf_id.is_set or
                                    self.vrf_state.is_set or
                                    (self.address is not None and self.address.has_data()) or
                                    (self.querier_address is not None and self.querier_address.has_data()) or
                                    (self.subscriber_address is not None and self.subscriber_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                    self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                    self.configurationvrf_error.yfilter != YFilter.not_set or
                                    self.configurationvrf_set.yfilter != YFilter.not_set or
                                    self.group_joins.yfilter != YFilter.not_set or
                                    self.group_leaves.yfilter != YFilter.not_set or
                                    self.host_version.yfilter != YFilter.not_set or
                                    self.igmp_version.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_configurationverify.yfilter != YFilter.not_set or
                                    self.is_identity_present.yfilter != YFilter.not_set or
                                    self.is_im_state_registered.yfilter != YFilter.not_set or
                                    self.is_interface_up.yfilter != YFilter.not_set or
                                    self.is_ip_enabled.yfilter != YFilter.not_set or
                                    self.is_las_registered.yfilter != YFilter.not_set or
                                    self.is_las_request.yfilter != YFilter.not_set or
                                    self.is_querier.yfilter != YFilter.not_set or
                                    self.is_router_enabled.yfilter != YFilter.not_set or
                                    self.is_subscriber.yfilter != YFilter.not_set or
                                    self.las_get_address_count.yfilter != YFilter.not_set or
                                    self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                    self.las_ll_registration_count.yfilter != YFilter.not_set or
                                    self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                    self.las_null_update_count.yfilter != YFilter.not_set or
                                    self.las_unregistration_count.yfilter != YFilter.not_set or
                                    self.las_update_count.yfilter != YFilter.not_set or
                                    self.last_member_query_interval.yfilter != YFilter.not_set or
                                    self.location.yfilter != YFilter.not_set or
                                    self.mte_tuple_count.yfilter != YFilter.not_set or
                                    self.mte_vrf_id.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.parent_ifhandle.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.proxy_interface.yfilter != YFilter.not_set or
                                    self.querier_uptime.yfilter != YFilter.not_set or
                                    self.query_interval.yfilter != YFilter.not_set or
                                    self.query_maximum_response_time.yfilter != YFilter.not_set or
                                    self.query_timeout.yfilter != YFilter.not_set or
                                    self.robustness.yfilter != YFilter.not_set or
                                    self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.subscriber_id.yfilter != YFilter.not_set or
                                    self.subscriber_mode.yfilter != YFilter.not_set or
                                    self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                    self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                    self.total_active_groups.yfilter != YFilter.not_set or
                                    self.vrf_id.yfilter != YFilter.not_set or
                                    self.vrf_state.yfilter != YFilter.not_set or
                                    (self.address is not None and self.address.has_operation()) or
                                    (self.querier_address is not None and self.querier_address.has_operation()) or
                                    (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "igmp-interface-entry" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                                if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                                if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                                if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                                if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_joins.get_name_leafdata())
                                if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_leaves.get_name_leafdata())
                                if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.host_version.get_name_leafdata())
                                if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_version.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                                if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                                if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                                if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                                if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                                if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                                if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_las_request.get_name_leafdata())
                                if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_querier.get_name_leafdata())
                                if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                                if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                                if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                                if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                                if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                                if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                                if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                                if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                                if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_update_count.get_name_leafdata())
                                if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                                if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.location.get_name_leafdata())
                                if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                                if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                                if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                                if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_interval.get_name_leafdata())
                                if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                                if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_timeout.get_name_leafdata())
                                if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.robustness.get_name_leafdata())
                                if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                                if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                                if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                                if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                                if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                                if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_id.get_name_leafdata())
                                if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "address"):
                                    if (self.address is None):
                                        self.address = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                    return self.address

                                if (child_yang_name == "querier-address"):
                                    if (self.querier_address is None):
                                        self.querier_address = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                        self.querier_address.parent = self
                                        self._children_name_map["querier_address"] = "querier-address"
                                    return self.querier_address

                                if (child_yang_name == "subscriber-address"):
                                    if (self.subscriber_address is None):
                                        self.subscriber_address = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                        self.subscriber_address.parent = self
                                        self._children_name_map["subscriber_address"] = "subscriber-address"
                                    return self.subscriber_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configuration-mcast-vrf-error"):
                                    self.configuration_mcast_vrf_error = value
                                    self.configuration_mcast_vrf_error.value_namespace = name_space
                                    self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "configuration-mcast-vrf-set"):
                                    self.configuration_mcast_vrf_set = value
                                    self.configuration_mcast_vrf_set.value_namespace = name_space
                                    self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "configurationvrf-error"):
                                    self.configurationvrf_error = value
                                    self.configurationvrf_error.value_namespace = name_space
                                    self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "configurationvrf-set"):
                                    self.configurationvrf_set = value
                                    self.configurationvrf_set.value_namespace = name_space
                                    self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-joins"):
                                    self.group_joins = value
                                    self.group_joins.value_namespace = name_space
                                    self.group_joins.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-leaves"):
                                    self.group_leaves = value
                                    self.group_leaves.value_namespace = name_space
                                    self.group_leaves.value_namespace_prefix = name_space_prefix
                                if(value_path == "host-version"):
                                    self.host_version = value
                                    self.host_version.value_namespace = name_space
                                    self.host_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-version"):
                                    self.igmp_version = value
                                    self.igmp_version.value_namespace = name_space
                                    self.igmp_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-configurationverify"):
                                    self.is_configurationverify = value
                                    self.is_configurationverify.value_namespace = name_space
                                    self.is_configurationverify.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-identity-present"):
                                    self.is_identity_present = value
                                    self.is_identity_present.value_namespace = name_space
                                    self.is_identity_present.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-im-state-registered"):
                                    self.is_im_state_registered = value
                                    self.is_im_state_registered.value_namespace = name_space
                                    self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-interface-up"):
                                    self.is_interface_up = value
                                    self.is_interface_up.value_namespace = name_space
                                    self.is_interface_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ip-enabled"):
                                    self.is_ip_enabled = value
                                    self.is_ip_enabled.value_namespace = name_space
                                    self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-las-registered"):
                                    self.is_las_registered = value
                                    self.is_las_registered.value_namespace = name_space
                                    self.is_las_registered.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-las-request"):
                                    self.is_las_request = value
                                    self.is_las_request.value_namespace = name_space
                                    self.is_las_request.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-querier"):
                                    self.is_querier = value
                                    self.is_querier.value_namespace = name_space
                                    self.is_querier.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-router-enabled"):
                                    self.is_router_enabled = value
                                    self.is_router_enabled.value_namespace = name_space
                                    self.is_router_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-subscriber"):
                                    self.is_subscriber = value
                                    self.is_subscriber.value_namespace = name_space
                                    self.is_subscriber.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-get-address-count"):
                                    self.las_get_address_count = value
                                    self.las_get_address_count.value_namespace = name_space
                                    self.las_get_address_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-add-update-count"):
                                    self.las_ll_add_update_count = value
                                    self.las_ll_add_update_count.value_namespace = name_space
                                    self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-registration-count"):
                                    self.las_ll_registration_count = value
                                    self.las_ll_registration_count.value_namespace = name_space
                                    self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-remove-update-count"):
                                    self.las_ll_remove_update_count = value
                                    self.las_ll_remove_update_count.value_namespace = name_space
                                    self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-null-update-count"):
                                    self.las_null_update_count = value
                                    self.las_null_update_count.value_namespace = name_space
                                    self.las_null_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-unregistration-count"):
                                    self.las_unregistration_count = value
                                    self.las_unregistration_count.value_namespace = name_space
                                    self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-update-count"):
                                    self.las_update_count = value
                                    self.las_update_count.value_namespace = name_space
                                    self.las_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-member-query-interval"):
                                    self.last_member_query_interval = value
                                    self.last_member_query_interval.value_namespace = name_space
                                    self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "location"):
                                    self.location = value
                                    self.location.value_namespace = name_space
                                    self.location.value_namespace_prefix = name_space_prefix
                                if(value_path == "mte-tuple-count"):
                                    self.mte_tuple_count = value
                                    self.mte_tuple_count.value_namespace = name_space
                                    self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "mte-vrf-id"):
                                    self.mte_vrf_id = value
                                    self.mte_vrf_id.value_namespace = name_space
                                    self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "parent-ifhandle"):
                                    self.parent_ifhandle = value
                                    self.parent_ifhandle.value_namespace = name_space
                                    self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "proxy-interface"):
                                    self.proxy_interface = value
                                    self.proxy_interface.value_namespace = name_space
                                    self.proxy_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "querier-uptime"):
                                    self.querier_uptime = value
                                    self.querier_uptime.value_namespace = name_space
                                    self.querier_uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-interval"):
                                    self.query_interval = value
                                    self.query_interval.value_namespace = name_space
                                    self.query_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-maximum-response-time"):
                                    self.query_maximum_response_time = value
                                    self.query_maximum_response_time.value_namespace = name_space
                                    self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-timeout"):
                                    self.query_timeout = value
                                    self.query_timeout.value_namespace = name_space
                                    self.query_timeout.value_namespace_prefix = name_space_prefix
                                if(value_path == "robustness"):
                                    self.robustness = value
                                    self.robustness.value_namespace = name_space
                                    self.robustness.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-uptime-in-seconds"):
                                    self.router_uptime_in_seconds = value
                                    self.router_uptime_in_seconds.value_namespace = name_space
                                    self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-id"):
                                    self.subscriber_id = value
                                    self.subscriber_id.value_namespace = name_space
                                    self.subscriber_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-mode"):
                                    self.subscriber_mode = value
                                    self.subscriber_mode.value_namespace = name_space
                                    self.subscriber_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-last-query-in-seconds"):
                                    self.time_since_last_query_in_seconds = value
                                    self.time_since_last_query_in_seconds.value_namespace = name_space
                                    self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-last-report-in-seconds"):
                                    self.time_since_last_report_in_seconds = value
                                    self.time_since_last_report_in_seconds.value_namespace = name_space
                                    self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "total-active-groups"):
                                    self.total_active_groups = value
                                    self.total_active_groups.value_namespace = name_space
                                    self.total_active_groups.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-id"):
                                    self.vrf_id = value
                                    self.vrf_id.value_namespace = name_space
                                    self.vrf_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-state"):
                                    self.vrf_state = value
                                    self.vrf_state.value_namespace = name_space
                                    self.vrf_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.join_group_count.is_set or
                                (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.join_group_count.yfilter != YFilter.not_set or
                                (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.join_group_count.is_set or self.join_group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_group_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "igmp-interface-entry"):
                                if (self.igmp_interface_entry is None):
                                    self.igmp_interface_entry = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                                    self.igmp_interface_entry.parent = self
                                    self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                                return self.igmp_interface_entry

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "igmp-interface-entry" or name == "interface-name" or name == "join-group-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-group-count"):
                                self.join_group_count = value
                                self.join_group_count.value_namespace = name_space
                                self.join_group_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ifrs_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ifrs_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ifrs-interface"):
                            for c in self.ifrs_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ifrs_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ifrs-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TrafficCounters(Entity):
                    """
                    IGMP Message Traffic Counters
                    
                    .. attribute:: auxillary_data_length_errors
                    
                    	AuxDataLen errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bad_scope_errors
                    
                    	BadScope errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_errors
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_errors
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: get_packet_failure
                    
                    	Packet get failed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_disabled_idb
                    
                    	Packet received on disabled idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_dvmrp
                    
                    	DVMRP packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_leaves
                    
                    	Leaves in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_martian_address
                    
                    	Packets received with Martian Address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_mtrace
                    
                    	Mtrace packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_assigned_vrf_id
                    
                    	Packets received with no assigned vrf id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb
                    
                    	Packets received without idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_platform_support_mtrace
                    
                    	mtrace packets without platform support
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_in_idb
                    
                    	Packets received on idb without VRF
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_mtrace
                    
                    	mtrace packets with no vrf associated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim
                    
                    	PIM packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_queries
                    
                    	Query packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_reports
                    
                    	Reports in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_address_errors
                    
                    	Invalid Source Address errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: miscellaneous_errors
                    
                    	Packets dropped for other reasons
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_dvmrp
                    
                    	DVMRP packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_leaves
                    
                    	Leaves out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_mtrace
                    
                    	Mtrace packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_no_parent_interface_handle
                    
                    	Failures setting 2nd ifhandle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_pim
                    
                    	PIM packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_queries
                    
                    	Query packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_reports
                    
                    	Reports out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_input_errors
                    
                    	Incoming Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_output_errors
                    
                    	Outgoing Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_in
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_out
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: receive_socket_errors
                    
                    	Socket errors on reception
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_errors
                    
                    	Socket errors on send
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"

                        self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                        self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                        self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_errors = YLeaf(YType.uint32, "format-errors")

                        self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                        self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                        self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                        self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                        self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                        self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                        self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                        self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                        self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                        self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                        self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                        self.input_pim = YLeaf(YType.uint32, "input-pim")

                        self.input_queries = YLeaf(YType.uint32, "input-queries")

                        self.input_reports = YLeaf(YType.uint32, "input-reports")

                        self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                        self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                        self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                        self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                        self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                        self.output_pim = YLeaf(YType.uint32, "output-pim")

                        self.output_queries = YLeaf(YType.uint32, "output-queries")

                        self.output_reports = YLeaf(YType.uint32, "output-reports")

                        self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                        self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                        self.packets_in = YLeaf(YType.uint32, "packets-in")

                        self.packets_out = YLeaf(YType.uint32, "packets-out")

                        self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                        self.socket_errors = YLeaf(YType.uint32, "socket-errors")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("auxillary_data_length_errors",
                                        "bad_scope_errors",
                                        "checksum_errors",
                                        "elapsed_time",
                                        "format_errors",
                                        "get_packet_failure",
                                        "input_disabled_idb",
                                        "input_dvmrp",
                                        "input_leaves",
                                        "input_martian_address",
                                        "input_mtrace",
                                        "input_no_assigned_vrf_id",
                                        "input_no_idb",
                                        "input_no_platform_support_mtrace",
                                        "input_no_vrf_in_idb",
                                        "input_no_vrf_mtrace",
                                        "input_pim",
                                        "input_queries",
                                        "input_reports",
                                        "invalid_source_address_errors",
                                        "miscellaneous_errors",
                                        "no_socket_connection",
                                        "output_dvmrp",
                                        "output_leaves",
                                        "output_mtrace",
                                        "output_no_parent_interface_handle",
                                        "output_pim",
                                        "output_queries",
                                        "output_reports",
                                        "packet_manager_input_errors",
                                        "packet_manager_output_errors",
                                        "packets_in",
                                        "packets_out",
                                        "receive_socket_errors",
                                        "socket_errors") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.auxillary_data_length_errors.is_set or
                            self.bad_scope_errors.is_set or
                            self.checksum_errors.is_set or
                            self.elapsed_time.is_set or
                            self.format_errors.is_set or
                            self.get_packet_failure.is_set or
                            self.input_disabled_idb.is_set or
                            self.input_dvmrp.is_set or
                            self.input_leaves.is_set or
                            self.input_martian_address.is_set or
                            self.input_mtrace.is_set or
                            self.input_no_assigned_vrf_id.is_set or
                            self.input_no_idb.is_set or
                            self.input_no_platform_support_mtrace.is_set or
                            self.input_no_vrf_in_idb.is_set or
                            self.input_no_vrf_mtrace.is_set or
                            self.input_pim.is_set or
                            self.input_queries.is_set or
                            self.input_reports.is_set or
                            self.invalid_source_address_errors.is_set or
                            self.miscellaneous_errors.is_set or
                            self.no_socket_connection.is_set or
                            self.output_dvmrp.is_set or
                            self.output_leaves.is_set or
                            self.output_mtrace.is_set or
                            self.output_no_parent_interface_handle.is_set or
                            self.output_pim.is_set or
                            self.output_queries.is_set or
                            self.output_reports.is_set or
                            self.packet_manager_input_errors.is_set or
                            self.packet_manager_output_errors.is_set or
                            self.packets_in.is_set or
                            self.packets_out.is_set or
                            self.receive_socket_errors.is_set or
                            self.socket_errors.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.auxillary_data_length_errors.yfilter != YFilter.not_set or
                            self.bad_scope_errors.yfilter != YFilter.not_set or
                            self.checksum_errors.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.format_errors.yfilter != YFilter.not_set or
                            self.get_packet_failure.yfilter != YFilter.not_set or
                            self.input_disabled_idb.yfilter != YFilter.not_set or
                            self.input_dvmrp.yfilter != YFilter.not_set or
                            self.input_leaves.yfilter != YFilter.not_set or
                            self.input_martian_address.yfilter != YFilter.not_set or
                            self.input_mtrace.yfilter != YFilter.not_set or
                            self.input_no_assigned_vrf_id.yfilter != YFilter.not_set or
                            self.input_no_idb.yfilter != YFilter.not_set or
                            self.input_no_platform_support_mtrace.yfilter != YFilter.not_set or
                            self.input_no_vrf_in_idb.yfilter != YFilter.not_set or
                            self.input_no_vrf_mtrace.yfilter != YFilter.not_set or
                            self.input_pim.yfilter != YFilter.not_set or
                            self.input_queries.yfilter != YFilter.not_set or
                            self.input_reports.yfilter != YFilter.not_set or
                            self.invalid_source_address_errors.yfilter != YFilter.not_set or
                            self.miscellaneous_errors.yfilter != YFilter.not_set or
                            self.no_socket_connection.yfilter != YFilter.not_set or
                            self.output_dvmrp.yfilter != YFilter.not_set or
                            self.output_leaves.yfilter != YFilter.not_set or
                            self.output_mtrace.yfilter != YFilter.not_set or
                            self.output_no_parent_interface_handle.yfilter != YFilter.not_set or
                            self.output_pim.yfilter != YFilter.not_set or
                            self.output_queries.yfilter != YFilter.not_set or
                            self.output_reports.yfilter != YFilter.not_set or
                            self.packet_manager_input_errors.yfilter != YFilter.not_set or
                            self.packet_manager_output_errors.yfilter != YFilter.not_set or
                            self.packets_in.yfilter != YFilter.not_set or
                            self.packets_out.yfilter != YFilter.not_set or
                            self.receive_socket_errors.yfilter != YFilter.not_set or
                            self.socket_errors.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "traffic-counters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.auxillary_data_length_errors.is_set or self.auxillary_data_length_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auxillary_data_length_errors.get_name_leafdata())
                        if (self.bad_scope_errors.is_set or self.bad_scope_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bad_scope_errors.get_name_leafdata())
                        if (self.checksum_errors.is_set or self.checksum_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checksum_errors.get_name_leafdata())
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.format_errors.is_set or self.format_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.format_errors.get_name_leafdata())
                        if (self.get_packet_failure.is_set or self.get_packet_failure.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.get_packet_failure.get_name_leafdata())
                        if (self.input_disabled_idb.is_set or self.input_disabled_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_disabled_idb.get_name_leafdata())
                        if (self.input_dvmrp.is_set or self.input_dvmrp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_dvmrp.get_name_leafdata())
                        if (self.input_leaves.is_set or self.input_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_leaves.get_name_leafdata())
                        if (self.input_martian_address.is_set or self.input_martian_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_martian_address.get_name_leafdata())
                        if (self.input_mtrace.is_set or self.input_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_mtrace.get_name_leafdata())
                        if (self.input_no_assigned_vrf_id.is_set or self.input_no_assigned_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_assigned_vrf_id.get_name_leafdata())
                        if (self.input_no_idb.is_set or self.input_no_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_idb.get_name_leafdata())
                        if (self.input_no_platform_support_mtrace.is_set or self.input_no_platform_support_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_platform_support_mtrace.get_name_leafdata())
                        if (self.input_no_vrf_in_idb.is_set or self.input_no_vrf_in_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_in_idb.get_name_leafdata())
                        if (self.input_no_vrf_mtrace.is_set or self.input_no_vrf_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_mtrace.get_name_leafdata())
                        if (self.input_pim.is_set or self.input_pim.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_pim.get_name_leafdata())
                        if (self.input_queries.is_set or self.input_queries.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_queries.get_name_leafdata())
                        if (self.input_reports.is_set or self.input_reports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_reports.get_name_leafdata())
                        if (self.invalid_source_address_errors.is_set or self.invalid_source_address_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_source_address_errors.get_name_leafdata())
                        if (self.miscellaneous_errors.is_set or self.miscellaneous_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.miscellaneous_errors.get_name_leafdata())
                        if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                        if (self.output_dvmrp.is_set or self.output_dvmrp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_dvmrp.get_name_leafdata())
                        if (self.output_leaves.is_set or self.output_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_leaves.get_name_leafdata())
                        if (self.output_mtrace.is_set or self.output_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_mtrace.get_name_leafdata())
                        if (self.output_no_parent_interface_handle.is_set or self.output_no_parent_interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_no_parent_interface_handle.get_name_leafdata())
                        if (self.output_pim.is_set or self.output_pim.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_pim.get_name_leafdata())
                        if (self.output_queries.is_set or self.output_queries.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_queries.get_name_leafdata())
                        if (self.output_reports.is_set or self.output_reports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_reports.get_name_leafdata())
                        if (self.packet_manager_input_errors.is_set or self.packet_manager_input_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_manager_input_errors.get_name_leafdata())
                        if (self.packet_manager_output_errors.is_set or self.packet_manager_output_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_manager_output_errors.get_name_leafdata())
                        if (self.packets_in.is_set or self.packets_in.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_in.get_name_leafdata())
                        if (self.packets_out.is_set or self.packets_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_out.get_name_leafdata())
                        if (self.receive_socket_errors.is_set or self.receive_socket_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.receive_socket_errors.get_name_leafdata())
                        if (self.socket_errors.is_set or self.socket_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.socket_errors.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auxillary-data-length-errors" or name == "bad-scope-errors" or name == "checksum-errors" or name == "elapsed-time" or name == "format-errors" or name == "get-packet-failure" or name == "input-disabled-idb" or name == "input-dvmrp" or name == "input-leaves" or name == "input-martian-address" or name == "input-mtrace" or name == "input-no-assigned-vrf-id" or name == "input-no-idb" or name == "input-no-platform-support-mtrace" or name == "input-no-vrf-in-idb" or name == "input-no-vrf-mtrace" or name == "input-pim" or name == "input-queries" or name == "input-reports" or name == "invalid-source-address-errors" or name == "miscellaneous-errors" or name == "no-socket-connection" or name == "output-dvmrp" or name == "output-leaves" or name == "output-mtrace" or name == "output-no-parent-interface-handle" or name == "output-pim" or name == "output-queries" or name == "output-reports" or name == "packet-manager-input-errors" or name == "packet-manager-output-errors" or name == "packets-in" or name == "packets-out" or name == "receive-socket-errors" or name == "socket-errors"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "auxillary-data-length-errors"):
                            self.auxillary_data_length_errors = value
                            self.auxillary_data_length_errors.value_namespace = name_space
                            self.auxillary_data_length_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "bad-scope-errors"):
                            self.bad_scope_errors = value
                            self.bad_scope_errors.value_namespace = name_space
                            self.bad_scope_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "checksum-errors"):
                            self.checksum_errors = value
                            self.checksum_errors.value_namespace = name_space
                            self.checksum_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "format-errors"):
                            self.format_errors = value
                            self.format_errors.value_namespace = name_space
                            self.format_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "get-packet-failure"):
                            self.get_packet_failure = value
                            self.get_packet_failure.value_namespace = name_space
                            self.get_packet_failure.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-disabled-idb"):
                            self.input_disabled_idb = value
                            self.input_disabled_idb.value_namespace = name_space
                            self.input_disabled_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-dvmrp"):
                            self.input_dvmrp = value
                            self.input_dvmrp.value_namespace = name_space
                            self.input_dvmrp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-leaves"):
                            self.input_leaves = value
                            self.input_leaves.value_namespace = name_space
                            self.input_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-martian-address"):
                            self.input_martian_address = value
                            self.input_martian_address.value_namespace = name_space
                            self.input_martian_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-mtrace"):
                            self.input_mtrace = value
                            self.input_mtrace.value_namespace = name_space
                            self.input_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-assigned-vrf-id"):
                            self.input_no_assigned_vrf_id = value
                            self.input_no_assigned_vrf_id.value_namespace = name_space
                            self.input_no_assigned_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-idb"):
                            self.input_no_idb = value
                            self.input_no_idb.value_namespace = name_space
                            self.input_no_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-platform-support-mtrace"):
                            self.input_no_platform_support_mtrace = value
                            self.input_no_platform_support_mtrace.value_namespace = name_space
                            self.input_no_platform_support_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-in-idb"):
                            self.input_no_vrf_in_idb = value
                            self.input_no_vrf_in_idb.value_namespace = name_space
                            self.input_no_vrf_in_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-mtrace"):
                            self.input_no_vrf_mtrace = value
                            self.input_no_vrf_mtrace.value_namespace = name_space
                            self.input_no_vrf_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-pim"):
                            self.input_pim = value
                            self.input_pim.value_namespace = name_space
                            self.input_pim.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-queries"):
                            self.input_queries = value
                            self.input_queries.value_namespace = name_space
                            self.input_queries.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-reports"):
                            self.input_reports = value
                            self.input_reports.value_namespace = name_space
                            self.input_reports.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-source-address-errors"):
                            self.invalid_source_address_errors = value
                            self.invalid_source_address_errors.value_namespace = name_space
                            self.invalid_source_address_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "miscellaneous-errors"):
                            self.miscellaneous_errors = value
                            self.miscellaneous_errors.value_namespace = name_space
                            self.miscellaneous_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-socket-connection"):
                            self.no_socket_connection = value
                            self.no_socket_connection.value_namespace = name_space
                            self.no_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-dvmrp"):
                            self.output_dvmrp = value
                            self.output_dvmrp.value_namespace = name_space
                            self.output_dvmrp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-leaves"):
                            self.output_leaves = value
                            self.output_leaves.value_namespace = name_space
                            self.output_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-mtrace"):
                            self.output_mtrace = value
                            self.output_mtrace.value_namespace = name_space
                            self.output_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-no-parent-interface-handle"):
                            self.output_no_parent_interface_handle = value
                            self.output_no_parent_interface_handle.value_namespace = name_space
                            self.output_no_parent_interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-pim"):
                            self.output_pim = value
                            self.output_pim.value_namespace = name_space
                            self.output_pim.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-queries"):
                            self.output_queries = value
                            self.output_queries.value_namespace = name_space
                            self.output_queries.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-reports"):
                            self.output_reports = value
                            self.output_reports.value_namespace = name_space
                            self.output_reports.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-manager-input-errors"):
                            self.packet_manager_input_errors = value
                            self.packet_manager_input_errors.value_namespace = name_space
                            self.packet_manager_input_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-manager-output-errors"):
                            self.packet_manager_output_errors = value
                            self.packet_manager_output_errors.value_namespace = name_space
                            self.packet_manager_output_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "packets-in"):
                            self.packets_in = value
                            self.packets_in.value_namespace = name_space
                            self.packets_in.value_namespace_prefix = name_space_prefix
                        if(value_path == "packets-out"):
                            self.packets_out = value
                            self.packets_out.value_namespace = name_space
                            self.packets_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "receive-socket-errors"):
                            self.receive_socket_errors = value
                            self.receive_socket_errors.value_namespace = name_space
                            self.receive_socket_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "socket-errors"):
                            self.socket_errors = value
                            self.socket_errors.value_namespace = name_space
                            self.socket_errors.value_namespace_prefix = name_space_prefix


                class Groups(Entity):
                    """
                    IGMP Group Database Table
                    
                    .. attribute:: group
                    
                    	IGMP Group Entry Information
                    	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Groups.Group>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.Groups, self).__init__()

                        self.yang_name = "groups"
                        self.yang_parent_name = "vrf"

                        self.group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.Groups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.Groups, self).__setattr__(name, value)


                    class Group(Entity):
                        """
                        IGMP Group Entry Information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.Groups.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "groups"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "group_address",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.Groups.Group, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.Groups.Group, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.group_address.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "group-address" or name == "interface-name" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group"):
                            for c in self.group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.Groups.Group()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupSummary(Entity):
                    """
                    IGMP Groups Summary
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groutes
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: sg_routes
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.GroupSummary, self).__init__()

                        self.yang_name = "group-summary"
                        self.yang_parent_name = "vrf"

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.groutes = YLeaf(YType.uint32, "groutes")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.sg_routes = YLeaf(YType.uint32, "sg-routes")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_count",
                                        "groutes",
                                        "is_low_memory",
                                        "sg_routes") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.GroupSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.GroupSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.group_count.is_set or
                            self.groutes.is_set or
                            self.is_low_memory.is_set or
                            self.sg_routes.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.groutes.yfilter != YFilter.not_set or
                            self.is_low_memory.yfilter != YFilter.not_set or
                            self.sg_routes.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.groutes.is_set or self.groutes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groutes.get_name_leafdata())
                        if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                        if (self.sg_routes.is_set or self.sg_routes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_routes.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-count" or name == "groutes" or name == "is-low-memory" or name == "sg-routes"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "groutes"):
                            self.groutes = value
                            self.groutes.value_namespace = name_space
                            self.groutes.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-low-memory"):
                            self.is_low_memory = value
                            self.is_low_memory.value_namespace = name_space
                            self.is_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-routes"):
                            self.sg_routes = value
                            self.sg_routes.value_namespace = name_space
                            self.sg_routes.value_namespace_prefix = name_space_prefix


                class IfrsInterfaceSummary(Entity):
                    """
                    IGMP IFRS Interface summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary, self).__init__()

                        self.yang_name = "ifrs-interface-summary"
                        self.yang_parent_name = "vrf"

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("configuration_count",
                                        "interface_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.configuration_count.is_set or
                            self.interface_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.configuration_count.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_count.get_name_leafdata())
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "configuration-count" or name == "interface-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "configuration-count"):
                            self.configuration_count = value
                            self.configuration_count.value_namespace = name_space
                            self.configuration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix


                class GlobalInterfaceTable(Entity):
                    """
                    IGMP Global Interface 
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable, self).__init__()

                        self.yang_name = "global-interface-table"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "global-interface-table"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "global-interface-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SsmMapDetails(Entity):
                    """
                    SSM Map Detail
                    
                    .. attribute:: ssm_map_detail
                    
                    	SSM Map Detail Table information
                    	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.SsmMapDetails, self).__init__()

                        self.yang_name = "ssm-map-details"
                        self.yang_parent_name = "vrf"

                        self.ssm_map_detail = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.SsmMapDetails, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.SsmMapDetails, self).__setattr__(name, value)


                    class SsmMapDetail(Entity):
                        """
                        SSM Map Detail Table information
                        
                        .. attribute:: elapsed_time
                        
                        	Elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: expiration_time
                        
                        	Expiration Time in Seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: map_info
                        
                        	Basic Map Info
                        	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo>`
                        
                        .. attribute:: query_interval
                        
                        	Query interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: response_pending
                        
                        	Response Pending
                        	**type**\:  bool
                        
                        .. attribute:: sources
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources>`
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__init__()

                            self.yang_name = "ssm-map-detail"
                            self.yang_parent_name = "ssm-map-details"

                            self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.query_interval = YLeaf(YType.uint32, "query-interval")

                            self.response_pending = YLeaf(YType.boolean, "response-pending")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.map_info = Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                            self.map_info.parent = self
                            self._children_name_map["map_info"] = "map-info"
                            self._children_yang_names.add("map-info")

                            self.sources = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("elapsed_time",
                                            "expiration_time",
                                            "group_address",
                                            "query_interval",
                                            "response_pending",
                                            "ssm_map_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)


                        class MapInfo(Entity):
                            """
                            Basic Map Info
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                            
                            .. attribute:: map_type
                            
                            	Map Type of group
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_counts
                            
                            	Count of Sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                                self.yang_name = "map-info"
                                self.yang_parent_name = "ssm-map-detail"

                                self.map_type = YLeaf(YType.uint32, "map-type")

                                self.source_counts = YLeaf(YType.uint32, "source-counts")

                                self.group_address_xr = Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("map_type",
                                                "source_counts") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "map-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.map_type.is_set or
                                    self.source_counts.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.map_type.yfilter != YFilter.not_set or
                                    self.source_counts.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "map-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.map_type.get_name_leafdata())
                                if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_counts.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "map-type" or name == "source-counts"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "map-type"):
                                    self.map_type = value
                                    self.map_type.value_namespace = name_space
                                    self.map_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-counts"):
                                    self.source_counts = value
                                    self.source_counts.value_namespace = name_space
                                    self.source_counts.value_namespace_prefix = name_space_prefix


                        class Sources(Entity):
                            """
                            List of sources
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                                self.yang_name = "sources"
                                self.yang_parent_name = "ssm-map-detail"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sources" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sources:
                                if (c.has_data()):
                                    return True
                            return (
                                self.elapsed_time.is_set or
                                self.expiration_time.is_set or
                                self.group_address.is_set or
                                self.query_interval.is_set or
                                self.response_pending.is_set or
                                self.ssm_map_type.is_set or
                                (self.map_info is not None and self.map_info.has_data()))

                        def has_operation(self):
                            for c in self.sources:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.elapsed_time.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.response_pending.yfilter != YFilter.not_set or
                                self.ssm_map_type.yfilter != YFilter.not_set or
                                (self.map_info is not None and self.map_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ssm-map-detail" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.response_pending.is_set or self.response_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.response_pending.get_name_leafdata())
                            if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "map-info"):
                                if (self.map_info is None):
                                    self.map_info = Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                                    self.map_info.parent = self
                                    self._children_name_map["map_info"] = "map-info"
                                return self.map_info

                            if (child_yang_name == "sources"):
                                for c in self.sources:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sources.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "map-info" or name == "sources" or name == "elapsed-time" or name == "expiration-time" or name == "group-address" or name == "query-interval" or name == "response-pending" or name == "ssm-map-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "elapsed-time"):
                                self.elapsed_time = value
                                self.elapsed_time.value_namespace = name_space
                                self.elapsed_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "response-pending"):
                                self.response_pending = value
                                self.response_pending.value_namespace = name_space
                                self.response_pending.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssm-map-type"):
                                self.ssm_map_type = value
                                self.ssm_map_type.value_namespace = name_space
                                self.ssm_map_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ssm_map_detail:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ssm_map_detail:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map-details" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ssm-map-detail"):
                            for c in self.ssm_map_detail:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ssm_map_detail.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ssm-map-detail"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceStateOffs(Entity):
                    """
                    IGMP Interface state off
                    
                    .. attribute:: interface_state_off
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs, self).__init__()

                        self.yang_name = "interface-state-offs"
                        self.yang_parent_name = "vrf"

                        self.interface_state_off = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs, self).__setattr__(name, value)


                    class InterfaceStateOff(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                            self.yang_name = "interface-state-off"
                            self.yang_parent_name = "interface-state-offs"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_state_off:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_state_off:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-offs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-state-off"):
                            for c in self.interface_state_off:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_state_off.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-state-off"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.vrf_name.is_set or
                        (self.detail_groups is not None and self.detail_groups.has_data()) or
                        (self.explicit_groups is not None and self.explicit_groups.has_data()) or
                        (self.global_interface_table is not None and self.global_interface_table.has_data()) or
                        (self.group_summary is not None and self.group_summary.has_data()) or
                        (self.groups is not None and self.groups.has_data()) or
                        (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_data()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                        (self.interface_state_offs is not None and self.interface_state_offs.has_data()) or
                        (self.interface_state_ons is not None and self.interface_state_ons.has_data()) or
                        (self.interface_table is not None and self.interface_table.has_data()) or
                        (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_data()) or
                        (self.non_active_groups is not None and self.non_active_groups.has_data()) or
                        (self.ranges is not None and self.ranges.has_data()) or
                        (self.ssm_map_details is not None and self.ssm_map_details.has_data()) or
                        (self.ssm_maps is not None and self.ssm_maps.has_data()) or
                        (self.summary is not None and self.summary.has_data()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vrf_name.yfilter != YFilter.not_set or
                        (self.detail_groups is not None and self.detail_groups.has_operation()) or
                        (self.explicit_groups is not None and self.explicit_groups.has_operation()) or
                        (self.global_interface_table is not None and self.global_interface_table.has_operation()) or
                        (self.group_summary is not None and self.group_summary.has_operation()) or
                        (self.groups is not None and self.groups.has_operation()) or
                        (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_operation()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                        (self.interface_state_offs is not None and self.interface_state_offs.has_operation()) or
                        (self.interface_state_ons is not None and self.interface_state_ons.has_operation()) or
                        (self.interface_table is not None and self.interface_table.has_operation()) or
                        (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_operation()) or
                        (self.non_active_groups is not None and self.non_active_groups.has_operation()) or
                        (self.ranges is not None and self.ranges.has_operation()) or
                        (self.ssm_map_details is not None and self.ssm_map_details.has_operation()) or
                        (self.ssm_maps is not None and self.ssm_maps.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/vrfs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "detail-groups"):
                        if (self.detail_groups is None):
                            self.detail_groups = Mld.Standby.Vrfs.Vrf.DetailGroups()
                            self.detail_groups.parent = self
                            self._children_name_map["detail_groups"] = "detail-groups"
                        return self.detail_groups

                    if (child_yang_name == "explicit-groups"):
                        if (self.explicit_groups is None):
                            self.explicit_groups = Mld.Standby.Vrfs.Vrf.ExplicitGroups()
                            self.explicit_groups.parent = self
                            self._children_name_map["explicit_groups"] = "explicit-groups"
                        return self.explicit_groups

                    if (child_yang_name == "global-interface-table"):
                        if (self.global_interface_table is None):
                            self.global_interface_table = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable()
                            self.global_interface_table.parent = self
                            self._children_name_map["global_interface_table"] = "global-interface-table"
                        return self.global_interface_table

                    if (child_yang_name == "group-summary"):
                        if (self.group_summary is None):
                            self.group_summary = Mld.Standby.Vrfs.Vrf.GroupSummary()
                            self.group_summary.parent = self
                            self._children_name_map["group_summary"] = "group-summary"
                        return self.group_summary

                    if (child_yang_name == "groups"):
                        if (self.groups is None):
                            self.groups = Mld.Standby.Vrfs.Vrf.Groups()
                            self.groups.parent = self
                            self._children_name_map["groups"] = "groups"
                        return self.groups

                    if (child_yang_name == "ifrs-interface-summary"):
                        if (self.ifrs_interface_summary is None):
                            self.ifrs_interface_summary = Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary()
                            self.ifrs_interface_summary.parent = self
                            self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                        return self.ifrs_interface_summary

                    if (child_yang_name == "ifrs-interfaces"):
                        if (self.ifrs_interfaces is None):
                            self.ifrs_interfaces = Mld.Standby.Vrfs.Vrf.IfrsInterfaces()
                            self.ifrs_interfaces.parent = self
                            self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                        return self.ifrs_interfaces

                    if (child_yang_name == "interface-state-offs"):
                        if (self.interface_state_offs is None):
                            self.interface_state_offs = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs()
                            self.interface_state_offs.parent = self
                            self._children_name_map["interface_state_offs"] = "interface-state-offs"
                        return self.interface_state_offs

                    if (child_yang_name == "interface-state-ons"):
                        if (self.interface_state_ons is None):
                            self.interface_state_ons = Mld.Standby.Vrfs.Vrf.InterfaceStateOns()
                            self.interface_state_ons.parent = self
                            self._children_name_map["interface_state_ons"] = "interface-state-ons"
                        return self.interface_state_ons

                    if (child_yang_name == "interface-table"):
                        if (self.interface_table is None):
                            self.interface_table = Mld.Standby.Vrfs.Vrf.InterfaceTable()
                            self.interface_table.parent = self
                            self._children_name_map["interface_table"] = "interface-table"
                        return self.interface_table

                    if (child_yang_name == "interface-unicast-qos-adjusts"):
                        if (self.interface_unicast_qos_adjusts is None):
                            self.interface_unicast_qos_adjusts = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                            self.interface_unicast_qos_adjusts.parent = self
                            self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                        return self.interface_unicast_qos_adjusts

                    if (child_yang_name == "non-active-groups"):
                        if (self.non_active_groups is None):
                            self.non_active_groups = Mld.Standby.Vrfs.Vrf.NonActiveGroups()
                            self.non_active_groups.parent = self
                            self._children_name_map["non_active_groups"] = "non-active-groups"
                        return self.non_active_groups

                    if (child_yang_name == "ranges"):
                        if (self.ranges is None):
                            self.ranges = Mld.Standby.Vrfs.Vrf.Ranges()
                            self.ranges.parent = self
                            self._children_name_map["ranges"] = "ranges"
                        return self.ranges

                    if (child_yang_name == "ssm-map-details"):
                        if (self.ssm_map_details is None):
                            self.ssm_map_details = Mld.Standby.Vrfs.Vrf.SsmMapDetails()
                            self.ssm_map_details.parent = self
                            self._children_name_map["ssm_map_details"] = "ssm-map-details"
                        return self.ssm_map_details

                    if (child_yang_name == "ssm-maps"):
                        if (self.ssm_maps is None):
                            self.ssm_maps = Mld.Standby.Vrfs.Vrf.SsmMaps()
                            self.ssm_maps.parent = self
                            self._children_name_map["ssm_maps"] = "ssm-maps"
                        return self.ssm_maps

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = Mld.Standby.Vrfs.Vrf.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    if (child_yang_name == "traffic-counters"):
                        if (self.traffic_counters is None):
                            self.traffic_counters = Mld.Standby.Vrfs.Vrf.TrafficCounters()
                            self.traffic_counters.parent = self
                            self._children_name_map["traffic_counters"] = "traffic-counters"
                        return self.traffic_counters

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "detail-groups" or name == "explicit-groups" or name == "global-interface-table" or name == "group-summary" or name == "groups" or name == "ifrs-interface-summary" or name == "ifrs-interfaces" or name == "interface-state-offs" or name == "interface-state-ons" or name == "interface-table" or name == "interface-unicast-qos-adjusts" or name == "non-active-groups" or name == "ranges" or name == "ssm-map-details" or name == "ssm-maps" or name == "summary" or name == "traffic-counters" or name == "vrf-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vrf-name"):
                        self.vrf_name = value
                        self.vrf_name.value_namespace = name_space
                        self.vrf_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.vrf:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.vrf:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrfs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "vrf"):
                    for c in self.vrf:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Mld.Standby.Vrfs.Vrf()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.vrf.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "vrf"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Process(Entity):
            """
            Process
            
            .. attribute:: amt_gatewaies
            
            	Table containing AMT Gateway DataBase information
            	**type**\:   :py:class:`AmtGatewaies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.AmtGatewaies>`
            
            .. attribute:: amt_summary
            
            	MRIB RouteDB Expiry Information
            	**type**\:   :py:class:`AmtSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.AmtSummary>`
            
            .. attribute:: bvi_statistics
            
            	IGMP BVI Stats
            	**type**\:   :py:class:`BviStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.BviStatistics>`
            
            .. attribute:: nsf
            
            	NSF Information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.Nsr>`
            
            .. attribute:: unicast_qos_adjust_stats
            
            	IGMP Unicast\-Qos\-Adjust Statistics
            	**type**\:   :py:class:`UnicastQosAdjustStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.UnicastQosAdjustStats>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Standby.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "standby"

                self.amt_gatewaies = Mld.Standby.Process.AmtGatewaies()
                self.amt_gatewaies.parent = self
                self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                self._children_yang_names.add("amt-gatewaies")

                self.amt_summary = Mld.Standby.Process.AmtSummary()
                self.amt_summary.parent = self
                self._children_name_map["amt_summary"] = "amt-summary"
                self._children_yang_names.add("amt-summary")

                self.bvi_statistics = Mld.Standby.Process.BviStatistics()
                self.bvi_statistics.parent = self
                self._children_name_map["bvi_statistics"] = "bvi-statistics"
                self._children_yang_names.add("bvi-statistics")

                self.nsf = Mld.Standby.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Mld.Standby.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.unicast_qos_adjust_stats = Mld.Standby.Process.UnicastQosAdjustStats()
                self.unicast_qos_adjust_stats.parent = self
                self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                self._children_yang_names.add("unicast-qos-adjust-stats")


            class AmtSummary(Entity):
                """
                MRIB RouteDB Expiry Information
                
                .. attribute:: anycast_prefix
                
                	Robustness variable
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: gateway_count
                
                	Number of AMT Gateway
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_acl_configured
                
                	ACL configured under AMT
                	**type**\:  bool
                
                .. attribute:: is_gateway_simulation
                
                	AMT Gateway Simulation
                	**type**\:  bool
                
                .. attribute:: is_ou_of_resource
                
                	AMT Out Of Resource
                	**type**\:  bool
                
                .. attribute:: max_gateway
                
                	Maximum Gateway allowed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mtu
                
                	AMT Tunnel MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: prefix_length
                
                	Advertize AMT prefix length
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: query_interval
                
                	AMT Query interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: relay_address
                
                	Advertaisment for AMT Relay address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: tos
                
                	Type Of Service value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ttl
                
                	Time To Live value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_configured_maximum
                
                	AMT Tunnel configured Maximum
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_count
                
                	AMT Tunnel Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.AmtSummary, self).__init__()

                    self.yang_name = "amt-summary"
                    self.yang_parent_name = "process"

                    self.anycast_prefix = YLeaf(YType.str, "anycast-prefix")

                    self.gateway_count = YLeaf(YType.uint32, "gateway-count")

                    self.is_acl_configured = YLeaf(YType.boolean, "is-acl-configured")

                    self.is_gateway_simulation = YLeaf(YType.boolean, "is-gateway-simulation")

                    self.is_ou_of_resource = YLeaf(YType.boolean, "is-ou-of-resource")

                    self.max_gateway = YLeaf(YType.uint32, "max-gateway")

                    self.mtu = YLeaf(YType.uint32, "mtu")

                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                    self.query_interval = YLeaf(YType.uint32, "query-interval")

                    self.relay_address = YLeaf(YType.str, "relay-address")

                    self.tos = YLeaf(YType.uint32, "tos")

                    self.ttl = YLeaf(YType.uint32, "ttl")

                    self.tunnel_configured_maximum = YLeaf(YType.uint32, "tunnel-configured-maximum")

                    self.tunnel_count = YLeaf(YType.uint32, "tunnel-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("anycast_prefix",
                                    "gateway_count",
                                    "is_acl_configured",
                                    "is_gateway_simulation",
                                    "is_ou_of_resource",
                                    "max_gateway",
                                    "mtu",
                                    "prefix_length",
                                    "query_interval",
                                    "relay_address",
                                    "tos",
                                    "ttl",
                                    "tunnel_configured_maximum",
                                    "tunnel_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.Process.AmtSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.Process.AmtSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.anycast_prefix.is_set or
                        self.gateway_count.is_set or
                        self.is_acl_configured.is_set or
                        self.is_gateway_simulation.is_set or
                        self.is_ou_of_resource.is_set or
                        self.max_gateway.is_set or
                        self.mtu.is_set or
                        self.prefix_length.is_set or
                        self.query_interval.is_set or
                        self.relay_address.is_set or
                        self.tos.is_set or
                        self.ttl.is_set or
                        self.tunnel_configured_maximum.is_set or
                        self.tunnel_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.anycast_prefix.yfilter != YFilter.not_set or
                        self.gateway_count.yfilter != YFilter.not_set or
                        self.is_acl_configured.yfilter != YFilter.not_set or
                        self.is_gateway_simulation.yfilter != YFilter.not_set or
                        self.is_ou_of_resource.yfilter != YFilter.not_set or
                        self.max_gateway.yfilter != YFilter.not_set or
                        self.mtu.yfilter != YFilter.not_set or
                        self.prefix_length.yfilter != YFilter.not_set or
                        self.query_interval.yfilter != YFilter.not_set or
                        self.relay_address.yfilter != YFilter.not_set or
                        self.tos.yfilter != YFilter.not_set or
                        self.ttl.yfilter != YFilter.not_set or
                        self.tunnel_configured_maximum.yfilter != YFilter.not_set or
                        self.tunnel_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "amt-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.anycast_prefix.is_set or self.anycast_prefix.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_prefix.get_name_leafdata())
                    if (self.gateway_count.is_set or self.gateway_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gateway_count.get_name_leafdata())
                    if (self.is_acl_configured.is_set or self.is_acl_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_acl_configured.get_name_leafdata())
                    if (self.is_gateway_simulation.is_set or self.is_gateway_simulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_gateway_simulation.get_name_leafdata())
                    if (self.is_ou_of_resource.is_set or self.is_ou_of_resource.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ou_of_resource.get_name_leafdata())
                    if (self.max_gateway.is_set or self.max_gateway.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.max_gateway.get_name_leafdata())
                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mtu.get_name_leafdata())
                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                    if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.query_interval.get_name_leafdata())
                    if (self.relay_address.is_set or self.relay_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.relay_address.get_name_leafdata())
                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tos.get_name_leafdata())
                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ttl.get_name_leafdata())
                    if (self.tunnel_configured_maximum.is_set or self.tunnel_configured_maximum.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_configured_maximum.get_name_leafdata())
                    if (self.tunnel_count.is_set or self.tunnel_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "anycast-prefix" or name == "gateway-count" or name == "is-acl-configured" or name == "is-gateway-simulation" or name == "is-ou-of-resource" or name == "max-gateway" or name == "mtu" or name == "prefix-length" or name == "query-interval" or name == "relay-address" or name == "tos" or name == "ttl" or name == "tunnel-configured-maximum" or name == "tunnel-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "anycast-prefix"):
                        self.anycast_prefix = value
                        self.anycast_prefix.value_namespace = name_space
                        self.anycast_prefix.value_namespace_prefix = name_space_prefix
                    if(value_path == "gateway-count"):
                        self.gateway_count = value
                        self.gateway_count.value_namespace = name_space
                        self.gateway_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-acl-configured"):
                        self.is_acl_configured = value
                        self.is_acl_configured.value_namespace = name_space
                        self.is_acl_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-gateway-simulation"):
                        self.is_gateway_simulation = value
                        self.is_gateway_simulation.value_namespace = name_space
                        self.is_gateway_simulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ou-of-resource"):
                        self.is_ou_of_resource = value
                        self.is_ou_of_resource.value_namespace = name_space
                        self.is_ou_of_resource.value_namespace_prefix = name_space_prefix
                    if(value_path == "max-gateway"):
                        self.max_gateway = value
                        self.max_gateway.value_namespace = name_space
                        self.max_gateway.value_namespace_prefix = name_space_prefix
                    if(value_path == "mtu"):
                        self.mtu = value
                        self.mtu.value_namespace = name_space
                        self.mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "prefix-length"):
                        self.prefix_length = value
                        self.prefix_length.value_namespace = name_space
                        self.prefix_length.value_namespace_prefix = name_space_prefix
                    if(value_path == "query-interval"):
                        self.query_interval = value
                        self.query_interval.value_namespace = name_space
                        self.query_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "relay-address"):
                        self.relay_address = value
                        self.relay_address.value_namespace = name_space
                        self.relay_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "tos"):
                        self.tos = value
                        self.tos.value_namespace = name_space
                        self.tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ttl"):
                        self.ttl = value
                        self.ttl.value_namespace = name_space
                        self.ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-configured-maximum"):
                        self.tunnel_configured_maximum = value
                        self.tunnel_configured_maximum.value_namespace = name_space
                        self.tunnel_configured_maximum.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-count"):
                        self.tunnel_count = value
                        self.tunnel_count.value_namespace = name_space
                        self.tunnel_count.value_namespace_prefix = name_space_prefix


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: collab_conv_done
                
                	Collaborators convergence done
                	**type**\:  bool
                
                .. attribute:: count_proc_connection_dn
                
                	No. of times process connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_proc_connection_up
                
                	No. of times process connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_proc
                
                	Time when process came up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_dn
                
                	Time when process connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_up
                
                	Time when process connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_proc_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"

                    self.collab_conv_done = YLeaf(YType.boolean, "collab-conv-done")

                    self.count_proc_connection_dn = YLeaf(YType.uint32, "count-proc-connection-dn")

                    self.count_proc_connection_up = YLeaf(YType.uint32, "count-proc-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_proc = YLeaf(YType.uint64, "last-proc")

                    self.last_proc_connection_dn = YLeaf(YType.uint64, "last-proc-connection-dn")

                    self.last_proc_connection_up = YLeaf(YType.uint64, "last-proc-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_proc_connected = YLeaf(YType.boolean, "partner-proc-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.state = YLeaf(YType.uint8, "state")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("collab_conv_done",
                                    "count_proc_connection_dn",
                                    "count_proc_connection_up",
                                    "count_rmf_not_ready",
                                    "count_rmf_ready",
                                    "last_proc",
                                    "last_proc_connection_dn",
                                    "last_proc_connection_up",
                                    "last_rmf_not_ready",
                                    "last_rmf_ready",
                                    "partner_proc_connected",
                                    "rmf_notification_done",
                                    "state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.Process.Nsr, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.Process.Nsr, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.collab_conv_done.is_set or
                        self.count_proc_connection_dn.is_set or
                        self.count_proc_connection_up.is_set or
                        self.count_rmf_not_ready.is_set or
                        self.count_rmf_ready.is_set or
                        self.last_proc.is_set or
                        self.last_proc_connection_dn.is_set or
                        self.last_proc_connection_up.is_set or
                        self.last_rmf_not_ready.is_set or
                        self.last_rmf_ready.is_set or
                        self.partner_proc_connected.is_set or
                        self.rmf_notification_done.is_set or
                        self.state.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.collab_conv_done.yfilter != YFilter.not_set or
                        self.count_proc_connection_dn.yfilter != YFilter.not_set or
                        self.count_proc_connection_up.yfilter != YFilter.not_set or
                        self.count_rmf_not_ready.yfilter != YFilter.not_set or
                        self.count_rmf_ready.yfilter != YFilter.not_set or
                        self.last_proc.yfilter != YFilter.not_set or
                        self.last_proc_connection_dn.yfilter != YFilter.not_set or
                        self.last_proc_connection_up.yfilter != YFilter.not_set or
                        self.last_rmf_not_ready.yfilter != YFilter.not_set or
                        self.last_rmf_ready.yfilter != YFilter.not_set or
                        self.partner_proc_connected.yfilter != YFilter.not_set or
                        self.rmf_notification_done.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.collab_conv_done.is_set or self.collab_conv_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collab_conv_done.get_name_leafdata())
                    if (self.count_proc_connection_dn.is_set or self.count_proc_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_proc_connection_dn.get_name_leafdata())
                    if (self.count_proc_connection_up.is_set or self.count_proc_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_proc_connection_up.get_name_leafdata())
                    if (self.count_rmf_not_ready.is_set or self.count_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_not_ready.get_name_leafdata())
                    if (self.count_rmf_ready.is_set or self.count_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_ready.get_name_leafdata())
                    if (self.last_proc.is_set or self.last_proc.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc.get_name_leafdata())
                    if (self.last_proc_connection_dn.is_set or self.last_proc_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc_connection_dn.get_name_leafdata())
                    if (self.last_proc_connection_up.is_set or self.last_proc_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc_connection_up.get_name_leafdata())
                    if (self.last_rmf_not_ready.is_set or self.last_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_not_ready.get_name_leafdata())
                    if (self.last_rmf_ready.is_set or self.last_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_ready.get_name_leafdata())
                    if (self.partner_proc_connected.is_set or self.partner_proc_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_proc_connected.get_name_leafdata())
                    if (self.rmf_notification_done.is_set or self.rmf_notification_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_notification_done.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "collab-conv-done" or name == "count-proc-connection-dn" or name == "count-proc-connection-up" or name == "count-rmf-not-ready" or name == "count-rmf-ready" or name == "last-proc" or name == "last-proc-connection-dn" or name == "last-proc-connection-up" or name == "last-rmf-not-ready" or name == "last-rmf-ready" or name == "partner-proc-connected" or name == "rmf-notification-done" or name == "state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "collab-conv-done"):
                        self.collab_conv_done = value
                        self.collab_conv_done.value_namespace = name_space
                        self.collab_conv_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-proc-connection-dn"):
                        self.count_proc_connection_dn = value
                        self.count_proc_connection_dn.value_namespace = name_space
                        self.count_proc_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-proc-connection-up"):
                        self.count_proc_connection_up = value
                        self.count_proc_connection_up.value_namespace = name_space
                        self.count_proc_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-not-ready"):
                        self.count_rmf_not_ready = value
                        self.count_rmf_not_ready.value_namespace = name_space
                        self.count_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-ready"):
                        self.count_rmf_ready = value
                        self.count_rmf_ready.value_namespace = name_space
                        self.count_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc"):
                        self.last_proc = value
                        self.last_proc.value_namespace = name_space
                        self.last_proc.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc-connection-dn"):
                        self.last_proc_connection_dn = value
                        self.last_proc_connection_dn.value_namespace = name_space
                        self.last_proc_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc-connection-up"):
                        self.last_proc_connection_up = value
                        self.last_proc_connection_up.value_namespace = name_space
                        self.last_proc_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-not-ready"):
                        self.last_rmf_not_ready = value
                        self.last_rmf_not_ready.value_namespace = name_space
                        self.last_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-ready"):
                        self.last_rmf_ready = value
                        self.last_rmf_ready.value_namespace = name_space
                        self.last_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-proc-connected"):
                        self.partner_proc_connected = value
                        self.partner_proc_connected.value_namespace = name_space
                        self.partner_proc_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-notification-done"):
                        self.rmf_notification_done = value
                        self.rmf_notification_done.value_namespace = name_space
                        self.rmf_notification_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix


            class AmtGatewaies(Entity):
                """
                Table containing AMT Gateway DataBase
                information
                
                .. attribute:: amt_gateway
                
                	AMT Gateway DataBase information
                	**type**\: list of    :py:class:`AmtGateway <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.AmtGatewaies.AmtGateway>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.AmtGatewaies, self).__init__()

                    self.yang_name = "amt-gatewaies"
                    self.yang_parent_name = "process"

                    self.amt_gateway = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.Process.AmtGatewaies, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.Process.AmtGatewaies, self).__setattr__(name, value)


                class AmtGateway(Entity):
                    """
                    AMT Gateway DataBase information
                    
                    .. attribute:: amt_nonce
                    
                    	Nonce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amt_port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amtgw
                    
                    	GW
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: amtnh
                    
                    	AMT NH
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gateway_address
                    
                    	Gateway Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: idb
                    
                    	IDB
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: key_len
                    
                    	Len
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_in
                    
                    	UpdIn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_out
                    
                    	UpdOut
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Process.AmtGatewaies.AmtGateway, self).__init__()

                        self.yang_name = "amt-gateway"
                        self.yang_parent_name = "amt-gatewaies"

                        self.amt_nonce = YLeaf(YType.uint32, "amt-nonce")

                        self.amt_port = YLeaf(YType.uint32, "amt-port")

                        self.amtgw = YLeaf(YType.str, "amtgw")

                        self.amtnh = YLeaf(YType.uint32, "amtnh")

                        self.gateway_address = YLeaf(YType.str, "gateway-address")

                        self.idb = YLeaf(YType.uint64, "idb")

                        self.key_len = YLeaf(YType.uint32, "key-len")

                        self.mem_upd_in = YLeaf(YType.uint32, "mem-upd-in")

                        self.mem_upd_out = YLeaf(YType.uint32, "mem-upd-out")

                        self.port = YLeaf(YType.int32, "port")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("amt_nonce",
                                        "amt_port",
                                        "amtgw",
                                        "amtnh",
                                        "gateway_address",
                                        "idb",
                                        "key_len",
                                        "mem_upd_in",
                                        "mem_upd_out",
                                        "port") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.Process.AmtGatewaies.AmtGateway, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.Process.AmtGatewaies.AmtGateway, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.amt_nonce.is_set or
                            self.amt_port.is_set or
                            self.amtgw.is_set or
                            self.amtnh.is_set or
                            self.gateway_address.is_set or
                            self.idb.is_set or
                            self.key_len.is_set or
                            self.mem_upd_in.is_set or
                            self.mem_upd_out.is_set or
                            self.port.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.amt_nonce.yfilter != YFilter.not_set or
                            self.amt_port.yfilter != YFilter.not_set or
                            self.amtgw.yfilter != YFilter.not_set or
                            self.amtnh.yfilter != YFilter.not_set or
                            self.gateway_address.yfilter != YFilter.not_set or
                            self.idb.yfilter != YFilter.not_set or
                            self.key_len.yfilter != YFilter.not_set or
                            self.mem_upd_in.yfilter != YFilter.not_set or
                            self.mem_upd_out.yfilter != YFilter.not_set or
                            self.port.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "amt-gateway" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/amt-gatewaies/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.amt_nonce.is_set or self.amt_nonce.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amt_nonce.get_name_leafdata())
                        if (self.amt_port.is_set or self.amt_port.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amt_port.get_name_leafdata())
                        if (self.amtgw.is_set or self.amtgw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amtgw.get_name_leafdata())
                        if (self.amtnh.is_set or self.amtnh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amtnh.get_name_leafdata())
                        if (self.gateway_address.is_set or self.gateway_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gateway_address.get_name_leafdata())
                        if (self.idb.is_set or self.idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb.get_name_leafdata())
                        if (self.key_len.is_set or self.key_len.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.key_len.get_name_leafdata())
                        if (self.mem_upd_in.is_set or self.mem_upd_in.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mem_upd_in.get_name_leafdata())
                        if (self.mem_upd_out.is_set or self.mem_upd_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mem_upd_out.get_name_leafdata())
                        if (self.port.is_set or self.port.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "amt-nonce" or name == "amt-port" or name == "amtgw" or name == "amtnh" or name == "gateway-address" or name == "idb" or name == "key-len" or name == "mem-upd-in" or name == "mem-upd-out" or name == "port"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "amt-nonce"):
                            self.amt_nonce = value
                            self.amt_nonce.value_namespace = name_space
                            self.amt_nonce.value_namespace_prefix = name_space_prefix
                        if(value_path == "amt-port"):
                            self.amt_port = value
                            self.amt_port.value_namespace = name_space
                            self.amt_port.value_namespace_prefix = name_space_prefix
                        if(value_path == "amtgw"):
                            self.amtgw = value
                            self.amtgw.value_namespace = name_space
                            self.amtgw.value_namespace_prefix = name_space_prefix
                        if(value_path == "amtnh"):
                            self.amtnh = value
                            self.amtnh.value_namespace = name_space
                            self.amtnh.value_namespace_prefix = name_space_prefix
                        if(value_path == "gateway-address"):
                            self.gateway_address = value
                            self.gateway_address.value_namespace = name_space
                            self.gateway_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb"):
                            self.idb = value
                            self.idb.value_namespace = name_space
                            self.idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "key-len"):
                            self.key_len = value
                            self.key_len.value_namespace = name_space
                            self.key_len.value_namespace_prefix = name_space_prefix
                        if(value_path == "mem-upd-in"):
                            self.mem_upd_in = value
                            self.mem_upd_in.value_namespace = name_space
                            self.mem_upd_in.value_namespace_prefix = name_space_prefix
                        if(value_path == "mem-upd-out"):
                            self.mem_upd_out = value
                            self.mem_upd_out.value_namespace = name_space
                            self.mem_upd_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "port"):
                            self.port = value
                            self.port.value_namespace = name_space
                            self.port.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.amt_gateway:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.amt_gateway:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "amt-gatewaies" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "amt-gateway"):
                        for c in self.amt_gateway:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.Process.AmtGatewaies.AmtGateway()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.amt_gateway.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "amt-gateway"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class UnicastQosAdjustStats(Entity):
                """
                IGMP Unicast\-Qos\-Adjust Statistics
                
                .. attribute:: add_to_batches
                
                	Add to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: batches
                
                	I2Q Rate Batch count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: delete_to_batches
                
                	Delete to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_qos_s_sweeped
                
                	Is QOS Sweeped once 
                	**type**\:  bool
                
                .. attribute:: is_resync_received
                
                	Is Resync request received
                	**type**\:  bool
                
                .. attribute:: is_resync_required
                
                	Is Resync required
                	**type**\:  bool
                
                .. attribute:: is_resync_start_sent
                
                	Is Resync Start message sent
                	**type**\:  bool
                
                .. attribute:: last_download_time
                
                	Time elapsed since Last download to QOS in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: last_sweep_time
                
                	Time elapsed since Last mark and sweep in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: queues
                
                	I2Q Queue count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: received_resync_requests
                
                	Number of Resync request received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_comm_errors
                
                	Send Error due to comms count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_errors
                
                	Number of Send errors in batch
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_partial_errors
                
                	Send Error due to partial issue count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_success
                
                	Send Success count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sent_resync_bulks
                
                	Number of bulks sent for last resync received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.UnicastQosAdjustStats, self).__init__()

                    self.yang_name = "unicast-qos-adjust-stats"
                    self.yang_parent_name = "process"

                    self.add_to_batches = YLeaf(YType.uint32, "add-to-batches")

                    self.batches = YLeaf(YType.uint16, "batches")

                    self.delete_to_batches = YLeaf(YType.uint32, "delete-to-batches")

                    self.is_qos_s_sweeped = YLeaf(YType.boolean, "is-qos-s-sweeped")

                    self.is_resync_received = YLeaf(YType.boolean, "is-resync-received")

                    self.is_resync_required = YLeaf(YType.boolean, "is-resync-required")

                    self.is_resync_start_sent = YLeaf(YType.boolean, "is-resync-start-sent")

                    self.last_download_time = YLeaf(YType.uint64, "last-download-time")

                    self.last_sweep_time = YLeaf(YType.uint64, "last-sweep-time")

                    self.queues = YLeaf(YType.uint16, "queues")

                    self.received_resync_requests = YLeaf(YType.uint32, "received-resync-requests")

                    self.send_comm_errors = YLeaf(YType.uint32, "send-comm-errors")

                    self.send_errors = YLeaf(YType.uint32, "send-errors")

                    self.send_partial_errors = YLeaf(YType.uint32, "send-partial-errors")

                    self.send_success = YLeaf(YType.uint32, "send-success")

                    self.sent_resync_bulks = YLeaf(YType.uint32, "sent-resync-bulks")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("add_to_batches",
                                    "batches",
                                    "delete_to_batches",
                                    "is_qos_s_sweeped",
                                    "is_resync_received",
                                    "is_resync_required",
                                    "is_resync_start_sent",
                                    "last_download_time",
                                    "last_sweep_time",
                                    "queues",
                                    "received_resync_requests",
                                    "send_comm_errors",
                                    "send_errors",
                                    "send_partial_errors",
                                    "send_success",
                                    "sent_resync_bulks") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.Process.UnicastQosAdjustStats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.Process.UnicastQosAdjustStats, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.add_to_batches.is_set or
                        self.batches.is_set or
                        self.delete_to_batches.is_set or
                        self.is_qos_s_sweeped.is_set or
                        self.is_resync_received.is_set or
                        self.is_resync_required.is_set or
                        self.is_resync_start_sent.is_set or
                        self.last_download_time.is_set or
                        self.last_sweep_time.is_set or
                        self.queues.is_set or
                        self.received_resync_requests.is_set or
                        self.send_comm_errors.is_set or
                        self.send_errors.is_set or
                        self.send_partial_errors.is_set or
                        self.send_success.is_set or
                        self.sent_resync_bulks.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.add_to_batches.yfilter != YFilter.not_set or
                        self.batches.yfilter != YFilter.not_set or
                        self.delete_to_batches.yfilter != YFilter.not_set or
                        self.is_qos_s_sweeped.yfilter != YFilter.not_set or
                        self.is_resync_received.yfilter != YFilter.not_set or
                        self.is_resync_required.yfilter != YFilter.not_set or
                        self.is_resync_start_sent.yfilter != YFilter.not_set or
                        self.last_download_time.yfilter != YFilter.not_set or
                        self.last_sweep_time.yfilter != YFilter.not_set or
                        self.queues.yfilter != YFilter.not_set or
                        self.received_resync_requests.yfilter != YFilter.not_set or
                        self.send_comm_errors.yfilter != YFilter.not_set or
                        self.send_errors.yfilter != YFilter.not_set or
                        self.send_partial_errors.yfilter != YFilter.not_set or
                        self.send_success.yfilter != YFilter.not_set or
                        self.sent_resync_bulks.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "unicast-qos-adjust-stats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.add_to_batches.is_set or self.add_to_batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.add_to_batches.get_name_leafdata())
                    if (self.batches.is_set or self.batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.batches.get_name_leafdata())
                    if (self.delete_to_batches.is_set or self.delete_to_batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.delete_to_batches.get_name_leafdata())
                    if (self.is_qos_s_sweeped.is_set or self.is_qos_s_sweeped.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_qos_s_sweeped.get_name_leafdata())
                    if (self.is_resync_received.is_set or self.is_resync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_received.get_name_leafdata())
                    if (self.is_resync_required.is_set or self.is_resync_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_required.get_name_leafdata())
                    if (self.is_resync_start_sent.is_set or self.is_resync_start_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_start_sent.get_name_leafdata())
                    if (self.last_download_time.is_set or self.last_download_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_download_time.get_name_leafdata())
                    if (self.last_sweep_time.is_set or self.last_sweep_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_sweep_time.get_name_leafdata())
                    if (self.queues.is_set or self.queues.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.queues.get_name_leafdata())
                    if (self.received_resync_requests.is_set or self.received_resync_requests.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.received_resync_requests.get_name_leafdata())
                    if (self.send_comm_errors.is_set or self.send_comm_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_comm_errors.get_name_leafdata())
                    if (self.send_errors.is_set or self.send_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_errors.get_name_leafdata())
                    if (self.send_partial_errors.is_set or self.send_partial_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_partial_errors.get_name_leafdata())
                    if (self.send_success.is_set or self.send_success.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_success.get_name_leafdata())
                    if (self.sent_resync_bulks.is_set or self.sent_resync_bulks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sent_resync_bulks.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "add-to-batches" or name == "batches" or name == "delete-to-batches" or name == "is-qos-s-sweeped" or name == "is-resync-received" or name == "is-resync-required" or name == "is-resync-start-sent" or name == "last-download-time" or name == "last-sweep-time" or name == "queues" or name == "received-resync-requests" or name == "send-comm-errors" or name == "send-errors" or name == "send-partial-errors" or name == "send-success" or name == "sent-resync-bulks"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "add-to-batches"):
                        self.add_to_batches = value
                        self.add_to_batches.value_namespace = name_space
                        self.add_to_batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "batches"):
                        self.batches = value
                        self.batches.value_namespace = name_space
                        self.batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "delete-to-batches"):
                        self.delete_to_batches = value
                        self.delete_to_batches.value_namespace = name_space
                        self.delete_to_batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-qos-s-sweeped"):
                        self.is_qos_s_sweeped = value
                        self.is_qos_s_sweeped.value_namespace = name_space
                        self.is_qos_s_sweeped.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-received"):
                        self.is_resync_received = value
                        self.is_resync_received.value_namespace = name_space
                        self.is_resync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-required"):
                        self.is_resync_required = value
                        self.is_resync_required.value_namespace = name_space
                        self.is_resync_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-start-sent"):
                        self.is_resync_start_sent = value
                        self.is_resync_start_sent.value_namespace = name_space
                        self.is_resync_start_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-download-time"):
                        self.last_download_time = value
                        self.last_download_time.value_namespace = name_space
                        self.last_download_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-sweep-time"):
                        self.last_sweep_time = value
                        self.last_sweep_time.value_namespace = name_space
                        self.last_sweep_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "queues"):
                        self.queues = value
                        self.queues.value_namespace = name_space
                        self.queues.value_namespace_prefix = name_space_prefix
                    if(value_path == "received-resync-requests"):
                        self.received_resync_requests = value
                        self.received_resync_requests.value_namespace = name_space
                        self.received_resync_requests.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-comm-errors"):
                        self.send_comm_errors = value
                        self.send_comm_errors.value_namespace = name_space
                        self.send_comm_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-errors"):
                        self.send_errors = value
                        self.send_errors.value_namespace = name_space
                        self.send_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-partial-errors"):
                        self.send_partial_errors = value
                        self.send_partial_errors.value_namespace = name_space
                        self.send_partial_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-success"):
                        self.send_success = value
                        self.send_success.value_namespace = name_space
                        self.send_success.value_namespace_prefix = name_space_prefix
                    if(value_path == "sent-resync-bulks"):
                        self.sent_resync_bulks = value
                        self.sent_resync_bulks.value_namespace = name_space
                        self.sent_resync_bulks.value_namespace_prefix = name_space_prefix


            class BviStatistics(Entity):
                """
                IGMP BVI Stats
                
                .. attribute:: null_buffer_handles
                
                	Number of AIPC NULL buffer handles
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_buffers
                
                	Number of AIPC buffers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_buffers
                
                	Number of AIPC buffers released
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_fail_buffers
                
                	Number of AIPC buffers release failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_igmp_packet_success
                
                	Number of IGMP protocol messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_close_notif
                
                	Number of AIPC close notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_connect_notif
                
                	Number of AIPC connect notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_error_notif
                
                	Number of AIPC error notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_input_wait_notif
                
                	Number of AIPC input waiting notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_lwm_notif
                
                	Number of AIPC LWM notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_open_notif
                
                	Number of AIPC open notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_output_notif
                
                	Number of AIPC output notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_publish_notif
                
                	Number of AIPC publish notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_q_full_notif
                
                	Number of AIPC queue full notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_send_status_notif
                
                	Number of AIPC send status notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_blocks
                
                	Number of AIPC buffers send blocked
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffer_errors
                
                	Number of AIPC transmission errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffers
                
                	Number of AIPC buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_mrouter_buffers
                
                	Number of IGMP Mrouter buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_protocol_buffers
                
                	Number of IGMP protocol buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_buffers
                
                	Number of IGMP Unknown buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_dc
                
                	Number of WTX messages dropped due to disconnect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_nomem
                
                	Number of WTX messages dropped to memory
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_freed
                
                	Number of WTX messages freed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_proto_sent
                
                	Number of WTX messages sent to Protocol
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_recvd
                
                	Number of WTX messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_sent
                
                	Number of WTX messages sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.BviStatistics, self).__init__()

                    self.yang_name = "bvi-statistics"
                    self.yang_parent_name = "process"

                    self.null_buffer_handles = YLeaf(YType.uint32, "null-buffer-handles")

                    self.receive_buffers = YLeaf(YType.uint32, "receive-buffers")

                    self.release_buffers = YLeaf(YType.uint32, "release-buffers")

                    self.release_fail_buffers = YLeaf(YType.uint32, "release-fail-buffers")

                    self.rx_add_mrouter_msg = YLeaf(YType.uint32, "rx-add-mrouter-msg")

                    self.rx_delete_mrouter_msg = YLeaf(YType.uint32, "rx-delete-mrouter-msg")

                    self.rx_igmp_packet_success = YLeaf(YType.uint32, "rx-igmp-packet-success")

                    self.rx_ipc_close_notif = YLeaf(YType.uint32, "rx-ipc-close-notif")

                    self.rx_ipc_connect_notif = YLeaf(YType.uint32, "rx-ipc-connect-notif")

                    self.rx_ipc_error_notif = YLeaf(YType.uint32, "rx-ipc-error-notif")

                    self.rx_ipc_input_wait_notif = YLeaf(YType.uint32, "rx-ipc-input-wait-notif")

                    self.rx_ipc_lwm_notif = YLeaf(YType.uint32, "rx-ipc-lwm-notif")

                    self.rx_ipc_open_notif = YLeaf(YType.uint32, "rx-ipc-open-notif")

                    self.rx_ipc_output_notif = YLeaf(YType.uint32, "rx-ipc-output-notif")

                    self.rx_ipc_publish_notif = YLeaf(YType.uint32, "rx-ipc-publish-notif")

                    self.rx_ipc_q_full_notif = YLeaf(YType.uint32, "rx-ipc-q-full-notif")

                    self.rx_ipc_send_status_notif = YLeaf(YType.uint32, "rx-ipc-send-status-notif")

                    self.rx_sweep_mrouter_msg = YLeaf(YType.uint32, "rx-sweep-mrouter-msg")

                    self.rx_unknown_mrouter_msg = YLeaf(YType.uint32, "rx-unknown-mrouter-msg")

                    self.send_blocks = YLeaf(YType.uint32, "send-blocks")

                    self.tx_add_mrouter_msg = YLeaf(YType.uint32, "tx-add-mrouter-msg")

                    self.tx_buffer_errors = YLeaf(YType.uint32, "tx-buffer-errors")

                    self.tx_buffers = YLeaf(YType.uint32, "tx-buffers")

                    self.tx_delete_mrouter_msg = YLeaf(YType.uint32, "tx-delete-mrouter-msg")

                    self.tx_mrouter_buffers = YLeaf(YType.uint32, "tx-mrouter-buffers")

                    self.tx_protocol_buffers = YLeaf(YType.uint32, "tx-protocol-buffers")

                    self.tx_sweep_mrouter_msg = YLeaf(YType.uint32, "tx-sweep-mrouter-msg")

                    self.tx_unknown_buffers = YLeaf(YType.uint32, "tx-unknown-buffers")

                    self.tx_unknown_mrouter_msg = YLeaf(YType.uint32, "tx-unknown-mrouter-msg")

                    self.wtx_msg_drop_dc = YLeaf(YType.uint32, "wtx-msg-drop-dc")

                    self.wtx_msg_drop_nomem = YLeaf(YType.uint32, "wtx-msg-drop-nomem")

                    self.wtx_msg_freed = YLeaf(YType.uint32, "wtx-msg-freed")

                    self.wtx_msg_proto_sent = YLeaf(YType.uint32, "wtx-msg-proto-sent")

                    self.wtx_msg_recvd = YLeaf(YType.uint32, "wtx-msg-recvd")

                    self.wtx_msg_sent = YLeaf(YType.uint32, "wtx-msg-sent")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("null_buffer_handles",
                                    "receive_buffers",
                                    "release_buffers",
                                    "release_fail_buffers",
                                    "rx_add_mrouter_msg",
                                    "rx_delete_mrouter_msg",
                                    "rx_igmp_packet_success",
                                    "rx_ipc_close_notif",
                                    "rx_ipc_connect_notif",
                                    "rx_ipc_error_notif",
                                    "rx_ipc_input_wait_notif",
                                    "rx_ipc_lwm_notif",
                                    "rx_ipc_open_notif",
                                    "rx_ipc_output_notif",
                                    "rx_ipc_publish_notif",
                                    "rx_ipc_q_full_notif",
                                    "rx_ipc_send_status_notif",
                                    "rx_sweep_mrouter_msg",
                                    "rx_unknown_mrouter_msg",
                                    "send_blocks",
                                    "tx_add_mrouter_msg",
                                    "tx_buffer_errors",
                                    "tx_buffers",
                                    "tx_delete_mrouter_msg",
                                    "tx_mrouter_buffers",
                                    "tx_protocol_buffers",
                                    "tx_sweep_mrouter_msg",
                                    "tx_unknown_buffers",
                                    "tx_unknown_mrouter_msg",
                                    "wtx_msg_drop_dc",
                                    "wtx_msg_drop_nomem",
                                    "wtx_msg_freed",
                                    "wtx_msg_proto_sent",
                                    "wtx_msg_recvd",
                                    "wtx_msg_sent") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.Process.BviStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.Process.BviStatistics, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.null_buffer_handles.is_set or
                        self.receive_buffers.is_set or
                        self.release_buffers.is_set or
                        self.release_fail_buffers.is_set or
                        self.rx_add_mrouter_msg.is_set or
                        self.rx_delete_mrouter_msg.is_set or
                        self.rx_igmp_packet_success.is_set or
                        self.rx_ipc_close_notif.is_set or
                        self.rx_ipc_connect_notif.is_set or
                        self.rx_ipc_error_notif.is_set or
                        self.rx_ipc_input_wait_notif.is_set or
                        self.rx_ipc_lwm_notif.is_set or
                        self.rx_ipc_open_notif.is_set or
                        self.rx_ipc_output_notif.is_set or
                        self.rx_ipc_publish_notif.is_set or
                        self.rx_ipc_q_full_notif.is_set or
                        self.rx_ipc_send_status_notif.is_set or
                        self.rx_sweep_mrouter_msg.is_set or
                        self.rx_unknown_mrouter_msg.is_set or
                        self.send_blocks.is_set or
                        self.tx_add_mrouter_msg.is_set or
                        self.tx_buffer_errors.is_set or
                        self.tx_buffers.is_set or
                        self.tx_delete_mrouter_msg.is_set or
                        self.tx_mrouter_buffers.is_set or
                        self.tx_protocol_buffers.is_set or
                        self.tx_sweep_mrouter_msg.is_set or
                        self.tx_unknown_buffers.is_set or
                        self.tx_unknown_mrouter_msg.is_set or
                        self.wtx_msg_drop_dc.is_set or
                        self.wtx_msg_drop_nomem.is_set or
                        self.wtx_msg_freed.is_set or
                        self.wtx_msg_proto_sent.is_set or
                        self.wtx_msg_recvd.is_set or
                        self.wtx_msg_sent.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.null_buffer_handles.yfilter != YFilter.not_set or
                        self.receive_buffers.yfilter != YFilter.not_set or
                        self.release_buffers.yfilter != YFilter.not_set or
                        self.release_fail_buffers.yfilter != YFilter.not_set or
                        self.rx_add_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_delete_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_igmp_packet_success.yfilter != YFilter.not_set or
                        self.rx_ipc_close_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_connect_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_error_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_input_wait_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_lwm_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_open_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_output_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_publish_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_q_full_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_send_status_notif.yfilter != YFilter.not_set or
                        self.rx_sweep_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_unknown_mrouter_msg.yfilter != YFilter.not_set or
                        self.send_blocks.yfilter != YFilter.not_set or
                        self.tx_add_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_buffer_errors.yfilter != YFilter.not_set or
                        self.tx_buffers.yfilter != YFilter.not_set or
                        self.tx_delete_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_mrouter_buffers.yfilter != YFilter.not_set or
                        self.tx_protocol_buffers.yfilter != YFilter.not_set or
                        self.tx_sweep_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_unknown_buffers.yfilter != YFilter.not_set or
                        self.tx_unknown_mrouter_msg.yfilter != YFilter.not_set or
                        self.wtx_msg_drop_dc.yfilter != YFilter.not_set or
                        self.wtx_msg_drop_nomem.yfilter != YFilter.not_set or
                        self.wtx_msg_freed.yfilter != YFilter.not_set or
                        self.wtx_msg_proto_sent.yfilter != YFilter.not_set or
                        self.wtx_msg_recvd.yfilter != YFilter.not_set or
                        self.wtx_msg_sent.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bvi-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.null_buffer_handles.is_set or self.null_buffer_handles.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.null_buffer_handles.get_name_leafdata())
                    if (self.receive_buffers.is_set or self.receive_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.receive_buffers.get_name_leafdata())
                    if (self.release_buffers.is_set or self.release_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.release_buffers.get_name_leafdata())
                    if (self.release_fail_buffers.is_set or self.release_fail_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.release_fail_buffers.get_name_leafdata())
                    if (self.rx_add_mrouter_msg.is_set or self.rx_add_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_add_mrouter_msg.get_name_leafdata())
                    if (self.rx_delete_mrouter_msg.is_set or self.rx_delete_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_delete_mrouter_msg.get_name_leafdata())
                    if (self.rx_igmp_packet_success.is_set or self.rx_igmp_packet_success.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_igmp_packet_success.get_name_leafdata())
                    if (self.rx_ipc_close_notif.is_set or self.rx_ipc_close_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_close_notif.get_name_leafdata())
                    if (self.rx_ipc_connect_notif.is_set or self.rx_ipc_connect_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_connect_notif.get_name_leafdata())
                    if (self.rx_ipc_error_notif.is_set or self.rx_ipc_error_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_error_notif.get_name_leafdata())
                    if (self.rx_ipc_input_wait_notif.is_set or self.rx_ipc_input_wait_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_input_wait_notif.get_name_leafdata())
                    if (self.rx_ipc_lwm_notif.is_set or self.rx_ipc_lwm_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_lwm_notif.get_name_leafdata())
                    if (self.rx_ipc_open_notif.is_set or self.rx_ipc_open_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_open_notif.get_name_leafdata())
                    if (self.rx_ipc_output_notif.is_set or self.rx_ipc_output_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_output_notif.get_name_leafdata())
                    if (self.rx_ipc_publish_notif.is_set or self.rx_ipc_publish_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_publish_notif.get_name_leafdata())
                    if (self.rx_ipc_q_full_notif.is_set or self.rx_ipc_q_full_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_q_full_notif.get_name_leafdata())
                    if (self.rx_ipc_send_status_notif.is_set or self.rx_ipc_send_status_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_send_status_notif.get_name_leafdata())
                    if (self.rx_sweep_mrouter_msg.is_set or self.rx_sweep_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_sweep_mrouter_msg.get_name_leafdata())
                    if (self.rx_unknown_mrouter_msg.is_set or self.rx_unknown_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_unknown_mrouter_msg.get_name_leafdata())
                    if (self.send_blocks.is_set or self.send_blocks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_blocks.get_name_leafdata())
                    if (self.tx_add_mrouter_msg.is_set or self.tx_add_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_add_mrouter_msg.get_name_leafdata())
                    if (self.tx_buffer_errors.is_set or self.tx_buffer_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_buffer_errors.get_name_leafdata())
                    if (self.tx_buffers.is_set or self.tx_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_buffers.get_name_leafdata())
                    if (self.tx_delete_mrouter_msg.is_set or self.tx_delete_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_delete_mrouter_msg.get_name_leafdata())
                    if (self.tx_mrouter_buffers.is_set or self.tx_mrouter_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_mrouter_buffers.get_name_leafdata())
                    if (self.tx_protocol_buffers.is_set or self.tx_protocol_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_protocol_buffers.get_name_leafdata())
                    if (self.tx_sweep_mrouter_msg.is_set or self.tx_sweep_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_sweep_mrouter_msg.get_name_leafdata())
                    if (self.tx_unknown_buffers.is_set or self.tx_unknown_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_unknown_buffers.get_name_leafdata())
                    if (self.tx_unknown_mrouter_msg.is_set or self.tx_unknown_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_unknown_mrouter_msg.get_name_leafdata())
                    if (self.wtx_msg_drop_dc.is_set or self.wtx_msg_drop_dc.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_drop_dc.get_name_leafdata())
                    if (self.wtx_msg_drop_nomem.is_set or self.wtx_msg_drop_nomem.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_drop_nomem.get_name_leafdata())
                    if (self.wtx_msg_freed.is_set or self.wtx_msg_freed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_freed.get_name_leafdata())
                    if (self.wtx_msg_proto_sent.is_set or self.wtx_msg_proto_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_proto_sent.get_name_leafdata())
                    if (self.wtx_msg_recvd.is_set or self.wtx_msg_recvd.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_recvd.get_name_leafdata())
                    if (self.wtx_msg_sent.is_set or self.wtx_msg_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_sent.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "null-buffer-handles" or name == "receive-buffers" or name == "release-buffers" or name == "release-fail-buffers" or name == "rx-add-mrouter-msg" or name == "rx-delete-mrouter-msg" or name == "rx-igmp-packet-success" or name == "rx-ipc-close-notif" or name == "rx-ipc-connect-notif" or name == "rx-ipc-error-notif" or name == "rx-ipc-input-wait-notif" or name == "rx-ipc-lwm-notif" or name == "rx-ipc-open-notif" or name == "rx-ipc-output-notif" or name == "rx-ipc-publish-notif" or name == "rx-ipc-q-full-notif" or name == "rx-ipc-send-status-notif" or name == "rx-sweep-mrouter-msg" or name == "rx-unknown-mrouter-msg" or name == "send-blocks" or name == "tx-add-mrouter-msg" or name == "tx-buffer-errors" or name == "tx-buffers" or name == "tx-delete-mrouter-msg" or name == "tx-mrouter-buffers" or name == "tx-protocol-buffers" or name == "tx-sweep-mrouter-msg" or name == "tx-unknown-buffers" or name == "tx-unknown-mrouter-msg" or name == "wtx-msg-drop-dc" or name == "wtx-msg-drop-nomem" or name == "wtx-msg-freed" or name == "wtx-msg-proto-sent" or name == "wtx-msg-recvd" or name == "wtx-msg-sent"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "null-buffer-handles"):
                        self.null_buffer_handles = value
                        self.null_buffer_handles.value_namespace = name_space
                        self.null_buffer_handles.value_namespace_prefix = name_space_prefix
                    if(value_path == "receive-buffers"):
                        self.receive_buffers = value
                        self.receive_buffers.value_namespace = name_space
                        self.receive_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "release-buffers"):
                        self.release_buffers = value
                        self.release_buffers.value_namespace = name_space
                        self.release_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "release-fail-buffers"):
                        self.release_fail_buffers = value
                        self.release_fail_buffers.value_namespace = name_space
                        self.release_fail_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-add-mrouter-msg"):
                        self.rx_add_mrouter_msg = value
                        self.rx_add_mrouter_msg.value_namespace = name_space
                        self.rx_add_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-delete-mrouter-msg"):
                        self.rx_delete_mrouter_msg = value
                        self.rx_delete_mrouter_msg.value_namespace = name_space
                        self.rx_delete_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-igmp-packet-success"):
                        self.rx_igmp_packet_success = value
                        self.rx_igmp_packet_success.value_namespace = name_space
                        self.rx_igmp_packet_success.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-close-notif"):
                        self.rx_ipc_close_notif = value
                        self.rx_ipc_close_notif.value_namespace = name_space
                        self.rx_ipc_close_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-connect-notif"):
                        self.rx_ipc_connect_notif = value
                        self.rx_ipc_connect_notif.value_namespace = name_space
                        self.rx_ipc_connect_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-error-notif"):
                        self.rx_ipc_error_notif = value
                        self.rx_ipc_error_notif.value_namespace = name_space
                        self.rx_ipc_error_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-input-wait-notif"):
                        self.rx_ipc_input_wait_notif = value
                        self.rx_ipc_input_wait_notif.value_namespace = name_space
                        self.rx_ipc_input_wait_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-lwm-notif"):
                        self.rx_ipc_lwm_notif = value
                        self.rx_ipc_lwm_notif.value_namespace = name_space
                        self.rx_ipc_lwm_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-open-notif"):
                        self.rx_ipc_open_notif = value
                        self.rx_ipc_open_notif.value_namespace = name_space
                        self.rx_ipc_open_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-output-notif"):
                        self.rx_ipc_output_notif = value
                        self.rx_ipc_output_notif.value_namespace = name_space
                        self.rx_ipc_output_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-publish-notif"):
                        self.rx_ipc_publish_notif = value
                        self.rx_ipc_publish_notif.value_namespace = name_space
                        self.rx_ipc_publish_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-q-full-notif"):
                        self.rx_ipc_q_full_notif = value
                        self.rx_ipc_q_full_notif.value_namespace = name_space
                        self.rx_ipc_q_full_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-send-status-notif"):
                        self.rx_ipc_send_status_notif = value
                        self.rx_ipc_send_status_notif.value_namespace = name_space
                        self.rx_ipc_send_status_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-sweep-mrouter-msg"):
                        self.rx_sweep_mrouter_msg = value
                        self.rx_sweep_mrouter_msg.value_namespace = name_space
                        self.rx_sweep_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-unknown-mrouter-msg"):
                        self.rx_unknown_mrouter_msg = value
                        self.rx_unknown_mrouter_msg.value_namespace = name_space
                        self.rx_unknown_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-blocks"):
                        self.send_blocks = value
                        self.send_blocks.value_namespace = name_space
                        self.send_blocks.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-add-mrouter-msg"):
                        self.tx_add_mrouter_msg = value
                        self.tx_add_mrouter_msg.value_namespace = name_space
                        self.tx_add_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-buffer-errors"):
                        self.tx_buffer_errors = value
                        self.tx_buffer_errors.value_namespace = name_space
                        self.tx_buffer_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-buffers"):
                        self.tx_buffers = value
                        self.tx_buffers.value_namespace = name_space
                        self.tx_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-delete-mrouter-msg"):
                        self.tx_delete_mrouter_msg = value
                        self.tx_delete_mrouter_msg.value_namespace = name_space
                        self.tx_delete_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-mrouter-buffers"):
                        self.tx_mrouter_buffers = value
                        self.tx_mrouter_buffers.value_namespace = name_space
                        self.tx_mrouter_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-protocol-buffers"):
                        self.tx_protocol_buffers = value
                        self.tx_protocol_buffers.value_namespace = name_space
                        self.tx_protocol_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-sweep-mrouter-msg"):
                        self.tx_sweep_mrouter_msg = value
                        self.tx_sweep_mrouter_msg.value_namespace = name_space
                        self.tx_sweep_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-unknown-buffers"):
                        self.tx_unknown_buffers = value
                        self.tx_unknown_buffers.value_namespace = name_space
                        self.tx_unknown_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-unknown-mrouter-msg"):
                        self.tx_unknown_mrouter_msg = value
                        self.tx_unknown_mrouter_msg.value_namespace = name_space
                        self.tx_unknown_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-drop-dc"):
                        self.wtx_msg_drop_dc = value
                        self.wtx_msg_drop_dc.value_namespace = name_space
                        self.wtx_msg_drop_dc.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-drop-nomem"):
                        self.wtx_msg_drop_nomem = value
                        self.wtx_msg_drop_nomem.value_namespace = name_space
                        self.wtx_msg_drop_nomem.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-freed"):
                        self.wtx_msg_freed = value
                        self.wtx_msg_freed.value_namespace = name_space
                        self.wtx_msg_freed.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-proto-sent"):
                        self.wtx_msg_proto_sent = value
                        self.wtx_msg_proto_sent.value_namespace = name_space
                        self.wtx_msg_proto_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-recvd"):
                        self.wtx_msg_recvd = value
                        self.wtx_msg_recvd.value_namespace = name_space
                        self.wtx_msg_recvd.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-sent"):
                        self.wtx_msg_sent = value
                        self.wtx_msg_sent.value_namespace = name_space
                        self.wtx_msg_sent.value_namespace_prefix = name_space_prefix


            class Nsf(Entity):
                """
                NSF Information
                
                .. attribute:: is_multicast_nsf_active
                
                	Is Multicast NSF active
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_min
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_min
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_min
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_time_left
                
                	Multicast NSF time remaining in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_timeout
                
                	Multicast NSF timeout in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"

                    self.is_multicast_nsf_active = YLeaf(YType.boolean, "is-multicast-nsf-active")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_min = YLeaf(YType.int32, "last-icd-notif-recv-min")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_min = YLeaf(YType.int32, "last-nsf-off-min")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_min = YLeaf(YType.int32, "last-nsf-on-min")

                    self.multicast_nsf_time_left = YLeaf(YType.uint32, "multicast-nsf-time-left")

                    self.multicast_nsf_timeout = YLeaf(YType.uint32, "multicast-nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_multicast_nsf_active",
                                    "last_icd_notif_recv",
                                    "last_icd_notif_recv_min",
                                    "last_nsf_off",
                                    "last_nsf_off_min",
                                    "last_nsf_on",
                                    "last_nsf_on_min",
                                    "multicast_nsf_time_left",
                                    "multicast_nsf_timeout",
                                    "respawn_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.Process.Nsf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.Process.Nsf, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_multicast_nsf_active.is_set or
                        self.last_icd_notif_recv.is_set or
                        self.last_icd_notif_recv_min.is_set or
                        self.last_nsf_off.is_set or
                        self.last_nsf_off_min.is_set or
                        self.last_nsf_on.is_set or
                        self.last_nsf_on_min.is_set or
                        self.multicast_nsf_time_left.is_set or
                        self.multicast_nsf_timeout.is_set or
                        self.respawn_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_multicast_nsf_active.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv_min.yfilter != YFilter.not_set or
                        self.last_nsf_off.yfilter != YFilter.not_set or
                        self.last_nsf_off_min.yfilter != YFilter.not_set or
                        self.last_nsf_on.yfilter != YFilter.not_set or
                        self.last_nsf_on_min.yfilter != YFilter.not_set or
                        self.multicast_nsf_time_left.yfilter != YFilter.not_set or
                        self.multicast_nsf_timeout.yfilter != YFilter.not_set or
                        self.respawn_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsf" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_multicast_nsf_active.is_set or self.is_multicast_nsf_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multicast_nsf_active.get_name_leafdata())
                    if (self.last_icd_notif_recv.is_set or self.last_icd_notif_recv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv.get_name_leafdata())
                    if (self.last_icd_notif_recv_min.is_set or self.last_icd_notif_recv_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv_min.get_name_leafdata())
                    if (self.last_nsf_off.is_set or self.last_nsf_off.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off.get_name_leafdata())
                    if (self.last_nsf_off_min.is_set or self.last_nsf_off_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off_min.get_name_leafdata())
                    if (self.last_nsf_on.is_set or self.last_nsf_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on.get_name_leafdata())
                    if (self.last_nsf_on_min.is_set or self.last_nsf_on_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on_min.get_name_leafdata())
                    if (self.multicast_nsf_time_left.is_set or self.multicast_nsf_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.multicast_nsf_time_left.get_name_leafdata())
                    if (self.multicast_nsf_timeout.is_set or self.multicast_nsf_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.multicast_nsf_timeout.get_name_leafdata())
                    if (self.respawn_count.is_set or self.respawn_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.respawn_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-multicast-nsf-active" or name == "last-icd-notif-recv" or name == "last-icd-notif-recv-min" or name == "last-nsf-off" or name == "last-nsf-off-min" or name == "last-nsf-on" or name == "last-nsf-on-min" or name == "multicast-nsf-time-left" or name == "multicast-nsf-timeout" or name == "respawn-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-multicast-nsf-active"):
                        self.is_multicast_nsf_active = value
                        self.is_multicast_nsf_active.value_namespace = name_space
                        self.is_multicast_nsf_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv"):
                        self.last_icd_notif_recv = value
                        self.last_icd_notif_recv.value_namespace = name_space
                        self.last_icd_notif_recv.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv-min"):
                        self.last_icd_notif_recv_min = value
                        self.last_icd_notif_recv_min.value_namespace = name_space
                        self.last_icd_notif_recv_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off"):
                        self.last_nsf_off = value
                        self.last_nsf_off.value_namespace = name_space
                        self.last_nsf_off.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off-min"):
                        self.last_nsf_off_min = value
                        self.last_nsf_off_min.value_namespace = name_space
                        self.last_nsf_off_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on"):
                        self.last_nsf_on = value
                        self.last_nsf_on.value_namespace = name_space
                        self.last_nsf_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on-min"):
                        self.last_nsf_on_min = value
                        self.last_nsf_on_min.value_namespace = name_space
                        self.last_nsf_on_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "multicast-nsf-time-left"):
                        self.multicast_nsf_time_left = value
                        self.multicast_nsf_time_left.value_namespace = name_space
                        self.multicast_nsf_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "multicast-nsf-timeout"):
                        self.multicast_nsf_timeout = value
                        self.multicast_nsf_timeout.value_namespace = name_space
                        self.multicast_nsf_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "respawn-count"):
                        self.respawn_count = value
                        self.respawn_count.value_namespace = name_space
                        self.respawn_count.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.amt_gatewaies is not None and self.amt_gatewaies.has_data()) or
                    (self.amt_summary is not None and self.amt_summary.has_data()) or
                    (self.bvi_statistics is not None and self.bvi_statistics.has_data()) or
                    (self.nsf is not None and self.nsf.has_data()) or
                    (self.nsr is not None and self.nsr.has_data()) or
                    (self.unicast_qos_adjust_stats is not None and self.unicast_qos_adjust_stats.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.amt_gatewaies is not None and self.amt_gatewaies.has_operation()) or
                    (self.amt_summary is not None and self.amt_summary.has_operation()) or
                    (self.bvi_statistics is not None and self.bvi_statistics.has_operation()) or
                    (self.nsf is not None and self.nsf.has_operation()) or
                    (self.nsr is not None and self.nsr.has_operation()) or
                    (self.unicast_qos_adjust_stats is not None and self.unicast_qos_adjust_stats.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "process" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "amt-gatewaies"):
                    if (self.amt_gatewaies is None):
                        self.amt_gatewaies = Mld.Standby.Process.AmtGatewaies()
                        self.amt_gatewaies.parent = self
                        self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                    return self.amt_gatewaies

                if (child_yang_name == "amt-summary"):
                    if (self.amt_summary is None):
                        self.amt_summary = Mld.Standby.Process.AmtSummary()
                        self.amt_summary.parent = self
                        self._children_name_map["amt_summary"] = "amt-summary"
                    return self.amt_summary

                if (child_yang_name == "bvi-statistics"):
                    if (self.bvi_statistics is None):
                        self.bvi_statistics = Mld.Standby.Process.BviStatistics()
                        self.bvi_statistics.parent = self
                        self._children_name_map["bvi_statistics"] = "bvi-statistics"
                    return self.bvi_statistics

                if (child_yang_name == "nsf"):
                    if (self.nsf is None):
                        self.nsf = Mld.Standby.Process.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"
                    return self.nsf

                if (child_yang_name == "nsr"):
                    if (self.nsr is None):
                        self.nsr = Mld.Standby.Process.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                    return self.nsr

                if (child_yang_name == "unicast-qos-adjust-stats"):
                    if (self.unicast_qos_adjust_stats is None):
                        self.unicast_qos_adjust_stats = Mld.Standby.Process.UnicastQosAdjustStats()
                        self.unicast_qos_adjust_stats.parent = self
                        self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                    return self.unicast_qos_adjust_stats

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "amt-gatewaies" or name == "amt-summary" or name == "bvi-statistics" or name == "nsf" or name == "nsr" or name == "unicast-qos-adjust-stats"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: detail_groups
            
            	IGMP Detail Group Database
            	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups>`
            
            .. attribute:: explicit_groups
            
            	IGMP Explicit Group Database
            	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups>`
            
            .. attribute:: global_interface_table
            
            	IGMP Global Interface 
            	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GlobalInterfaceTable>`
            
            .. attribute:: group_summary
            
            	IGMP Groups Summary
            	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GroupSummary>`
            
            .. attribute:: groups
            
            	IGMP Group Database Table
            	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Groups>`
            
            .. attribute:: ifrs_interface_summary
            
            	IGMP IFRS Interface summary
            	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaceSummary>`
            
            .. attribute:: ifrs_interfaces
            
            	IGMP Interface specific
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: interface_state_offs
            
            	IGMP Interface state off
            	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOffs>`
            
            .. attribute:: interface_state_ons
            
            	IGMP Interface state on
            	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOns>`
            
            .. attribute:: interface_table
            
            	IGMP Interface specific Table
            	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceTable>`
            
            .. attribute:: interface_unicast_qos_adjusts
            
            	IGMP Interface Unicast\-Qos\-Adjust
            	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts>`
            
            .. attribute:: non_active_groups
            
            	IGMP Non\-Active Groups Information
            	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.NonActiveGroups>`
            
            .. attribute:: ranges
            
            	Range table
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Ranges>`
            
            .. attribute:: ssm_map_details
            
            	SSM Map Detail
            	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMapDetails>`
            
            .. attribute:: ssm_maps
            
            	SSM Map Table
            	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMaps>`
            
            .. attribute:: summary
            
            	IGMP Summary Information
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Summary>`
            
            .. attribute:: traffic_counters
            
            	IGMP Message Traffic Counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.TrafficCounters>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Standby.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "standby"

                self.detail_groups = Mld.Standby.DefaultContext.DetailGroups()
                self.detail_groups.parent = self
                self._children_name_map["detail_groups"] = "detail-groups"
                self._children_yang_names.add("detail-groups")

                self.explicit_groups = Mld.Standby.DefaultContext.ExplicitGroups()
                self.explicit_groups.parent = self
                self._children_name_map["explicit_groups"] = "explicit-groups"
                self._children_yang_names.add("explicit-groups")

                self.global_interface_table = Mld.Standby.DefaultContext.GlobalInterfaceTable()
                self.global_interface_table.parent = self
                self._children_name_map["global_interface_table"] = "global-interface-table"
                self._children_yang_names.add("global-interface-table")

                self.group_summary = Mld.Standby.DefaultContext.GroupSummary()
                self.group_summary.parent = self
                self._children_name_map["group_summary"] = "group-summary"
                self._children_yang_names.add("group-summary")

                self.groups = Mld.Standby.DefaultContext.Groups()
                self.groups.parent = self
                self._children_name_map["groups"] = "groups"
                self._children_yang_names.add("groups")

                self.ifrs_interface_summary = Mld.Standby.DefaultContext.IfrsInterfaceSummary()
                self.ifrs_interface_summary.parent = self
                self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                self._children_yang_names.add("ifrs-interface-summary")

                self.ifrs_interfaces = Mld.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.interface_state_offs = Mld.Standby.DefaultContext.InterfaceStateOffs()
                self.interface_state_offs.parent = self
                self._children_name_map["interface_state_offs"] = "interface-state-offs"
                self._children_yang_names.add("interface-state-offs")

                self.interface_state_ons = Mld.Standby.DefaultContext.InterfaceStateOns()
                self.interface_state_ons.parent = self
                self._children_name_map["interface_state_ons"] = "interface-state-ons"
                self._children_yang_names.add("interface-state-ons")

                self.interface_table = Mld.Standby.DefaultContext.InterfaceTable()
                self.interface_table.parent = self
                self._children_name_map["interface_table"] = "interface-table"
                self._children_yang_names.add("interface-table")

                self.interface_unicast_qos_adjusts = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts()
                self.interface_unicast_qos_adjusts.parent = self
                self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                self._children_yang_names.add("interface-unicast-qos-adjusts")

                self.non_active_groups = Mld.Standby.DefaultContext.NonActiveGroups()
                self.non_active_groups.parent = self
                self._children_name_map["non_active_groups"] = "non-active-groups"
                self._children_yang_names.add("non-active-groups")

                self.ranges = Mld.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.ssm_map_details = Mld.Standby.DefaultContext.SsmMapDetails()
                self.ssm_map_details.parent = self
                self._children_name_map["ssm_map_details"] = "ssm-map-details"
                self._children_yang_names.add("ssm-map-details")

                self.ssm_maps = Mld.Standby.DefaultContext.SsmMaps()
                self.ssm_maps.parent = self
                self._children_name_map["ssm_maps"] = "ssm-maps"
                self._children_yang_names.add("ssm-maps")

                self.summary = Mld.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.traffic_counters = Mld.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")


            class Summary(Entity):
                """
                IGMP Summary Information
                
                .. attribute:: disabled_interface_count
                
                	No. of disabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: enabled_interface_count
                
                	No. of enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_limit
                
                	Maximum groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Maximum and current groups accepted for each interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Summary.Interface>`
                
                .. attribute:: is_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: robustness
                
                	Robustness variable
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: supported_interfaces
                
                	No. of supported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_mte_config_count
                
                	No. of static group commands
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsupported_interfaces
                
                	No. of unsupported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"

                    self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                    self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.group_limit = YLeaf(YType.uint32, "group-limit")

                    self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                    self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                    self.robustness = YLeaf(YType.uint32, "robustness")

                    self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                    self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                    self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("disabled_interface_count",
                                    "enabled_interface_count",
                                    "group_count",
                                    "group_limit",
                                    "is_disabled",
                                    "node_low_memory",
                                    "robustness",
                                    "supported_interfaces",
                                    "tunnel_mte_config_count",
                                    "unsupported_interfaces") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.Summary, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    Maximum and current groups accepted for each
                    interface
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: on_off
                    
                    	Enabled/Disabled
                    	**type**\:  bool
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent if handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Time elapsed since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.Summary.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "summary"

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.on_off = YLeaf(YType.boolean, "on-off")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_count",
                                        "group_limit",
                                        "interface_name",
                                        "on_off",
                                        "parent_ifhandle",
                                        "router_uptime_in_seconds",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.Summary.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.Summary.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.group_count.is_set or
                            self.group_limit.is_set or
                            self.interface_name.is_set or
                            self.on_off.is_set or
                            self.parent_ifhandle.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.group_limit.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.on_off.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/summary/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_limit.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.on_off.is_set or self.on_off.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.on_off.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-count" or name == "group-limit" or name == "interface-name" or name == "on-off" or name == "parent-ifhandle" or name == "router-uptime-in-seconds" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-limit"):
                            self.group_limit = value
                            self.group_limit.value_namespace = name_space
                            self.group_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "on-off"):
                            self.on_off = value
                            self.on_off.value_namespace = name_space
                            self.on_off.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.disabled_interface_count.is_set or
                        self.enabled_interface_count.is_set or
                        self.group_count.is_set or
                        self.group_limit.is_set or
                        self.is_disabled.is_set or
                        self.node_low_memory.is_set or
                        self.robustness.is_set or
                        self.supported_interfaces.is_set or
                        self.tunnel_mte_config_count.is_set or
                        self.unsupported_interfaces.is_set)

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.disabled_interface_count.yfilter != YFilter.not_set or
                        self.enabled_interface_count.yfilter != YFilter.not_set or
                        self.group_count.yfilter != YFilter.not_set or
                        self.group_limit.yfilter != YFilter.not_set or
                        self.is_disabled.yfilter != YFilter.not_set or
                        self.node_low_memory.yfilter != YFilter.not_set or
                        self.robustness.yfilter != YFilter.not_set or
                        self.supported_interfaces.yfilter != YFilter.not_set or
                        self.tunnel_mte_config_count.yfilter != YFilter.not_set or
                        self.unsupported_interfaces.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.disabled_interface_count.is_set or self.disabled_interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disabled_interface_count.get_name_leafdata())
                    if (self.enabled_interface_count.is_set or self.enabled_interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enabled_interface_count.get_name_leafdata())
                    if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_count.get_name_leafdata())
                    if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_limit.get_name_leafdata())
                    if (self.is_disabled.is_set or self.is_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_disabled.get_name_leafdata())
                    if (self.node_low_memory.is_set or self.node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.node_low_memory.get_name_leafdata())
                    if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.robustness.get_name_leafdata())
                    if (self.supported_interfaces.is_set or self.supported_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.supported_interfaces.get_name_leafdata())
                    if (self.tunnel_mte_config_count.is_set or self.tunnel_mte_config_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_mte_config_count.get_name_leafdata())
                    if (self.unsupported_interfaces.is_set or self.unsupported_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unsupported_interfaces.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.Summary.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "disabled-interface-count" or name == "enabled-interface-count" or name == "group-count" or name == "group-limit" or name == "is-disabled" or name == "node-low-memory" or name == "robustness" or name == "supported-interfaces" or name == "tunnel-mte-config-count" or name == "unsupported-interfaces"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "disabled-interface-count"):
                        self.disabled_interface_count = value
                        self.disabled_interface_count.value_namespace = name_space
                        self.disabled_interface_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "enabled-interface-count"):
                        self.enabled_interface_count = value
                        self.enabled_interface_count.value_namespace = name_space
                        self.enabled_interface_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-count"):
                        self.group_count = value
                        self.group_count.value_namespace = name_space
                        self.group_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-limit"):
                        self.group_limit = value
                        self.group_limit.value_namespace = name_space
                        self.group_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-disabled"):
                        self.is_disabled = value
                        self.is_disabled.value_namespace = name_space
                        self.is_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "node-low-memory"):
                        self.node_low_memory = value
                        self.node_low_memory.value_namespace = name_space
                        self.node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "robustness"):
                        self.robustness = value
                        self.robustness.value_namespace = name_space
                        self.robustness.value_namespace_prefix = name_space_prefix
                    if(value_path == "supported-interfaces"):
                        self.supported_interfaces = value
                        self.supported_interfaces.value_namespace = name_space
                        self.supported_interfaces.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-mte-config-count"):
                        self.tunnel_mte_config_count = value
                        self.tunnel_mte_config_count.value_namespace = name_space
                        self.tunnel_mte_config_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "unsupported-interfaces"):
                        self.unsupported_interfaces = value
                        self.unsupported_interfaces.value_namespace = name_space
                        self.unsupported_interfaces.value_namespace_prefix = name_space_prefix


            class InterfaceStateOns(Entity):
                """
                IGMP Interface state on
                
                .. attribute:: interface_state_on
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.InterfaceStateOns, self).__init__()

                    self.yang_name = "interface-state-ons"
                    self.yang_parent_name = "default-context"

                    self.interface_state_on = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.InterfaceStateOns, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.InterfaceStateOns, self).__setattr__(name, value)


                class InterfaceStateOn(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__init__()

                        self.yang_name = "interface-state-on"
                        self.yang_parent_name = "interface-state-ons"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/interface-state-ons/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_state_on:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_state_on:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-state-ons" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-state-on"):
                        for c in self.interface_state_on:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_state_on.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-state-on"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class DetailGroups(Entity):
                """
                IGMP Detail Group Database
                
                .. attribute:: detail_group
                
                	IGMP Detail Group Entry Information
                	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.DetailGroups, self).__init__()

                    self.yang_name = "detail-groups"
                    self.yang_parent_name = "default-context"

                    self.detail_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.DetailGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.DetailGroups, self).__setattr__(name, value)


                class DetailGroup(Entity):
                    """
                    IGMP Detail Group Entry Information
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_host_exclude_mode
                    
                    	Group host filter mode
                    	**type**\:  bool
                    
                    .. attribute:: is_router_exclude_mode
                    
                    	Group router filter mode
                    	**type**\:  bool
                    
                    .. attribute:: source
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup, self).__init__()

                        self.yang_name = "detail-group"
                        self.yang_parent_name = "detail-groups"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                        self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "interface_name",
                                        "is_host_exclude_mode",
                                        "is_router_exclude_mode",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup, self).__setattr__(name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "detail-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix


                    class Source(Entity):
                        """
                        List of sources
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: flags
                        
                        	Source flags
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_forward
                        
                        	Should we forward on this entry
                        	**type**\:  bool
                        
                        .. attribute:: is_local
                        
                        	Is this a local source
                        	**type**\:  bool
                        
                        .. attribute:: is_remote
                        
                        	Is this a remote source
                        	**type**\:  bool
                        
                        .. attribute:: is_we_report
                        
                        	Should we report the source
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "detail-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.flags = YLeaf(YType.int32, "flags")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_forward = YLeaf(YType.boolean, "is-forward")

                            self.is_local = YLeaf(YType.boolean, "is-local")

                            self.is_remote = YLeaf(YType.boolean, "is-remote")

                            self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.source_address = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "flags",
                                            "is_added",
                                            "is_forward",
                                            "is_local",
                                            "is_remote",
                                            "is_we_report",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/source/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.flags.is_set or
                                self.is_added.is_set or
                                self.is_forward.is_set or
                                self.is_local.is_set or
                                self.is_remote.is_set or
                                self.is_we_report.is_set or
                                self.uptime.is_set or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.flags.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_forward.yfilter != YFilter.not_set or
                                self.is_local.yfilter != YFilter.not_set or
                                self.is_remote.yfilter != YFilter.not_set or
                                self.is_we_report.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flags.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_forward.is_set or self.is_forward.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_forward.get_name_leafdata())
                            if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_local.get_name_leafdata())
                            if (self.is_remote.is_set or self.is_remote.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_remote.get_name_leafdata())
                            if (self.is_we_report.is_set or self.is_we_report.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_we_report.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "expiration-time" or name == "flags" or name == "is-added" or name == "is-forward" or name == "is-local" or name == "is-remote" or name == "is-we-report" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "flags"):
                                self.flags = value
                                self.flags.value_namespace = name_space
                                self.flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-forward"):
                                self.is_forward = value
                                self.is_forward.value_namespace = name_space
                                self.is_forward.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-local"):
                                self.is_local = value
                                self.is_local.value_namespace = name_space
                                self.is_local.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-remote"):
                                self.is_remote = value
                                self.is_remote.value_namespace = name_space
                                self.is_remote.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-we-report"):
                                self.is_we_report = value
                                self.is_we_report.value_namespace = name_space
                                self.is_we_report.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.source:
                            if (c.has_data()):
                                return True
                        return (
                            self.group_address.is_set or
                            self.interface_name.is_set or
                            self.is_host_exclude_mode.is_set or
                            self.is_router_exclude_mode.is_set or
                            self.source_address.is_set or
                            (self.group_info is not None and self.group_info.has_data()))

                    def has_operation(self):
                        for c in self.source:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_host_exclude_mode.yfilter != YFilter.not_set or
                            self.is_router_exclude_mode.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group_info is not None and self.group_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "detail-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_host_exclude_mode.is_set or self.is_host_exclude_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_host_exclude_mode.get_name_leafdata())
                        if (self.is_router_exclude_mode.is_set or self.is_router_exclude_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_exclude_mode.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-info"):
                            if (self.group_info is None):
                                self.group_info = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                                self.group_info.parent = self
                                self._children_name_map["group_info"] = "group-info"
                            return self.group_info

                        if (child_yang_name == "source"):
                            for c in self.source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-info" or name == "source" or name == "group-address" or name == "interface-name" or name == "is-host-exclude-mode" or name == "is-router-exclude-mode" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-host-exclude-mode"):
                            self.is_host_exclude_mode = value
                            self.is_host_exclude_mode.value_namespace = name_space
                            self.is_host_exclude_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-exclude-mode"):
                            self.is_router_exclude_mode = value
                            self.is_router_exclude_mode.value_namespace = name_space
                            self.is_router_exclude_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.detail_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.detail_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "detail-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "detail-group"):
                        for c in self.detail_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.DetailGroups.DetailGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.detail_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "detail-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NonActiveGroups(Entity):
                """
                IGMP Non\-Active Groups Information
                
                .. attribute:: non_active_groups
                
                	List of non\-active groups
                	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.NonActiveGroups, self).__init__()

                    self.yang_name = "non-active-groups"
                    self.yang_parent_name = "default-context"

                    self.non_active_groups = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.NonActiveGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.NonActiveGroups, self).__setattr__(name, value)


                class NonActiveGroups(Entity):
                    """
                    List of non\-active groups
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress>`
                    
                    .. attribute:: interface
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**length:** 0..65
                    
                    .. attribute:: reason_for_non_activity
                    
                    	Reason for group join not being processed
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "non-active-groups"

                        self.interface = YLeaf(YType.str, "interface")

                        self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                        self.group_address = Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                        self.source_address = Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface",
                                        "reason_for_non_activity") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "non-active-groups"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/non-active-groups/non-active-groups/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "non-active-groups"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/non-active-groups/non-active-groups/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface.is_set or
                            self.reason_for_non_activity.is_set or
                            (self.group_address is not None and self.group_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface.yfilter != YFilter.not_set or
                            self.reason_for_non_activity.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "non-active-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/non-active-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface.get_name_leafdata())
                        if (self.reason_for_non_activity.is_set or self.reason_for_non_activity.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reason_for_non_activity.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "source-address" or name == "interface" or name == "reason-for-non-activity"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface"):
                            self.interface = value
                            self.interface.value_namespace = name_space
                            self.interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "reason-for-non-activity"):
                            self.reason_for_non_activity = value
                            self.reason_for_non_activity.value_namespace = name_space
                            self.reason_for_non_activity.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.non_active_groups:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.non_active_groups:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "non-active-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "non-active-groups"):
                        for c in self.non_active_groups:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.non_active_groups.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "non-active-groups"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SsmMaps(Entity):
                """
                SSM Map Table
                
                .. attribute:: ssm_map
                
                	SSM Map information
                	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMaps.SsmMap>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.SsmMaps, self).__init__()

                    self.yang_name = "ssm-maps"
                    self.yang_parent_name = "default-context"

                    self.ssm_map = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.SsmMaps, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.SsmMaps, self).__setattr__(name, value)


                class SsmMap(Entity):
                    """
                    SSM Map information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr>`
                    
                    .. attribute:: map_type
                    
                    	Map Type of group
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_counts
                    
                    	Count of Sources
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.SsmMaps.SsmMap, self).__init__()

                        self.yang_name = "ssm-map"
                        self.yang_parent_name = "ssm-maps"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.map_type = YLeaf(YType.uint32, "map-type")

                        self.source_counts = YLeaf(YType.uint32, "source-counts")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.group_address_xr = Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "map_type",
                                        "source_counts",
                                        "ssm_map_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.SsmMaps.SsmMap, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.SsmMaps.SsmMap, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "ssm-map"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-maps/ssm-map/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.map_type.is_set or
                            self.source_counts.is_set or
                            self.ssm_map_type.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.map_type.yfilter != YFilter.not_set or
                            self.source_counts.yfilter != YFilter.not_set or
                            self.ssm_map_type.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-maps/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.map_type.get_name_leafdata())
                        if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_counts.get_name_leafdata())
                        if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "group-address" or name == "map-type" or name == "source-counts" or name == "ssm-map-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "map-type"):
                            self.map_type = value
                            self.map_type.value_namespace = name_space
                            self.map_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-counts"):
                            self.source_counts = value
                            self.source_counts.value_namespace = name_space
                            self.source_counts.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssm-map-type"):
                            self.ssm_map_type = value
                            self.ssm_map_type.value_namespace = name_space
                            self.ssm_map_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ssm_map:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ssm_map:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ssm-maps" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ssm-map"):
                        for c in self.ssm_map:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.SsmMaps.SsmMap()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ssm_map.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ssm-map"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class ExplicitGroups(Entity):
                """
                IGMP Explicit Group Database
                
                .. attribute:: explicit_group
                
                	IGMP Explicit Group Entry Information
                	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.ExplicitGroups, self).__init__()

                    self.yang_name = "explicit-groups"
                    self.yang_parent_name = "default-context"

                    self.explicit_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.ExplicitGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.ExplicitGroups, self).__setattr__(name, value)


                class ExplicitGroup(Entity):
                    """
                    IGMP Explicit Group Entry Information
                    
                    .. attribute:: exclude_hosts
                    
                    	No. of hosts who are excluded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo>`
                    
                    .. attribute:: host
                    
                    	List of hosts
                    	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host>`
                    
                    .. attribute:: include_hosts
                    
                    	No. of hosts who are included
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup, self).__init__()

                        self.yang_name = "explicit-group"
                        self.yang_parent_name = "explicit-groups"

                        self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.host = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("exclude_hosts",
                                        "group_address",
                                        "include_hosts",
                                        "interface_name",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "explicit-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix


                    class Host(Entity):
                        """
                        List of hosts
                        
                        .. attribute:: address
                        
                        	Host Address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address>`
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: is_exclude
                        
                        	Exclude flag set
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	First 3 source addresses
                        	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                        
                        .. attribute:: source_count
                        
                        	No. of sources in entry
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "explicit-group"

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                            self.source_count = YLeaf(YType.uint32, "source-count")

                            self.uptime = YLeaf(YType.uint32, "uptime")

                            self.address = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.source_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "is_exclude",
                                            "source_count",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            Host Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "host"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/host/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            First 3 source addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "host"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/host/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.source_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.expiration_time.is_set or
                                self.is_exclude.is_set or
                                self.source_count.is_set or
                                self.uptime.is_set or
                                (self.address is not None and self.address.has_data()))

                        def has_operation(self):
                            for c in self.source_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.is_exclude.yfilter != YFilter.not_set or
                                self.source_count.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "host" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.is_exclude.is_set or self.is_exclude.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_exclude.get_name_leafdata())
                            if (self.source_count.is_set or self.source_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_count.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "source-address"):
                                for c in self.source_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.source_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "source-address" or name == "expiration-time" or name == "is-exclude" or name == "source-count" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-exclude"):
                                self.is_exclude = value
                                self.is_exclude.value_namespace = name_space
                                self.is_exclude.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-count"):
                                self.source_count = value
                                self.source_count.value_namespace = name_space
                                self.source_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.host:
                            if (c.has_data()):
                                return True
                        return (
                            self.exclude_hosts.is_set or
                            self.group_address.is_set or
                            self.include_hosts.is_set or
                            self.interface_name.is_set or
                            self.source_address.is_set or
                            (self.group_info is not None and self.group_info.has_data()))

                    def has_operation(self):
                        for c in self.host:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.exclude_hosts.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.include_hosts.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group_info is not None and self.group_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "explicit-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.exclude_hosts.is_set or self.exclude_hosts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.exclude_hosts.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.include_hosts.is_set or self.include_hosts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.include_hosts.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-info"):
                            if (self.group_info is None):
                                self.group_info = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                                self.group_info.parent = self
                                self._children_name_map["group_info"] = "group-info"
                            return self.group_info

                        if (child_yang_name == "host"):
                            for c in self.host:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.host.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-info" or name == "host" or name == "exclude-hosts" or name == "group-address" or name == "include-hosts" or name == "interface-name" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "exclude-hosts"):
                            self.exclude_hosts = value
                            self.exclude_hosts.value_namespace = name_space
                            self.exclude_hosts.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "include-hosts"):
                            self.include_hosts = value
                            self.include_hosts.value_namespace = name_space
                            self.include_hosts.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.explicit_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.explicit_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "explicit-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "explicit-group"):
                        for c in self.explicit_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.explicit_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "explicit-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceTable(Entity):
                """
                IGMP Interface specific Table
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.InterfaceTable, self).__init__()

                    self.yang_name = "interface-table"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.InterfaceTable, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.InterfaceTable, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.InterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interface-table"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Standby.DefaultContext.InterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.InterfaceTable.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.InterfaceTable.Interface, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.InterfaceTable.Interface.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.InterfaceTable.Interface.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/interface-table/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Mld.Standby.DefaultContext.InterfaceTable.Interface.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.InterfaceTable.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceUnicastQosAdjusts(Entity):
                """
                IGMP Interface Unicast\-Qos\-Adjust
                
                .. attribute:: interface_unicast_qos_adjust
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts, self).__init__()

                    self.yang_name = "interface-unicast-qos-adjusts"
                    self.yang_parent_name = "default-context"

                    self.interface_unicast_qos_adjust = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)


                class InterfaceUnicastQosAdjust(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_virtual_access
                    
                    	Is VirtualAccess Interface
                    	**type**\:  bool
                    
                    .. attribute:: rate
                    
                    	Overall rate in Kbps
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: rate_decrements
                    
                    	Count of rate decrements
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rate_increments
                    
                    	Count of rate increments
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update
                    
                    	List of updates
                    	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjust"
                        self.yang_parent_name = "interface-unicast-qos-adjusts"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                        self.rate = YLeaf(YType.uint32, "rate")

                        self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                        self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                        self.update = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_virtual_access",
                                        "rate",
                                        "rate_decrements",
                                        "rate_increments") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)


                    class Update(Entity):
                        """
                        List of updates
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                        
                        .. attribute:: is_add
                        
                        	Is this a rate increment
                        	**type**\:  bool
                        
                        .. attribute:: received_time
                        
                        	Time this update is received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                        
                        .. attribute:: weight
                        
                        	Weight from policy
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                            self.yang_name = "update"
                            self.yang_parent_name = "interface-unicast-qos-adjust"

                            self.is_add = YLeaf(YType.boolean, "is-add")

                            self.received_time = YLeaf(YType.uint64, "received-time")

                            self.weight = YLeaf(YType.uint32, "weight")

                            self.group_address = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("is_add",
                                            "received_time",
                                            "weight") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "update"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddress(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "update"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.is_add.is_set or
                                self.received_time.is_set or
                                self.weight.is_set or
                                (self.group_address is not None and self.group_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.is_add.yfilter != YFilter.not_set or
                                self.received_time.yfilter != YFilter.not_set or
                                self.weight.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "update" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_add.is_set or self.is_add.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_add.get_name_leafdata())
                            if (self.received_time.is_set or self.received_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_time.get_name_leafdata())
                            if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.weight.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "source-address" or name == "is-add" or name == "received-time" or name == "weight"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "is-add"):
                                self.is_add = value
                                self.is_add.value_namespace = name_space
                                self.is_add.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-time"):
                                self.received_time = value
                                self.received_time.value_namespace = name_space
                                self.received_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "weight"):
                                self.weight = value
                                self.weight.value_namespace = name_space
                                self.weight.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.update:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.is_virtual_access.is_set or
                            self.rate.is_set or
                            self.rate_decrements.is_set or
                            self.rate_increments.is_set)

                    def has_operation(self):
                        for c in self.update:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_virtual_access.yfilter != YFilter.not_set or
                            self.rate.yfilter != YFilter.not_set or
                            self.rate_decrements.yfilter != YFilter.not_set or
                            self.rate_increments.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/interface-unicast-qos-adjusts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_virtual_access.is_set or self.is_virtual_access.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_virtual_access.get_name_leafdata())
                        if (self.rate.is_set or self.rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate.get_name_leafdata())
                        if (self.rate_decrements.is_set or self.rate_decrements.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate_decrements.get_name_leafdata())
                        if (self.rate_increments.is_set or self.rate_increments.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate_increments.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "update"):
                            for c in self.update:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.update.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "update" or name == "interface-name" or name == "is-virtual-access" or name == "rate" or name == "rate-decrements" or name == "rate-increments"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-virtual-access"):
                            self.is_virtual_access = value
                            self.is_virtual_access.value_namespace = name_space
                            self.is_virtual_access.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate"):
                            self.rate = value
                            self.rate.value_namespace = name_space
                            self.rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate-decrements"):
                            self.rate_decrements = value
                            self.rate_decrements.value_namespace = name_space
                            self.rate_decrements.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate-increments"):
                            self.rate_increments = value
                            self.rate_increments.value_namespace = name_space
                            self.rate_increments.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_unicast_qos_adjust:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_unicast_qos_adjust:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-unicast-qos-adjusts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-unicast-qos-adjust"):
                        for c in self.interface_unicast_qos_adjust:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_unicast_qos_adjust.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-unicast-qos-adjust"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Ranges(Entity):
                """
                Range table
                
                .. attribute:: range
                
                	Range information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"

                    self.range = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.Ranges, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.Ranges, self).__setattr__(name, value)


                class Range(Entity):
                    """
                    Range information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr>`
                    
                    .. attribute:: group_mask
                    
                    	Group Mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: is_stale
                    
                    	Is the entry stale
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.group_mask = YLeaf(YType.int32, "group-mask")

                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.group_address_xr = Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "group_mask",
                                        "is_stale",
                                        "prefix_length",
                                        "protocol") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.Ranges.Range, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.Ranges.Range, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.group_mask.is_set or
                            self.is_stale.is_set or
                            self.prefix_length.is_set or
                            self.protocol.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.group_mask.yfilter != YFilter.not_set or
                            self.is_stale.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ranges/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.group_mask.is_set or self.group_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_mask.get_name_leafdata())
                        if (self.is_stale.is_set or self.is_stale.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_stale.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "group-address" or name == "group-mask" or name == "is-stale" or name == "prefix-length" or name == "protocol"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-mask"):
                            self.group_mask = value
                            self.group_mask.value_namespace = name_space
                            self.group_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-stale"):
                            self.is_stale = value
                            self.is_stale.value_namespace = name_space
                            self.is_stale.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.range:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.range:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ranges" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "range"):
                        for c in self.range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.Ranges.Range()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.range.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "range"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsInterfaces(Entity):
                """
                IGMP Interface specific
                
                .. attribute:: ifrs_interface
                
                	IGMP IFRS Interface
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"

                    self.ifrs_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)


                class IfrsInterface(Entity):
                    """
                    IGMP IFRS Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	IFRS Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: igmp_interface_entry
                    
                    	IGMP interface entry
                    	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                    
                    .. attribute:: join_group_count
                    
                    	Join group count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                        self.igmp_interface_entry = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                        self.igmp_interface_entry.parent = self
                        self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                        self._children_yang_names.add("igmp-interface-entry")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "join_group_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                    class IgmpInterfaceEntry(Entity):
                        """
                        IGMP interface entry
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                            self.yang_name = "igmp-interface-entry"
                            self.yang_parent_name = "ifrs-interface"

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "igmp-interface-entry" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.join_group_count.is_set or
                            (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.join_group_count.yfilter != YFilter.not_set or
                            (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ifrs-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.join_group_count.is_set or self.join_group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_group_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "igmp-interface-entry"):
                            if (self.igmp_interface_entry is None):
                                self.igmp_interface_entry = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                                self.igmp_interface_entry.parent = self
                                self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            return self.igmp_interface_entry

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "igmp-interface-entry" or name == "interface-name" or name == "join-group-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-group-count"):
                            self.join_group_count = value
                            self.join_group_count.value_namespace = name_space
                            self.join_group_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ifrs_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ifrs_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ifrs-interface"):
                        for c in self.ifrs_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ifrs_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ifrs-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TrafficCounters(Entity):
                """
                IGMP Message Traffic Counters
                
                .. attribute:: auxillary_data_length_errors
                
                	AuxDataLen errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bad_scope_errors
                
                	BadScope errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_errors
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_errors
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: get_packet_failure
                
                	Packet get failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_disabled_idb
                
                	Packet received on disabled idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_dvmrp
                
                	DVMRP packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_leaves
                
                	Leaves in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_martian_address
                
                	Packets received with Martian Address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_mtrace
                
                	Mtrace packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_assigned_vrf_id
                
                	Packets received with no assigned vrf id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb
                
                	Packets received without idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_platform_support_mtrace
                
                	mtrace packets without platform support
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_in_idb
                
                	Packets received on idb without VRF
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_mtrace
                
                	mtrace packets with no vrf associated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim
                
                	PIM packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_queries
                
                	Query packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_reports
                
                	Reports in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_address_errors
                
                	Invalid Source Address errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: miscellaneous_errors
                
                	Packets dropped for other reasons
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_dvmrp
                
                	DVMRP packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_leaves
                
                	Leaves out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_mtrace
                
                	Mtrace packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_no_parent_interface_handle
                
                	Failures setting 2nd ifhandle
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_pim
                
                	PIM packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_queries
                
                	Query packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_reports
                
                	Reports out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_input_errors
                
                	Incoming Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_output_errors
                
                	Outgoing Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_in
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_out
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_socket_errors
                
                	Socket errors on reception
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_errors
                
                	Socket errors on send
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"

                    self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                    self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                    self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_errors = YLeaf(YType.uint32, "format-errors")

                    self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                    self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                    self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                    self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                    self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                    self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                    self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                    self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                    self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                    self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                    self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                    self.input_pim = YLeaf(YType.uint32, "input-pim")

                    self.input_queries = YLeaf(YType.uint32, "input-queries")

                    self.input_reports = YLeaf(YType.uint32, "input-reports")

                    self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                    self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                    self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                    self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                    self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                    self.output_pim = YLeaf(YType.uint32, "output-pim")

                    self.output_queries = YLeaf(YType.uint32, "output-queries")

                    self.output_reports = YLeaf(YType.uint32, "output-reports")

                    self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                    self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                    self.packets_in = YLeaf(YType.uint32, "packets-in")

                    self.packets_out = YLeaf(YType.uint32, "packets-out")

                    self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                    self.socket_errors = YLeaf(YType.uint32, "socket-errors")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("auxillary_data_length_errors",
                                    "bad_scope_errors",
                                    "checksum_errors",
                                    "elapsed_time",
                                    "format_errors",
                                    "get_packet_failure",
                                    "input_disabled_idb",
                                    "input_dvmrp",
                                    "input_leaves",
                                    "input_martian_address",
                                    "input_mtrace",
                                    "input_no_assigned_vrf_id",
                                    "input_no_idb",
                                    "input_no_platform_support_mtrace",
                                    "input_no_vrf_in_idb",
                                    "input_no_vrf_mtrace",
                                    "input_pim",
                                    "input_queries",
                                    "input_reports",
                                    "invalid_source_address_errors",
                                    "miscellaneous_errors",
                                    "no_socket_connection",
                                    "output_dvmrp",
                                    "output_leaves",
                                    "output_mtrace",
                                    "output_no_parent_interface_handle",
                                    "output_pim",
                                    "output_queries",
                                    "output_reports",
                                    "packet_manager_input_errors",
                                    "packet_manager_output_errors",
                                    "packets_in",
                                    "packets_out",
                                    "receive_socket_errors",
                                    "socket_errors") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.TrafficCounters, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.TrafficCounters, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.auxillary_data_length_errors.is_set or
                        self.bad_scope_errors.is_set or
                        self.checksum_errors.is_set or
                        self.elapsed_time.is_set or
                        self.format_errors.is_set or
                        self.get_packet_failure.is_set or
                        self.input_disabled_idb.is_set or
                        self.input_dvmrp.is_set or
                        self.input_leaves.is_set or
                        self.input_martian_address.is_set or
                        self.input_mtrace.is_set or
                        self.input_no_assigned_vrf_id.is_set or
                        self.input_no_idb.is_set or
                        self.input_no_platform_support_mtrace.is_set or
                        self.input_no_vrf_in_idb.is_set or
                        self.input_no_vrf_mtrace.is_set or
                        self.input_pim.is_set or
                        self.input_queries.is_set or
                        self.input_reports.is_set or
                        self.invalid_source_address_errors.is_set or
                        self.miscellaneous_errors.is_set or
                        self.no_socket_connection.is_set or
                        self.output_dvmrp.is_set or
                        self.output_leaves.is_set or
                        self.output_mtrace.is_set or
                        self.output_no_parent_interface_handle.is_set or
                        self.output_pim.is_set or
                        self.output_queries.is_set or
                        self.output_reports.is_set or
                        self.packet_manager_input_errors.is_set or
                        self.packet_manager_output_errors.is_set or
                        self.packets_in.is_set or
                        self.packets_out.is_set or
                        self.receive_socket_errors.is_set or
                        self.socket_errors.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.auxillary_data_length_errors.yfilter != YFilter.not_set or
                        self.bad_scope_errors.yfilter != YFilter.not_set or
                        self.checksum_errors.yfilter != YFilter.not_set or
                        self.elapsed_time.yfilter != YFilter.not_set or
                        self.format_errors.yfilter != YFilter.not_set or
                        self.get_packet_failure.yfilter != YFilter.not_set or
                        self.input_disabled_idb.yfilter != YFilter.not_set or
                        self.input_dvmrp.yfilter != YFilter.not_set or
                        self.input_leaves.yfilter != YFilter.not_set or
                        self.input_martian_address.yfilter != YFilter.not_set or
                        self.input_mtrace.yfilter != YFilter.not_set or
                        self.input_no_assigned_vrf_id.yfilter != YFilter.not_set or
                        self.input_no_idb.yfilter != YFilter.not_set or
                        self.input_no_platform_support_mtrace.yfilter != YFilter.not_set or
                        self.input_no_vrf_in_idb.yfilter != YFilter.not_set or
                        self.input_no_vrf_mtrace.yfilter != YFilter.not_set or
                        self.input_pim.yfilter != YFilter.not_set or
                        self.input_queries.yfilter != YFilter.not_set or
                        self.input_reports.yfilter != YFilter.not_set or
                        self.invalid_source_address_errors.yfilter != YFilter.not_set or
                        self.miscellaneous_errors.yfilter != YFilter.not_set or
                        self.no_socket_connection.yfilter != YFilter.not_set or
                        self.output_dvmrp.yfilter != YFilter.not_set or
                        self.output_leaves.yfilter != YFilter.not_set or
                        self.output_mtrace.yfilter != YFilter.not_set or
                        self.output_no_parent_interface_handle.yfilter != YFilter.not_set or
                        self.output_pim.yfilter != YFilter.not_set or
                        self.output_queries.yfilter != YFilter.not_set or
                        self.output_reports.yfilter != YFilter.not_set or
                        self.packet_manager_input_errors.yfilter != YFilter.not_set or
                        self.packet_manager_output_errors.yfilter != YFilter.not_set or
                        self.packets_in.yfilter != YFilter.not_set or
                        self.packets_out.yfilter != YFilter.not_set or
                        self.receive_socket_errors.yfilter != YFilter.not_set or
                        self.socket_errors.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-counters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.auxillary_data_length_errors.is_set or self.auxillary_data_length_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.auxillary_data_length_errors.get_name_leafdata())
                    if (self.bad_scope_errors.is_set or self.bad_scope_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bad_scope_errors.get_name_leafdata())
                    if (self.checksum_errors.is_set or self.checksum_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checksum_errors.get_name_leafdata())
                    if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                    if (self.format_errors.is_set or self.format_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.format_errors.get_name_leafdata())
                    if (self.get_packet_failure.is_set or self.get_packet_failure.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.get_packet_failure.get_name_leafdata())
                    if (self.input_disabled_idb.is_set or self.input_disabled_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_disabled_idb.get_name_leafdata())
                    if (self.input_dvmrp.is_set or self.input_dvmrp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_dvmrp.get_name_leafdata())
                    if (self.input_leaves.is_set or self.input_leaves.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_leaves.get_name_leafdata())
                    if (self.input_martian_address.is_set or self.input_martian_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_martian_address.get_name_leafdata())
                    if (self.input_mtrace.is_set or self.input_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_mtrace.get_name_leafdata())
                    if (self.input_no_assigned_vrf_id.is_set or self.input_no_assigned_vrf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_assigned_vrf_id.get_name_leafdata())
                    if (self.input_no_idb.is_set or self.input_no_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_idb.get_name_leafdata())
                    if (self.input_no_platform_support_mtrace.is_set or self.input_no_platform_support_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_platform_support_mtrace.get_name_leafdata())
                    if (self.input_no_vrf_in_idb.is_set or self.input_no_vrf_in_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_in_idb.get_name_leafdata())
                    if (self.input_no_vrf_mtrace.is_set or self.input_no_vrf_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_mtrace.get_name_leafdata())
                    if (self.input_pim.is_set or self.input_pim.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_pim.get_name_leafdata())
                    if (self.input_queries.is_set or self.input_queries.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_queries.get_name_leafdata())
                    if (self.input_reports.is_set or self.input_reports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_reports.get_name_leafdata())
                    if (self.invalid_source_address_errors.is_set or self.invalid_source_address_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_source_address_errors.get_name_leafdata())
                    if (self.miscellaneous_errors.is_set or self.miscellaneous_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.miscellaneous_errors.get_name_leafdata())
                    if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                    if (self.output_dvmrp.is_set or self.output_dvmrp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_dvmrp.get_name_leafdata())
                    if (self.output_leaves.is_set or self.output_leaves.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_leaves.get_name_leafdata())
                    if (self.output_mtrace.is_set or self.output_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_mtrace.get_name_leafdata())
                    if (self.output_no_parent_interface_handle.is_set or self.output_no_parent_interface_handle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_no_parent_interface_handle.get_name_leafdata())
                    if (self.output_pim.is_set or self.output_pim.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_pim.get_name_leafdata())
                    if (self.output_queries.is_set or self.output_queries.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_queries.get_name_leafdata())
                    if (self.output_reports.is_set or self.output_reports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_reports.get_name_leafdata())
                    if (self.packet_manager_input_errors.is_set or self.packet_manager_input_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_manager_input_errors.get_name_leafdata())
                    if (self.packet_manager_output_errors.is_set or self.packet_manager_output_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_manager_output_errors.get_name_leafdata())
                    if (self.packets_in.is_set or self.packets_in.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_in.get_name_leafdata())
                    if (self.packets_out.is_set or self.packets_out.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_out.get_name_leafdata())
                    if (self.receive_socket_errors.is_set or self.receive_socket_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.receive_socket_errors.get_name_leafdata())
                    if (self.socket_errors.is_set or self.socket_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.socket_errors.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auxillary-data-length-errors" or name == "bad-scope-errors" or name == "checksum-errors" or name == "elapsed-time" or name == "format-errors" or name == "get-packet-failure" or name == "input-disabled-idb" or name == "input-dvmrp" or name == "input-leaves" or name == "input-martian-address" or name == "input-mtrace" or name == "input-no-assigned-vrf-id" or name == "input-no-idb" or name == "input-no-platform-support-mtrace" or name == "input-no-vrf-in-idb" or name == "input-no-vrf-mtrace" or name == "input-pim" or name == "input-queries" or name == "input-reports" or name == "invalid-source-address-errors" or name == "miscellaneous-errors" or name == "no-socket-connection" or name == "output-dvmrp" or name == "output-leaves" or name == "output-mtrace" or name == "output-no-parent-interface-handle" or name == "output-pim" or name == "output-queries" or name == "output-reports" or name == "packet-manager-input-errors" or name == "packet-manager-output-errors" or name == "packets-in" or name == "packets-out" or name == "receive-socket-errors" or name == "socket-errors"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "auxillary-data-length-errors"):
                        self.auxillary_data_length_errors = value
                        self.auxillary_data_length_errors.value_namespace = name_space
                        self.auxillary_data_length_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "bad-scope-errors"):
                        self.bad_scope_errors = value
                        self.bad_scope_errors.value_namespace = name_space
                        self.bad_scope_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "checksum-errors"):
                        self.checksum_errors = value
                        self.checksum_errors.value_namespace = name_space
                        self.checksum_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "elapsed-time"):
                        self.elapsed_time = value
                        self.elapsed_time.value_namespace = name_space
                        self.elapsed_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "format-errors"):
                        self.format_errors = value
                        self.format_errors.value_namespace = name_space
                        self.format_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "get-packet-failure"):
                        self.get_packet_failure = value
                        self.get_packet_failure.value_namespace = name_space
                        self.get_packet_failure.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-disabled-idb"):
                        self.input_disabled_idb = value
                        self.input_disabled_idb.value_namespace = name_space
                        self.input_disabled_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-dvmrp"):
                        self.input_dvmrp = value
                        self.input_dvmrp.value_namespace = name_space
                        self.input_dvmrp.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-leaves"):
                        self.input_leaves = value
                        self.input_leaves.value_namespace = name_space
                        self.input_leaves.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-martian-address"):
                        self.input_martian_address = value
                        self.input_martian_address.value_namespace = name_space
                        self.input_martian_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-mtrace"):
                        self.input_mtrace = value
                        self.input_mtrace.value_namespace = name_space
                        self.input_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-assigned-vrf-id"):
                        self.input_no_assigned_vrf_id = value
                        self.input_no_assigned_vrf_id.value_namespace = name_space
                        self.input_no_assigned_vrf_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-idb"):
                        self.input_no_idb = value
                        self.input_no_idb.value_namespace = name_space
                        self.input_no_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-platform-support-mtrace"):
                        self.input_no_platform_support_mtrace = value
                        self.input_no_platform_support_mtrace.value_namespace = name_space
                        self.input_no_platform_support_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-in-idb"):
                        self.input_no_vrf_in_idb = value
                        self.input_no_vrf_in_idb.value_namespace = name_space
                        self.input_no_vrf_in_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-mtrace"):
                        self.input_no_vrf_mtrace = value
                        self.input_no_vrf_mtrace.value_namespace = name_space
                        self.input_no_vrf_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-pim"):
                        self.input_pim = value
                        self.input_pim.value_namespace = name_space
                        self.input_pim.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-queries"):
                        self.input_queries = value
                        self.input_queries.value_namespace = name_space
                        self.input_queries.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-reports"):
                        self.input_reports = value
                        self.input_reports.value_namespace = name_space
                        self.input_reports.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-source-address-errors"):
                        self.invalid_source_address_errors = value
                        self.invalid_source_address_errors.value_namespace = name_space
                        self.invalid_source_address_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "miscellaneous-errors"):
                        self.miscellaneous_errors = value
                        self.miscellaneous_errors.value_namespace = name_space
                        self.miscellaneous_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-socket-connection"):
                        self.no_socket_connection = value
                        self.no_socket_connection.value_namespace = name_space
                        self.no_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-dvmrp"):
                        self.output_dvmrp = value
                        self.output_dvmrp.value_namespace = name_space
                        self.output_dvmrp.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-leaves"):
                        self.output_leaves = value
                        self.output_leaves.value_namespace = name_space
                        self.output_leaves.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-mtrace"):
                        self.output_mtrace = value
                        self.output_mtrace.value_namespace = name_space
                        self.output_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-no-parent-interface-handle"):
                        self.output_no_parent_interface_handle = value
                        self.output_no_parent_interface_handle.value_namespace = name_space
                        self.output_no_parent_interface_handle.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-pim"):
                        self.output_pim = value
                        self.output_pim.value_namespace = name_space
                        self.output_pim.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-queries"):
                        self.output_queries = value
                        self.output_queries.value_namespace = name_space
                        self.output_queries.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-reports"):
                        self.output_reports = value
                        self.output_reports.value_namespace = name_space
                        self.output_reports.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-manager-input-errors"):
                        self.packet_manager_input_errors = value
                        self.packet_manager_input_errors.value_namespace = name_space
                        self.packet_manager_input_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-manager-output-errors"):
                        self.packet_manager_output_errors = value
                        self.packet_manager_output_errors.value_namespace = name_space
                        self.packet_manager_output_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "packets-in"):
                        self.packets_in = value
                        self.packets_in.value_namespace = name_space
                        self.packets_in.value_namespace_prefix = name_space_prefix
                    if(value_path == "packets-out"):
                        self.packets_out = value
                        self.packets_out.value_namespace = name_space
                        self.packets_out.value_namespace_prefix = name_space_prefix
                    if(value_path == "receive-socket-errors"):
                        self.receive_socket_errors = value
                        self.receive_socket_errors.value_namespace = name_space
                        self.receive_socket_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "socket-errors"):
                        self.socket_errors = value
                        self.socket_errors.value_namespace = name_space
                        self.socket_errors.value_namespace_prefix = name_space_prefix


            class Groups(Entity):
                """
                IGMP Group Database Table
                
                .. attribute:: group
                
                	IGMP Group Entry Information
                	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Groups.Group>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.Groups, self).__init__()

                    self.yang_name = "groups"
                    self.yang_parent_name = "default-context"

                    self.group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.Groups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.Groups, self).__setattr__(name, value)


                class Group(Entity):
                    """
                    IGMP Group Entry Information
                    
                    .. attribute:: expiration_time
                    
                    	Expiration time in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: explicit_tracking_enabled
                    
                    	Is explicit tracking enabled
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_added
                    
                    	Joined
                    	**type**\:  bool
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: is_self_join
                    
                    	If local system is member of this group on this interface
                    	**type**\:  bool
                    
                    .. attribute:: is_suppressed
                    
                    	Suppressed
                    	**type**\:  bool
                    
                    .. attribute:: last_reporter
                    
                    	Last reporter address
                    	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Groups.Group.LastReporter>`
                    
                    .. attribute:: older_host_version1_timer
                    
                    	IGMP Hostversion1timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: older_host_version2_timer
                    
                    	IGMP Hostversion2timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_filter_mode
                    
                    	Filter mode
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: row_status
                    
                    	interface on or off for the group
                    	**type**\:  str
                    
                    	**length:** 0..16
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Groups.Group.SourceAddress>`
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.Groups.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "groups"

                        self.expiration_time = YLeaf(YType.int32, "expiration-time")

                        self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_added = YLeaf(YType.boolean, "is-added")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                        self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                        self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                        self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                        self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                        self.row_status = YLeaf(YType.str, "row-status")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.last_reporter = Mld.Standby.DefaultContext.Groups.Group.LastReporter()
                        self.last_reporter.parent = self
                        self._children_name_map["last_reporter"] = "last-reporter"
                        self._children_yang_names.add("last-reporter")

                        self.source_address = Mld.Standby.DefaultContext.Groups.Group.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("expiration_time",
                                        "explicit_tracking_enabled",
                                        "group_address",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_added",
                                        "is_low_memory",
                                        "is_self_join",
                                        "is_suppressed",
                                        "older_host_version1_timer",
                                        "older_host_version2_timer",
                                        "router_filter_mode",
                                        "row_status",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.Groups.Group, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.Groups.Group, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class LastReporter(Entity):
                        """
                        Last reporter address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.Groups.Group.LastReporter, self).__init__()

                            self.yang_name = "last-reporter"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.Groups.Group.LastReporter, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.Groups.Group.LastReporter, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "last-reporter" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.Groups.Group.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.Groups.Group.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.Groups.Group.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.expiration_time.is_set or
                            self.explicit_tracking_enabled.is_set or
                            self.group_address.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_added.is_set or
                            self.is_low_memory.is_set or
                            self.is_self_join.is_set or
                            self.is_suppressed.is_set or
                            self.older_host_version1_timer.is_set or
                            self.older_host_version2_timer.is_set or
                            self.router_filter_mode.is_set or
                            self.row_status.is_set or
                            self.uptime.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.last_reporter is not None and self.last_reporter.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.expiration_time.yfilter != YFilter.not_set or
                            self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_added.yfilter != YFilter.not_set or
                            self.is_low_memory.yfilter != YFilter.not_set or
                            self.is_self_join.yfilter != YFilter.not_set or
                            self.is_suppressed.yfilter != YFilter.not_set or
                            self.older_host_version1_timer.yfilter != YFilter.not_set or
                            self.older_host_version2_timer.yfilter != YFilter.not_set or
                            self.router_filter_mode.yfilter != YFilter.not_set or
                            self.row_status.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.last_reporter is not None and self.last_reporter.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiration_time.get_name_leafdata())
                        if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_added.get_name_leafdata())
                        if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                        if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_self_join.get_name_leafdata())
                        if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                        if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                        if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                        if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                        if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.row_status.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "last-reporter"):
                            if (self.last_reporter is None):
                                self.last_reporter = Mld.Standby.DefaultContext.Groups.Group.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                            return self.last_reporter

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Mld.Standby.DefaultContext.Groups.Group.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "group-address" or name == "interface-name" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "expiration-time"):
                            self.expiration_time = value
                            self.expiration_time.value_namespace = name_space
                            self.expiration_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "explicit-tracking-enabled"):
                            self.explicit_tracking_enabled = value
                            self.explicit_tracking_enabled.value_namespace = name_space
                            self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-added"):
                            self.is_added = value
                            self.is_added.value_namespace = name_space
                            self.is_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-low-memory"):
                            self.is_low_memory = value
                            self.is_low_memory.value_namespace = name_space
                            self.is_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-self-join"):
                            self.is_self_join = value
                            self.is_self_join.value_namespace = name_space
                            self.is_self_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-suppressed"):
                            self.is_suppressed = value
                            self.is_suppressed.value_namespace = name_space
                            self.is_suppressed.value_namespace_prefix = name_space_prefix
                        if(value_path == "older-host-version1-timer"):
                            self.older_host_version1_timer = value
                            self.older_host_version1_timer.value_namespace = name_space
                            self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "older-host-version2-timer"):
                            self.older_host_version2_timer = value
                            self.older_host_version2_timer.value_namespace = name_space
                            self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-filter-mode"):
                            self.router_filter_mode = value
                            self.router_filter_mode.value_namespace = name_space
                            self.router_filter_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "row-status"):
                            self.row_status = value
                            self.row_status.value_namespace = name_space
                            self.row_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group"):
                        for c in self.group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.Groups.Group()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupSummary(Entity):
                """
                IGMP Groups Summary
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groutes
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_low_memory
                
                	Node is running low on memory
                	**type**\:  bool
                
                .. attribute:: sg_routes
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.GroupSummary, self).__init__()

                    self.yang_name = "group-summary"
                    self.yang_parent_name = "default-context"

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.groutes = YLeaf(YType.uint32, "groutes")

                    self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                    self.sg_routes = YLeaf(YType.uint32, "sg-routes")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_count",
                                    "groutes",
                                    "is_low_memory",
                                    "sg_routes") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.GroupSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.GroupSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.group_count.is_set or
                        self.groutes.is_set or
                        self.is_low_memory.is_set or
                        self.sg_routes.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_count.yfilter != YFilter.not_set or
                        self.groutes.yfilter != YFilter.not_set or
                        self.is_low_memory.yfilter != YFilter.not_set or
                        self.sg_routes.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_count.get_name_leafdata())
                    if (self.groutes.is_set or self.groutes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.groutes.get_name_leafdata())
                    if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                    if (self.sg_routes.is_set or self.sg_routes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_routes.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-count" or name == "groutes" or name == "is-low-memory" or name == "sg-routes"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-count"):
                        self.group_count = value
                        self.group_count.value_namespace = name_space
                        self.group_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "groutes"):
                        self.groutes = value
                        self.groutes.value_namespace = name_space
                        self.groutes.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-low-memory"):
                        self.is_low_memory = value
                        self.is_low_memory.value_namespace = name_space
                        self.is_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-routes"):
                        self.sg_routes = value
                        self.sg_routes.value_namespace = name_space
                        self.sg_routes.value_namespace_prefix = name_space_prefix


            class IfrsInterfaceSummary(Entity):
                """
                IGMP IFRS Interface summary
                
                .. attribute:: configuration_count
                
                	Configuration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Interface Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.IfrsInterfaceSummary, self).__init__()

                    self.yang_name = "ifrs-interface-summary"
                    self.yang_parent_name = "default-context"

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configuration_count",
                                    "interface_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.IfrsInterfaceSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.IfrsInterfaceSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configuration_count.is_set or
                        self.interface_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configuration_count.yfilter != YFilter.not_set or
                        self.interface_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interface-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configuration_count.get_name_leafdata())
                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configuration-count" or name == "interface-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configuration-count"):
                        self.configuration_count = value
                        self.configuration_count.value_namespace = name_space
                        self.configuration_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-count"):
                        self.interface_count = value
                        self.interface_count.value_namespace = name_space
                        self.interface_count.value_namespace_prefix = name_space_prefix


            class GlobalInterfaceTable(Entity):
                """
                IGMP Global Interface 
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.GlobalInterfaceTable, self).__init__()

                    self.yang_name = "global-interface-table"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.GlobalInterfaceTable, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.GlobalInterfaceTable, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "global-interface-table"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/global-interface-table/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-interface-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SsmMapDetails(Entity):
                """
                SSM Map Detail
                
                .. attribute:: ssm_map_detail
                
                	SSM Map Detail Table information
                	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.SsmMapDetails, self).__init__()

                    self.yang_name = "ssm-map-details"
                    self.yang_parent_name = "default-context"

                    self.ssm_map_detail = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.SsmMapDetails, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.SsmMapDetails, self).__setattr__(name, value)


                class SsmMapDetail(Entity):
                    """
                    SSM Map Detail Table information
                    
                    .. attribute:: elapsed_time
                    
                    	Elapsed time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: expiration_time
                    
                    	Expiration Time in Seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: map_info
                    
                    	Basic Map Info
                    	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo>`
                    
                    .. attribute:: query_interval
                    
                    	Query interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response_pending
                    
                    	Response Pending
                    	**type**\:  bool
                    
                    .. attribute:: sources
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources>`
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail, self).__init__()

                        self.yang_name = "ssm-map-detail"
                        self.yang_parent_name = "ssm-map-details"

                        self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                        self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.query_interval = YLeaf(YType.uint32, "query-interval")

                        self.response_pending = YLeaf(YType.boolean, "response-pending")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.map_info = Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                        self.map_info.parent = self
                        self._children_name_map["map_info"] = "map-info"
                        self._children_yang_names.add("map-info")

                        self.sources = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("elapsed_time",
                                        "expiration_time",
                                        "group_address",
                                        "query_interval",
                                        "response_pending",
                                        "ssm_map_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)


                    class MapInfo(Entity):
                        """
                        Basic Map Info
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                            self.yang_name = "map-info"
                            self.yang_parent_name = "ssm-map-detail"

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.group_address_xr = Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("map_type",
                                            "source_counts") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "map-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-map-details/ssm-map-detail/map-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.map_type.is_set or
                                self.source_counts.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.map_type.yfilter != YFilter.not_set or
                                self.source_counts.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "map-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-map-details/ssm-map-detail/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.map_type.get_name_leafdata())
                            if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_counts.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "map-type" or name == "source-counts"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "map-type"):
                                self.map_type = value
                                self.map_type.value_namespace = name_space
                                self.map_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-counts"):
                                self.source_counts = value
                                self.source_counts.value_namespace = name_space
                                self.source_counts.value_namespace_prefix = name_space_prefix


                    class Sources(Entity):
                        """
                        List of sources
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                            self.yang_name = "sources"
                            self.yang_parent_name = "ssm-map-detail"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sources" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-map-details/ssm-map-detail/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.sources:
                            if (c.has_data()):
                                return True
                        return (
                            self.elapsed_time.is_set or
                            self.expiration_time.is_set or
                            self.group_address.is_set or
                            self.query_interval.is_set or
                            self.response_pending.is_set or
                            self.ssm_map_type.is_set or
                            (self.map_info is not None and self.map_info.has_data()))

                    def has_operation(self):
                        for c in self.sources:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.expiration_time.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.response_pending.yfilter != YFilter.not_set or
                            self.ssm_map_type.yfilter != YFilter.not_set or
                            (self.map_info is not None and self.map_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map-detail" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-map-details/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiration_time.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.response_pending.is_set or self.response_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response_pending.get_name_leafdata())
                        if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "map-info"):
                            if (self.map_info is None):
                                self.map_info = Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                                self.map_info.parent = self
                                self._children_name_map["map_info"] = "map-info"
                            return self.map_info

                        if (child_yang_name == "sources"):
                            for c in self.sources:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.sources.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "map-info" or name == "sources" or name == "elapsed-time" or name == "expiration-time" or name == "group-address" or name == "query-interval" or name == "response-pending" or name == "ssm-map-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiration-time"):
                            self.expiration_time = value
                            self.expiration_time.value_namespace = name_space
                            self.expiration_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "response-pending"):
                            self.response_pending = value
                            self.response_pending.value_namespace = name_space
                            self.response_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssm-map-type"):
                            self.ssm_map_type = value
                            self.ssm_map_type.value_namespace = name_space
                            self.ssm_map_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ssm_map_detail:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ssm_map_detail:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ssm-map-details" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ssm-map-detail"):
                        for c in self.ssm_map_detail:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ssm_map_detail.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ssm-map-detail"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceStateOffs(Entity):
                """
                IGMP Interface state off
                
                .. attribute:: interface_state_off
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.InterfaceStateOffs, self).__init__()

                    self.yang_name = "interface-state-offs"
                    self.yang_parent_name = "default-context"

                    self.interface_state_off = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Standby.DefaultContext.InterfaceStateOffs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Standby.DefaultContext.InterfaceStateOffs, self).__setattr__(name, value)


                class InterfaceStateOff(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                        self.yang_name = "interface-state-off"
                        self.yang_parent_name = "interface-state-offs"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/interface-state-offs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_state_off:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_state_off:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-state-offs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-state-off"):
                        for c in self.interface_state_off:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_state_off.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-state-off"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.detail_groups is not None and self.detail_groups.has_data()) or
                    (self.explicit_groups is not None and self.explicit_groups.has_data()) or
                    (self.global_interface_table is not None and self.global_interface_table.has_data()) or
                    (self.group_summary is not None and self.group_summary.has_data()) or
                    (self.groups is not None and self.groups.has_data()) or
                    (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_data()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                    (self.interface_state_offs is not None and self.interface_state_offs.has_data()) or
                    (self.interface_state_ons is not None and self.interface_state_ons.has_data()) or
                    (self.interface_table is not None and self.interface_table.has_data()) or
                    (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_data()) or
                    (self.non_active_groups is not None and self.non_active_groups.has_data()) or
                    (self.ranges is not None and self.ranges.has_data()) or
                    (self.ssm_map_details is not None and self.ssm_map_details.has_data()) or
                    (self.ssm_maps is not None and self.ssm_maps.has_data()) or
                    (self.summary is not None and self.summary.has_data()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.detail_groups is not None and self.detail_groups.has_operation()) or
                    (self.explicit_groups is not None and self.explicit_groups.has_operation()) or
                    (self.global_interface_table is not None and self.global_interface_table.has_operation()) or
                    (self.group_summary is not None and self.group_summary.has_operation()) or
                    (self.groups is not None and self.groups.has_operation()) or
                    (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_operation()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                    (self.interface_state_offs is not None and self.interface_state_offs.has_operation()) or
                    (self.interface_state_ons is not None and self.interface_state_ons.has_operation()) or
                    (self.interface_table is not None and self.interface_table.has_operation()) or
                    (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_operation()) or
                    (self.non_active_groups is not None and self.non_active_groups.has_operation()) or
                    (self.ranges is not None and self.ranges.has_operation()) or
                    (self.ssm_map_details is not None and self.ssm_map_details.has_operation()) or
                    (self.ssm_maps is not None and self.ssm_maps.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "default-context" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "detail-groups"):
                    if (self.detail_groups is None):
                        self.detail_groups = Mld.Standby.DefaultContext.DetailGroups()
                        self.detail_groups.parent = self
                        self._children_name_map["detail_groups"] = "detail-groups"
                    return self.detail_groups

                if (child_yang_name == "explicit-groups"):
                    if (self.explicit_groups is None):
                        self.explicit_groups = Mld.Standby.DefaultContext.ExplicitGroups()
                        self.explicit_groups.parent = self
                        self._children_name_map["explicit_groups"] = "explicit-groups"
                    return self.explicit_groups

                if (child_yang_name == "global-interface-table"):
                    if (self.global_interface_table is None):
                        self.global_interface_table = Mld.Standby.DefaultContext.GlobalInterfaceTable()
                        self.global_interface_table.parent = self
                        self._children_name_map["global_interface_table"] = "global-interface-table"
                    return self.global_interface_table

                if (child_yang_name == "group-summary"):
                    if (self.group_summary is None):
                        self.group_summary = Mld.Standby.DefaultContext.GroupSummary()
                        self.group_summary.parent = self
                        self._children_name_map["group_summary"] = "group-summary"
                    return self.group_summary

                if (child_yang_name == "groups"):
                    if (self.groups is None):
                        self.groups = Mld.Standby.DefaultContext.Groups()
                        self.groups.parent = self
                        self._children_name_map["groups"] = "groups"
                    return self.groups

                if (child_yang_name == "ifrs-interface-summary"):
                    if (self.ifrs_interface_summary is None):
                        self.ifrs_interface_summary = Mld.Standby.DefaultContext.IfrsInterfaceSummary()
                        self.ifrs_interface_summary.parent = self
                        self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    return self.ifrs_interface_summary

                if (child_yang_name == "ifrs-interfaces"):
                    if (self.ifrs_interfaces is None):
                        self.ifrs_interfaces = Mld.Standby.DefaultContext.IfrsInterfaces()
                        self.ifrs_interfaces.parent = self
                        self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    return self.ifrs_interfaces

                if (child_yang_name == "interface-state-offs"):
                    if (self.interface_state_offs is None):
                        self.interface_state_offs = Mld.Standby.DefaultContext.InterfaceStateOffs()
                        self.interface_state_offs.parent = self
                        self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    return self.interface_state_offs

                if (child_yang_name == "interface-state-ons"):
                    if (self.interface_state_ons is None):
                        self.interface_state_ons = Mld.Standby.DefaultContext.InterfaceStateOns()
                        self.interface_state_ons.parent = self
                        self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    return self.interface_state_ons

                if (child_yang_name == "interface-table"):
                    if (self.interface_table is None):
                        self.interface_table = Mld.Standby.DefaultContext.InterfaceTable()
                        self.interface_table.parent = self
                        self._children_name_map["interface_table"] = "interface-table"
                    return self.interface_table

                if (child_yang_name == "interface-unicast-qos-adjusts"):
                    if (self.interface_unicast_qos_adjusts is None):
                        self.interface_unicast_qos_adjusts = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts()
                        self.interface_unicast_qos_adjusts.parent = self
                        self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    return self.interface_unicast_qos_adjusts

                if (child_yang_name == "non-active-groups"):
                    if (self.non_active_groups is None):
                        self.non_active_groups = Mld.Standby.DefaultContext.NonActiveGroups()
                        self.non_active_groups.parent = self
                        self._children_name_map["non_active_groups"] = "non-active-groups"
                    return self.non_active_groups

                if (child_yang_name == "ranges"):
                    if (self.ranges is None):
                        self.ranges = Mld.Standby.DefaultContext.Ranges()
                        self.ranges.parent = self
                        self._children_name_map["ranges"] = "ranges"
                    return self.ranges

                if (child_yang_name == "ssm-map-details"):
                    if (self.ssm_map_details is None):
                        self.ssm_map_details = Mld.Standby.DefaultContext.SsmMapDetails()
                        self.ssm_map_details.parent = self
                        self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    return self.ssm_map_details

                if (child_yang_name == "ssm-maps"):
                    if (self.ssm_maps is None):
                        self.ssm_maps = Mld.Standby.DefaultContext.SsmMaps()
                        self.ssm_maps.parent = self
                        self._children_name_map["ssm_maps"] = "ssm-maps"
                    return self.ssm_maps

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Mld.Standby.DefaultContext.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                if (child_yang_name == "traffic-counters"):
                    if (self.traffic_counters is None):
                        self.traffic_counters = Mld.Standby.DefaultContext.TrafficCounters()
                        self.traffic_counters.parent = self
                        self._children_name_map["traffic_counters"] = "traffic-counters"
                    return self.traffic_counters

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "detail-groups" or name == "explicit-groups" or name == "global-interface-table" or name == "group-summary" or name == "groups" or name == "ifrs-interface-summary" or name == "ifrs-interfaces" or name == "interface-state-offs" or name == "interface-state-ons" or name == "interface-table" or name == "interface-unicast-qos-adjusts" or name == "non-active-groups" or name == "ranges" or name == "ssm-map-details" or name == "ssm-maps" or name == "summary" or name == "traffic-counters"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.default_context is not None and self.default_context.has_data()) or
                (self.process is not None and self.process.has_data()) or
                (self.vrfs is not None and self.vrfs.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.default_context is not None and self.default_context.has_operation()) or
                (self.process is not None and self.process.has_operation()) or
                (self.vrfs is not None and self.vrfs.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "standby" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "default-context"):
                if (self.default_context is None):
                    self.default_context = Mld.Standby.DefaultContext()
                    self.default_context.parent = self
                    self._children_name_map["default_context"] = "default-context"
                return self.default_context

            if (child_yang_name == "process"):
                if (self.process is None):
                    self.process = Mld.Standby.Process()
                    self.process.parent = self
                    self._children_name_map["process"] = "process"
                return self.process

            if (child_yang_name == "vrfs"):
                if (self.vrfs is None):
                    self.vrfs = Mld.Standby.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                return self.vrfs

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "default-context" or name == "process" or name == "vrfs"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-igmp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Mld.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "mld"

            self.default_context = Mld.Active.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Mld.Active.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Mld.Active.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF table Names
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Active.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "active"

                self.vrf = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Mld.Active.Vrfs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Mld.Active.Vrfs, self).__setattr__(name, value)


            class Vrf(Entity):
                """
                VRF table Names
                
                .. attribute:: vrf_name  <key>
                
                	VRF name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: detail_groups
                
                	IGMP Detail Group Database
                	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups>`
                
                .. attribute:: explicit_groups
                
                	IGMP Explicit Group Database
                	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups>`
                
                .. attribute:: global_interface_table
                
                	IGMP Global Interface 
                	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GlobalInterfaceTable>`
                
                .. attribute:: group_summary
                
                	IGMP Groups Summary
                	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GroupSummary>`
                
                .. attribute:: groups
                
                	IGMP Group Database Table
                	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Groups>`
                
                .. attribute:: ifrs_interface_summary
                
                	IGMP IFRS Interface summary
                	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary>`
                
                .. attribute:: ifrs_interfaces
                
                	IGMP Interface specific
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: interface_state_offs
                
                	IGMP Interface state off
                	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOffs>`
                
                .. attribute:: interface_state_ons
                
                	IGMP Interface state on
                	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOns>`
                
                .. attribute:: interface_table
                
                	IGMP Interface specific Table
                	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceTable>`
                
                .. attribute:: interface_unicast_qos_adjusts
                
                	IGMP Interface Unicast\-Qos\-Adjust
                	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts>`
                
                .. attribute:: non_active_groups
                
                	IGMP Non\-Active Groups Information
                	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.NonActiveGroups>`
                
                .. attribute:: ranges
                
                	Range table
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: ssm_map_details
                
                	SSM Map Detail
                	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMapDetails>`
                
                .. attribute:: ssm_maps
                
                	SSM Map Table
                	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMaps>`
                
                .. attribute:: summary
                
                	IGMP Summary Information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: traffic_counters
                
                	IGMP Message Traffic Counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.TrafficCounters>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.detail_groups = Mld.Active.Vrfs.Vrf.DetailGroups()
                    self.detail_groups.parent = self
                    self._children_name_map["detail_groups"] = "detail-groups"
                    self._children_yang_names.add("detail-groups")

                    self.explicit_groups = Mld.Active.Vrfs.Vrf.ExplicitGroups()
                    self.explicit_groups.parent = self
                    self._children_name_map["explicit_groups"] = "explicit-groups"
                    self._children_yang_names.add("explicit-groups")

                    self.global_interface_table = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable()
                    self.global_interface_table.parent = self
                    self._children_name_map["global_interface_table"] = "global-interface-table"
                    self._children_yang_names.add("global-interface-table")

                    self.group_summary = Mld.Active.Vrfs.Vrf.GroupSummary()
                    self.group_summary.parent = self
                    self._children_name_map["group_summary"] = "group-summary"
                    self._children_yang_names.add("group-summary")

                    self.groups = Mld.Active.Vrfs.Vrf.Groups()
                    self.groups.parent = self
                    self._children_name_map["groups"] = "groups"
                    self._children_yang_names.add("groups")

                    self.ifrs_interface_summary = Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary()
                    self.ifrs_interface_summary.parent = self
                    self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    self._children_yang_names.add("ifrs-interface-summary")

                    self.ifrs_interfaces = Mld.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.interface_state_offs = Mld.Active.Vrfs.Vrf.InterfaceStateOffs()
                    self.interface_state_offs.parent = self
                    self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    self._children_yang_names.add("interface-state-offs")

                    self.interface_state_ons = Mld.Active.Vrfs.Vrf.InterfaceStateOns()
                    self.interface_state_ons.parent = self
                    self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    self._children_yang_names.add("interface-state-ons")

                    self.interface_table = Mld.Active.Vrfs.Vrf.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                    self._children_yang_names.add("interface-table")

                    self.interface_unicast_qos_adjusts = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                    self.interface_unicast_qos_adjusts.parent = self
                    self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    self._children_yang_names.add("interface-unicast-qos-adjusts")

                    self.non_active_groups = Mld.Active.Vrfs.Vrf.NonActiveGroups()
                    self.non_active_groups.parent = self
                    self._children_name_map["non_active_groups"] = "non-active-groups"
                    self._children_yang_names.add("non-active-groups")

                    self.ranges = Mld.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.ssm_map_details = Mld.Active.Vrfs.Vrf.SsmMapDetails()
                    self.ssm_map_details.parent = self
                    self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    self._children_yang_names.add("ssm-map-details")

                    self.ssm_maps = Mld.Active.Vrfs.Vrf.SsmMaps()
                    self.ssm_maps.parent = self
                    self._children_name_map["ssm_maps"] = "ssm-maps"
                    self._children_yang_names.add("ssm-maps")

                    self.summary = Mld.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.traffic_counters = Mld.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vrf_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.Vrfs.Vrf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.Vrfs.Vrf, self).__setattr__(name, value)


                class Summary(Entity):
                    """
                    IGMP Summary Information
                    
                    .. attribute:: disabled_interface_count
                    
                    	No. of disabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: enabled_interface_count
                    
                    	No. of enabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Maximum and current groups accepted for each interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Summary.Interface>`
                    
                    .. attribute:: is_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: robustness
                    
                    	Robustness variable
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: supported_interfaces
                    
                    	No. of supported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_mte_config_count
                    
                    	No. of static group commands
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsupported_interfaces
                    
                    	No. of unsupported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"

                        self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                        self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                        self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                        self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                        self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("disabled_interface_count",
                                        "enabled_interface_count",
                                        "group_count",
                                        "group_limit",
                                        "is_disabled",
                                        "node_low_memory",
                                        "robustness",
                                        "supported_interfaces",
                                        "tunnel_mte_config_count",
                                        "unsupported_interfaces") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.Summary, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Maximum and current groups accepted for each
                        interface
                        
                        .. attribute:: group_count
                        
                        	Current groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_limit
                        
                        	Maximum groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: on_off
                        
                        	Enabled/Disabled
                        	**type**\:  bool
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent if handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Time elapsed since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.group_limit = YLeaf(YType.uint32, "group-limit")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.on_off = YLeaf(YType.boolean, "on-off")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_count",
                                            "group_limit",
                                            "interface_name",
                                            "on_off",
                                            "parent_ifhandle",
                                            "router_uptime_in_seconds",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.Summary.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.Summary.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.group_count.is_set or
                                self.group_limit.is_set or
                                self.interface_name.is_set or
                                self.on_off.is_set or
                                self.parent_ifhandle.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.group_limit.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.on_off.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_limit.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.on_off.is_set or self.on_off.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.on_off.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-count" or name == "group-limit" or name == "interface-name" or name == "on-off" or name == "parent-ifhandle" or name == "router-uptime-in-seconds" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-limit"):
                                self.group_limit = value
                                self.group_limit.value_namespace = name_space
                                self.group_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "on-off"):
                                self.on_off = value
                                self.on_off.value_namespace = name_space
                                self.on_off.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.disabled_interface_count.is_set or
                            self.enabled_interface_count.is_set or
                            self.group_count.is_set or
                            self.group_limit.is_set or
                            self.is_disabled.is_set or
                            self.node_low_memory.is_set or
                            self.robustness.is_set or
                            self.supported_interfaces.is_set or
                            self.tunnel_mte_config_count.is_set or
                            self.unsupported_interfaces.is_set)

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.disabled_interface_count.yfilter != YFilter.not_set or
                            self.enabled_interface_count.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.group_limit.yfilter != YFilter.not_set or
                            self.is_disabled.yfilter != YFilter.not_set or
                            self.node_low_memory.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.supported_interfaces.yfilter != YFilter.not_set or
                            self.tunnel_mte_config_count.yfilter != YFilter.not_set or
                            self.unsupported_interfaces.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.disabled_interface_count.is_set or self.disabled_interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disabled_interface_count.get_name_leafdata())
                        if (self.enabled_interface_count.is_set or self.enabled_interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enabled_interface_count.get_name_leafdata())
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_limit.get_name_leafdata())
                        if (self.is_disabled.is_set or self.is_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_disabled.get_name_leafdata())
                        if (self.node_low_memory.is_set or self.node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_low_memory.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.supported_interfaces.is_set or self.supported_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.supported_interfaces.get_name_leafdata())
                        if (self.tunnel_mte_config_count.is_set or self.tunnel_mte_config_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_mte_config_count.get_name_leafdata())
                        if (self.unsupported_interfaces.is_set or self.unsupported_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unsupported_interfaces.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.Summary.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "disabled-interface-count" or name == "enabled-interface-count" or name == "group-count" or name == "group-limit" or name == "is-disabled" or name == "node-low-memory" or name == "robustness" or name == "supported-interfaces" or name == "tunnel-mte-config-count" or name == "unsupported-interfaces"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "disabled-interface-count"):
                            self.disabled_interface_count = value
                            self.disabled_interface_count.value_namespace = name_space
                            self.disabled_interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "enabled-interface-count"):
                            self.enabled_interface_count = value
                            self.enabled_interface_count.value_namespace = name_space
                            self.enabled_interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-limit"):
                            self.group_limit = value
                            self.group_limit.value_namespace = name_space
                            self.group_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-disabled"):
                            self.is_disabled = value
                            self.is_disabled.value_namespace = name_space
                            self.is_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-low-memory"):
                            self.node_low_memory = value
                            self.node_low_memory.value_namespace = name_space
                            self.node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "supported-interfaces"):
                            self.supported_interfaces = value
                            self.supported_interfaces.value_namespace = name_space
                            self.supported_interfaces.value_namespace_prefix = name_space_prefix
                        if(value_path == "tunnel-mte-config-count"):
                            self.tunnel_mte_config_count = value
                            self.tunnel_mte_config_count.value_namespace = name_space
                            self.tunnel_mte_config_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "unsupported-interfaces"):
                            self.unsupported_interfaces = value
                            self.unsupported_interfaces.value_namespace = name_space
                            self.unsupported_interfaces.value_namespace_prefix = name_space_prefix


                class InterfaceStateOns(Entity):
                    """
                    IGMP Interface state on
                    
                    .. attribute:: interface_state_on
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOns, self).__init__()

                        self.yang_name = "interface-state-ons"
                        self.yang_parent_name = "vrf"

                        self.interface_state_on = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.InterfaceStateOns, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOns, self).__setattr__(name, value)


                    class InterfaceStateOn(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__init__()

                            self.yang_name = "interface-state-on"
                            self.yang_parent_name = "interface-state-ons"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_state_on:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_state_on:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-ons" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-state-on"):
                            for c in self.interface_state_on:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_state_on.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-state-on"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class DetailGroups(Entity):
                    """
                    IGMP Detail Group Database
                    
                    .. attribute:: detail_group
                    
                    	IGMP Detail Group Entry Information
                    	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.DetailGroups, self).__init__()

                        self.yang_name = "detail-groups"
                        self.yang_parent_name = "vrf"

                        self.detail_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.DetailGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.DetailGroups, self).__setattr__(name, value)


                    class DetailGroup(Entity):
                        """
                        IGMP Detail Group Entry Information
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_host_exclude_mode
                        
                        	Group host filter mode
                        	**type**\:  bool
                        
                        .. attribute:: is_router_exclude_mode
                        
                        	Group router filter mode
                        	**type**\:  bool
                        
                        .. attribute:: source
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup, self).__init__()

                            self.yang_name = "detail-group"
                            self.yang_parent_name = "detail-groups"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                            self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.source = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "interface_name",
                                            "is_host_exclude_mode",
                                            "is_router_exclude_mode",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup, self).__setattr__(name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "detail-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "explicit_tracking_enabled",
                                                "interface_name_xr",
                                                "is_added",
                                                "is_low_memory",
                                                "is_self_join",
                                                "is_suppressed",
                                                "older_host_version1_timer",
                                                "older_host_version2_timer",
                                                "router_filter_mode",
                                                "row_status",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "last-reporter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.explicit_tracking_enabled.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_added.is_set or
                                    self.is_low_memory.is_set or
                                    self.is_self_join.is_set or
                                    self.is_suppressed.is_set or
                                    self.older_host_version1_timer.is_set or
                                    self.older_host_version2_timer.is_set or
                                    self.router_filter_mode.is_set or
                                    self.row_status.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.last_reporter is not None and self.last_reporter.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_low_memory.yfilter != YFilter.not_set or
                                    self.is_self_join.yfilter != YFilter.not_set or
                                    self.is_suppressed.yfilter != YFilter.not_set or
                                    self.older_host_version1_timer.yfilter != YFilter.not_set or
                                    self.older_host_version2_timer.yfilter != YFilter.not_set or
                                    self.router_filter_mode.yfilter != YFilter.not_set or
                                    self.row_status.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                                if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_self_join.get_name_leafdata())
                                if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                                if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                                if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                                if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                                if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.row_status.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "last-reporter"):
                                    if (self.last_reporter is None):
                                        self.last_reporter = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                        self.last_reporter.parent = self
                                        self._children_name_map["last_reporter"] = "last-reporter"
                                    return self.last_reporter

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "explicit-tracking-enabled"):
                                    self.explicit_tracking_enabled = value
                                    self.explicit_tracking_enabled.value_namespace = name_space
                                    self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-low-memory"):
                                    self.is_low_memory = value
                                    self.is_low_memory.value_namespace = name_space
                                    self.is_low_memory.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-self-join"):
                                    self.is_self_join = value
                                    self.is_self_join.value_namespace = name_space
                                    self.is_self_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-suppressed"):
                                    self.is_suppressed = value
                                    self.is_suppressed.value_namespace = name_space
                                    self.is_suppressed.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version1-timer"):
                                    self.older_host_version1_timer = value
                                    self.older_host_version1_timer.value_namespace = name_space
                                    self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version2-timer"):
                                    self.older_host_version2_timer = value
                                    self.older_host_version2_timer.value_namespace = name_space
                                    self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-filter-mode"):
                                    self.router_filter_mode = value
                                    self.router_filter_mode.value_namespace = name_space
                                    self.router_filter_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "row-status"):
                                    self.row_status = value
                                    self.row_status.value_namespace = name_space
                                    self.row_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix


                        class Source(Entity):
                            """
                            List of sources
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: flags
                            
                            	Source flags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_forward
                            
                            	Should we forward on this entry
                            	**type**\:  bool
                            
                            .. attribute:: is_local
                            
                            	Is this a local source
                            	**type**\:  bool
                            
                            .. attribute:: is_remote
                            
                            	Is this a remote source
                            	**type**\:  bool
                            
                            .. attribute:: is_we_report
                            
                            	Should we report the source
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "detail-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.flags = YLeaf(YType.int32, "flags")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_forward = YLeaf(YType.boolean, "is-forward")

                                self.is_local = YLeaf(YType.boolean, "is-local")

                                self.is_remote = YLeaf(YType.boolean, "is-remote")

                                self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.source_address = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "flags",
                                                "is_added",
                                                "is_forward",
                                                "is_local",
                                                "is_remote",
                                                "is_we_report",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.flags.is_set or
                                    self.is_added.is_set or
                                    self.is_forward.is_set or
                                    self.is_local.is_set or
                                    self.is_remote.is_set or
                                    self.is_we_report.is_set or
                                    self.uptime.is_set or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.flags.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_forward.yfilter != YFilter.not_set or
                                    self.is_local.yfilter != YFilter.not_set or
                                    self.is_remote.yfilter != YFilter.not_set or
                                    self.is_we_report.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_forward.is_set or self.is_forward.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_forward.get_name_leafdata())
                                if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_local.get_name_leafdata())
                                if (self.is_remote.is_set or self.is_remote.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_remote.get_name_leafdata())
                                if (self.is_we_report.is_set or self.is_we_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_we_report.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "source-address" or name == "expiration-time" or name == "flags" or name == "is-added" or name == "is-forward" or name == "is-local" or name == "is-remote" or name == "is-we-report" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "flags"):
                                    self.flags = value
                                    self.flags.value_namespace = name_space
                                    self.flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-forward"):
                                    self.is_forward = value
                                    self.is_forward.value_namespace = name_space
                                    self.is_forward.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-local"):
                                    self.is_local = value
                                    self.is_local.value_namespace = name_space
                                    self.is_local.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-remote"):
                                    self.is_remote = value
                                    self.is_remote.value_namespace = name_space
                                    self.is_remote.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-we-report"):
                                    self.is_we_report = value
                                    self.is_we_report.value_namespace = name_space
                                    self.is_we_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.source:
                                if (c.has_data()):
                                    return True
                            return (
                                self.group_address.is_set or
                                self.interface_name.is_set or
                                self.is_host_exclude_mode.is_set or
                                self.is_router_exclude_mode.is_set or
                                self.source_address.is_set or
                                (self.group_info is not None and self.group_info.has_data()))

                        def has_operation(self):
                            for c in self.source:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_host_exclude_mode.yfilter != YFilter.not_set or
                                self.is_router_exclude_mode.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group_info is not None and self.group_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "detail-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_host_exclude_mode.is_set or self.is_host_exclude_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_host_exclude_mode.get_name_leafdata())
                            if (self.is_router_exclude_mode.is_set or self.is_router_exclude_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_exclude_mode.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-info"):
                                if (self.group_info is None):
                                    self.group_info = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                                    self.group_info.parent = self
                                    self._children_name_map["group_info"] = "group-info"
                                return self.group_info

                            if (child_yang_name == "source"):
                                for c in self.source:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.source.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-info" or name == "source" or name == "group-address" or name == "interface-name" or name == "is-host-exclude-mode" or name == "is-router-exclude-mode" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-host-exclude-mode"):
                                self.is_host_exclude_mode = value
                                self.is_host_exclude_mode.value_namespace = name_space
                                self.is_host_exclude_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-exclude-mode"):
                                self.is_router_exclude_mode = value
                                self.is_router_exclude_mode.value_namespace = name_space
                                self.is_router_exclude_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.detail_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.detail_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "detail-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "detail-group"):
                            for c in self.detail_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.detail_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "detail-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NonActiveGroups(Entity):
                    """
                    IGMP Non\-Active Groups Information
                    
                    .. attribute:: non_active_groups
                    
                    	List of non\-active groups
                    	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "vrf"

                        self.non_active_groups = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.NonActiveGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.NonActiveGroups, self).__setattr__(name, value)


                    class NonActiveGroups(Entity):
                        """
                        List of non\-active groups
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress>`
                        
                        .. attribute:: interface
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: reason_for_non_activity
                        
                        	Reason for group join not being processed
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__init__()

                            self.yang_name = "non-active-groups"
                            self.yang_parent_name = "non-active-groups"

                            self.interface = YLeaf(YType.str, "interface")

                            self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                            self.group_address = Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface",
                                            "reason_for_non_activity") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "non-active-groups"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "non-active-groups"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface.is_set or
                                self.reason_for_non_activity.is_set or
                                (self.group_address is not None and self.group_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface.yfilter != YFilter.not_set or
                                self.reason_for_non_activity.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "non-active-groups" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface.get_name_leafdata())
                            if (self.reason_for_non_activity.is_set or self.reason_for_non_activity.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reason_for_non_activity.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "source-address" or name == "interface" or name == "reason-for-non-activity"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface"):
                                self.interface = value
                                self.interface.value_namespace = name_space
                                self.interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "reason-for-non-activity"):
                                self.reason_for_non_activity = value
                                self.reason_for_non_activity.value_namespace = name_space
                                self.reason_for_non_activity.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.non_active_groups:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.non_active_groups:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "non-active-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "non-active-groups"):
                            for c in self.non_active_groups:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.non_active_groups.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "non-active-groups"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SsmMaps(Entity):
                    """
                    SSM Map Table
                    
                    .. attribute:: ssm_map
                    
                    	SSM Map information
                    	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.SsmMaps, self).__init__()

                        self.yang_name = "ssm-maps"
                        self.yang_parent_name = "vrf"

                        self.ssm_map = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.SsmMaps, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.SsmMaps, self).__setattr__(name, value)


                    class SsmMap(Entity):
                        """
                        SSM Map information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap, self).__init__()

                            self.yang_name = "ssm-map"
                            self.yang_parent_name = "ssm-maps"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.group_address_xr = Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "map_type",
                                            "source_counts",
                                            "ssm_map_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "ssm-map"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.map_type.is_set or
                                self.source_counts.is_set or
                                self.ssm_map_type.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.map_type.yfilter != YFilter.not_set or
                                self.source_counts.yfilter != YFilter.not_set or
                                self.ssm_map_type.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ssm-map" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.map_type.get_name_leafdata())
                            if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_counts.get_name_leafdata())
                            if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "group-address" or name == "map-type" or name == "source-counts" or name == "ssm-map-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "map-type"):
                                self.map_type = value
                                self.map_type.value_namespace = name_space
                                self.map_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-counts"):
                                self.source_counts = value
                                self.source_counts.value_namespace = name_space
                                self.source_counts.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssm-map-type"):
                                self.ssm_map_type = value
                                self.ssm_map_type.value_namespace = name_space
                                self.ssm_map_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ssm_map:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ssm_map:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-maps" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ssm-map"):
                            for c in self.ssm_map:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ssm_map.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ssm-map"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class ExplicitGroups(Entity):
                    """
                    IGMP Explicit Group Database
                    
                    .. attribute:: explicit_group
                    
                    	IGMP Explicit Group Entry Information
                    	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.ExplicitGroups, self).__init__()

                        self.yang_name = "explicit-groups"
                        self.yang_parent_name = "vrf"

                        self.explicit_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.ExplicitGroups, self).__setattr__(name, value)


                    class ExplicitGroup(Entity):
                        """
                        IGMP Explicit Group Entry Information
                        
                        .. attribute:: exclude_hosts
                        
                        	No. of hosts who are excluded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo>`
                        
                        .. attribute:: host
                        
                        	List of hosts
                        	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host>`
                        
                        .. attribute:: include_hosts
                        
                        	No. of hosts who are included
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__init__()

                            self.yang_name = "explicit-group"
                            self.yang_parent_name = "explicit-groups"

                            self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.host = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("exclude_hosts",
                                            "group_address",
                                            "include_hosts",
                                            "interface_name",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "explicit-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "explicit_tracking_enabled",
                                                "interface_name_xr",
                                                "is_added",
                                                "is_low_memory",
                                                "is_self_join",
                                                "is_suppressed",
                                                "older_host_version1_timer",
                                                "older_host_version2_timer",
                                                "router_filter_mode",
                                                "row_status",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "last-reporter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.explicit_tracking_enabled.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_added.is_set or
                                    self.is_low_memory.is_set or
                                    self.is_self_join.is_set or
                                    self.is_suppressed.is_set or
                                    self.older_host_version1_timer.is_set or
                                    self.older_host_version2_timer.is_set or
                                    self.router_filter_mode.is_set or
                                    self.row_status.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.last_reporter is not None and self.last_reporter.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_low_memory.yfilter != YFilter.not_set or
                                    self.is_self_join.yfilter != YFilter.not_set or
                                    self.is_suppressed.yfilter != YFilter.not_set or
                                    self.older_host_version1_timer.yfilter != YFilter.not_set or
                                    self.older_host_version2_timer.yfilter != YFilter.not_set or
                                    self.router_filter_mode.yfilter != YFilter.not_set or
                                    self.row_status.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                                if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_self_join.get_name_leafdata())
                                if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                                if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                                if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                                if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                                if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.row_status.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "last-reporter"):
                                    if (self.last_reporter is None):
                                        self.last_reporter = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                        self.last_reporter.parent = self
                                        self._children_name_map["last_reporter"] = "last-reporter"
                                    return self.last_reporter

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "explicit-tracking-enabled"):
                                    self.explicit_tracking_enabled = value
                                    self.explicit_tracking_enabled.value_namespace = name_space
                                    self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-low-memory"):
                                    self.is_low_memory = value
                                    self.is_low_memory.value_namespace = name_space
                                    self.is_low_memory.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-self-join"):
                                    self.is_self_join = value
                                    self.is_self_join.value_namespace = name_space
                                    self.is_self_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-suppressed"):
                                    self.is_suppressed = value
                                    self.is_suppressed.value_namespace = name_space
                                    self.is_suppressed.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version1-timer"):
                                    self.older_host_version1_timer = value
                                    self.older_host_version1_timer.value_namespace = name_space
                                    self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version2-timer"):
                                    self.older_host_version2_timer = value
                                    self.older_host_version2_timer.value_namespace = name_space
                                    self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-filter-mode"):
                                    self.router_filter_mode = value
                                    self.router_filter_mode.value_namespace = name_space
                                    self.router_filter_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "row-status"):
                                    self.row_status = value
                                    self.row_status.value_namespace = name_space
                                    self.row_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix


                        class Host(Entity):
                            """
                            List of hosts
                            
                            .. attribute:: address
                            
                            	Host Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address>`
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_exclude
                            
                            	Exclude flag set
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	First 3 source addresses
                            	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                            
                            .. attribute:: source_count
                            
                            	No. of sources in entry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "explicit-group"

                                self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                                self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                                self.source_count = YLeaf(YType.uint32, "source-count")

                                self.uptime = YLeaf(YType.uint32, "uptime")

                                self.address = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.source_address = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "is_exclude",
                                                "source_count",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)


                            class Address(Entity):
                                """
                                Host Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "host"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                First 3 source addresses
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "host"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.source_address:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.expiration_time.is_set or
                                    self.is_exclude.is_set or
                                    self.source_count.is_set or
                                    self.uptime.is_set or
                                    (self.address is not None and self.address.has_data()))

                            def has_operation(self):
                                for c in self.source_address:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.is_exclude.yfilter != YFilter.not_set or
                                    self.source_count.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.address is not None and self.address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "host" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.is_exclude.is_set or self.is_exclude.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_exclude.get_name_leafdata())
                                if (self.source_count.is_set or self.source_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_count.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "address"):
                                    if (self.address is None):
                                        self.address = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                    return self.address

                                if (child_yang_name == "source-address"):
                                    for c in self.source_address:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.source_address.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "source-address" or name == "expiration-time" or name == "is-exclude" or name == "source-count" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-exclude"):
                                    self.is_exclude = value
                                    self.is_exclude.value_namespace = name_space
                                    self.is_exclude.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-count"):
                                    self.source_count = value
                                    self.source_count.value_namespace = name_space
                                    self.source_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.host:
                                if (c.has_data()):
                                    return True
                            return (
                                self.exclude_hosts.is_set or
                                self.group_address.is_set or
                                self.include_hosts.is_set or
                                self.interface_name.is_set or
                                self.source_address.is_set or
                                (self.group_info is not None and self.group_info.has_data()))

                        def has_operation(self):
                            for c in self.host:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.exclude_hosts.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.include_hosts.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group_info is not None and self.group_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "explicit-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.exclude_hosts.is_set or self.exclude_hosts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.exclude_hosts.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.include_hosts.is_set or self.include_hosts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.include_hosts.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-info"):
                                if (self.group_info is None):
                                    self.group_info = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                                    self.group_info.parent = self
                                    self._children_name_map["group_info"] = "group-info"
                                return self.group_info

                            if (child_yang_name == "host"):
                                for c in self.host:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.host.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-info" or name == "host" or name == "exclude-hosts" or name == "group-address" or name == "include-hosts" or name == "interface-name" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "exclude-hosts"):
                                self.exclude_hosts = value
                                self.exclude_hosts.value_namespace = name_space
                                self.exclude_hosts.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "include-hosts"):
                                self.include_hosts = value
                                self.include_hosts.value_namespace = name_space
                                self.include_hosts.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.explicit_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.explicit_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "explicit-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "explicit-group"):
                            for c in self.explicit_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.explicit_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "explicit-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceTable(Entity):
                    """
                    IGMP Interface specific Table
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.InterfaceTable, self).__init__()

                        self.yang_name = "interface-table"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.InterfaceTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.InterfaceTable, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-table"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.InterfaceTable.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceUnicastQosAdjusts(Entity):
                    """
                    IGMP Interface Unicast\-Qos\-Adjust
                    
                    .. attribute:: interface_unicast_qos_adjust
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjusts"
                        self.yang_parent_name = "vrf"

                        self.interface_unicast_qos_adjust = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)


                    class InterfaceUnicastQosAdjust(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_virtual_access
                        
                        	Is VirtualAccess Interface
                        	**type**\:  bool
                        
                        .. attribute:: rate
                        
                        	Overall rate in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: rate_decrements
                        
                        	Count of rate decrements
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rate_increments
                        
                        	Count of rate increments
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update
                        
                        	List of updates
                        	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                            self.yang_name = "interface-unicast-qos-adjust"
                            self.yang_parent_name = "interface-unicast-qos-adjusts"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                            self.rate = YLeaf(YType.uint32, "rate")

                            self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                            self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                            self.update = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "is_virtual_access",
                                            "rate",
                                            "rate_decrements",
                                            "rate_increments") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)


                        class Update(Entity):
                            """
                            List of updates
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                            
                            .. attribute:: is_add
                            
                            	Is this a rate increment
                            	**type**\:  bool
                            
                            .. attribute:: received_time
                            
                            	Time this update is received
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                            
                            .. attribute:: weight
                            
                            	Weight from policy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                                self.yang_name = "update"
                                self.yang_parent_name = "interface-unicast-qos-adjust"

                                self.is_add = YLeaf(YType.boolean, "is-add")

                                self.received_time = YLeaf(YType.uint64, "received-time")

                                self.weight = YLeaf(YType.uint32, "weight")

                                self.group_address = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                                self._children_yang_names.add("group-address")

                                self.source_address = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_add",
                                                "received_time",
                                                "weight") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)


                            class SourceAddress(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "update"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GroupAddress(Entity):
                                """
                                Group address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                    self.yang_name = "group-address"
                                    self.yang_parent_name = "update"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.is_add.is_set or
                                    self.received_time.is_set or
                                    self.weight.is_set or
                                    (self.group_address is not None and self.group_address.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_add.yfilter != YFilter.not_set or
                                    self.received_time.yfilter != YFilter.not_set or
                                    self.weight.yfilter != YFilter.not_set or
                                    (self.group_address is not None and self.group_address.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "update" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_add.is_set or self.is_add.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_add.get_name_leafdata())
                                if (self.received_time.is_set or self.received_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_time.get_name_leafdata())
                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address"):
                                    if (self.group_address is None):
                                        self.group_address = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                        self.group_address.parent = self
                                        self._children_name_map["group_address"] = "group-address"
                                    return self.group_address

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address" or name == "source-address" or name == "is-add" or name == "received-time" or name == "weight"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-add"):
                                    self.is_add = value
                                    self.is_add.value_namespace = name_space
                                    self.is_add.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-time"):
                                    self.received_time = value
                                    self.received_time.value_namespace = name_space
                                    self.received_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "weight"):
                                    self.weight = value
                                    self.weight.value_namespace = name_space
                                    self.weight.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.update:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.is_virtual_access.is_set or
                                self.rate.is_set or
                                self.rate_decrements.is_set or
                                self.rate_increments.is_set)

                        def has_operation(self):
                            for c in self.update:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_virtual_access.yfilter != YFilter.not_set or
                                self.rate.yfilter != YFilter.not_set or
                                self.rate_decrements.yfilter != YFilter.not_set or
                                self.rate_increments.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_virtual_access.is_set or self.is_virtual_access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_virtual_access.get_name_leafdata())
                            if (self.rate.is_set or self.rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate.get_name_leafdata())
                            if (self.rate_decrements.is_set or self.rate_decrements.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate_decrements.get_name_leafdata())
                            if (self.rate_increments.is_set or self.rate_increments.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate_increments.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "update"):
                                for c in self.update:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.update.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "update" or name == "interface-name" or name == "is-virtual-access" or name == "rate" or name == "rate-decrements" or name == "rate-increments"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-virtual-access"):
                                self.is_virtual_access = value
                                self.is_virtual_access.value_namespace = name_space
                                self.is_virtual_access.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate"):
                                self.rate = value
                                self.rate.value_namespace = name_space
                                self.rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate-decrements"):
                                self.rate_decrements = value
                                self.rate_decrements.value_namespace = name_space
                                self.rate_decrements.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate-increments"):
                                self.rate_increments = value
                                self.rate_increments.value_namespace = name_space
                                self.rate_increments.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_unicast_qos_adjust:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_unicast_qos_adjust:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-unicast-qos-adjusts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-unicast-qos-adjust"):
                            for c in self.interface_unicast_qos_adjust:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_unicast_qos_adjust.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-unicast-qos-adjust"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Ranges(Entity):
                    """
                    Range table
                    
                    .. attribute:: range
                    
                    	Range information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"

                        self.range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.Ranges, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.Ranges, self).__setattr__(name, value)


                    class Range(Entity):
                        """
                        Range information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr>`
                        
                        .. attribute:: group_mask
                        
                        	Group Mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_stale
                        
                        	Is the entry stale
                        	**type**\:  bool
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.group_mask = YLeaf(YType.int32, "group-mask")

                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.group_address_xr = Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "group_mask",
                                            "is_stale",
                                            "prefix_length",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.group_mask.is_set or
                                self.is_stale.is_set or
                                self.prefix_length.is_set or
                                self.protocol.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.group_mask.yfilter != YFilter.not_set or
                                self.is_stale.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.group_mask.is_set or self.group_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_mask.get_name_leafdata())
                            if (self.is_stale.is_set or self.is_stale.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_stale.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "group-address" or name == "group-mask" or name == "is-stale" or name == "prefix-length" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-mask"):
                                self.group_mask = value
                                self.group_mask.value_namespace = name_space
                                self.group_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-stale"):
                                self.is_stale = value
                                self.is_stale.value_namespace = name_space
                                self.is_stale.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.range:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.range:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ranges" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "range"):
                            for c in self.range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.Ranges.Range()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.range.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "range"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class IfrsInterfaces(Entity):
                    """
                    IGMP Interface specific
                    
                    .. attribute:: ifrs_interface
                    
                    	IGMP IFRS Interface
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"

                        self.ifrs_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)


                    class IfrsInterface(Entity):
                        """
                        IGMP IFRS Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	IFRS Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: igmp_interface_entry
                        
                        	IGMP interface entry
                        	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                        
                        .. attribute:: join_group_count
                        
                        	Join group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                            self.igmp_interface_entry = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                            self.igmp_interface_entry.parent = self
                            self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            self._children_yang_names.add("igmp-interface-entry")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "join_group_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                        class IgmpInterfaceEntry(Entity):
                            """
                            IGMP interface entry
                            
                            .. attribute:: address
                            
                            	IP address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                            
                            .. attribute:: configuration_mcast_vrf_error
                            
                            	Is mcast error
                            	**type**\:  bool
                            
                            .. attribute:: configuration_mcast_vrf_set
                            
                            	Is mcast set
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_error
                            
                            	CFG vrf error
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_set
                            
                            	CFG vrf set
                            	**type**\:  bool
                            
                            .. attribute:: group_joins
                            
                            	No. of group joins
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_leaves
                            
                            	No. of group leaves
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: host_version
                            
                            	IGMP Host version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: igmp_version
                            
                            	IGMP Router version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_configurationverify
                            
                            	CFG verify
                            	**type**\:  bool
                            
                            .. attribute:: is_identity_present
                            
                            	Subscriber ID or Address available from AAA
                            	**type**\:  bool
                            
                            .. attribute:: is_im_state_registered
                            
                            	Im state registered
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_up
                            
                            	Is interface up
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_enabled
                            
                            	Is IP enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_las_registered
                            
                            	LAS registered
                            	**type**\:  bool
                            
                            .. attribute:: is_las_request
                            
                            	LAS req
                            	**type**\:  bool
                            
                            .. attribute:: is_querier
                            
                            	Are we querier
                            	**type**\:  bool
                            
                            .. attribute:: is_router_enabled
                            
                            	Is Router functionality enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_subscriber
                            
                            	Subscriber interface
                            	**type**\:  bool
                            
                            .. attribute:: las_get_address_count
                            
                            	LAS get addr count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_add_update_count
                            
                            	LAS LL add update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_registration_count
                            
                            	LAS reg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_remove_update_count
                            
                            	LAS LL remove update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_null_update_count
                            
                            	LAS Null update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_unregistration_count
                            
                            	LAS unreg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_update_count
                            
                            	LAS Update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_member_query_interval
                            
                            	Last Member Query Interval
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: location
                            
                            	Location
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_tuple_count
                            
                            	MTE Tuple count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_vrf_id
                            
                            	MTE VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_ifhandle
                            
                            	Parent If Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: proxy_interface
                            
                            	Proxy interface index
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: querier_address
                            
                            	Address of the Querier
                            	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                            
                            .. attribute:: querier_uptime
                            
                            	Time since the last querier took over
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_interval
                            
                            	Query Interval value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: query_maximum_response_time
                            
                            	Max Response Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_timeout
                            
                            	Query Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: robustness
                            
                            	Robustness Variable value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_uptime_in_seconds
                            
                            	Uptime since router enabled event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	Interface state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: subscriber_address
                            
                            	Address of subscriber
                            	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                            
                            .. attribute:: subscriber_id
                            
                            	ID string of subscriber
                            	**type**\:  str
                            
                            	**length:** 0..257
                            
                            .. attribute:: subscriber_mode
                            
                            	Subscriber mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_query_in_seconds
                            
                            	Time elapsed since last query
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_report_in_seconds
                            
                            	Time elapsed since last report
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_active_groups
                            
                            	Actual number of groups on interface
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_id
                            
                            	VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_state
                            
                            	Vrf State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                                self.yang_name = "igmp-interface-entry"
                                self.yang_parent_name = "ifrs-interface"

                                self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                                self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                                self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                                self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                                self.group_joins = YLeaf(YType.uint32, "group-joins")

                                self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                                self.host_version = YLeaf(YType.uint8, "host-version")

                                self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                                self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                                self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                                self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                                self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                                self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                                self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                                self.is_querier = YLeaf(YType.boolean, "is-querier")

                                self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                                self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                                self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                                self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                                self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                                self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                                self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                                self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                                self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                                self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                                self.location = YLeaf(YType.uint32, "location")

                                self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                                self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                                self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                                self.query_interval = YLeaf(YType.uint16, "query-interval")

                                self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                                self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                                self.robustness = YLeaf(YType.uint32, "robustness")

                                self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                                self.state = YLeaf(YType.uint32, "state")

                                self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                                self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                                self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                                self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                                self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                                self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                                self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                                self.address = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.querier_address = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                                self._children_yang_names.add("querier-address")

                                self.subscriber_address = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                                self._children_yang_names.add("subscriber-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configuration_mcast_vrf_error",
                                                "configuration_mcast_vrf_set",
                                                "configurationvrf_error",
                                                "configurationvrf_set",
                                                "group_joins",
                                                "group_leaves",
                                                "host_version",
                                                "igmp_version",
                                                "interface_name_xr",
                                                "is_configurationverify",
                                                "is_identity_present",
                                                "is_im_state_registered",
                                                "is_interface_up",
                                                "is_ip_enabled",
                                                "is_las_registered",
                                                "is_las_request",
                                                "is_querier",
                                                "is_router_enabled",
                                                "is_subscriber",
                                                "las_get_address_count",
                                                "las_ll_add_update_count",
                                                "las_ll_registration_count",
                                                "las_ll_remove_update_count",
                                                "las_null_update_count",
                                                "las_unregistration_count",
                                                "las_update_count",
                                                "last_member_query_interval",
                                                "location",
                                                "mte_tuple_count",
                                                "mte_vrf_id",
                                                "mtu",
                                                "parent_ifhandle",
                                                "prefix_length",
                                                "proxy_interface",
                                                "querier_uptime",
                                                "query_interval",
                                                "query_maximum_response_time",
                                                "query_timeout",
                                                "robustness",
                                                "router_uptime_in_seconds",
                                                "state",
                                                "subscriber_id",
                                                "subscriber_mode",
                                                "time_since_last_query_in_seconds",
                                                "time_since_last_report_in_seconds",
                                                "total_active_groups",
                                                "vrf_id",
                                                "vrf_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)


                            class Address(Entity):
                                """
                                IP address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class QuerierAddress(Entity):
                                """
                                Address of the Querier
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                    self.yang_name = "querier-address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "querier-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SubscriberAddress(Entity):
                                """
                                Address of subscriber
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                    self.yang_name = "subscriber-address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.configuration_mcast_vrf_error.is_set or
                                    self.configuration_mcast_vrf_set.is_set or
                                    self.configurationvrf_error.is_set or
                                    self.configurationvrf_set.is_set or
                                    self.group_joins.is_set or
                                    self.group_leaves.is_set or
                                    self.host_version.is_set or
                                    self.igmp_version.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_configurationverify.is_set or
                                    self.is_identity_present.is_set or
                                    self.is_im_state_registered.is_set or
                                    self.is_interface_up.is_set or
                                    self.is_ip_enabled.is_set or
                                    self.is_las_registered.is_set or
                                    self.is_las_request.is_set or
                                    self.is_querier.is_set or
                                    self.is_router_enabled.is_set or
                                    self.is_subscriber.is_set or
                                    self.las_get_address_count.is_set or
                                    self.las_ll_add_update_count.is_set or
                                    self.las_ll_registration_count.is_set or
                                    self.las_ll_remove_update_count.is_set or
                                    self.las_null_update_count.is_set or
                                    self.las_unregistration_count.is_set or
                                    self.las_update_count.is_set or
                                    self.last_member_query_interval.is_set or
                                    self.location.is_set or
                                    self.mte_tuple_count.is_set or
                                    self.mte_vrf_id.is_set or
                                    self.mtu.is_set or
                                    self.parent_ifhandle.is_set or
                                    self.prefix_length.is_set or
                                    self.proxy_interface.is_set or
                                    self.querier_uptime.is_set or
                                    self.query_interval.is_set or
                                    self.query_maximum_response_time.is_set or
                                    self.query_timeout.is_set or
                                    self.robustness.is_set or
                                    self.router_uptime_in_seconds.is_set or
                                    self.state.is_set or
                                    self.subscriber_id.is_set or
                                    self.subscriber_mode.is_set or
                                    self.time_since_last_query_in_seconds.is_set or
                                    self.time_since_last_report_in_seconds.is_set or
                                    self.total_active_groups.is_set or
                                    self.vrf_id.is_set or
                                    self.vrf_state.is_set or
                                    (self.address is not None and self.address.has_data()) or
                                    (self.querier_address is not None and self.querier_address.has_data()) or
                                    (self.subscriber_address is not None and self.subscriber_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                    self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                    self.configurationvrf_error.yfilter != YFilter.not_set or
                                    self.configurationvrf_set.yfilter != YFilter.not_set or
                                    self.group_joins.yfilter != YFilter.not_set or
                                    self.group_leaves.yfilter != YFilter.not_set or
                                    self.host_version.yfilter != YFilter.not_set or
                                    self.igmp_version.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_configurationverify.yfilter != YFilter.not_set or
                                    self.is_identity_present.yfilter != YFilter.not_set or
                                    self.is_im_state_registered.yfilter != YFilter.not_set or
                                    self.is_interface_up.yfilter != YFilter.not_set or
                                    self.is_ip_enabled.yfilter != YFilter.not_set or
                                    self.is_las_registered.yfilter != YFilter.not_set or
                                    self.is_las_request.yfilter != YFilter.not_set or
                                    self.is_querier.yfilter != YFilter.not_set or
                                    self.is_router_enabled.yfilter != YFilter.not_set or
                                    self.is_subscriber.yfilter != YFilter.not_set or
                                    self.las_get_address_count.yfilter != YFilter.not_set or
                                    self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                    self.las_ll_registration_count.yfilter != YFilter.not_set or
                                    self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                    self.las_null_update_count.yfilter != YFilter.not_set or
                                    self.las_unregistration_count.yfilter != YFilter.not_set or
                                    self.las_update_count.yfilter != YFilter.not_set or
                                    self.last_member_query_interval.yfilter != YFilter.not_set or
                                    self.location.yfilter != YFilter.not_set or
                                    self.mte_tuple_count.yfilter != YFilter.not_set or
                                    self.mte_vrf_id.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.parent_ifhandle.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.proxy_interface.yfilter != YFilter.not_set or
                                    self.querier_uptime.yfilter != YFilter.not_set or
                                    self.query_interval.yfilter != YFilter.not_set or
                                    self.query_maximum_response_time.yfilter != YFilter.not_set or
                                    self.query_timeout.yfilter != YFilter.not_set or
                                    self.robustness.yfilter != YFilter.not_set or
                                    self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.subscriber_id.yfilter != YFilter.not_set or
                                    self.subscriber_mode.yfilter != YFilter.not_set or
                                    self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                    self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                    self.total_active_groups.yfilter != YFilter.not_set or
                                    self.vrf_id.yfilter != YFilter.not_set or
                                    self.vrf_state.yfilter != YFilter.not_set or
                                    (self.address is not None and self.address.has_operation()) or
                                    (self.querier_address is not None and self.querier_address.has_operation()) or
                                    (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "igmp-interface-entry" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                                if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                                if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                                if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                                if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_joins.get_name_leafdata())
                                if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_leaves.get_name_leafdata())
                                if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.host_version.get_name_leafdata())
                                if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_version.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                                if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                                if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                                if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                                if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                                if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                                if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_las_request.get_name_leafdata())
                                if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_querier.get_name_leafdata())
                                if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                                if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                                if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                                if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                                if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                                if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                                if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                                if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                                if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_update_count.get_name_leafdata())
                                if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                                if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.location.get_name_leafdata())
                                if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                                if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                                if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                                if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_interval.get_name_leafdata())
                                if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                                if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_timeout.get_name_leafdata())
                                if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.robustness.get_name_leafdata())
                                if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                                if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                                if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                                if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                                if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                                if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_id.get_name_leafdata())
                                if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "address"):
                                    if (self.address is None):
                                        self.address = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                    return self.address

                                if (child_yang_name == "querier-address"):
                                    if (self.querier_address is None):
                                        self.querier_address = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                        self.querier_address.parent = self
                                        self._children_name_map["querier_address"] = "querier-address"
                                    return self.querier_address

                                if (child_yang_name == "subscriber-address"):
                                    if (self.subscriber_address is None):
                                        self.subscriber_address = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                        self.subscriber_address.parent = self
                                        self._children_name_map["subscriber_address"] = "subscriber-address"
                                    return self.subscriber_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configuration-mcast-vrf-error"):
                                    self.configuration_mcast_vrf_error = value
                                    self.configuration_mcast_vrf_error.value_namespace = name_space
                                    self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "configuration-mcast-vrf-set"):
                                    self.configuration_mcast_vrf_set = value
                                    self.configuration_mcast_vrf_set.value_namespace = name_space
                                    self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "configurationvrf-error"):
                                    self.configurationvrf_error = value
                                    self.configurationvrf_error.value_namespace = name_space
                                    self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "configurationvrf-set"):
                                    self.configurationvrf_set = value
                                    self.configurationvrf_set.value_namespace = name_space
                                    self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-joins"):
                                    self.group_joins = value
                                    self.group_joins.value_namespace = name_space
                                    self.group_joins.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-leaves"):
                                    self.group_leaves = value
                                    self.group_leaves.value_namespace = name_space
                                    self.group_leaves.value_namespace_prefix = name_space_prefix
                                if(value_path == "host-version"):
                                    self.host_version = value
                                    self.host_version.value_namespace = name_space
                                    self.host_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-version"):
                                    self.igmp_version = value
                                    self.igmp_version.value_namespace = name_space
                                    self.igmp_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-configurationverify"):
                                    self.is_configurationverify = value
                                    self.is_configurationverify.value_namespace = name_space
                                    self.is_configurationverify.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-identity-present"):
                                    self.is_identity_present = value
                                    self.is_identity_present.value_namespace = name_space
                                    self.is_identity_present.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-im-state-registered"):
                                    self.is_im_state_registered = value
                                    self.is_im_state_registered.value_namespace = name_space
                                    self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-interface-up"):
                                    self.is_interface_up = value
                                    self.is_interface_up.value_namespace = name_space
                                    self.is_interface_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ip-enabled"):
                                    self.is_ip_enabled = value
                                    self.is_ip_enabled.value_namespace = name_space
                                    self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-las-registered"):
                                    self.is_las_registered = value
                                    self.is_las_registered.value_namespace = name_space
                                    self.is_las_registered.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-las-request"):
                                    self.is_las_request = value
                                    self.is_las_request.value_namespace = name_space
                                    self.is_las_request.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-querier"):
                                    self.is_querier = value
                                    self.is_querier.value_namespace = name_space
                                    self.is_querier.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-router-enabled"):
                                    self.is_router_enabled = value
                                    self.is_router_enabled.value_namespace = name_space
                                    self.is_router_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-subscriber"):
                                    self.is_subscriber = value
                                    self.is_subscriber.value_namespace = name_space
                                    self.is_subscriber.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-get-address-count"):
                                    self.las_get_address_count = value
                                    self.las_get_address_count.value_namespace = name_space
                                    self.las_get_address_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-add-update-count"):
                                    self.las_ll_add_update_count = value
                                    self.las_ll_add_update_count.value_namespace = name_space
                                    self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-registration-count"):
                                    self.las_ll_registration_count = value
                                    self.las_ll_registration_count.value_namespace = name_space
                                    self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-remove-update-count"):
                                    self.las_ll_remove_update_count = value
                                    self.las_ll_remove_update_count.value_namespace = name_space
                                    self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-null-update-count"):
                                    self.las_null_update_count = value
                                    self.las_null_update_count.value_namespace = name_space
                                    self.las_null_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-unregistration-count"):
                                    self.las_unregistration_count = value
                                    self.las_unregistration_count.value_namespace = name_space
                                    self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-update-count"):
                                    self.las_update_count = value
                                    self.las_update_count.value_namespace = name_space
                                    self.las_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-member-query-interval"):
                                    self.last_member_query_interval = value
                                    self.last_member_query_interval.value_namespace = name_space
                                    self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "location"):
                                    self.location = value
                                    self.location.value_namespace = name_space
                                    self.location.value_namespace_prefix = name_space_prefix
                                if(value_path == "mte-tuple-count"):
                                    self.mte_tuple_count = value
                                    self.mte_tuple_count.value_namespace = name_space
                                    self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "mte-vrf-id"):
                                    self.mte_vrf_id = value
                                    self.mte_vrf_id.value_namespace = name_space
                                    self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "parent-ifhandle"):
                                    self.parent_ifhandle = value
                                    self.parent_ifhandle.value_namespace = name_space
                                    self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "proxy-interface"):
                                    self.proxy_interface = value
                                    self.proxy_interface.value_namespace = name_space
                                    self.proxy_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "querier-uptime"):
                                    self.querier_uptime = value
                                    self.querier_uptime.value_namespace = name_space
                                    self.querier_uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-interval"):
                                    self.query_interval = value
                                    self.query_interval.value_namespace = name_space
                                    self.query_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-maximum-response-time"):
                                    self.query_maximum_response_time = value
                                    self.query_maximum_response_time.value_namespace = name_space
                                    self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-timeout"):
                                    self.query_timeout = value
                                    self.query_timeout.value_namespace = name_space
                                    self.query_timeout.value_namespace_prefix = name_space_prefix
                                if(value_path == "robustness"):
                                    self.robustness = value
                                    self.robustness.value_namespace = name_space
                                    self.robustness.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-uptime-in-seconds"):
                                    self.router_uptime_in_seconds = value
                                    self.router_uptime_in_seconds.value_namespace = name_space
                                    self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-id"):
                                    self.subscriber_id = value
                                    self.subscriber_id.value_namespace = name_space
                                    self.subscriber_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-mode"):
                                    self.subscriber_mode = value
                                    self.subscriber_mode.value_namespace = name_space
                                    self.subscriber_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-last-query-in-seconds"):
                                    self.time_since_last_query_in_seconds = value
                                    self.time_since_last_query_in_seconds.value_namespace = name_space
                                    self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-last-report-in-seconds"):
                                    self.time_since_last_report_in_seconds = value
                                    self.time_since_last_report_in_seconds.value_namespace = name_space
                                    self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "total-active-groups"):
                                    self.total_active_groups = value
                                    self.total_active_groups.value_namespace = name_space
                                    self.total_active_groups.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-id"):
                                    self.vrf_id = value
                                    self.vrf_id.value_namespace = name_space
                                    self.vrf_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-state"):
                                    self.vrf_state = value
                                    self.vrf_state.value_namespace = name_space
                                    self.vrf_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.join_group_count.is_set or
                                (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.join_group_count.yfilter != YFilter.not_set or
                                (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.join_group_count.is_set or self.join_group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_group_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "igmp-interface-entry"):
                                if (self.igmp_interface_entry is None):
                                    self.igmp_interface_entry = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                                    self.igmp_interface_entry.parent = self
                                    self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                                return self.igmp_interface_entry

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "igmp-interface-entry" or name == "interface-name" or name == "join-group-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-group-count"):
                                self.join_group_count = value
                                self.join_group_count.value_namespace = name_space
                                self.join_group_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ifrs_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ifrs_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ifrs-interface"):
                            for c in self.ifrs_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ifrs_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ifrs-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TrafficCounters(Entity):
                    """
                    IGMP Message Traffic Counters
                    
                    .. attribute:: auxillary_data_length_errors
                    
                    	AuxDataLen errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bad_scope_errors
                    
                    	BadScope errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_errors
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_errors
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: get_packet_failure
                    
                    	Packet get failed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_disabled_idb
                    
                    	Packet received on disabled idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_dvmrp
                    
                    	DVMRP packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_leaves
                    
                    	Leaves in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_martian_address
                    
                    	Packets received with Martian Address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_mtrace
                    
                    	Mtrace packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_assigned_vrf_id
                    
                    	Packets received with no assigned vrf id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb
                    
                    	Packets received without idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_platform_support_mtrace
                    
                    	mtrace packets without platform support
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_in_idb
                    
                    	Packets received on idb without VRF
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_mtrace
                    
                    	mtrace packets with no vrf associated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim
                    
                    	PIM packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_queries
                    
                    	Query packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_reports
                    
                    	Reports in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_address_errors
                    
                    	Invalid Source Address errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: miscellaneous_errors
                    
                    	Packets dropped for other reasons
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_dvmrp
                    
                    	DVMRP packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_leaves
                    
                    	Leaves out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_mtrace
                    
                    	Mtrace packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_no_parent_interface_handle
                    
                    	Failures setting 2nd ifhandle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_pim
                    
                    	PIM packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_queries
                    
                    	Query packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_reports
                    
                    	Reports out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_input_errors
                    
                    	Incoming Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_output_errors
                    
                    	Outgoing Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_in
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_out
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: receive_socket_errors
                    
                    	Socket errors on reception
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_errors
                    
                    	Socket errors on send
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"

                        self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                        self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                        self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_errors = YLeaf(YType.uint32, "format-errors")

                        self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                        self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                        self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                        self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                        self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                        self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                        self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                        self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                        self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                        self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                        self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                        self.input_pim = YLeaf(YType.uint32, "input-pim")

                        self.input_queries = YLeaf(YType.uint32, "input-queries")

                        self.input_reports = YLeaf(YType.uint32, "input-reports")

                        self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                        self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                        self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                        self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                        self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                        self.output_pim = YLeaf(YType.uint32, "output-pim")

                        self.output_queries = YLeaf(YType.uint32, "output-queries")

                        self.output_reports = YLeaf(YType.uint32, "output-reports")

                        self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                        self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                        self.packets_in = YLeaf(YType.uint32, "packets-in")

                        self.packets_out = YLeaf(YType.uint32, "packets-out")

                        self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                        self.socket_errors = YLeaf(YType.uint32, "socket-errors")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("auxillary_data_length_errors",
                                        "bad_scope_errors",
                                        "checksum_errors",
                                        "elapsed_time",
                                        "format_errors",
                                        "get_packet_failure",
                                        "input_disabled_idb",
                                        "input_dvmrp",
                                        "input_leaves",
                                        "input_martian_address",
                                        "input_mtrace",
                                        "input_no_assigned_vrf_id",
                                        "input_no_idb",
                                        "input_no_platform_support_mtrace",
                                        "input_no_vrf_in_idb",
                                        "input_no_vrf_mtrace",
                                        "input_pim",
                                        "input_queries",
                                        "input_reports",
                                        "invalid_source_address_errors",
                                        "miscellaneous_errors",
                                        "no_socket_connection",
                                        "output_dvmrp",
                                        "output_leaves",
                                        "output_mtrace",
                                        "output_no_parent_interface_handle",
                                        "output_pim",
                                        "output_queries",
                                        "output_reports",
                                        "packet_manager_input_errors",
                                        "packet_manager_output_errors",
                                        "packets_in",
                                        "packets_out",
                                        "receive_socket_errors",
                                        "socket_errors") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.auxillary_data_length_errors.is_set or
                            self.bad_scope_errors.is_set or
                            self.checksum_errors.is_set or
                            self.elapsed_time.is_set or
                            self.format_errors.is_set or
                            self.get_packet_failure.is_set or
                            self.input_disabled_idb.is_set or
                            self.input_dvmrp.is_set or
                            self.input_leaves.is_set or
                            self.input_martian_address.is_set or
                            self.input_mtrace.is_set or
                            self.input_no_assigned_vrf_id.is_set or
                            self.input_no_idb.is_set or
                            self.input_no_platform_support_mtrace.is_set or
                            self.input_no_vrf_in_idb.is_set or
                            self.input_no_vrf_mtrace.is_set or
                            self.input_pim.is_set or
                            self.input_queries.is_set or
                            self.input_reports.is_set or
                            self.invalid_source_address_errors.is_set or
                            self.miscellaneous_errors.is_set or
                            self.no_socket_connection.is_set or
                            self.output_dvmrp.is_set or
                            self.output_leaves.is_set or
                            self.output_mtrace.is_set or
                            self.output_no_parent_interface_handle.is_set or
                            self.output_pim.is_set or
                            self.output_queries.is_set or
                            self.output_reports.is_set or
                            self.packet_manager_input_errors.is_set or
                            self.packet_manager_output_errors.is_set or
                            self.packets_in.is_set or
                            self.packets_out.is_set or
                            self.receive_socket_errors.is_set or
                            self.socket_errors.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.auxillary_data_length_errors.yfilter != YFilter.not_set or
                            self.bad_scope_errors.yfilter != YFilter.not_set or
                            self.checksum_errors.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.format_errors.yfilter != YFilter.not_set or
                            self.get_packet_failure.yfilter != YFilter.not_set or
                            self.input_disabled_idb.yfilter != YFilter.not_set or
                            self.input_dvmrp.yfilter != YFilter.not_set or
                            self.input_leaves.yfilter != YFilter.not_set or
                            self.input_martian_address.yfilter != YFilter.not_set or
                            self.input_mtrace.yfilter != YFilter.not_set or
                            self.input_no_assigned_vrf_id.yfilter != YFilter.not_set or
                            self.input_no_idb.yfilter != YFilter.not_set or
                            self.input_no_platform_support_mtrace.yfilter != YFilter.not_set or
                            self.input_no_vrf_in_idb.yfilter != YFilter.not_set or
                            self.input_no_vrf_mtrace.yfilter != YFilter.not_set or
                            self.input_pim.yfilter != YFilter.not_set or
                            self.input_queries.yfilter != YFilter.not_set or
                            self.input_reports.yfilter != YFilter.not_set or
                            self.invalid_source_address_errors.yfilter != YFilter.not_set or
                            self.miscellaneous_errors.yfilter != YFilter.not_set or
                            self.no_socket_connection.yfilter != YFilter.not_set or
                            self.output_dvmrp.yfilter != YFilter.not_set or
                            self.output_leaves.yfilter != YFilter.not_set or
                            self.output_mtrace.yfilter != YFilter.not_set or
                            self.output_no_parent_interface_handle.yfilter != YFilter.not_set or
                            self.output_pim.yfilter != YFilter.not_set or
                            self.output_queries.yfilter != YFilter.not_set or
                            self.output_reports.yfilter != YFilter.not_set or
                            self.packet_manager_input_errors.yfilter != YFilter.not_set or
                            self.packet_manager_output_errors.yfilter != YFilter.not_set or
                            self.packets_in.yfilter != YFilter.not_set or
                            self.packets_out.yfilter != YFilter.not_set or
                            self.receive_socket_errors.yfilter != YFilter.not_set or
                            self.socket_errors.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "traffic-counters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.auxillary_data_length_errors.is_set or self.auxillary_data_length_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auxillary_data_length_errors.get_name_leafdata())
                        if (self.bad_scope_errors.is_set or self.bad_scope_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bad_scope_errors.get_name_leafdata())
                        if (self.checksum_errors.is_set or self.checksum_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checksum_errors.get_name_leafdata())
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.format_errors.is_set or self.format_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.format_errors.get_name_leafdata())
                        if (self.get_packet_failure.is_set or self.get_packet_failure.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.get_packet_failure.get_name_leafdata())
                        if (self.input_disabled_idb.is_set or self.input_disabled_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_disabled_idb.get_name_leafdata())
                        if (self.input_dvmrp.is_set or self.input_dvmrp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_dvmrp.get_name_leafdata())
                        if (self.input_leaves.is_set or self.input_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_leaves.get_name_leafdata())
                        if (self.input_martian_address.is_set or self.input_martian_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_martian_address.get_name_leafdata())
                        if (self.input_mtrace.is_set or self.input_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_mtrace.get_name_leafdata())
                        if (self.input_no_assigned_vrf_id.is_set or self.input_no_assigned_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_assigned_vrf_id.get_name_leafdata())
                        if (self.input_no_idb.is_set or self.input_no_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_idb.get_name_leafdata())
                        if (self.input_no_platform_support_mtrace.is_set or self.input_no_platform_support_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_platform_support_mtrace.get_name_leafdata())
                        if (self.input_no_vrf_in_idb.is_set or self.input_no_vrf_in_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_in_idb.get_name_leafdata())
                        if (self.input_no_vrf_mtrace.is_set or self.input_no_vrf_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_mtrace.get_name_leafdata())
                        if (self.input_pim.is_set or self.input_pim.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_pim.get_name_leafdata())
                        if (self.input_queries.is_set or self.input_queries.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_queries.get_name_leafdata())
                        if (self.input_reports.is_set or self.input_reports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_reports.get_name_leafdata())
                        if (self.invalid_source_address_errors.is_set or self.invalid_source_address_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_source_address_errors.get_name_leafdata())
                        if (self.miscellaneous_errors.is_set or self.miscellaneous_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.miscellaneous_errors.get_name_leafdata())
                        if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                        if (self.output_dvmrp.is_set or self.output_dvmrp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_dvmrp.get_name_leafdata())
                        if (self.output_leaves.is_set or self.output_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_leaves.get_name_leafdata())
                        if (self.output_mtrace.is_set or self.output_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_mtrace.get_name_leafdata())
                        if (self.output_no_parent_interface_handle.is_set or self.output_no_parent_interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_no_parent_interface_handle.get_name_leafdata())
                        if (self.output_pim.is_set or self.output_pim.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_pim.get_name_leafdata())
                        if (self.output_queries.is_set or self.output_queries.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_queries.get_name_leafdata())
                        if (self.output_reports.is_set or self.output_reports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_reports.get_name_leafdata())
                        if (self.packet_manager_input_errors.is_set or self.packet_manager_input_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_manager_input_errors.get_name_leafdata())
                        if (self.packet_manager_output_errors.is_set or self.packet_manager_output_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_manager_output_errors.get_name_leafdata())
                        if (self.packets_in.is_set or self.packets_in.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_in.get_name_leafdata())
                        if (self.packets_out.is_set or self.packets_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_out.get_name_leafdata())
                        if (self.receive_socket_errors.is_set or self.receive_socket_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.receive_socket_errors.get_name_leafdata())
                        if (self.socket_errors.is_set or self.socket_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.socket_errors.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auxillary-data-length-errors" or name == "bad-scope-errors" or name == "checksum-errors" or name == "elapsed-time" or name == "format-errors" or name == "get-packet-failure" or name == "input-disabled-idb" or name == "input-dvmrp" or name == "input-leaves" or name == "input-martian-address" or name == "input-mtrace" or name == "input-no-assigned-vrf-id" or name == "input-no-idb" or name == "input-no-platform-support-mtrace" or name == "input-no-vrf-in-idb" or name == "input-no-vrf-mtrace" or name == "input-pim" or name == "input-queries" or name == "input-reports" or name == "invalid-source-address-errors" or name == "miscellaneous-errors" or name == "no-socket-connection" or name == "output-dvmrp" or name == "output-leaves" or name == "output-mtrace" or name == "output-no-parent-interface-handle" or name == "output-pim" or name == "output-queries" or name == "output-reports" or name == "packet-manager-input-errors" or name == "packet-manager-output-errors" or name == "packets-in" or name == "packets-out" or name == "receive-socket-errors" or name == "socket-errors"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "auxillary-data-length-errors"):
                            self.auxillary_data_length_errors = value
                            self.auxillary_data_length_errors.value_namespace = name_space
                            self.auxillary_data_length_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "bad-scope-errors"):
                            self.bad_scope_errors = value
                            self.bad_scope_errors.value_namespace = name_space
                            self.bad_scope_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "checksum-errors"):
                            self.checksum_errors = value
                            self.checksum_errors.value_namespace = name_space
                            self.checksum_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "format-errors"):
                            self.format_errors = value
                            self.format_errors.value_namespace = name_space
                            self.format_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "get-packet-failure"):
                            self.get_packet_failure = value
                            self.get_packet_failure.value_namespace = name_space
                            self.get_packet_failure.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-disabled-idb"):
                            self.input_disabled_idb = value
                            self.input_disabled_idb.value_namespace = name_space
                            self.input_disabled_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-dvmrp"):
                            self.input_dvmrp = value
                            self.input_dvmrp.value_namespace = name_space
                            self.input_dvmrp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-leaves"):
                            self.input_leaves = value
                            self.input_leaves.value_namespace = name_space
                            self.input_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-martian-address"):
                            self.input_martian_address = value
                            self.input_martian_address.value_namespace = name_space
                            self.input_martian_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-mtrace"):
                            self.input_mtrace = value
                            self.input_mtrace.value_namespace = name_space
                            self.input_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-assigned-vrf-id"):
                            self.input_no_assigned_vrf_id = value
                            self.input_no_assigned_vrf_id.value_namespace = name_space
                            self.input_no_assigned_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-idb"):
                            self.input_no_idb = value
                            self.input_no_idb.value_namespace = name_space
                            self.input_no_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-platform-support-mtrace"):
                            self.input_no_platform_support_mtrace = value
                            self.input_no_platform_support_mtrace.value_namespace = name_space
                            self.input_no_platform_support_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-in-idb"):
                            self.input_no_vrf_in_idb = value
                            self.input_no_vrf_in_idb.value_namespace = name_space
                            self.input_no_vrf_in_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-mtrace"):
                            self.input_no_vrf_mtrace = value
                            self.input_no_vrf_mtrace.value_namespace = name_space
                            self.input_no_vrf_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-pim"):
                            self.input_pim = value
                            self.input_pim.value_namespace = name_space
                            self.input_pim.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-queries"):
                            self.input_queries = value
                            self.input_queries.value_namespace = name_space
                            self.input_queries.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-reports"):
                            self.input_reports = value
                            self.input_reports.value_namespace = name_space
                            self.input_reports.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-source-address-errors"):
                            self.invalid_source_address_errors = value
                            self.invalid_source_address_errors.value_namespace = name_space
                            self.invalid_source_address_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "miscellaneous-errors"):
                            self.miscellaneous_errors = value
                            self.miscellaneous_errors.value_namespace = name_space
                            self.miscellaneous_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-socket-connection"):
                            self.no_socket_connection = value
                            self.no_socket_connection.value_namespace = name_space
                            self.no_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-dvmrp"):
                            self.output_dvmrp = value
                            self.output_dvmrp.value_namespace = name_space
                            self.output_dvmrp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-leaves"):
                            self.output_leaves = value
                            self.output_leaves.value_namespace = name_space
                            self.output_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-mtrace"):
                            self.output_mtrace = value
                            self.output_mtrace.value_namespace = name_space
                            self.output_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-no-parent-interface-handle"):
                            self.output_no_parent_interface_handle = value
                            self.output_no_parent_interface_handle.value_namespace = name_space
                            self.output_no_parent_interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-pim"):
                            self.output_pim = value
                            self.output_pim.value_namespace = name_space
                            self.output_pim.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-queries"):
                            self.output_queries = value
                            self.output_queries.value_namespace = name_space
                            self.output_queries.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-reports"):
                            self.output_reports = value
                            self.output_reports.value_namespace = name_space
                            self.output_reports.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-manager-input-errors"):
                            self.packet_manager_input_errors = value
                            self.packet_manager_input_errors.value_namespace = name_space
                            self.packet_manager_input_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-manager-output-errors"):
                            self.packet_manager_output_errors = value
                            self.packet_manager_output_errors.value_namespace = name_space
                            self.packet_manager_output_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "packets-in"):
                            self.packets_in = value
                            self.packets_in.value_namespace = name_space
                            self.packets_in.value_namespace_prefix = name_space_prefix
                        if(value_path == "packets-out"):
                            self.packets_out = value
                            self.packets_out.value_namespace = name_space
                            self.packets_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "receive-socket-errors"):
                            self.receive_socket_errors = value
                            self.receive_socket_errors.value_namespace = name_space
                            self.receive_socket_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "socket-errors"):
                            self.socket_errors = value
                            self.socket_errors.value_namespace = name_space
                            self.socket_errors.value_namespace_prefix = name_space_prefix


                class Groups(Entity):
                    """
                    IGMP Group Database Table
                    
                    .. attribute:: group
                    
                    	IGMP Group Entry Information
                    	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Groups.Group>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.Groups, self).__init__()

                        self.yang_name = "groups"
                        self.yang_parent_name = "vrf"

                        self.group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.Groups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.Groups, self).__setattr__(name, value)


                    class Group(Entity):
                        """
                        IGMP Group Entry Information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.Groups.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "groups"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "group_address",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.Groups.Group, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.Groups.Group, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.group_address.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "group-address" or name == "interface-name" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group"):
                            for c in self.group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.Groups.Group()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupSummary(Entity):
                    """
                    IGMP Groups Summary
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groutes
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: sg_routes
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.GroupSummary, self).__init__()

                        self.yang_name = "group-summary"
                        self.yang_parent_name = "vrf"

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.groutes = YLeaf(YType.uint32, "groutes")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.sg_routes = YLeaf(YType.uint32, "sg-routes")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_count",
                                        "groutes",
                                        "is_low_memory",
                                        "sg_routes") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.GroupSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.GroupSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.group_count.is_set or
                            self.groutes.is_set or
                            self.is_low_memory.is_set or
                            self.sg_routes.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.groutes.yfilter != YFilter.not_set or
                            self.is_low_memory.yfilter != YFilter.not_set or
                            self.sg_routes.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.groutes.is_set or self.groutes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groutes.get_name_leafdata())
                        if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                        if (self.sg_routes.is_set or self.sg_routes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_routes.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-count" or name == "groutes" or name == "is-low-memory" or name == "sg-routes"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "groutes"):
                            self.groutes = value
                            self.groutes.value_namespace = name_space
                            self.groutes.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-low-memory"):
                            self.is_low_memory = value
                            self.is_low_memory.value_namespace = name_space
                            self.is_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-routes"):
                            self.sg_routes = value
                            self.sg_routes.value_namespace = name_space
                            self.sg_routes.value_namespace_prefix = name_space_prefix


                class IfrsInterfaceSummary(Entity):
                    """
                    IGMP IFRS Interface summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary, self).__init__()

                        self.yang_name = "ifrs-interface-summary"
                        self.yang_parent_name = "vrf"

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("configuration_count",
                                        "interface_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.configuration_count.is_set or
                            self.interface_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.configuration_count.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_count.get_name_leafdata())
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "configuration-count" or name == "interface-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "configuration-count"):
                            self.configuration_count = value
                            self.configuration_count.value_namespace = name_space
                            self.configuration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix


                class GlobalInterfaceTable(Entity):
                    """
                    IGMP Global Interface 
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable, self).__init__()

                        self.yang_name = "global-interface-table"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "global-interface-table"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "global-interface-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SsmMapDetails(Entity):
                    """
                    SSM Map Detail
                    
                    .. attribute:: ssm_map_detail
                    
                    	SSM Map Detail Table information
                    	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.SsmMapDetails, self).__init__()

                        self.yang_name = "ssm-map-details"
                        self.yang_parent_name = "vrf"

                        self.ssm_map_detail = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.SsmMapDetails, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.SsmMapDetails, self).__setattr__(name, value)


                    class SsmMapDetail(Entity):
                        """
                        SSM Map Detail Table information
                        
                        .. attribute:: elapsed_time
                        
                        	Elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: expiration_time
                        
                        	Expiration Time in Seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: map_info
                        
                        	Basic Map Info
                        	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo>`
                        
                        .. attribute:: query_interval
                        
                        	Query interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: response_pending
                        
                        	Response Pending
                        	**type**\:  bool
                        
                        .. attribute:: sources
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources>`
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__init__()

                            self.yang_name = "ssm-map-detail"
                            self.yang_parent_name = "ssm-map-details"

                            self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.query_interval = YLeaf(YType.uint32, "query-interval")

                            self.response_pending = YLeaf(YType.boolean, "response-pending")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.map_info = Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                            self.map_info.parent = self
                            self._children_name_map["map_info"] = "map-info"
                            self._children_yang_names.add("map-info")

                            self.sources = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("elapsed_time",
                                            "expiration_time",
                                            "group_address",
                                            "query_interval",
                                            "response_pending",
                                            "ssm_map_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)


                        class MapInfo(Entity):
                            """
                            Basic Map Info
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                            
                            .. attribute:: map_type
                            
                            	Map Type of group
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_counts
                            
                            	Count of Sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                                self.yang_name = "map-info"
                                self.yang_parent_name = "ssm-map-detail"

                                self.map_type = YLeaf(YType.uint32, "map-type")

                                self.source_counts = YLeaf(YType.uint32, "source-counts")

                                self.group_address_xr = Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("map_type",
                                                "source_counts") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "map-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.map_type.is_set or
                                    self.source_counts.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.map_type.yfilter != YFilter.not_set or
                                    self.source_counts.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "map-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.map_type.get_name_leafdata())
                                if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_counts.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "map-type" or name == "source-counts"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "map-type"):
                                    self.map_type = value
                                    self.map_type.value_namespace = name_space
                                    self.map_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-counts"):
                                    self.source_counts = value
                                    self.source_counts.value_namespace = name_space
                                    self.source_counts.value_namespace_prefix = name_space_prefix


                        class Sources(Entity):
                            """
                            List of sources
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                                self.yang_name = "sources"
                                self.yang_parent_name = "ssm-map-detail"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sources" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sources:
                                if (c.has_data()):
                                    return True
                            return (
                                self.elapsed_time.is_set or
                                self.expiration_time.is_set or
                                self.group_address.is_set or
                                self.query_interval.is_set or
                                self.response_pending.is_set or
                                self.ssm_map_type.is_set or
                                (self.map_info is not None and self.map_info.has_data()))

                        def has_operation(self):
                            for c in self.sources:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.elapsed_time.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.response_pending.yfilter != YFilter.not_set or
                                self.ssm_map_type.yfilter != YFilter.not_set or
                                (self.map_info is not None and self.map_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ssm-map-detail" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.response_pending.is_set or self.response_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.response_pending.get_name_leafdata())
                            if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "map-info"):
                                if (self.map_info is None):
                                    self.map_info = Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                                    self.map_info.parent = self
                                    self._children_name_map["map_info"] = "map-info"
                                return self.map_info

                            if (child_yang_name == "sources"):
                                for c in self.sources:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sources.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "map-info" or name == "sources" or name == "elapsed-time" or name == "expiration-time" or name == "group-address" or name == "query-interval" or name == "response-pending" or name == "ssm-map-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "elapsed-time"):
                                self.elapsed_time = value
                                self.elapsed_time.value_namespace = name_space
                                self.elapsed_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "response-pending"):
                                self.response_pending = value
                                self.response_pending.value_namespace = name_space
                                self.response_pending.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssm-map-type"):
                                self.ssm_map_type = value
                                self.ssm_map_type.value_namespace = name_space
                                self.ssm_map_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ssm_map_detail:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ssm_map_detail:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map-details" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ssm-map-detail"):
                            for c in self.ssm_map_detail:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ssm_map_detail.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ssm-map-detail"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceStateOffs(Entity):
                    """
                    IGMP Interface state off
                    
                    .. attribute:: interface_state_off
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs, self).__init__()

                        self.yang_name = "interface-state-offs"
                        self.yang_parent_name = "vrf"

                        self.interface_state_off = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs, self).__setattr__(name, value)


                    class InterfaceStateOff(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                            self.yang_name = "interface-state-off"
                            self.yang_parent_name = "interface-state-offs"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_state_off:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_state_off:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-offs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-state-off"):
                            for c in self.interface_state_off:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_state_off.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-state-off"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.vrf_name.is_set or
                        (self.detail_groups is not None and self.detail_groups.has_data()) or
                        (self.explicit_groups is not None and self.explicit_groups.has_data()) or
                        (self.global_interface_table is not None and self.global_interface_table.has_data()) or
                        (self.group_summary is not None and self.group_summary.has_data()) or
                        (self.groups is not None and self.groups.has_data()) or
                        (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_data()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                        (self.interface_state_offs is not None and self.interface_state_offs.has_data()) or
                        (self.interface_state_ons is not None and self.interface_state_ons.has_data()) or
                        (self.interface_table is not None and self.interface_table.has_data()) or
                        (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_data()) or
                        (self.non_active_groups is not None and self.non_active_groups.has_data()) or
                        (self.ranges is not None and self.ranges.has_data()) or
                        (self.ssm_map_details is not None and self.ssm_map_details.has_data()) or
                        (self.ssm_maps is not None and self.ssm_maps.has_data()) or
                        (self.summary is not None and self.summary.has_data()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vrf_name.yfilter != YFilter.not_set or
                        (self.detail_groups is not None and self.detail_groups.has_operation()) or
                        (self.explicit_groups is not None and self.explicit_groups.has_operation()) or
                        (self.global_interface_table is not None and self.global_interface_table.has_operation()) or
                        (self.group_summary is not None and self.group_summary.has_operation()) or
                        (self.groups is not None and self.groups.has_operation()) or
                        (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_operation()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                        (self.interface_state_offs is not None and self.interface_state_offs.has_operation()) or
                        (self.interface_state_ons is not None and self.interface_state_ons.has_operation()) or
                        (self.interface_table is not None and self.interface_table.has_operation()) or
                        (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_operation()) or
                        (self.non_active_groups is not None and self.non_active_groups.has_operation()) or
                        (self.ranges is not None and self.ranges.has_operation()) or
                        (self.ssm_map_details is not None and self.ssm_map_details.has_operation()) or
                        (self.ssm_maps is not None and self.ssm_maps.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/vrfs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "detail-groups"):
                        if (self.detail_groups is None):
                            self.detail_groups = Mld.Active.Vrfs.Vrf.DetailGroups()
                            self.detail_groups.parent = self
                            self._children_name_map["detail_groups"] = "detail-groups"
                        return self.detail_groups

                    if (child_yang_name == "explicit-groups"):
                        if (self.explicit_groups is None):
                            self.explicit_groups = Mld.Active.Vrfs.Vrf.ExplicitGroups()
                            self.explicit_groups.parent = self
                            self._children_name_map["explicit_groups"] = "explicit-groups"
                        return self.explicit_groups

                    if (child_yang_name == "global-interface-table"):
                        if (self.global_interface_table is None):
                            self.global_interface_table = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable()
                            self.global_interface_table.parent = self
                            self._children_name_map["global_interface_table"] = "global-interface-table"
                        return self.global_interface_table

                    if (child_yang_name == "group-summary"):
                        if (self.group_summary is None):
                            self.group_summary = Mld.Active.Vrfs.Vrf.GroupSummary()
                            self.group_summary.parent = self
                            self._children_name_map["group_summary"] = "group-summary"
                        return self.group_summary

                    if (child_yang_name == "groups"):
                        if (self.groups is None):
                            self.groups = Mld.Active.Vrfs.Vrf.Groups()
                            self.groups.parent = self
                            self._children_name_map["groups"] = "groups"
                        return self.groups

                    if (child_yang_name == "ifrs-interface-summary"):
                        if (self.ifrs_interface_summary is None):
                            self.ifrs_interface_summary = Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary()
                            self.ifrs_interface_summary.parent = self
                            self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                        return self.ifrs_interface_summary

                    if (child_yang_name == "ifrs-interfaces"):
                        if (self.ifrs_interfaces is None):
                            self.ifrs_interfaces = Mld.Active.Vrfs.Vrf.IfrsInterfaces()
                            self.ifrs_interfaces.parent = self
                            self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                        return self.ifrs_interfaces

                    if (child_yang_name == "interface-state-offs"):
                        if (self.interface_state_offs is None):
                            self.interface_state_offs = Mld.Active.Vrfs.Vrf.InterfaceStateOffs()
                            self.interface_state_offs.parent = self
                            self._children_name_map["interface_state_offs"] = "interface-state-offs"
                        return self.interface_state_offs

                    if (child_yang_name == "interface-state-ons"):
                        if (self.interface_state_ons is None):
                            self.interface_state_ons = Mld.Active.Vrfs.Vrf.InterfaceStateOns()
                            self.interface_state_ons.parent = self
                            self._children_name_map["interface_state_ons"] = "interface-state-ons"
                        return self.interface_state_ons

                    if (child_yang_name == "interface-table"):
                        if (self.interface_table is None):
                            self.interface_table = Mld.Active.Vrfs.Vrf.InterfaceTable()
                            self.interface_table.parent = self
                            self._children_name_map["interface_table"] = "interface-table"
                        return self.interface_table

                    if (child_yang_name == "interface-unicast-qos-adjusts"):
                        if (self.interface_unicast_qos_adjusts is None):
                            self.interface_unicast_qos_adjusts = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                            self.interface_unicast_qos_adjusts.parent = self
                            self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                        return self.interface_unicast_qos_adjusts

                    if (child_yang_name == "non-active-groups"):
                        if (self.non_active_groups is None):
                            self.non_active_groups = Mld.Active.Vrfs.Vrf.NonActiveGroups()
                            self.non_active_groups.parent = self
                            self._children_name_map["non_active_groups"] = "non-active-groups"
                        return self.non_active_groups

                    if (child_yang_name == "ranges"):
                        if (self.ranges is None):
                            self.ranges = Mld.Active.Vrfs.Vrf.Ranges()
                            self.ranges.parent = self
                            self._children_name_map["ranges"] = "ranges"
                        return self.ranges

                    if (child_yang_name == "ssm-map-details"):
                        if (self.ssm_map_details is None):
                            self.ssm_map_details = Mld.Active.Vrfs.Vrf.SsmMapDetails()
                            self.ssm_map_details.parent = self
                            self._children_name_map["ssm_map_details"] = "ssm-map-details"
                        return self.ssm_map_details

                    if (child_yang_name == "ssm-maps"):
                        if (self.ssm_maps is None):
                            self.ssm_maps = Mld.Active.Vrfs.Vrf.SsmMaps()
                            self.ssm_maps.parent = self
                            self._children_name_map["ssm_maps"] = "ssm-maps"
                        return self.ssm_maps

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = Mld.Active.Vrfs.Vrf.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    if (child_yang_name == "traffic-counters"):
                        if (self.traffic_counters is None):
                            self.traffic_counters = Mld.Active.Vrfs.Vrf.TrafficCounters()
                            self.traffic_counters.parent = self
                            self._children_name_map["traffic_counters"] = "traffic-counters"
                        return self.traffic_counters

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "detail-groups" or name == "explicit-groups" or name == "global-interface-table" or name == "group-summary" or name == "groups" or name == "ifrs-interface-summary" or name == "ifrs-interfaces" or name == "interface-state-offs" or name == "interface-state-ons" or name == "interface-table" or name == "interface-unicast-qos-adjusts" or name == "non-active-groups" or name == "ranges" or name == "ssm-map-details" or name == "ssm-maps" or name == "summary" or name == "traffic-counters" or name == "vrf-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vrf-name"):
                        self.vrf_name = value
                        self.vrf_name.value_namespace = name_space
                        self.vrf_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.vrf:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.vrf:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrfs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "vrf"):
                    for c in self.vrf:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Mld.Active.Vrfs.Vrf()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.vrf.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "vrf"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Process(Entity):
            """
            Process
            
            .. attribute:: amt_gatewaies
            
            	Table containing AMT Gateway DataBase information
            	**type**\:   :py:class:`AmtGatewaies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.AmtGatewaies>`
            
            .. attribute:: amt_summary
            
            	MRIB RouteDB Expiry Information
            	**type**\:   :py:class:`AmtSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.AmtSummary>`
            
            .. attribute:: bvi_statistics
            
            	IGMP BVI Stats
            	**type**\:   :py:class:`BviStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.BviStatistics>`
            
            .. attribute:: nsf
            
            	NSF Information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.Nsr>`
            
            .. attribute:: unicast_qos_adjust_stats
            
            	IGMP Unicast\-Qos\-Adjust Statistics
            	**type**\:   :py:class:`UnicastQosAdjustStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.UnicastQosAdjustStats>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Active.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "active"

                self.amt_gatewaies = Mld.Active.Process.AmtGatewaies()
                self.amt_gatewaies.parent = self
                self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                self._children_yang_names.add("amt-gatewaies")

                self.amt_summary = Mld.Active.Process.AmtSummary()
                self.amt_summary.parent = self
                self._children_name_map["amt_summary"] = "amt-summary"
                self._children_yang_names.add("amt-summary")

                self.bvi_statistics = Mld.Active.Process.BviStatistics()
                self.bvi_statistics.parent = self
                self._children_name_map["bvi_statistics"] = "bvi-statistics"
                self._children_yang_names.add("bvi-statistics")

                self.nsf = Mld.Active.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Mld.Active.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.unicast_qos_adjust_stats = Mld.Active.Process.UnicastQosAdjustStats()
                self.unicast_qos_adjust_stats.parent = self
                self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                self._children_yang_names.add("unicast-qos-adjust-stats")


            class AmtSummary(Entity):
                """
                MRIB RouteDB Expiry Information
                
                .. attribute:: anycast_prefix
                
                	Robustness variable
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: gateway_count
                
                	Number of AMT Gateway
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_acl_configured
                
                	ACL configured under AMT
                	**type**\:  bool
                
                .. attribute:: is_gateway_simulation
                
                	AMT Gateway Simulation
                	**type**\:  bool
                
                .. attribute:: is_ou_of_resource
                
                	AMT Out Of Resource
                	**type**\:  bool
                
                .. attribute:: max_gateway
                
                	Maximum Gateway allowed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mtu
                
                	AMT Tunnel MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: prefix_length
                
                	Advertize AMT prefix length
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: query_interval
                
                	AMT Query interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: relay_address
                
                	Advertaisment for AMT Relay address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: tos
                
                	Type Of Service value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ttl
                
                	Time To Live value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_configured_maximum
                
                	AMT Tunnel configured Maximum
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_count
                
                	AMT Tunnel Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.AmtSummary, self).__init__()

                    self.yang_name = "amt-summary"
                    self.yang_parent_name = "process"

                    self.anycast_prefix = YLeaf(YType.str, "anycast-prefix")

                    self.gateway_count = YLeaf(YType.uint32, "gateway-count")

                    self.is_acl_configured = YLeaf(YType.boolean, "is-acl-configured")

                    self.is_gateway_simulation = YLeaf(YType.boolean, "is-gateway-simulation")

                    self.is_ou_of_resource = YLeaf(YType.boolean, "is-ou-of-resource")

                    self.max_gateway = YLeaf(YType.uint32, "max-gateway")

                    self.mtu = YLeaf(YType.uint32, "mtu")

                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                    self.query_interval = YLeaf(YType.uint32, "query-interval")

                    self.relay_address = YLeaf(YType.str, "relay-address")

                    self.tos = YLeaf(YType.uint32, "tos")

                    self.ttl = YLeaf(YType.uint32, "ttl")

                    self.tunnel_configured_maximum = YLeaf(YType.uint32, "tunnel-configured-maximum")

                    self.tunnel_count = YLeaf(YType.uint32, "tunnel-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("anycast_prefix",
                                    "gateway_count",
                                    "is_acl_configured",
                                    "is_gateway_simulation",
                                    "is_ou_of_resource",
                                    "max_gateway",
                                    "mtu",
                                    "prefix_length",
                                    "query_interval",
                                    "relay_address",
                                    "tos",
                                    "ttl",
                                    "tunnel_configured_maximum",
                                    "tunnel_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.Process.AmtSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.Process.AmtSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.anycast_prefix.is_set or
                        self.gateway_count.is_set or
                        self.is_acl_configured.is_set or
                        self.is_gateway_simulation.is_set or
                        self.is_ou_of_resource.is_set or
                        self.max_gateway.is_set or
                        self.mtu.is_set or
                        self.prefix_length.is_set or
                        self.query_interval.is_set or
                        self.relay_address.is_set or
                        self.tos.is_set or
                        self.ttl.is_set or
                        self.tunnel_configured_maximum.is_set or
                        self.tunnel_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.anycast_prefix.yfilter != YFilter.not_set or
                        self.gateway_count.yfilter != YFilter.not_set or
                        self.is_acl_configured.yfilter != YFilter.not_set or
                        self.is_gateway_simulation.yfilter != YFilter.not_set or
                        self.is_ou_of_resource.yfilter != YFilter.not_set or
                        self.max_gateway.yfilter != YFilter.not_set or
                        self.mtu.yfilter != YFilter.not_set or
                        self.prefix_length.yfilter != YFilter.not_set or
                        self.query_interval.yfilter != YFilter.not_set or
                        self.relay_address.yfilter != YFilter.not_set or
                        self.tos.yfilter != YFilter.not_set or
                        self.ttl.yfilter != YFilter.not_set or
                        self.tunnel_configured_maximum.yfilter != YFilter.not_set or
                        self.tunnel_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "amt-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.anycast_prefix.is_set or self.anycast_prefix.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_prefix.get_name_leafdata())
                    if (self.gateway_count.is_set or self.gateway_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gateway_count.get_name_leafdata())
                    if (self.is_acl_configured.is_set or self.is_acl_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_acl_configured.get_name_leafdata())
                    if (self.is_gateway_simulation.is_set or self.is_gateway_simulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_gateway_simulation.get_name_leafdata())
                    if (self.is_ou_of_resource.is_set or self.is_ou_of_resource.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ou_of_resource.get_name_leafdata())
                    if (self.max_gateway.is_set or self.max_gateway.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.max_gateway.get_name_leafdata())
                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mtu.get_name_leafdata())
                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                    if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.query_interval.get_name_leafdata())
                    if (self.relay_address.is_set or self.relay_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.relay_address.get_name_leafdata())
                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tos.get_name_leafdata())
                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ttl.get_name_leafdata())
                    if (self.tunnel_configured_maximum.is_set or self.tunnel_configured_maximum.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_configured_maximum.get_name_leafdata())
                    if (self.tunnel_count.is_set or self.tunnel_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "anycast-prefix" or name == "gateway-count" or name == "is-acl-configured" or name == "is-gateway-simulation" or name == "is-ou-of-resource" or name == "max-gateway" or name == "mtu" or name == "prefix-length" or name == "query-interval" or name == "relay-address" or name == "tos" or name == "ttl" or name == "tunnel-configured-maximum" or name == "tunnel-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "anycast-prefix"):
                        self.anycast_prefix = value
                        self.anycast_prefix.value_namespace = name_space
                        self.anycast_prefix.value_namespace_prefix = name_space_prefix
                    if(value_path == "gateway-count"):
                        self.gateway_count = value
                        self.gateway_count.value_namespace = name_space
                        self.gateway_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-acl-configured"):
                        self.is_acl_configured = value
                        self.is_acl_configured.value_namespace = name_space
                        self.is_acl_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-gateway-simulation"):
                        self.is_gateway_simulation = value
                        self.is_gateway_simulation.value_namespace = name_space
                        self.is_gateway_simulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ou-of-resource"):
                        self.is_ou_of_resource = value
                        self.is_ou_of_resource.value_namespace = name_space
                        self.is_ou_of_resource.value_namespace_prefix = name_space_prefix
                    if(value_path == "max-gateway"):
                        self.max_gateway = value
                        self.max_gateway.value_namespace = name_space
                        self.max_gateway.value_namespace_prefix = name_space_prefix
                    if(value_path == "mtu"):
                        self.mtu = value
                        self.mtu.value_namespace = name_space
                        self.mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "prefix-length"):
                        self.prefix_length = value
                        self.prefix_length.value_namespace = name_space
                        self.prefix_length.value_namespace_prefix = name_space_prefix
                    if(value_path == "query-interval"):
                        self.query_interval = value
                        self.query_interval.value_namespace = name_space
                        self.query_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "relay-address"):
                        self.relay_address = value
                        self.relay_address.value_namespace = name_space
                        self.relay_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "tos"):
                        self.tos = value
                        self.tos.value_namespace = name_space
                        self.tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ttl"):
                        self.ttl = value
                        self.ttl.value_namespace = name_space
                        self.ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-configured-maximum"):
                        self.tunnel_configured_maximum = value
                        self.tunnel_configured_maximum.value_namespace = name_space
                        self.tunnel_configured_maximum.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-count"):
                        self.tunnel_count = value
                        self.tunnel_count.value_namespace = name_space
                        self.tunnel_count.value_namespace_prefix = name_space_prefix


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: collab_conv_done
                
                	Collaborators convergence done
                	**type**\:  bool
                
                .. attribute:: count_proc_connection_dn
                
                	No. of times process connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_proc_connection_up
                
                	No. of times process connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_proc
                
                	Time when process came up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_dn
                
                	Time when process connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_up
                
                	Time when process connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_proc_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"

                    self.collab_conv_done = YLeaf(YType.boolean, "collab-conv-done")

                    self.count_proc_connection_dn = YLeaf(YType.uint32, "count-proc-connection-dn")

                    self.count_proc_connection_up = YLeaf(YType.uint32, "count-proc-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_proc = YLeaf(YType.uint64, "last-proc")

                    self.last_proc_connection_dn = YLeaf(YType.uint64, "last-proc-connection-dn")

                    self.last_proc_connection_up = YLeaf(YType.uint64, "last-proc-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_proc_connected = YLeaf(YType.boolean, "partner-proc-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.state = YLeaf(YType.uint8, "state")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("collab_conv_done",
                                    "count_proc_connection_dn",
                                    "count_proc_connection_up",
                                    "count_rmf_not_ready",
                                    "count_rmf_ready",
                                    "last_proc",
                                    "last_proc_connection_dn",
                                    "last_proc_connection_up",
                                    "last_rmf_not_ready",
                                    "last_rmf_ready",
                                    "partner_proc_connected",
                                    "rmf_notification_done",
                                    "state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.Process.Nsr, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.Process.Nsr, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.collab_conv_done.is_set or
                        self.count_proc_connection_dn.is_set or
                        self.count_proc_connection_up.is_set or
                        self.count_rmf_not_ready.is_set or
                        self.count_rmf_ready.is_set or
                        self.last_proc.is_set or
                        self.last_proc_connection_dn.is_set or
                        self.last_proc_connection_up.is_set or
                        self.last_rmf_not_ready.is_set or
                        self.last_rmf_ready.is_set or
                        self.partner_proc_connected.is_set or
                        self.rmf_notification_done.is_set or
                        self.state.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.collab_conv_done.yfilter != YFilter.not_set or
                        self.count_proc_connection_dn.yfilter != YFilter.not_set or
                        self.count_proc_connection_up.yfilter != YFilter.not_set or
                        self.count_rmf_not_ready.yfilter != YFilter.not_set or
                        self.count_rmf_ready.yfilter != YFilter.not_set or
                        self.last_proc.yfilter != YFilter.not_set or
                        self.last_proc_connection_dn.yfilter != YFilter.not_set or
                        self.last_proc_connection_up.yfilter != YFilter.not_set or
                        self.last_rmf_not_ready.yfilter != YFilter.not_set or
                        self.last_rmf_ready.yfilter != YFilter.not_set or
                        self.partner_proc_connected.yfilter != YFilter.not_set or
                        self.rmf_notification_done.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.collab_conv_done.is_set or self.collab_conv_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collab_conv_done.get_name_leafdata())
                    if (self.count_proc_connection_dn.is_set or self.count_proc_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_proc_connection_dn.get_name_leafdata())
                    if (self.count_proc_connection_up.is_set or self.count_proc_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_proc_connection_up.get_name_leafdata())
                    if (self.count_rmf_not_ready.is_set or self.count_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_not_ready.get_name_leafdata())
                    if (self.count_rmf_ready.is_set or self.count_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_ready.get_name_leafdata())
                    if (self.last_proc.is_set or self.last_proc.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc.get_name_leafdata())
                    if (self.last_proc_connection_dn.is_set or self.last_proc_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc_connection_dn.get_name_leafdata())
                    if (self.last_proc_connection_up.is_set or self.last_proc_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc_connection_up.get_name_leafdata())
                    if (self.last_rmf_not_ready.is_set or self.last_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_not_ready.get_name_leafdata())
                    if (self.last_rmf_ready.is_set or self.last_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_ready.get_name_leafdata())
                    if (self.partner_proc_connected.is_set or self.partner_proc_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_proc_connected.get_name_leafdata())
                    if (self.rmf_notification_done.is_set or self.rmf_notification_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_notification_done.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "collab-conv-done" or name == "count-proc-connection-dn" or name == "count-proc-connection-up" or name == "count-rmf-not-ready" or name == "count-rmf-ready" or name == "last-proc" or name == "last-proc-connection-dn" or name == "last-proc-connection-up" or name == "last-rmf-not-ready" or name == "last-rmf-ready" or name == "partner-proc-connected" or name == "rmf-notification-done" or name == "state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "collab-conv-done"):
                        self.collab_conv_done = value
                        self.collab_conv_done.value_namespace = name_space
                        self.collab_conv_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-proc-connection-dn"):
                        self.count_proc_connection_dn = value
                        self.count_proc_connection_dn.value_namespace = name_space
                        self.count_proc_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-proc-connection-up"):
                        self.count_proc_connection_up = value
                        self.count_proc_connection_up.value_namespace = name_space
                        self.count_proc_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-not-ready"):
                        self.count_rmf_not_ready = value
                        self.count_rmf_not_ready.value_namespace = name_space
                        self.count_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-ready"):
                        self.count_rmf_ready = value
                        self.count_rmf_ready.value_namespace = name_space
                        self.count_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc"):
                        self.last_proc = value
                        self.last_proc.value_namespace = name_space
                        self.last_proc.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc-connection-dn"):
                        self.last_proc_connection_dn = value
                        self.last_proc_connection_dn.value_namespace = name_space
                        self.last_proc_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc-connection-up"):
                        self.last_proc_connection_up = value
                        self.last_proc_connection_up.value_namespace = name_space
                        self.last_proc_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-not-ready"):
                        self.last_rmf_not_ready = value
                        self.last_rmf_not_ready.value_namespace = name_space
                        self.last_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-ready"):
                        self.last_rmf_ready = value
                        self.last_rmf_ready.value_namespace = name_space
                        self.last_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-proc-connected"):
                        self.partner_proc_connected = value
                        self.partner_proc_connected.value_namespace = name_space
                        self.partner_proc_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-notification-done"):
                        self.rmf_notification_done = value
                        self.rmf_notification_done.value_namespace = name_space
                        self.rmf_notification_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix


            class AmtGatewaies(Entity):
                """
                Table containing AMT Gateway DataBase
                information
                
                .. attribute:: amt_gateway
                
                	AMT Gateway DataBase information
                	**type**\: list of    :py:class:`AmtGateway <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.AmtGatewaies.AmtGateway>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.AmtGatewaies, self).__init__()

                    self.yang_name = "amt-gatewaies"
                    self.yang_parent_name = "process"

                    self.amt_gateway = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.Process.AmtGatewaies, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.Process.AmtGatewaies, self).__setattr__(name, value)


                class AmtGateway(Entity):
                    """
                    AMT Gateway DataBase information
                    
                    .. attribute:: amt_nonce
                    
                    	Nonce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amt_port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amtgw
                    
                    	GW
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: amtnh
                    
                    	AMT NH
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gateway_address
                    
                    	Gateway Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: idb
                    
                    	IDB
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: key_len
                    
                    	Len
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_in
                    
                    	UpdIn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_out
                    
                    	UpdOut
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Process.AmtGatewaies.AmtGateway, self).__init__()

                        self.yang_name = "amt-gateway"
                        self.yang_parent_name = "amt-gatewaies"

                        self.amt_nonce = YLeaf(YType.uint32, "amt-nonce")

                        self.amt_port = YLeaf(YType.uint32, "amt-port")

                        self.amtgw = YLeaf(YType.str, "amtgw")

                        self.amtnh = YLeaf(YType.uint32, "amtnh")

                        self.gateway_address = YLeaf(YType.str, "gateway-address")

                        self.idb = YLeaf(YType.uint64, "idb")

                        self.key_len = YLeaf(YType.uint32, "key-len")

                        self.mem_upd_in = YLeaf(YType.uint32, "mem-upd-in")

                        self.mem_upd_out = YLeaf(YType.uint32, "mem-upd-out")

                        self.port = YLeaf(YType.int32, "port")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("amt_nonce",
                                        "amt_port",
                                        "amtgw",
                                        "amtnh",
                                        "gateway_address",
                                        "idb",
                                        "key_len",
                                        "mem_upd_in",
                                        "mem_upd_out",
                                        "port") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.Process.AmtGatewaies.AmtGateway, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.Process.AmtGatewaies.AmtGateway, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.amt_nonce.is_set or
                            self.amt_port.is_set or
                            self.amtgw.is_set or
                            self.amtnh.is_set or
                            self.gateway_address.is_set or
                            self.idb.is_set or
                            self.key_len.is_set or
                            self.mem_upd_in.is_set or
                            self.mem_upd_out.is_set or
                            self.port.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.amt_nonce.yfilter != YFilter.not_set or
                            self.amt_port.yfilter != YFilter.not_set or
                            self.amtgw.yfilter != YFilter.not_set or
                            self.amtnh.yfilter != YFilter.not_set or
                            self.gateway_address.yfilter != YFilter.not_set or
                            self.idb.yfilter != YFilter.not_set or
                            self.key_len.yfilter != YFilter.not_set or
                            self.mem_upd_in.yfilter != YFilter.not_set or
                            self.mem_upd_out.yfilter != YFilter.not_set or
                            self.port.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "amt-gateway" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/amt-gatewaies/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.amt_nonce.is_set or self.amt_nonce.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amt_nonce.get_name_leafdata())
                        if (self.amt_port.is_set or self.amt_port.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amt_port.get_name_leafdata())
                        if (self.amtgw.is_set or self.amtgw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amtgw.get_name_leafdata())
                        if (self.amtnh.is_set or self.amtnh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amtnh.get_name_leafdata())
                        if (self.gateway_address.is_set or self.gateway_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gateway_address.get_name_leafdata())
                        if (self.idb.is_set or self.idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb.get_name_leafdata())
                        if (self.key_len.is_set or self.key_len.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.key_len.get_name_leafdata())
                        if (self.mem_upd_in.is_set or self.mem_upd_in.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mem_upd_in.get_name_leafdata())
                        if (self.mem_upd_out.is_set or self.mem_upd_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mem_upd_out.get_name_leafdata())
                        if (self.port.is_set or self.port.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "amt-nonce" or name == "amt-port" or name == "amtgw" or name == "amtnh" or name == "gateway-address" or name == "idb" or name == "key-len" or name == "mem-upd-in" or name == "mem-upd-out" or name == "port"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "amt-nonce"):
                            self.amt_nonce = value
                            self.amt_nonce.value_namespace = name_space
                            self.amt_nonce.value_namespace_prefix = name_space_prefix
                        if(value_path == "amt-port"):
                            self.amt_port = value
                            self.amt_port.value_namespace = name_space
                            self.amt_port.value_namespace_prefix = name_space_prefix
                        if(value_path == "amtgw"):
                            self.amtgw = value
                            self.amtgw.value_namespace = name_space
                            self.amtgw.value_namespace_prefix = name_space_prefix
                        if(value_path == "amtnh"):
                            self.amtnh = value
                            self.amtnh.value_namespace = name_space
                            self.amtnh.value_namespace_prefix = name_space_prefix
                        if(value_path == "gateway-address"):
                            self.gateway_address = value
                            self.gateway_address.value_namespace = name_space
                            self.gateway_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb"):
                            self.idb = value
                            self.idb.value_namespace = name_space
                            self.idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "key-len"):
                            self.key_len = value
                            self.key_len.value_namespace = name_space
                            self.key_len.value_namespace_prefix = name_space_prefix
                        if(value_path == "mem-upd-in"):
                            self.mem_upd_in = value
                            self.mem_upd_in.value_namespace = name_space
                            self.mem_upd_in.value_namespace_prefix = name_space_prefix
                        if(value_path == "mem-upd-out"):
                            self.mem_upd_out = value
                            self.mem_upd_out.value_namespace = name_space
                            self.mem_upd_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "port"):
                            self.port = value
                            self.port.value_namespace = name_space
                            self.port.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.amt_gateway:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.amt_gateway:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "amt-gatewaies" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "amt-gateway"):
                        for c in self.amt_gateway:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.Process.AmtGatewaies.AmtGateway()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.amt_gateway.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "amt-gateway"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class UnicastQosAdjustStats(Entity):
                """
                IGMP Unicast\-Qos\-Adjust Statistics
                
                .. attribute:: add_to_batches
                
                	Add to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: batches
                
                	I2Q Rate Batch count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: delete_to_batches
                
                	Delete to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_qos_s_sweeped
                
                	Is QOS Sweeped once 
                	**type**\:  bool
                
                .. attribute:: is_resync_received
                
                	Is Resync request received
                	**type**\:  bool
                
                .. attribute:: is_resync_required
                
                	Is Resync required
                	**type**\:  bool
                
                .. attribute:: is_resync_start_sent
                
                	Is Resync Start message sent
                	**type**\:  bool
                
                .. attribute:: last_download_time
                
                	Time elapsed since Last download to QOS in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: last_sweep_time
                
                	Time elapsed since Last mark and sweep in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: queues
                
                	I2Q Queue count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: received_resync_requests
                
                	Number of Resync request received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_comm_errors
                
                	Send Error due to comms count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_errors
                
                	Number of Send errors in batch
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_partial_errors
                
                	Send Error due to partial issue count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_success
                
                	Send Success count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sent_resync_bulks
                
                	Number of bulks sent for last resync received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.UnicastQosAdjustStats, self).__init__()

                    self.yang_name = "unicast-qos-adjust-stats"
                    self.yang_parent_name = "process"

                    self.add_to_batches = YLeaf(YType.uint32, "add-to-batches")

                    self.batches = YLeaf(YType.uint16, "batches")

                    self.delete_to_batches = YLeaf(YType.uint32, "delete-to-batches")

                    self.is_qos_s_sweeped = YLeaf(YType.boolean, "is-qos-s-sweeped")

                    self.is_resync_received = YLeaf(YType.boolean, "is-resync-received")

                    self.is_resync_required = YLeaf(YType.boolean, "is-resync-required")

                    self.is_resync_start_sent = YLeaf(YType.boolean, "is-resync-start-sent")

                    self.last_download_time = YLeaf(YType.uint64, "last-download-time")

                    self.last_sweep_time = YLeaf(YType.uint64, "last-sweep-time")

                    self.queues = YLeaf(YType.uint16, "queues")

                    self.received_resync_requests = YLeaf(YType.uint32, "received-resync-requests")

                    self.send_comm_errors = YLeaf(YType.uint32, "send-comm-errors")

                    self.send_errors = YLeaf(YType.uint32, "send-errors")

                    self.send_partial_errors = YLeaf(YType.uint32, "send-partial-errors")

                    self.send_success = YLeaf(YType.uint32, "send-success")

                    self.sent_resync_bulks = YLeaf(YType.uint32, "sent-resync-bulks")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("add_to_batches",
                                    "batches",
                                    "delete_to_batches",
                                    "is_qos_s_sweeped",
                                    "is_resync_received",
                                    "is_resync_required",
                                    "is_resync_start_sent",
                                    "last_download_time",
                                    "last_sweep_time",
                                    "queues",
                                    "received_resync_requests",
                                    "send_comm_errors",
                                    "send_errors",
                                    "send_partial_errors",
                                    "send_success",
                                    "sent_resync_bulks") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.Process.UnicastQosAdjustStats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.Process.UnicastQosAdjustStats, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.add_to_batches.is_set or
                        self.batches.is_set or
                        self.delete_to_batches.is_set or
                        self.is_qos_s_sweeped.is_set or
                        self.is_resync_received.is_set or
                        self.is_resync_required.is_set or
                        self.is_resync_start_sent.is_set or
                        self.last_download_time.is_set or
                        self.last_sweep_time.is_set or
                        self.queues.is_set or
                        self.received_resync_requests.is_set or
                        self.send_comm_errors.is_set or
                        self.send_errors.is_set or
                        self.send_partial_errors.is_set or
                        self.send_success.is_set or
                        self.sent_resync_bulks.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.add_to_batches.yfilter != YFilter.not_set or
                        self.batches.yfilter != YFilter.not_set or
                        self.delete_to_batches.yfilter != YFilter.not_set or
                        self.is_qos_s_sweeped.yfilter != YFilter.not_set or
                        self.is_resync_received.yfilter != YFilter.not_set or
                        self.is_resync_required.yfilter != YFilter.not_set or
                        self.is_resync_start_sent.yfilter != YFilter.not_set or
                        self.last_download_time.yfilter != YFilter.not_set or
                        self.last_sweep_time.yfilter != YFilter.not_set or
                        self.queues.yfilter != YFilter.not_set or
                        self.received_resync_requests.yfilter != YFilter.not_set or
                        self.send_comm_errors.yfilter != YFilter.not_set or
                        self.send_errors.yfilter != YFilter.not_set or
                        self.send_partial_errors.yfilter != YFilter.not_set or
                        self.send_success.yfilter != YFilter.not_set or
                        self.sent_resync_bulks.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "unicast-qos-adjust-stats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.add_to_batches.is_set or self.add_to_batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.add_to_batches.get_name_leafdata())
                    if (self.batches.is_set or self.batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.batches.get_name_leafdata())
                    if (self.delete_to_batches.is_set or self.delete_to_batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.delete_to_batches.get_name_leafdata())
                    if (self.is_qos_s_sweeped.is_set or self.is_qos_s_sweeped.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_qos_s_sweeped.get_name_leafdata())
                    if (self.is_resync_received.is_set or self.is_resync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_received.get_name_leafdata())
                    if (self.is_resync_required.is_set or self.is_resync_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_required.get_name_leafdata())
                    if (self.is_resync_start_sent.is_set or self.is_resync_start_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_start_sent.get_name_leafdata())
                    if (self.last_download_time.is_set or self.last_download_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_download_time.get_name_leafdata())
                    if (self.last_sweep_time.is_set or self.last_sweep_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_sweep_time.get_name_leafdata())
                    if (self.queues.is_set or self.queues.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.queues.get_name_leafdata())
                    if (self.received_resync_requests.is_set or self.received_resync_requests.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.received_resync_requests.get_name_leafdata())
                    if (self.send_comm_errors.is_set or self.send_comm_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_comm_errors.get_name_leafdata())
                    if (self.send_errors.is_set or self.send_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_errors.get_name_leafdata())
                    if (self.send_partial_errors.is_set or self.send_partial_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_partial_errors.get_name_leafdata())
                    if (self.send_success.is_set or self.send_success.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_success.get_name_leafdata())
                    if (self.sent_resync_bulks.is_set or self.sent_resync_bulks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sent_resync_bulks.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "add-to-batches" or name == "batches" or name == "delete-to-batches" or name == "is-qos-s-sweeped" or name == "is-resync-received" or name == "is-resync-required" or name == "is-resync-start-sent" or name == "last-download-time" or name == "last-sweep-time" or name == "queues" or name == "received-resync-requests" or name == "send-comm-errors" or name == "send-errors" or name == "send-partial-errors" or name == "send-success" or name == "sent-resync-bulks"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "add-to-batches"):
                        self.add_to_batches = value
                        self.add_to_batches.value_namespace = name_space
                        self.add_to_batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "batches"):
                        self.batches = value
                        self.batches.value_namespace = name_space
                        self.batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "delete-to-batches"):
                        self.delete_to_batches = value
                        self.delete_to_batches.value_namespace = name_space
                        self.delete_to_batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-qos-s-sweeped"):
                        self.is_qos_s_sweeped = value
                        self.is_qos_s_sweeped.value_namespace = name_space
                        self.is_qos_s_sweeped.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-received"):
                        self.is_resync_received = value
                        self.is_resync_received.value_namespace = name_space
                        self.is_resync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-required"):
                        self.is_resync_required = value
                        self.is_resync_required.value_namespace = name_space
                        self.is_resync_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-start-sent"):
                        self.is_resync_start_sent = value
                        self.is_resync_start_sent.value_namespace = name_space
                        self.is_resync_start_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-download-time"):
                        self.last_download_time = value
                        self.last_download_time.value_namespace = name_space
                        self.last_download_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-sweep-time"):
                        self.last_sweep_time = value
                        self.last_sweep_time.value_namespace = name_space
                        self.last_sweep_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "queues"):
                        self.queues = value
                        self.queues.value_namespace = name_space
                        self.queues.value_namespace_prefix = name_space_prefix
                    if(value_path == "received-resync-requests"):
                        self.received_resync_requests = value
                        self.received_resync_requests.value_namespace = name_space
                        self.received_resync_requests.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-comm-errors"):
                        self.send_comm_errors = value
                        self.send_comm_errors.value_namespace = name_space
                        self.send_comm_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-errors"):
                        self.send_errors = value
                        self.send_errors.value_namespace = name_space
                        self.send_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-partial-errors"):
                        self.send_partial_errors = value
                        self.send_partial_errors.value_namespace = name_space
                        self.send_partial_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-success"):
                        self.send_success = value
                        self.send_success.value_namespace = name_space
                        self.send_success.value_namespace_prefix = name_space_prefix
                    if(value_path == "sent-resync-bulks"):
                        self.sent_resync_bulks = value
                        self.sent_resync_bulks.value_namespace = name_space
                        self.sent_resync_bulks.value_namespace_prefix = name_space_prefix


            class BviStatistics(Entity):
                """
                IGMP BVI Stats
                
                .. attribute:: null_buffer_handles
                
                	Number of AIPC NULL buffer handles
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_buffers
                
                	Number of AIPC buffers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_buffers
                
                	Number of AIPC buffers released
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_fail_buffers
                
                	Number of AIPC buffers release failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_igmp_packet_success
                
                	Number of IGMP protocol messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_close_notif
                
                	Number of AIPC close notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_connect_notif
                
                	Number of AIPC connect notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_error_notif
                
                	Number of AIPC error notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_input_wait_notif
                
                	Number of AIPC input waiting notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_lwm_notif
                
                	Number of AIPC LWM notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_open_notif
                
                	Number of AIPC open notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_output_notif
                
                	Number of AIPC output notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_publish_notif
                
                	Number of AIPC publish notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_q_full_notif
                
                	Number of AIPC queue full notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_send_status_notif
                
                	Number of AIPC send status notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_blocks
                
                	Number of AIPC buffers send blocked
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffer_errors
                
                	Number of AIPC transmission errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffers
                
                	Number of AIPC buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_mrouter_buffers
                
                	Number of IGMP Mrouter buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_protocol_buffers
                
                	Number of IGMP protocol buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_buffers
                
                	Number of IGMP Unknown buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_dc
                
                	Number of WTX messages dropped due to disconnect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_nomem
                
                	Number of WTX messages dropped to memory
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_freed
                
                	Number of WTX messages freed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_proto_sent
                
                	Number of WTX messages sent to Protocol
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_recvd
                
                	Number of WTX messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_sent
                
                	Number of WTX messages sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.BviStatistics, self).__init__()

                    self.yang_name = "bvi-statistics"
                    self.yang_parent_name = "process"

                    self.null_buffer_handles = YLeaf(YType.uint32, "null-buffer-handles")

                    self.receive_buffers = YLeaf(YType.uint32, "receive-buffers")

                    self.release_buffers = YLeaf(YType.uint32, "release-buffers")

                    self.release_fail_buffers = YLeaf(YType.uint32, "release-fail-buffers")

                    self.rx_add_mrouter_msg = YLeaf(YType.uint32, "rx-add-mrouter-msg")

                    self.rx_delete_mrouter_msg = YLeaf(YType.uint32, "rx-delete-mrouter-msg")

                    self.rx_igmp_packet_success = YLeaf(YType.uint32, "rx-igmp-packet-success")

                    self.rx_ipc_close_notif = YLeaf(YType.uint32, "rx-ipc-close-notif")

                    self.rx_ipc_connect_notif = YLeaf(YType.uint32, "rx-ipc-connect-notif")

                    self.rx_ipc_error_notif = YLeaf(YType.uint32, "rx-ipc-error-notif")

                    self.rx_ipc_input_wait_notif = YLeaf(YType.uint32, "rx-ipc-input-wait-notif")

                    self.rx_ipc_lwm_notif = YLeaf(YType.uint32, "rx-ipc-lwm-notif")

                    self.rx_ipc_open_notif = YLeaf(YType.uint32, "rx-ipc-open-notif")

                    self.rx_ipc_output_notif = YLeaf(YType.uint32, "rx-ipc-output-notif")

                    self.rx_ipc_publish_notif = YLeaf(YType.uint32, "rx-ipc-publish-notif")

                    self.rx_ipc_q_full_notif = YLeaf(YType.uint32, "rx-ipc-q-full-notif")

                    self.rx_ipc_send_status_notif = YLeaf(YType.uint32, "rx-ipc-send-status-notif")

                    self.rx_sweep_mrouter_msg = YLeaf(YType.uint32, "rx-sweep-mrouter-msg")

                    self.rx_unknown_mrouter_msg = YLeaf(YType.uint32, "rx-unknown-mrouter-msg")

                    self.send_blocks = YLeaf(YType.uint32, "send-blocks")

                    self.tx_add_mrouter_msg = YLeaf(YType.uint32, "tx-add-mrouter-msg")

                    self.tx_buffer_errors = YLeaf(YType.uint32, "tx-buffer-errors")

                    self.tx_buffers = YLeaf(YType.uint32, "tx-buffers")

                    self.tx_delete_mrouter_msg = YLeaf(YType.uint32, "tx-delete-mrouter-msg")

                    self.tx_mrouter_buffers = YLeaf(YType.uint32, "tx-mrouter-buffers")

                    self.tx_protocol_buffers = YLeaf(YType.uint32, "tx-protocol-buffers")

                    self.tx_sweep_mrouter_msg = YLeaf(YType.uint32, "tx-sweep-mrouter-msg")

                    self.tx_unknown_buffers = YLeaf(YType.uint32, "tx-unknown-buffers")

                    self.tx_unknown_mrouter_msg = YLeaf(YType.uint32, "tx-unknown-mrouter-msg")

                    self.wtx_msg_drop_dc = YLeaf(YType.uint32, "wtx-msg-drop-dc")

                    self.wtx_msg_drop_nomem = YLeaf(YType.uint32, "wtx-msg-drop-nomem")

                    self.wtx_msg_freed = YLeaf(YType.uint32, "wtx-msg-freed")

                    self.wtx_msg_proto_sent = YLeaf(YType.uint32, "wtx-msg-proto-sent")

                    self.wtx_msg_recvd = YLeaf(YType.uint32, "wtx-msg-recvd")

                    self.wtx_msg_sent = YLeaf(YType.uint32, "wtx-msg-sent")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("null_buffer_handles",
                                    "receive_buffers",
                                    "release_buffers",
                                    "release_fail_buffers",
                                    "rx_add_mrouter_msg",
                                    "rx_delete_mrouter_msg",
                                    "rx_igmp_packet_success",
                                    "rx_ipc_close_notif",
                                    "rx_ipc_connect_notif",
                                    "rx_ipc_error_notif",
                                    "rx_ipc_input_wait_notif",
                                    "rx_ipc_lwm_notif",
                                    "rx_ipc_open_notif",
                                    "rx_ipc_output_notif",
                                    "rx_ipc_publish_notif",
                                    "rx_ipc_q_full_notif",
                                    "rx_ipc_send_status_notif",
                                    "rx_sweep_mrouter_msg",
                                    "rx_unknown_mrouter_msg",
                                    "send_blocks",
                                    "tx_add_mrouter_msg",
                                    "tx_buffer_errors",
                                    "tx_buffers",
                                    "tx_delete_mrouter_msg",
                                    "tx_mrouter_buffers",
                                    "tx_protocol_buffers",
                                    "tx_sweep_mrouter_msg",
                                    "tx_unknown_buffers",
                                    "tx_unknown_mrouter_msg",
                                    "wtx_msg_drop_dc",
                                    "wtx_msg_drop_nomem",
                                    "wtx_msg_freed",
                                    "wtx_msg_proto_sent",
                                    "wtx_msg_recvd",
                                    "wtx_msg_sent") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.Process.BviStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.Process.BviStatistics, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.null_buffer_handles.is_set or
                        self.receive_buffers.is_set or
                        self.release_buffers.is_set or
                        self.release_fail_buffers.is_set or
                        self.rx_add_mrouter_msg.is_set or
                        self.rx_delete_mrouter_msg.is_set or
                        self.rx_igmp_packet_success.is_set or
                        self.rx_ipc_close_notif.is_set or
                        self.rx_ipc_connect_notif.is_set or
                        self.rx_ipc_error_notif.is_set or
                        self.rx_ipc_input_wait_notif.is_set or
                        self.rx_ipc_lwm_notif.is_set or
                        self.rx_ipc_open_notif.is_set or
                        self.rx_ipc_output_notif.is_set or
                        self.rx_ipc_publish_notif.is_set or
                        self.rx_ipc_q_full_notif.is_set or
                        self.rx_ipc_send_status_notif.is_set or
                        self.rx_sweep_mrouter_msg.is_set or
                        self.rx_unknown_mrouter_msg.is_set or
                        self.send_blocks.is_set or
                        self.tx_add_mrouter_msg.is_set or
                        self.tx_buffer_errors.is_set or
                        self.tx_buffers.is_set or
                        self.tx_delete_mrouter_msg.is_set or
                        self.tx_mrouter_buffers.is_set or
                        self.tx_protocol_buffers.is_set or
                        self.tx_sweep_mrouter_msg.is_set or
                        self.tx_unknown_buffers.is_set or
                        self.tx_unknown_mrouter_msg.is_set or
                        self.wtx_msg_drop_dc.is_set or
                        self.wtx_msg_drop_nomem.is_set or
                        self.wtx_msg_freed.is_set or
                        self.wtx_msg_proto_sent.is_set or
                        self.wtx_msg_recvd.is_set or
                        self.wtx_msg_sent.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.null_buffer_handles.yfilter != YFilter.not_set or
                        self.receive_buffers.yfilter != YFilter.not_set or
                        self.release_buffers.yfilter != YFilter.not_set or
                        self.release_fail_buffers.yfilter != YFilter.not_set or
                        self.rx_add_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_delete_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_igmp_packet_success.yfilter != YFilter.not_set or
                        self.rx_ipc_close_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_connect_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_error_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_input_wait_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_lwm_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_open_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_output_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_publish_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_q_full_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_send_status_notif.yfilter != YFilter.not_set or
                        self.rx_sweep_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_unknown_mrouter_msg.yfilter != YFilter.not_set or
                        self.send_blocks.yfilter != YFilter.not_set or
                        self.tx_add_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_buffer_errors.yfilter != YFilter.not_set or
                        self.tx_buffers.yfilter != YFilter.not_set or
                        self.tx_delete_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_mrouter_buffers.yfilter != YFilter.not_set or
                        self.tx_protocol_buffers.yfilter != YFilter.not_set or
                        self.tx_sweep_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_unknown_buffers.yfilter != YFilter.not_set or
                        self.tx_unknown_mrouter_msg.yfilter != YFilter.not_set or
                        self.wtx_msg_drop_dc.yfilter != YFilter.not_set or
                        self.wtx_msg_drop_nomem.yfilter != YFilter.not_set or
                        self.wtx_msg_freed.yfilter != YFilter.not_set or
                        self.wtx_msg_proto_sent.yfilter != YFilter.not_set or
                        self.wtx_msg_recvd.yfilter != YFilter.not_set or
                        self.wtx_msg_sent.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bvi-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.null_buffer_handles.is_set or self.null_buffer_handles.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.null_buffer_handles.get_name_leafdata())
                    if (self.receive_buffers.is_set or self.receive_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.receive_buffers.get_name_leafdata())
                    if (self.release_buffers.is_set or self.release_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.release_buffers.get_name_leafdata())
                    if (self.release_fail_buffers.is_set or self.release_fail_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.release_fail_buffers.get_name_leafdata())
                    if (self.rx_add_mrouter_msg.is_set or self.rx_add_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_add_mrouter_msg.get_name_leafdata())
                    if (self.rx_delete_mrouter_msg.is_set or self.rx_delete_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_delete_mrouter_msg.get_name_leafdata())
                    if (self.rx_igmp_packet_success.is_set or self.rx_igmp_packet_success.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_igmp_packet_success.get_name_leafdata())
                    if (self.rx_ipc_close_notif.is_set or self.rx_ipc_close_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_close_notif.get_name_leafdata())
                    if (self.rx_ipc_connect_notif.is_set or self.rx_ipc_connect_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_connect_notif.get_name_leafdata())
                    if (self.rx_ipc_error_notif.is_set or self.rx_ipc_error_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_error_notif.get_name_leafdata())
                    if (self.rx_ipc_input_wait_notif.is_set or self.rx_ipc_input_wait_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_input_wait_notif.get_name_leafdata())
                    if (self.rx_ipc_lwm_notif.is_set or self.rx_ipc_lwm_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_lwm_notif.get_name_leafdata())
                    if (self.rx_ipc_open_notif.is_set or self.rx_ipc_open_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_open_notif.get_name_leafdata())
                    if (self.rx_ipc_output_notif.is_set or self.rx_ipc_output_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_output_notif.get_name_leafdata())
                    if (self.rx_ipc_publish_notif.is_set or self.rx_ipc_publish_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_publish_notif.get_name_leafdata())
                    if (self.rx_ipc_q_full_notif.is_set or self.rx_ipc_q_full_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_q_full_notif.get_name_leafdata())
                    if (self.rx_ipc_send_status_notif.is_set or self.rx_ipc_send_status_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_send_status_notif.get_name_leafdata())
                    if (self.rx_sweep_mrouter_msg.is_set or self.rx_sweep_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_sweep_mrouter_msg.get_name_leafdata())
                    if (self.rx_unknown_mrouter_msg.is_set or self.rx_unknown_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_unknown_mrouter_msg.get_name_leafdata())
                    if (self.send_blocks.is_set or self.send_blocks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_blocks.get_name_leafdata())
                    if (self.tx_add_mrouter_msg.is_set or self.tx_add_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_add_mrouter_msg.get_name_leafdata())
                    if (self.tx_buffer_errors.is_set or self.tx_buffer_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_buffer_errors.get_name_leafdata())
                    if (self.tx_buffers.is_set or self.tx_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_buffers.get_name_leafdata())
                    if (self.tx_delete_mrouter_msg.is_set or self.tx_delete_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_delete_mrouter_msg.get_name_leafdata())
                    if (self.tx_mrouter_buffers.is_set or self.tx_mrouter_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_mrouter_buffers.get_name_leafdata())
                    if (self.tx_protocol_buffers.is_set or self.tx_protocol_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_protocol_buffers.get_name_leafdata())
                    if (self.tx_sweep_mrouter_msg.is_set or self.tx_sweep_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_sweep_mrouter_msg.get_name_leafdata())
                    if (self.tx_unknown_buffers.is_set or self.tx_unknown_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_unknown_buffers.get_name_leafdata())
                    if (self.tx_unknown_mrouter_msg.is_set or self.tx_unknown_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_unknown_mrouter_msg.get_name_leafdata())
                    if (self.wtx_msg_drop_dc.is_set or self.wtx_msg_drop_dc.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_drop_dc.get_name_leafdata())
                    if (self.wtx_msg_drop_nomem.is_set or self.wtx_msg_drop_nomem.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_drop_nomem.get_name_leafdata())
                    if (self.wtx_msg_freed.is_set or self.wtx_msg_freed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_freed.get_name_leafdata())
                    if (self.wtx_msg_proto_sent.is_set or self.wtx_msg_proto_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_proto_sent.get_name_leafdata())
                    if (self.wtx_msg_recvd.is_set or self.wtx_msg_recvd.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_recvd.get_name_leafdata())
                    if (self.wtx_msg_sent.is_set or self.wtx_msg_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_sent.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "null-buffer-handles" or name == "receive-buffers" or name == "release-buffers" or name == "release-fail-buffers" or name == "rx-add-mrouter-msg" or name == "rx-delete-mrouter-msg" or name == "rx-igmp-packet-success" or name == "rx-ipc-close-notif" or name == "rx-ipc-connect-notif" or name == "rx-ipc-error-notif" or name == "rx-ipc-input-wait-notif" or name == "rx-ipc-lwm-notif" or name == "rx-ipc-open-notif" or name == "rx-ipc-output-notif" or name == "rx-ipc-publish-notif" or name == "rx-ipc-q-full-notif" or name == "rx-ipc-send-status-notif" or name == "rx-sweep-mrouter-msg" or name == "rx-unknown-mrouter-msg" or name == "send-blocks" or name == "tx-add-mrouter-msg" or name == "tx-buffer-errors" or name == "tx-buffers" or name == "tx-delete-mrouter-msg" or name == "tx-mrouter-buffers" or name == "tx-protocol-buffers" or name == "tx-sweep-mrouter-msg" or name == "tx-unknown-buffers" or name == "tx-unknown-mrouter-msg" or name == "wtx-msg-drop-dc" or name == "wtx-msg-drop-nomem" or name == "wtx-msg-freed" or name == "wtx-msg-proto-sent" or name == "wtx-msg-recvd" or name == "wtx-msg-sent"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "null-buffer-handles"):
                        self.null_buffer_handles = value
                        self.null_buffer_handles.value_namespace = name_space
                        self.null_buffer_handles.value_namespace_prefix = name_space_prefix
                    if(value_path == "receive-buffers"):
                        self.receive_buffers = value
                        self.receive_buffers.value_namespace = name_space
                        self.receive_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "release-buffers"):
                        self.release_buffers = value
                        self.release_buffers.value_namespace = name_space
                        self.release_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "release-fail-buffers"):
                        self.release_fail_buffers = value
                        self.release_fail_buffers.value_namespace = name_space
                        self.release_fail_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-add-mrouter-msg"):
                        self.rx_add_mrouter_msg = value
                        self.rx_add_mrouter_msg.value_namespace = name_space
                        self.rx_add_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-delete-mrouter-msg"):
                        self.rx_delete_mrouter_msg = value
                        self.rx_delete_mrouter_msg.value_namespace = name_space
                        self.rx_delete_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-igmp-packet-success"):
                        self.rx_igmp_packet_success = value
                        self.rx_igmp_packet_success.value_namespace = name_space
                        self.rx_igmp_packet_success.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-close-notif"):
                        self.rx_ipc_close_notif = value
                        self.rx_ipc_close_notif.value_namespace = name_space
                        self.rx_ipc_close_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-connect-notif"):
                        self.rx_ipc_connect_notif = value
                        self.rx_ipc_connect_notif.value_namespace = name_space
                        self.rx_ipc_connect_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-error-notif"):
                        self.rx_ipc_error_notif = value
                        self.rx_ipc_error_notif.value_namespace = name_space
                        self.rx_ipc_error_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-input-wait-notif"):
                        self.rx_ipc_input_wait_notif = value
                        self.rx_ipc_input_wait_notif.value_namespace = name_space
                        self.rx_ipc_input_wait_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-lwm-notif"):
                        self.rx_ipc_lwm_notif = value
                        self.rx_ipc_lwm_notif.value_namespace = name_space
                        self.rx_ipc_lwm_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-open-notif"):
                        self.rx_ipc_open_notif = value
                        self.rx_ipc_open_notif.value_namespace = name_space
                        self.rx_ipc_open_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-output-notif"):
                        self.rx_ipc_output_notif = value
                        self.rx_ipc_output_notif.value_namespace = name_space
                        self.rx_ipc_output_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-publish-notif"):
                        self.rx_ipc_publish_notif = value
                        self.rx_ipc_publish_notif.value_namespace = name_space
                        self.rx_ipc_publish_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-q-full-notif"):
                        self.rx_ipc_q_full_notif = value
                        self.rx_ipc_q_full_notif.value_namespace = name_space
                        self.rx_ipc_q_full_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-send-status-notif"):
                        self.rx_ipc_send_status_notif = value
                        self.rx_ipc_send_status_notif.value_namespace = name_space
                        self.rx_ipc_send_status_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-sweep-mrouter-msg"):
                        self.rx_sweep_mrouter_msg = value
                        self.rx_sweep_mrouter_msg.value_namespace = name_space
                        self.rx_sweep_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-unknown-mrouter-msg"):
                        self.rx_unknown_mrouter_msg = value
                        self.rx_unknown_mrouter_msg.value_namespace = name_space
                        self.rx_unknown_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-blocks"):
                        self.send_blocks = value
                        self.send_blocks.value_namespace = name_space
                        self.send_blocks.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-add-mrouter-msg"):
                        self.tx_add_mrouter_msg = value
                        self.tx_add_mrouter_msg.value_namespace = name_space
                        self.tx_add_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-buffer-errors"):
                        self.tx_buffer_errors = value
                        self.tx_buffer_errors.value_namespace = name_space
                        self.tx_buffer_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-buffers"):
                        self.tx_buffers = value
                        self.tx_buffers.value_namespace = name_space
                        self.tx_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-delete-mrouter-msg"):
                        self.tx_delete_mrouter_msg = value
                        self.tx_delete_mrouter_msg.value_namespace = name_space
                        self.tx_delete_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-mrouter-buffers"):
                        self.tx_mrouter_buffers = value
                        self.tx_mrouter_buffers.value_namespace = name_space
                        self.tx_mrouter_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-protocol-buffers"):
                        self.tx_protocol_buffers = value
                        self.tx_protocol_buffers.value_namespace = name_space
                        self.tx_protocol_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-sweep-mrouter-msg"):
                        self.tx_sweep_mrouter_msg = value
                        self.tx_sweep_mrouter_msg.value_namespace = name_space
                        self.tx_sweep_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-unknown-buffers"):
                        self.tx_unknown_buffers = value
                        self.tx_unknown_buffers.value_namespace = name_space
                        self.tx_unknown_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-unknown-mrouter-msg"):
                        self.tx_unknown_mrouter_msg = value
                        self.tx_unknown_mrouter_msg.value_namespace = name_space
                        self.tx_unknown_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-drop-dc"):
                        self.wtx_msg_drop_dc = value
                        self.wtx_msg_drop_dc.value_namespace = name_space
                        self.wtx_msg_drop_dc.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-drop-nomem"):
                        self.wtx_msg_drop_nomem = value
                        self.wtx_msg_drop_nomem.value_namespace = name_space
                        self.wtx_msg_drop_nomem.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-freed"):
                        self.wtx_msg_freed = value
                        self.wtx_msg_freed.value_namespace = name_space
                        self.wtx_msg_freed.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-proto-sent"):
                        self.wtx_msg_proto_sent = value
                        self.wtx_msg_proto_sent.value_namespace = name_space
                        self.wtx_msg_proto_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-recvd"):
                        self.wtx_msg_recvd = value
                        self.wtx_msg_recvd.value_namespace = name_space
                        self.wtx_msg_recvd.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-sent"):
                        self.wtx_msg_sent = value
                        self.wtx_msg_sent.value_namespace = name_space
                        self.wtx_msg_sent.value_namespace_prefix = name_space_prefix


            class Nsf(Entity):
                """
                NSF Information
                
                .. attribute:: is_multicast_nsf_active
                
                	Is Multicast NSF active
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_min
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_min
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_min
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_time_left
                
                	Multicast NSF time remaining in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_timeout
                
                	Multicast NSF timeout in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"

                    self.is_multicast_nsf_active = YLeaf(YType.boolean, "is-multicast-nsf-active")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_min = YLeaf(YType.int32, "last-icd-notif-recv-min")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_min = YLeaf(YType.int32, "last-nsf-off-min")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_min = YLeaf(YType.int32, "last-nsf-on-min")

                    self.multicast_nsf_time_left = YLeaf(YType.uint32, "multicast-nsf-time-left")

                    self.multicast_nsf_timeout = YLeaf(YType.uint32, "multicast-nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_multicast_nsf_active",
                                    "last_icd_notif_recv",
                                    "last_icd_notif_recv_min",
                                    "last_nsf_off",
                                    "last_nsf_off_min",
                                    "last_nsf_on",
                                    "last_nsf_on_min",
                                    "multicast_nsf_time_left",
                                    "multicast_nsf_timeout",
                                    "respawn_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.Process.Nsf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.Process.Nsf, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_multicast_nsf_active.is_set or
                        self.last_icd_notif_recv.is_set or
                        self.last_icd_notif_recv_min.is_set or
                        self.last_nsf_off.is_set or
                        self.last_nsf_off_min.is_set or
                        self.last_nsf_on.is_set or
                        self.last_nsf_on_min.is_set or
                        self.multicast_nsf_time_left.is_set or
                        self.multicast_nsf_timeout.is_set or
                        self.respawn_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_multicast_nsf_active.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv_min.yfilter != YFilter.not_set or
                        self.last_nsf_off.yfilter != YFilter.not_set or
                        self.last_nsf_off_min.yfilter != YFilter.not_set or
                        self.last_nsf_on.yfilter != YFilter.not_set or
                        self.last_nsf_on_min.yfilter != YFilter.not_set or
                        self.multicast_nsf_time_left.yfilter != YFilter.not_set or
                        self.multicast_nsf_timeout.yfilter != YFilter.not_set or
                        self.respawn_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsf" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_multicast_nsf_active.is_set or self.is_multicast_nsf_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multicast_nsf_active.get_name_leafdata())
                    if (self.last_icd_notif_recv.is_set or self.last_icd_notif_recv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv.get_name_leafdata())
                    if (self.last_icd_notif_recv_min.is_set or self.last_icd_notif_recv_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv_min.get_name_leafdata())
                    if (self.last_nsf_off.is_set or self.last_nsf_off.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off.get_name_leafdata())
                    if (self.last_nsf_off_min.is_set or self.last_nsf_off_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off_min.get_name_leafdata())
                    if (self.last_nsf_on.is_set or self.last_nsf_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on.get_name_leafdata())
                    if (self.last_nsf_on_min.is_set or self.last_nsf_on_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on_min.get_name_leafdata())
                    if (self.multicast_nsf_time_left.is_set or self.multicast_nsf_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.multicast_nsf_time_left.get_name_leafdata())
                    if (self.multicast_nsf_timeout.is_set or self.multicast_nsf_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.multicast_nsf_timeout.get_name_leafdata())
                    if (self.respawn_count.is_set or self.respawn_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.respawn_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-multicast-nsf-active" or name == "last-icd-notif-recv" or name == "last-icd-notif-recv-min" or name == "last-nsf-off" or name == "last-nsf-off-min" or name == "last-nsf-on" or name == "last-nsf-on-min" or name == "multicast-nsf-time-left" or name == "multicast-nsf-timeout" or name == "respawn-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-multicast-nsf-active"):
                        self.is_multicast_nsf_active = value
                        self.is_multicast_nsf_active.value_namespace = name_space
                        self.is_multicast_nsf_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv"):
                        self.last_icd_notif_recv = value
                        self.last_icd_notif_recv.value_namespace = name_space
                        self.last_icd_notif_recv.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv-min"):
                        self.last_icd_notif_recv_min = value
                        self.last_icd_notif_recv_min.value_namespace = name_space
                        self.last_icd_notif_recv_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off"):
                        self.last_nsf_off = value
                        self.last_nsf_off.value_namespace = name_space
                        self.last_nsf_off.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off-min"):
                        self.last_nsf_off_min = value
                        self.last_nsf_off_min.value_namespace = name_space
                        self.last_nsf_off_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on"):
                        self.last_nsf_on = value
                        self.last_nsf_on.value_namespace = name_space
                        self.last_nsf_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on-min"):
                        self.last_nsf_on_min = value
                        self.last_nsf_on_min.value_namespace = name_space
                        self.last_nsf_on_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "multicast-nsf-time-left"):
                        self.multicast_nsf_time_left = value
                        self.multicast_nsf_time_left.value_namespace = name_space
                        self.multicast_nsf_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "multicast-nsf-timeout"):
                        self.multicast_nsf_timeout = value
                        self.multicast_nsf_timeout.value_namespace = name_space
                        self.multicast_nsf_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "respawn-count"):
                        self.respawn_count = value
                        self.respawn_count.value_namespace = name_space
                        self.respawn_count.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.amt_gatewaies is not None and self.amt_gatewaies.has_data()) or
                    (self.amt_summary is not None and self.amt_summary.has_data()) or
                    (self.bvi_statistics is not None and self.bvi_statistics.has_data()) or
                    (self.nsf is not None and self.nsf.has_data()) or
                    (self.nsr is not None and self.nsr.has_data()) or
                    (self.unicast_qos_adjust_stats is not None and self.unicast_qos_adjust_stats.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.amt_gatewaies is not None and self.amt_gatewaies.has_operation()) or
                    (self.amt_summary is not None and self.amt_summary.has_operation()) or
                    (self.bvi_statistics is not None and self.bvi_statistics.has_operation()) or
                    (self.nsf is not None and self.nsf.has_operation()) or
                    (self.nsr is not None and self.nsr.has_operation()) or
                    (self.unicast_qos_adjust_stats is not None and self.unicast_qos_adjust_stats.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "process" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "amt-gatewaies"):
                    if (self.amt_gatewaies is None):
                        self.amt_gatewaies = Mld.Active.Process.AmtGatewaies()
                        self.amt_gatewaies.parent = self
                        self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                    return self.amt_gatewaies

                if (child_yang_name == "amt-summary"):
                    if (self.amt_summary is None):
                        self.amt_summary = Mld.Active.Process.AmtSummary()
                        self.amt_summary.parent = self
                        self._children_name_map["amt_summary"] = "amt-summary"
                    return self.amt_summary

                if (child_yang_name == "bvi-statistics"):
                    if (self.bvi_statistics is None):
                        self.bvi_statistics = Mld.Active.Process.BviStatistics()
                        self.bvi_statistics.parent = self
                        self._children_name_map["bvi_statistics"] = "bvi-statistics"
                    return self.bvi_statistics

                if (child_yang_name == "nsf"):
                    if (self.nsf is None):
                        self.nsf = Mld.Active.Process.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"
                    return self.nsf

                if (child_yang_name == "nsr"):
                    if (self.nsr is None):
                        self.nsr = Mld.Active.Process.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                    return self.nsr

                if (child_yang_name == "unicast-qos-adjust-stats"):
                    if (self.unicast_qos_adjust_stats is None):
                        self.unicast_qos_adjust_stats = Mld.Active.Process.UnicastQosAdjustStats()
                        self.unicast_qos_adjust_stats.parent = self
                        self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                    return self.unicast_qos_adjust_stats

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "amt-gatewaies" or name == "amt-summary" or name == "bvi-statistics" or name == "nsf" or name == "nsr" or name == "unicast-qos-adjust-stats"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: detail_groups
            
            	IGMP Detail Group Database
            	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups>`
            
            .. attribute:: explicit_groups
            
            	IGMP Explicit Group Database
            	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups>`
            
            .. attribute:: global_interface_table
            
            	IGMP Global Interface 
            	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GlobalInterfaceTable>`
            
            .. attribute:: group_summary
            
            	IGMP Groups Summary
            	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GroupSummary>`
            
            .. attribute:: groups
            
            	IGMP Group Database Table
            	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Groups>`
            
            .. attribute:: ifrs_interface_summary
            
            	IGMP IFRS Interface summary
            	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaceSummary>`
            
            .. attribute:: ifrs_interfaces
            
            	IGMP Interface specific
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: interface_state_offs
            
            	IGMP Interface state off
            	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOffs>`
            
            .. attribute:: interface_state_ons
            
            	IGMP Interface state on
            	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOns>`
            
            .. attribute:: interface_table
            
            	IGMP Interface specific Table
            	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceTable>`
            
            .. attribute:: interface_unicast_qos_adjusts
            
            	IGMP Interface Unicast\-Qos\-Adjust
            	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts>`
            
            .. attribute:: non_active_groups
            
            	IGMP Non\-Active Groups Information
            	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.NonActiveGroups>`
            
            .. attribute:: ranges
            
            	Range table
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Ranges>`
            
            .. attribute:: ssm_map_details
            
            	SSM Map Detail
            	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMapDetails>`
            
            .. attribute:: ssm_maps
            
            	SSM Map Table
            	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMaps>`
            
            .. attribute:: summary
            
            	IGMP Summary Information
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Summary>`
            
            .. attribute:: traffic_counters
            
            	IGMP Message Traffic Counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.TrafficCounters>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Active.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "active"

                self.detail_groups = Mld.Active.DefaultContext.DetailGroups()
                self.detail_groups.parent = self
                self._children_name_map["detail_groups"] = "detail-groups"
                self._children_yang_names.add("detail-groups")

                self.explicit_groups = Mld.Active.DefaultContext.ExplicitGroups()
                self.explicit_groups.parent = self
                self._children_name_map["explicit_groups"] = "explicit-groups"
                self._children_yang_names.add("explicit-groups")

                self.global_interface_table = Mld.Active.DefaultContext.GlobalInterfaceTable()
                self.global_interface_table.parent = self
                self._children_name_map["global_interface_table"] = "global-interface-table"
                self._children_yang_names.add("global-interface-table")

                self.group_summary = Mld.Active.DefaultContext.GroupSummary()
                self.group_summary.parent = self
                self._children_name_map["group_summary"] = "group-summary"
                self._children_yang_names.add("group-summary")

                self.groups = Mld.Active.DefaultContext.Groups()
                self.groups.parent = self
                self._children_name_map["groups"] = "groups"
                self._children_yang_names.add("groups")

                self.ifrs_interface_summary = Mld.Active.DefaultContext.IfrsInterfaceSummary()
                self.ifrs_interface_summary.parent = self
                self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                self._children_yang_names.add("ifrs-interface-summary")

                self.ifrs_interfaces = Mld.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.interface_state_offs = Mld.Active.DefaultContext.InterfaceStateOffs()
                self.interface_state_offs.parent = self
                self._children_name_map["interface_state_offs"] = "interface-state-offs"
                self._children_yang_names.add("interface-state-offs")

                self.interface_state_ons = Mld.Active.DefaultContext.InterfaceStateOns()
                self.interface_state_ons.parent = self
                self._children_name_map["interface_state_ons"] = "interface-state-ons"
                self._children_yang_names.add("interface-state-ons")

                self.interface_table = Mld.Active.DefaultContext.InterfaceTable()
                self.interface_table.parent = self
                self._children_name_map["interface_table"] = "interface-table"
                self._children_yang_names.add("interface-table")

                self.interface_unicast_qos_adjusts = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts()
                self.interface_unicast_qos_adjusts.parent = self
                self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                self._children_yang_names.add("interface-unicast-qos-adjusts")

                self.non_active_groups = Mld.Active.DefaultContext.NonActiveGroups()
                self.non_active_groups.parent = self
                self._children_name_map["non_active_groups"] = "non-active-groups"
                self._children_yang_names.add("non-active-groups")

                self.ranges = Mld.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.ssm_map_details = Mld.Active.DefaultContext.SsmMapDetails()
                self.ssm_map_details.parent = self
                self._children_name_map["ssm_map_details"] = "ssm-map-details"
                self._children_yang_names.add("ssm-map-details")

                self.ssm_maps = Mld.Active.DefaultContext.SsmMaps()
                self.ssm_maps.parent = self
                self._children_name_map["ssm_maps"] = "ssm-maps"
                self._children_yang_names.add("ssm-maps")

                self.summary = Mld.Active.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.traffic_counters = Mld.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")


            class Summary(Entity):
                """
                IGMP Summary Information
                
                .. attribute:: disabled_interface_count
                
                	No. of disabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: enabled_interface_count
                
                	No. of enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_limit
                
                	Maximum groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Maximum and current groups accepted for each interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Summary.Interface>`
                
                .. attribute:: is_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: robustness
                
                	Robustness variable
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: supported_interfaces
                
                	No. of supported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_mte_config_count
                
                	No. of static group commands
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsupported_interfaces
                
                	No. of unsupported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"

                    self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                    self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.group_limit = YLeaf(YType.uint32, "group-limit")

                    self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                    self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                    self.robustness = YLeaf(YType.uint32, "robustness")

                    self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                    self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                    self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("disabled_interface_count",
                                    "enabled_interface_count",
                                    "group_count",
                                    "group_limit",
                                    "is_disabled",
                                    "node_low_memory",
                                    "robustness",
                                    "supported_interfaces",
                                    "tunnel_mte_config_count",
                                    "unsupported_interfaces") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.Summary, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    Maximum and current groups accepted for each
                    interface
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: on_off
                    
                    	Enabled/Disabled
                    	**type**\:  bool
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent if handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Time elapsed since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.Summary.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "summary"

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.on_off = YLeaf(YType.boolean, "on-off")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_count",
                                        "group_limit",
                                        "interface_name",
                                        "on_off",
                                        "parent_ifhandle",
                                        "router_uptime_in_seconds",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.Summary.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.Summary.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.group_count.is_set or
                            self.group_limit.is_set or
                            self.interface_name.is_set or
                            self.on_off.is_set or
                            self.parent_ifhandle.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.group_limit.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.on_off.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/summary/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_limit.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.on_off.is_set or self.on_off.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.on_off.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-count" or name == "group-limit" or name == "interface-name" or name == "on-off" or name == "parent-ifhandle" or name == "router-uptime-in-seconds" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-limit"):
                            self.group_limit = value
                            self.group_limit.value_namespace = name_space
                            self.group_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "on-off"):
                            self.on_off = value
                            self.on_off.value_namespace = name_space
                            self.on_off.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.disabled_interface_count.is_set or
                        self.enabled_interface_count.is_set or
                        self.group_count.is_set or
                        self.group_limit.is_set or
                        self.is_disabled.is_set or
                        self.node_low_memory.is_set or
                        self.robustness.is_set or
                        self.supported_interfaces.is_set or
                        self.tunnel_mte_config_count.is_set or
                        self.unsupported_interfaces.is_set)

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.disabled_interface_count.yfilter != YFilter.not_set or
                        self.enabled_interface_count.yfilter != YFilter.not_set or
                        self.group_count.yfilter != YFilter.not_set or
                        self.group_limit.yfilter != YFilter.not_set or
                        self.is_disabled.yfilter != YFilter.not_set or
                        self.node_low_memory.yfilter != YFilter.not_set or
                        self.robustness.yfilter != YFilter.not_set or
                        self.supported_interfaces.yfilter != YFilter.not_set or
                        self.tunnel_mte_config_count.yfilter != YFilter.not_set or
                        self.unsupported_interfaces.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.disabled_interface_count.is_set or self.disabled_interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disabled_interface_count.get_name_leafdata())
                    if (self.enabled_interface_count.is_set or self.enabled_interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enabled_interface_count.get_name_leafdata())
                    if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_count.get_name_leafdata())
                    if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_limit.get_name_leafdata())
                    if (self.is_disabled.is_set or self.is_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_disabled.get_name_leafdata())
                    if (self.node_low_memory.is_set or self.node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.node_low_memory.get_name_leafdata())
                    if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.robustness.get_name_leafdata())
                    if (self.supported_interfaces.is_set or self.supported_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.supported_interfaces.get_name_leafdata())
                    if (self.tunnel_mte_config_count.is_set or self.tunnel_mte_config_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_mte_config_count.get_name_leafdata())
                    if (self.unsupported_interfaces.is_set or self.unsupported_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unsupported_interfaces.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.Summary.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "disabled-interface-count" or name == "enabled-interface-count" or name == "group-count" or name == "group-limit" or name == "is-disabled" or name == "node-low-memory" or name == "robustness" or name == "supported-interfaces" or name == "tunnel-mte-config-count" or name == "unsupported-interfaces"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "disabled-interface-count"):
                        self.disabled_interface_count = value
                        self.disabled_interface_count.value_namespace = name_space
                        self.disabled_interface_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "enabled-interface-count"):
                        self.enabled_interface_count = value
                        self.enabled_interface_count.value_namespace = name_space
                        self.enabled_interface_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-count"):
                        self.group_count = value
                        self.group_count.value_namespace = name_space
                        self.group_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-limit"):
                        self.group_limit = value
                        self.group_limit.value_namespace = name_space
                        self.group_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-disabled"):
                        self.is_disabled = value
                        self.is_disabled.value_namespace = name_space
                        self.is_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "node-low-memory"):
                        self.node_low_memory = value
                        self.node_low_memory.value_namespace = name_space
                        self.node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "robustness"):
                        self.robustness = value
                        self.robustness.value_namespace = name_space
                        self.robustness.value_namespace_prefix = name_space_prefix
                    if(value_path == "supported-interfaces"):
                        self.supported_interfaces = value
                        self.supported_interfaces.value_namespace = name_space
                        self.supported_interfaces.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-mte-config-count"):
                        self.tunnel_mte_config_count = value
                        self.tunnel_mte_config_count.value_namespace = name_space
                        self.tunnel_mte_config_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "unsupported-interfaces"):
                        self.unsupported_interfaces = value
                        self.unsupported_interfaces.value_namespace = name_space
                        self.unsupported_interfaces.value_namespace_prefix = name_space_prefix


            class InterfaceStateOns(Entity):
                """
                IGMP Interface state on
                
                .. attribute:: interface_state_on
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.InterfaceStateOns, self).__init__()

                    self.yang_name = "interface-state-ons"
                    self.yang_parent_name = "default-context"

                    self.interface_state_on = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.InterfaceStateOns, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.InterfaceStateOns, self).__setattr__(name, value)


                class InterfaceStateOn(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__init__()

                        self.yang_name = "interface-state-on"
                        self.yang_parent_name = "interface-state-ons"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/interface-state-ons/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_state_on:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_state_on:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-state-ons" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-state-on"):
                        for c in self.interface_state_on:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_state_on.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-state-on"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class DetailGroups(Entity):
                """
                IGMP Detail Group Database
                
                .. attribute:: detail_group
                
                	IGMP Detail Group Entry Information
                	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.DetailGroups, self).__init__()

                    self.yang_name = "detail-groups"
                    self.yang_parent_name = "default-context"

                    self.detail_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.DetailGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.DetailGroups, self).__setattr__(name, value)


                class DetailGroup(Entity):
                    """
                    IGMP Detail Group Entry Information
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_host_exclude_mode
                    
                    	Group host filter mode
                    	**type**\:  bool
                    
                    .. attribute:: is_router_exclude_mode
                    
                    	Group router filter mode
                    	**type**\:  bool
                    
                    .. attribute:: source
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.DetailGroups.DetailGroup, self).__init__()

                        self.yang_name = "detail-group"
                        self.yang_parent_name = "detail-groups"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                        self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "interface_name",
                                        "is_host_exclude_mode",
                                        "is_router_exclude_mode",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.DetailGroups.DetailGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.DetailGroups.DetailGroup, self).__setattr__(name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "detail-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix


                    class Source(Entity):
                        """
                        List of sources
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: flags
                        
                        	Source flags
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_forward
                        
                        	Should we forward on this entry
                        	**type**\:  bool
                        
                        .. attribute:: is_local
                        
                        	Is this a local source
                        	**type**\:  bool
                        
                        .. attribute:: is_remote
                        
                        	Is this a remote source
                        	**type**\:  bool
                        
                        .. attribute:: is_we_report
                        
                        	Should we report the source
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "detail-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.flags = YLeaf(YType.int32, "flags")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_forward = YLeaf(YType.boolean, "is-forward")

                            self.is_local = YLeaf(YType.boolean, "is-local")

                            self.is_remote = YLeaf(YType.boolean, "is-remote")

                            self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.source_address = Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "flags",
                                            "is_added",
                                            "is_forward",
                                            "is_local",
                                            "is_remote",
                                            "is_we_report",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/source/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.flags.is_set or
                                self.is_added.is_set or
                                self.is_forward.is_set or
                                self.is_local.is_set or
                                self.is_remote.is_set or
                                self.is_we_report.is_set or
                                self.uptime.is_set or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.flags.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_forward.yfilter != YFilter.not_set or
                                self.is_local.yfilter != YFilter.not_set or
                                self.is_remote.yfilter != YFilter.not_set or
                                self.is_we_report.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flags.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_forward.is_set or self.is_forward.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_forward.get_name_leafdata())
                            if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_local.get_name_leafdata())
                            if (self.is_remote.is_set or self.is_remote.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_remote.get_name_leafdata())
                            if (self.is_we_report.is_set or self.is_we_report.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_we_report.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "expiration-time" or name == "flags" or name == "is-added" or name == "is-forward" or name == "is-local" or name == "is-remote" or name == "is-we-report" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "flags"):
                                self.flags = value
                                self.flags.value_namespace = name_space
                                self.flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-forward"):
                                self.is_forward = value
                                self.is_forward.value_namespace = name_space
                                self.is_forward.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-local"):
                                self.is_local = value
                                self.is_local.value_namespace = name_space
                                self.is_local.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-remote"):
                                self.is_remote = value
                                self.is_remote.value_namespace = name_space
                                self.is_remote.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-we-report"):
                                self.is_we_report = value
                                self.is_we_report.value_namespace = name_space
                                self.is_we_report.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.source:
                            if (c.has_data()):
                                return True
                        return (
                            self.group_address.is_set or
                            self.interface_name.is_set or
                            self.is_host_exclude_mode.is_set or
                            self.is_router_exclude_mode.is_set or
                            self.source_address.is_set or
                            (self.group_info is not None and self.group_info.has_data()))

                    def has_operation(self):
                        for c in self.source:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_host_exclude_mode.yfilter != YFilter.not_set or
                            self.is_router_exclude_mode.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group_info is not None and self.group_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "detail-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_host_exclude_mode.is_set or self.is_host_exclude_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_host_exclude_mode.get_name_leafdata())
                        if (self.is_router_exclude_mode.is_set or self.is_router_exclude_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_exclude_mode.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-info"):
                            if (self.group_info is None):
                                self.group_info = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                                self.group_info.parent = self
                                self._children_name_map["group_info"] = "group-info"
                            return self.group_info

                        if (child_yang_name == "source"):
                            for c in self.source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-info" or name == "source" or name == "group-address" or name == "interface-name" or name == "is-host-exclude-mode" or name == "is-router-exclude-mode" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-host-exclude-mode"):
                            self.is_host_exclude_mode = value
                            self.is_host_exclude_mode.value_namespace = name_space
                            self.is_host_exclude_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-exclude-mode"):
                            self.is_router_exclude_mode = value
                            self.is_router_exclude_mode.value_namespace = name_space
                            self.is_router_exclude_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.detail_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.detail_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "detail-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "detail-group"):
                        for c in self.detail_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.DetailGroups.DetailGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.detail_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "detail-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NonActiveGroups(Entity):
                """
                IGMP Non\-Active Groups Information
                
                .. attribute:: non_active_groups
                
                	List of non\-active groups
                	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.NonActiveGroups, self).__init__()

                    self.yang_name = "non-active-groups"
                    self.yang_parent_name = "default-context"

                    self.non_active_groups = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.NonActiveGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.NonActiveGroups, self).__setattr__(name, value)


                class NonActiveGroups(Entity):
                    """
                    List of non\-active groups
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress>`
                    
                    .. attribute:: interface
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**length:** 0..65
                    
                    .. attribute:: reason_for_non_activity
                    
                    	Reason for group join not being processed
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "non-active-groups"

                        self.interface = YLeaf(YType.str, "interface")

                        self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                        self.group_address = Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                        self.source_address = Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface",
                                        "reason_for_non_activity") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "non-active-groups"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/non-active-groups/non-active-groups/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "non-active-groups"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/non-active-groups/non-active-groups/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface.is_set or
                            self.reason_for_non_activity.is_set or
                            (self.group_address is not None and self.group_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface.yfilter != YFilter.not_set or
                            self.reason_for_non_activity.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "non-active-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/non-active-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface.get_name_leafdata())
                        if (self.reason_for_non_activity.is_set or self.reason_for_non_activity.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reason_for_non_activity.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "source-address" or name == "interface" or name == "reason-for-non-activity"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface"):
                            self.interface = value
                            self.interface.value_namespace = name_space
                            self.interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "reason-for-non-activity"):
                            self.reason_for_non_activity = value
                            self.reason_for_non_activity.value_namespace = name_space
                            self.reason_for_non_activity.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.non_active_groups:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.non_active_groups:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "non-active-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "non-active-groups"):
                        for c in self.non_active_groups:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.non_active_groups.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "non-active-groups"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SsmMaps(Entity):
                """
                SSM Map Table
                
                .. attribute:: ssm_map
                
                	SSM Map information
                	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMaps.SsmMap>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.SsmMaps, self).__init__()

                    self.yang_name = "ssm-maps"
                    self.yang_parent_name = "default-context"

                    self.ssm_map = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.SsmMaps, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.SsmMaps, self).__setattr__(name, value)


                class SsmMap(Entity):
                    """
                    SSM Map information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr>`
                    
                    .. attribute:: map_type
                    
                    	Map Type of group
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_counts
                    
                    	Count of Sources
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.SsmMaps.SsmMap, self).__init__()

                        self.yang_name = "ssm-map"
                        self.yang_parent_name = "ssm-maps"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.map_type = YLeaf(YType.uint32, "map-type")

                        self.source_counts = YLeaf(YType.uint32, "source-counts")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.group_address_xr = Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "map_type",
                                        "source_counts",
                                        "ssm_map_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.SsmMaps.SsmMap, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.SsmMaps.SsmMap, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "ssm-map"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-maps/ssm-map/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.map_type.is_set or
                            self.source_counts.is_set or
                            self.ssm_map_type.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.map_type.yfilter != YFilter.not_set or
                            self.source_counts.yfilter != YFilter.not_set or
                            self.ssm_map_type.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-maps/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.map_type.get_name_leafdata())
                        if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_counts.get_name_leafdata())
                        if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "group-address" or name == "map-type" or name == "source-counts" or name == "ssm-map-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "map-type"):
                            self.map_type = value
                            self.map_type.value_namespace = name_space
                            self.map_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-counts"):
                            self.source_counts = value
                            self.source_counts.value_namespace = name_space
                            self.source_counts.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssm-map-type"):
                            self.ssm_map_type = value
                            self.ssm_map_type.value_namespace = name_space
                            self.ssm_map_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ssm_map:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ssm_map:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ssm-maps" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ssm-map"):
                        for c in self.ssm_map:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.SsmMaps.SsmMap()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ssm_map.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ssm-map"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class ExplicitGroups(Entity):
                """
                IGMP Explicit Group Database
                
                .. attribute:: explicit_group
                
                	IGMP Explicit Group Entry Information
                	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.ExplicitGroups, self).__init__()

                    self.yang_name = "explicit-groups"
                    self.yang_parent_name = "default-context"

                    self.explicit_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.ExplicitGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.ExplicitGroups, self).__setattr__(name, value)


                class ExplicitGroup(Entity):
                    """
                    IGMP Explicit Group Entry Information
                    
                    .. attribute:: exclude_hosts
                    
                    	No. of hosts who are excluded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo>`
                    
                    .. attribute:: host
                    
                    	List of hosts
                    	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host>`
                    
                    .. attribute:: include_hosts
                    
                    	No. of hosts who are included
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup, self).__init__()

                        self.yang_name = "explicit-group"
                        self.yang_parent_name = "explicit-groups"

                        self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.host = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("exclude_hosts",
                                        "group_address",
                                        "include_hosts",
                                        "interface_name",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "explicit-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix


                    class Host(Entity):
                        """
                        List of hosts
                        
                        .. attribute:: address
                        
                        	Host Address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address>`
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: is_exclude
                        
                        	Exclude flag set
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	First 3 source addresses
                        	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                        
                        .. attribute:: source_count
                        
                        	No. of sources in entry
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "explicit-group"

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                            self.source_count = YLeaf(YType.uint32, "source-count")

                            self.uptime = YLeaf(YType.uint32, "uptime")

                            self.address = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.source_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "is_exclude",
                                            "source_count",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            Host Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "host"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/host/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            First 3 source addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "host"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/host/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.source_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.expiration_time.is_set or
                                self.is_exclude.is_set or
                                self.source_count.is_set or
                                self.uptime.is_set or
                                (self.address is not None and self.address.has_data()))

                        def has_operation(self):
                            for c in self.source_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.is_exclude.yfilter != YFilter.not_set or
                                self.source_count.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "host" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.is_exclude.is_set or self.is_exclude.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_exclude.get_name_leafdata())
                            if (self.source_count.is_set or self.source_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_count.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "source-address"):
                                for c in self.source_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.source_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "source-address" or name == "expiration-time" or name == "is-exclude" or name == "source-count" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-exclude"):
                                self.is_exclude = value
                                self.is_exclude.value_namespace = name_space
                                self.is_exclude.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-count"):
                                self.source_count = value
                                self.source_count.value_namespace = name_space
                                self.source_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.host:
                            if (c.has_data()):
                                return True
                        return (
                            self.exclude_hosts.is_set or
                            self.group_address.is_set or
                            self.include_hosts.is_set or
                            self.interface_name.is_set or
                            self.source_address.is_set or
                            (self.group_info is not None and self.group_info.has_data()))

                    def has_operation(self):
                        for c in self.host:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.exclude_hosts.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.include_hosts.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group_info is not None and self.group_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "explicit-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.exclude_hosts.is_set or self.exclude_hosts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.exclude_hosts.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.include_hosts.is_set or self.include_hosts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.include_hosts.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-info"):
                            if (self.group_info is None):
                                self.group_info = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                                self.group_info.parent = self
                                self._children_name_map["group_info"] = "group-info"
                            return self.group_info

                        if (child_yang_name == "host"):
                            for c in self.host:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.host.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-info" or name == "host" or name == "exclude-hosts" or name == "group-address" or name == "include-hosts" or name == "interface-name" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "exclude-hosts"):
                            self.exclude_hosts = value
                            self.exclude_hosts.value_namespace = name_space
                            self.exclude_hosts.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "include-hosts"):
                            self.include_hosts = value
                            self.include_hosts.value_namespace = name_space
                            self.include_hosts.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.explicit_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.explicit_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "explicit-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "explicit-group"):
                        for c in self.explicit_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.explicit_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "explicit-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceTable(Entity):
                """
                IGMP Interface specific Table
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.InterfaceTable, self).__init__()

                    self.yang_name = "interface-table"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.InterfaceTable, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.InterfaceTable, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.InterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interface-table"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Active.DefaultContext.InterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.InterfaceTable.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.InterfaceTable.Interface, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.InterfaceTable.Interface.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.InterfaceTable.Interface.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/interface-table/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Mld.Active.DefaultContext.InterfaceTable.Interface.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.InterfaceTable.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceUnicastQosAdjusts(Entity):
                """
                IGMP Interface Unicast\-Qos\-Adjust
                
                .. attribute:: interface_unicast_qos_adjust
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts, self).__init__()

                    self.yang_name = "interface-unicast-qos-adjusts"
                    self.yang_parent_name = "default-context"

                    self.interface_unicast_qos_adjust = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)


                class InterfaceUnicastQosAdjust(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_virtual_access
                    
                    	Is VirtualAccess Interface
                    	**type**\:  bool
                    
                    .. attribute:: rate
                    
                    	Overall rate in Kbps
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: rate_decrements
                    
                    	Count of rate decrements
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rate_increments
                    
                    	Count of rate increments
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update
                    
                    	List of updates
                    	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjust"
                        self.yang_parent_name = "interface-unicast-qos-adjusts"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                        self.rate = YLeaf(YType.uint32, "rate")

                        self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                        self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                        self.update = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_virtual_access",
                                        "rate",
                                        "rate_decrements",
                                        "rate_increments") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)


                    class Update(Entity):
                        """
                        List of updates
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                        
                        .. attribute:: is_add
                        
                        	Is this a rate increment
                        	**type**\:  bool
                        
                        .. attribute:: received_time
                        
                        	Time this update is received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                        
                        .. attribute:: weight
                        
                        	Weight from policy
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                            self.yang_name = "update"
                            self.yang_parent_name = "interface-unicast-qos-adjust"

                            self.is_add = YLeaf(YType.boolean, "is-add")

                            self.received_time = YLeaf(YType.uint64, "received-time")

                            self.weight = YLeaf(YType.uint32, "weight")

                            self.group_address = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("is_add",
                                            "received_time",
                                            "weight") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "update"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddress(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "update"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.is_add.is_set or
                                self.received_time.is_set or
                                self.weight.is_set or
                                (self.group_address is not None and self.group_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.is_add.yfilter != YFilter.not_set or
                                self.received_time.yfilter != YFilter.not_set or
                                self.weight.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "update" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_add.is_set or self.is_add.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_add.get_name_leafdata())
                            if (self.received_time.is_set or self.received_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_time.get_name_leafdata())
                            if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.weight.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "source-address" or name == "is-add" or name == "received-time" or name == "weight"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "is-add"):
                                self.is_add = value
                                self.is_add.value_namespace = name_space
                                self.is_add.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-time"):
                                self.received_time = value
                                self.received_time.value_namespace = name_space
                                self.received_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "weight"):
                                self.weight = value
                                self.weight.value_namespace = name_space
                                self.weight.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.update:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.is_virtual_access.is_set or
                            self.rate.is_set or
                            self.rate_decrements.is_set or
                            self.rate_increments.is_set)

                    def has_operation(self):
                        for c in self.update:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_virtual_access.yfilter != YFilter.not_set or
                            self.rate.yfilter != YFilter.not_set or
                            self.rate_decrements.yfilter != YFilter.not_set or
                            self.rate_increments.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/interface-unicast-qos-adjusts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_virtual_access.is_set or self.is_virtual_access.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_virtual_access.get_name_leafdata())
                        if (self.rate.is_set or self.rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate.get_name_leafdata())
                        if (self.rate_decrements.is_set or self.rate_decrements.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate_decrements.get_name_leafdata())
                        if (self.rate_increments.is_set or self.rate_increments.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate_increments.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "update"):
                            for c in self.update:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.update.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "update" or name == "interface-name" or name == "is-virtual-access" or name == "rate" or name == "rate-decrements" or name == "rate-increments"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-virtual-access"):
                            self.is_virtual_access = value
                            self.is_virtual_access.value_namespace = name_space
                            self.is_virtual_access.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate"):
                            self.rate = value
                            self.rate.value_namespace = name_space
                            self.rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate-decrements"):
                            self.rate_decrements = value
                            self.rate_decrements.value_namespace = name_space
                            self.rate_decrements.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate-increments"):
                            self.rate_increments = value
                            self.rate_increments.value_namespace = name_space
                            self.rate_increments.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_unicast_qos_adjust:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_unicast_qos_adjust:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-unicast-qos-adjusts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-unicast-qos-adjust"):
                        for c in self.interface_unicast_qos_adjust:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_unicast_qos_adjust.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-unicast-qos-adjust"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Ranges(Entity):
                """
                Range table
                
                .. attribute:: range
                
                	Range information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"

                    self.range = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.Ranges, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.Ranges, self).__setattr__(name, value)


                class Range(Entity):
                    """
                    Range information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr>`
                    
                    .. attribute:: group_mask
                    
                    	Group Mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: is_stale
                    
                    	Is the entry stale
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.group_mask = YLeaf(YType.int32, "group-mask")

                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.group_address_xr = Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "group_mask",
                                        "is_stale",
                                        "prefix_length",
                                        "protocol") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.Ranges.Range, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.Ranges.Range, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.group_mask.is_set or
                            self.is_stale.is_set or
                            self.prefix_length.is_set or
                            self.protocol.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.group_mask.yfilter != YFilter.not_set or
                            self.is_stale.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ranges/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.group_mask.is_set or self.group_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_mask.get_name_leafdata())
                        if (self.is_stale.is_set or self.is_stale.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_stale.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "group-address" or name == "group-mask" or name == "is-stale" or name == "prefix-length" or name == "protocol"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-mask"):
                            self.group_mask = value
                            self.group_mask.value_namespace = name_space
                            self.group_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-stale"):
                            self.is_stale = value
                            self.is_stale.value_namespace = name_space
                            self.is_stale.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.range:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.range:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ranges" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "range"):
                        for c in self.range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.Ranges.Range()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.range.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "range"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsInterfaces(Entity):
                """
                IGMP Interface specific
                
                .. attribute:: ifrs_interface
                
                	IGMP IFRS Interface
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"

                    self.ifrs_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)


                class IfrsInterface(Entity):
                    """
                    IGMP IFRS Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	IFRS Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: igmp_interface_entry
                    
                    	IGMP interface entry
                    	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                    
                    .. attribute:: join_group_count
                    
                    	Join group count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                        self.igmp_interface_entry = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                        self.igmp_interface_entry.parent = self
                        self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                        self._children_yang_names.add("igmp-interface-entry")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "join_group_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                    class IgmpInterfaceEntry(Entity):
                        """
                        IGMP interface entry
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                            self.yang_name = "igmp-interface-entry"
                            self.yang_parent_name = "ifrs-interface"

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "igmp-interface-entry" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.join_group_count.is_set or
                            (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.join_group_count.yfilter != YFilter.not_set or
                            (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ifrs-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.join_group_count.is_set or self.join_group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_group_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "igmp-interface-entry"):
                            if (self.igmp_interface_entry is None):
                                self.igmp_interface_entry = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                                self.igmp_interface_entry.parent = self
                                self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            return self.igmp_interface_entry

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "igmp-interface-entry" or name == "interface-name" or name == "join-group-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-group-count"):
                            self.join_group_count = value
                            self.join_group_count.value_namespace = name_space
                            self.join_group_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ifrs_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ifrs_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ifrs-interface"):
                        for c in self.ifrs_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ifrs_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ifrs-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TrafficCounters(Entity):
                """
                IGMP Message Traffic Counters
                
                .. attribute:: auxillary_data_length_errors
                
                	AuxDataLen errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bad_scope_errors
                
                	BadScope errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_errors
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_errors
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: get_packet_failure
                
                	Packet get failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_disabled_idb
                
                	Packet received on disabled idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_dvmrp
                
                	DVMRP packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_leaves
                
                	Leaves in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_martian_address
                
                	Packets received with Martian Address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_mtrace
                
                	Mtrace packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_assigned_vrf_id
                
                	Packets received with no assigned vrf id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb
                
                	Packets received without idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_platform_support_mtrace
                
                	mtrace packets without platform support
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_in_idb
                
                	Packets received on idb without VRF
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_mtrace
                
                	mtrace packets with no vrf associated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim
                
                	PIM packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_queries
                
                	Query packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_reports
                
                	Reports in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_address_errors
                
                	Invalid Source Address errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: miscellaneous_errors
                
                	Packets dropped for other reasons
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_dvmrp
                
                	DVMRP packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_leaves
                
                	Leaves out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_mtrace
                
                	Mtrace packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_no_parent_interface_handle
                
                	Failures setting 2nd ifhandle
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_pim
                
                	PIM packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_queries
                
                	Query packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_reports
                
                	Reports out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_input_errors
                
                	Incoming Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_output_errors
                
                	Outgoing Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_in
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_out
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_socket_errors
                
                	Socket errors on reception
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_errors
                
                	Socket errors on send
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"

                    self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                    self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                    self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_errors = YLeaf(YType.uint32, "format-errors")

                    self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                    self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                    self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                    self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                    self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                    self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                    self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                    self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                    self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                    self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                    self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                    self.input_pim = YLeaf(YType.uint32, "input-pim")

                    self.input_queries = YLeaf(YType.uint32, "input-queries")

                    self.input_reports = YLeaf(YType.uint32, "input-reports")

                    self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                    self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                    self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                    self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                    self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                    self.output_pim = YLeaf(YType.uint32, "output-pim")

                    self.output_queries = YLeaf(YType.uint32, "output-queries")

                    self.output_reports = YLeaf(YType.uint32, "output-reports")

                    self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                    self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                    self.packets_in = YLeaf(YType.uint32, "packets-in")

                    self.packets_out = YLeaf(YType.uint32, "packets-out")

                    self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                    self.socket_errors = YLeaf(YType.uint32, "socket-errors")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("auxillary_data_length_errors",
                                    "bad_scope_errors",
                                    "checksum_errors",
                                    "elapsed_time",
                                    "format_errors",
                                    "get_packet_failure",
                                    "input_disabled_idb",
                                    "input_dvmrp",
                                    "input_leaves",
                                    "input_martian_address",
                                    "input_mtrace",
                                    "input_no_assigned_vrf_id",
                                    "input_no_idb",
                                    "input_no_platform_support_mtrace",
                                    "input_no_vrf_in_idb",
                                    "input_no_vrf_mtrace",
                                    "input_pim",
                                    "input_queries",
                                    "input_reports",
                                    "invalid_source_address_errors",
                                    "miscellaneous_errors",
                                    "no_socket_connection",
                                    "output_dvmrp",
                                    "output_leaves",
                                    "output_mtrace",
                                    "output_no_parent_interface_handle",
                                    "output_pim",
                                    "output_queries",
                                    "output_reports",
                                    "packet_manager_input_errors",
                                    "packet_manager_output_errors",
                                    "packets_in",
                                    "packets_out",
                                    "receive_socket_errors",
                                    "socket_errors") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.TrafficCounters, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.TrafficCounters, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.auxillary_data_length_errors.is_set or
                        self.bad_scope_errors.is_set or
                        self.checksum_errors.is_set or
                        self.elapsed_time.is_set or
                        self.format_errors.is_set or
                        self.get_packet_failure.is_set or
                        self.input_disabled_idb.is_set or
                        self.input_dvmrp.is_set or
                        self.input_leaves.is_set or
                        self.input_martian_address.is_set or
                        self.input_mtrace.is_set or
                        self.input_no_assigned_vrf_id.is_set or
                        self.input_no_idb.is_set or
                        self.input_no_platform_support_mtrace.is_set or
                        self.input_no_vrf_in_idb.is_set or
                        self.input_no_vrf_mtrace.is_set or
                        self.input_pim.is_set or
                        self.input_queries.is_set or
                        self.input_reports.is_set or
                        self.invalid_source_address_errors.is_set or
                        self.miscellaneous_errors.is_set or
                        self.no_socket_connection.is_set or
                        self.output_dvmrp.is_set or
                        self.output_leaves.is_set or
                        self.output_mtrace.is_set or
                        self.output_no_parent_interface_handle.is_set or
                        self.output_pim.is_set or
                        self.output_queries.is_set or
                        self.output_reports.is_set or
                        self.packet_manager_input_errors.is_set or
                        self.packet_manager_output_errors.is_set or
                        self.packets_in.is_set or
                        self.packets_out.is_set or
                        self.receive_socket_errors.is_set or
                        self.socket_errors.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.auxillary_data_length_errors.yfilter != YFilter.not_set or
                        self.bad_scope_errors.yfilter != YFilter.not_set or
                        self.checksum_errors.yfilter != YFilter.not_set or
                        self.elapsed_time.yfilter != YFilter.not_set or
                        self.format_errors.yfilter != YFilter.not_set or
                        self.get_packet_failure.yfilter != YFilter.not_set or
                        self.input_disabled_idb.yfilter != YFilter.not_set or
                        self.input_dvmrp.yfilter != YFilter.not_set or
                        self.input_leaves.yfilter != YFilter.not_set or
                        self.input_martian_address.yfilter != YFilter.not_set or
                        self.input_mtrace.yfilter != YFilter.not_set or
                        self.input_no_assigned_vrf_id.yfilter != YFilter.not_set or
                        self.input_no_idb.yfilter != YFilter.not_set or
                        self.input_no_platform_support_mtrace.yfilter != YFilter.not_set or
                        self.input_no_vrf_in_idb.yfilter != YFilter.not_set or
                        self.input_no_vrf_mtrace.yfilter != YFilter.not_set or
                        self.input_pim.yfilter != YFilter.not_set or
                        self.input_queries.yfilter != YFilter.not_set or
                        self.input_reports.yfilter != YFilter.not_set or
                        self.invalid_source_address_errors.yfilter != YFilter.not_set or
                        self.miscellaneous_errors.yfilter != YFilter.not_set or
                        self.no_socket_connection.yfilter != YFilter.not_set or
                        self.output_dvmrp.yfilter != YFilter.not_set or
                        self.output_leaves.yfilter != YFilter.not_set or
                        self.output_mtrace.yfilter != YFilter.not_set or
                        self.output_no_parent_interface_handle.yfilter != YFilter.not_set or
                        self.output_pim.yfilter != YFilter.not_set or
                        self.output_queries.yfilter != YFilter.not_set or
                        self.output_reports.yfilter != YFilter.not_set or
                        self.packet_manager_input_errors.yfilter != YFilter.not_set or
                        self.packet_manager_output_errors.yfilter != YFilter.not_set or
                        self.packets_in.yfilter != YFilter.not_set or
                        self.packets_out.yfilter != YFilter.not_set or
                        self.receive_socket_errors.yfilter != YFilter.not_set or
                        self.socket_errors.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-counters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.auxillary_data_length_errors.is_set or self.auxillary_data_length_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.auxillary_data_length_errors.get_name_leafdata())
                    if (self.bad_scope_errors.is_set or self.bad_scope_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bad_scope_errors.get_name_leafdata())
                    if (self.checksum_errors.is_set or self.checksum_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checksum_errors.get_name_leafdata())
                    if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                    if (self.format_errors.is_set or self.format_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.format_errors.get_name_leafdata())
                    if (self.get_packet_failure.is_set or self.get_packet_failure.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.get_packet_failure.get_name_leafdata())
                    if (self.input_disabled_idb.is_set or self.input_disabled_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_disabled_idb.get_name_leafdata())
                    if (self.input_dvmrp.is_set or self.input_dvmrp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_dvmrp.get_name_leafdata())
                    if (self.input_leaves.is_set or self.input_leaves.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_leaves.get_name_leafdata())
                    if (self.input_martian_address.is_set or self.input_martian_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_martian_address.get_name_leafdata())
                    if (self.input_mtrace.is_set or self.input_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_mtrace.get_name_leafdata())
                    if (self.input_no_assigned_vrf_id.is_set or self.input_no_assigned_vrf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_assigned_vrf_id.get_name_leafdata())
                    if (self.input_no_idb.is_set or self.input_no_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_idb.get_name_leafdata())
                    if (self.input_no_platform_support_mtrace.is_set or self.input_no_platform_support_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_platform_support_mtrace.get_name_leafdata())
                    if (self.input_no_vrf_in_idb.is_set or self.input_no_vrf_in_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_in_idb.get_name_leafdata())
                    if (self.input_no_vrf_mtrace.is_set or self.input_no_vrf_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_mtrace.get_name_leafdata())
                    if (self.input_pim.is_set or self.input_pim.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_pim.get_name_leafdata())
                    if (self.input_queries.is_set or self.input_queries.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_queries.get_name_leafdata())
                    if (self.input_reports.is_set or self.input_reports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_reports.get_name_leafdata())
                    if (self.invalid_source_address_errors.is_set or self.invalid_source_address_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_source_address_errors.get_name_leafdata())
                    if (self.miscellaneous_errors.is_set or self.miscellaneous_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.miscellaneous_errors.get_name_leafdata())
                    if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                    if (self.output_dvmrp.is_set or self.output_dvmrp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_dvmrp.get_name_leafdata())
                    if (self.output_leaves.is_set or self.output_leaves.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_leaves.get_name_leafdata())
                    if (self.output_mtrace.is_set or self.output_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_mtrace.get_name_leafdata())
                    if (self.output_no_parent_interface_handle.is_set or self.output_no_parent_interface_handle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_no_parent_interface_handle.get_name_leafdata())
                    if (self.output_pim.is_set or self.output_pim.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_pim.get_name_leafdata())
                    if (self.output_queries.is_set or self.output_queries.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_queries.get_name_leafdata())
                    if (self.output_reports.is_set or self.output_reports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_reports.get_name_leafdata())
                    if (self.packet_manager_input_errors.is_set or self.packet_manager_input_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_manager_input_errors.get_name_leafdata())
                    if (self.packet_manager_output_errors.is_set or self.packet_manager_output_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_manager_output_errors.get_name_leafdata())
                    if (self.packets_in.is_set or self.packets_in.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_in.get_name_leafdata())
                    if (self.packets_out.is_set or self.packets_out.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_out.get_name_leafdata())
                    if (self.receive_socket_errors.is_set or self.receive_socket_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.receive_socket_errors.get_name_leafdata())
                    if (self.socket_errors.is_set or self.socket_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.socket_errors.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auxillary-data-length-errors" or name == "bad-scope-errors" or name == "checksum-errors" or name == "elapsed-time" or name == "format-errors" or name == "get-packet-failure" or name == "input-disabled-idb" or name == "input-dvmrp" or name == "input-leaves" or name == "input-martian-address" or name == "input-mtrace" or name == "input-no-assigned-vrf-id" or name == "input-no-idb" or name == "input-no-platform-support-mtrace" or name == "input-no-vrf-in-idb" or name == "input-no-vrf-mtrace" or name == "input-pim" or name == "input-queries" or name == "input-reports" or name == "invalid-source-address-errors" or name == "miscellaneous-errors" or name == "no-socket-connection" or name == "output-dvmrp" or name == "output-leaves" or name == "output-mtrace" or name == "output-no-parent-interface-handle" or name == "output-pim" or name == "output-queries" or name == "output-reports" or name == "packet-manager-input-errors" or name == "packet-manager-output-errors" or name == "packets-in" or name == "packets-out" or name == "receive-socket-errors" or name == "socket-errors"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "auxillary-data-length-errors"):
                        self.auxillary_data_length_errors = value
                        self.auxillary_data_length_errors.value_namespace = name_space
                        self.auxillary_data_length_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "bad-scope-errors"):
                        self.bad_scope_errors = value
                        self.bad_scope_errors.value_namespace = name_space
                        self.bad_scope_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "checksum-errors"):
                        self.checksum_errors = value
                        self.checksum_errors.value_namespace = name_space
                        self.checksum_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "elapsed-time"):
                        self.elapsed_time = value
                        self.elapsed_time.value_namespace = name_space
                        self.elapsed_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "format-errors"):
                        self.format_errors = value
                        self.format_errors.value_namespace = name_space
                        self.format_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "get-packet-failure"):
                        self.get_packet_failure = value
                        self.get_packet_failure.value_namespace = name_space
                        self.get_packet_failure.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-disabled-idb"):
                        self.input_disabled_idb = value
                        self.input_disabled_idb.value_namespace = name_space
                        self.input_disabled_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-dvmrp"):
                        self.input_dvmrp = value
                        self.input_dvmrp.value_namespace = name_space
                        self.input_dvmrp.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-leaves"):
                        self.input_leaves = value
                        self.input_leaves.value_namespace = name_space
                        self.input_leaves.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-martian-address"):
                        self.input_martian_address = value
                        self.input_martian_address.value_namespace = name_space
                        self.input_martian_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-mtrace"):
                        self.input_mtrace = value
                        self.input_mtrace.value_namespace = name_space
                        self.input_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-assigned-vrf-id"):
                        self.input_no_assigned_vrf_id = value
                        self.input_no_assigned_vrf_id.value_namespace = name_space
                        self.input_no_assigned_vrf_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-idb"):
                        self.input_no_idb = value
                        self.input_no_idb.value_namespace = name_space
                        self.input_no_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-platform-support-mtrace"):
                        self.input_no_platform_support_mtrace = value
                        self.input_no_platform_support_mtrace.value_namespace = name_space
                        self.input_no_platform_support_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-in-idb"):
                        self.input_no_vrf_in_idb = value
                        self.input_no_vrf_in_idb.value_namespace = name_space
                        self.input_no_vrf_in_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-mtrace"):
                        self.input_no_vrf_mtrace = value
                        self.input_no_vrf_mtrace.value_namespace = name_space
                        self.input_no_vrf_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-pim"):
                        self.input_pim = value
                        self.input_pim.value_namespace = name_space
                        self.input_pim.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-queries"):
                        self.input_queries = value
                        self.input_queries.value_namespace = name_space
                        self.input_queries.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-reports"):
                        self.input_reports = value
                        self.input_reports.value_namespace = name_space
                        self.input_reports.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-source-address-errors"):
                        self.invalid_source_address_errors = value
                        self.invalid_source_address_errors.value_namespace = name_space
                        self.invalid_source_address_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "miscellaneous-errors"):
                        self.miscellaneous_errors = value
                        self.miscellaneous_errors.value_namespace = name_space
                        self.miscellaneous_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-socket-connection"):
                        self.no_socket_connection = value
                        self.no_socket_connection.value_namespace = name_space
                        self.no_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-dvmrp"):
                        self.output_dvmrp = value
                        self.output_dvmrp.value_namespace = name_space
                        self.output_dvmrp.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-leaves"):
                        self.output_leaves = value
                        self.output_leaves.value_namespace = name_space
                        self.output_leaves.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-mtrace"):
                        self.output_mtrace = value
                        self.output_mtrace.value_namespace = name_space
                        self.output_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-no-parent-interface-handle"):
                        self.output_no_parent_interface_handle = value
                        self.output_no_parent_interface_handle.value_namespace = name_space
                        self.output_no_parent_interface_handle.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-pim"):
                        self.output_pim = value
                        self.output_pim.value_namespace = name_space
                        self.output_pim.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-queries"):
                        self.output_queries = value
                        self.output_queries.value_namespace = name_space
                        self.output_queries.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-reports"):
                        self.output_reports = value
                        self.output_reports.value_namespace = name_space
                        self.output_reports.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-manager-input-errors"):
                        self.packet_manager_input_errors = value
                        self.packet_manager_input_errors.value_namespace = name_space
                        self.packet_manager_input_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-manager-output-errors"):
                        self.packet_manager_output_errors = value
                        self.packet_manager_output_errors.value_namespace = name_space
                        self.packet_manager_output_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "packets-in"):
                        self.packets_in = value
                        self.packets_in.value_namespace = name_space
                        self.packets_in.value_namespace_prefix = name_space_prefix
                    if(value_path == "packets-out"):
                        self.packets_out = value
                        self.packets_out.value_namespace = name_space
                        self.packets_out.value_namespace_prefix = name_space_prefix
                    if(value_path == "receive-socket-errors"):
                        self.receive_socket_errors = value
                        self.receive_socket_errors.value_namespace = name_space
                        self.receive_socket_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "socket-errors"):
                        self.socket_errors = value
                        self.socket_errors.value_namespace = name_space
                        self.socket_errors.value_namespace_prefix = name_space_prefix


            class Groups(Entity):
                """
                IGMP Group Database Table
                
                .. attribute:: group
                
                	IGMP Group Entry Information
                	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Groups.Group>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.Groups, self).__init__()

                    self.yang_name = "groups"
                    self.yang_parent_name = "default-context"

                    self.group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.Groups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.Groups, self).__setattr__(name, value)


                class Group(Entity):
                    """
                    IGMP Group Entry Information
                    
                    .. attribute:: expiration_time
                    
                    	Expiration time in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: explicit_tracking_enabled
                    
                    	Is explicit tracking enabled
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Groups.Group.GroupAddressXr>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_added
                    
                    	Joined
                    	**type**\:  bool
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: is_self_join
                    
                    	If local system is member of this group on this interface
                    	**type**\:  bool
                    
                    .. attribute:: is_suppressed
                    
                    	Suppressed
                    	**type**\:  bool
                    
                    .. attribute:: last_reporter
                    
                    	Last reporter address
                    	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Groups.Group.LastReporter>`
                    
                    .. attribute:: older_host_version1_timer
                    
                    	IGMP Hostversion1timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: older_host_version2_timer
                    
                    	IGMP Hostversion2timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_filter_mode
                    
                    	Filter mode
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: row_status
                    
                    	interface on or off for the group
                    	**type**\:  str
                    
                    	**length:** 0..16
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Groups.Group.SourceAddress>`
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.Groups.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "groups"

                        self.expiration_time = YLeaf(YType.int32, "expiration-time")

                        self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_added = YLeaf(YType.boolean, "is-added")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                        self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                        self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                        self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                        self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                        self.row_status = YLeaf(YType.str, "row-status")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Mld.Active.DefaultContext.Groups.Group.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.last_reporter = Mld.Active.DefaultContext.Groups.Group.LastReporter()
                        self.last_reporter.parent = self
                        self._children_name_map["last_reporter"] = "last-reporter"
                        self._children_yang_names.add("last-reporter")

                        self.source_address = Mld.Active.DefaultContext.Groups.Group.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("expiration_time",
                                        "explicit_tracking_enabled",
                                        "group_address",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_added",
                                        "is_low_memory",
                                        "is_self_join",
                                        "is_suppressed",
                                        "older_host_version1_timer",
                                        "older_host_version2_timer",
                                        "router_filter_mode",
                                        "row_status",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.Groups.Group, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.Groups.Group, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.Groups.Group.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.Groups.Group.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.Groups.Group.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class LastReporter(Entity):
                        """
                        Last reporter address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.Groups.Group.LastReporter, self).__init__()

                            self.yang_name = "last-reporter"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.Groups.Group.LastReporter, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.Groups.Group.LastReporter, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "last-reporter" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.Groups.Group.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.Groups.Group.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.Groups.Group.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.expiration_time.is_set or
                            self.explicit_tracking_enabled.is_set or
                            self.group_address.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_added.is_set or
                            self.is_low_memory.is_set or
                            self.is_self_join.is_set or
                            self.is_suppressed.is_set or
                            self.older_host_version1_timer.is_set or
                            self.older_host_version2_timer.is_set or
                            self.router_filter_mode.is_set or
                            self.row_status.is_set or
                            self.uptime.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.last_reporter is not None and self.last_reporter.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.expiration_time.yfilter != YFilter.not_set or
                            self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_added.yfilter != YFilter.not_set or
                            self.is_low_memory.yfilter != YFilter.not_set or
                            self.is_self_join.yfilter != YFilter.not_set or
                            self.is_suppressed.yfilter != YFilter.not_set or
                            self.older_host_version1_timer.yfilter != YFilter.not_set or
                            self.older_host_version2_timer.yfilter != YFilter.not_set or
                            self.router_filter_mode.yfilter != YFilter.not_set or
                            self.row_status.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.last_reporter is not None and self.last_reporter.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiration_time.get_name_leafdata())
                        if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_added.get_name_leafdata())
                        if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                        if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_self_join.get_name_leafdata())
                        if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                        if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                        if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                        if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                        if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.row_status.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Mld.Active.DefaultContext.Groups.Group.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "last-reporter"):
                            if (self.last_reporter is None):
                                self.last_reporter = Mld.Active.DefaultContext.Groups.Group.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                            return self.last_reporter

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Mld.Active.DefaultContext.Groups.Group.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "group-address" or name == "interface-name" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "expiration-time"):
                            self.expiration_time = value
                            self.expiration_time.value_namespace = name_space
                            self.expiration_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "explicit-tracking-enabled"):
                            self.explicit_tracking_enabled = value
                            self.explicit_tracking_enabled.value_namespace = name_space
                            self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-added"):
                            self.is_added = value
                            self.is_added.value_namespace = name_space
                            self.is_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-low-memory"):
                            self.is_low_memory = value
                            self.is_low_memory.value_namespace = name_space
                            self.is_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-self-join"):
                            self.is_self_join = value
                            self.is_self_join.value_namespace = name_space
                            self.is_self_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-suppressed"):
                            self.is_suppressed = value
                            self.is_suppressed.value_namespace = name_space
                            self.is_suppressed.value_namespace_prefix = name_space_prefix
                        if(value_path == "older-host-version1-timer"):
                            self.older_host_version1_timer = value
                            self.older_host_version1_timer.value_namespace = name_space
                            self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "older-host-version2-timer"):
                            self.older_host_version2_timer = value
                            self.older_host_version2_timer.value_namespace = name_space
                            self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-filter-mode"):
                            self.router_filter_mode = value
                            self.router_filter_mode.value_namespace = name_space
                            self.router_filter_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "row-status"):
                            self.row_status = value
                            self.row_status.value_namespace = name_space
                            self.row_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group"):
                        for c in self.group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.Groups.Group()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupSummary(Entity):
                """
                IGMP Groups Summary
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groutes
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_low_memory
                
                	Node is running low on memory
                	**type**\:  bool
                
                .. attribute:: sg_routes
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.GroupSummary, self).__init__()

                    self.yang_name = "group-summary"
                    self.yang_parent_name = "default-context"

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.groutes = YLeaf(YType.uint32, "groutes")

                    self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                    self.sg_routes = YLeaf(YType.uint32, "sg-routes")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_count",
                                    "groutes",
                                    "is_low_memory",
                                    "sg_routes") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.GroupSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.GroupSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.group_count.is_set or
                        self.groutes.is_set or
                        self.is_low_memory.is_set or
                        self.sg_routes.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_count.yfilter != YFilter.not_set or
                        self.groutes.yfilter != YFilter.not_set or
                        self.is_low_memory.yfilter != YFilter.not_set or
                        self.sg_routes.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_count.get_name_leafdata())
                    if (self.groutes.is_set or self.groutes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.groutes.get_name_leafdata())
                    if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                    if (self.sg_routes.is_set or self.sg_routes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_routes.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-count" or name == "groutes" or name == "is-low-memory" or name == "sg-routes"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-count"):
                        self.group_count = value
                        self.group_count.value_namespace = name_space
                        self.group_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "groutes"):
                        self.groutes = value
                        self.groutes.value_namespace = name_space
                        self.groutes.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-low-memory"):
                        self.is_low_memory = value
                        self.is_low_memory.value_namespace = name_space
                        self.is_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-routes"):
                        self.sg_routes = value
                        self.sg_routes.value_namespace = name_space
                        self.sg_routes.value_namespace_prefix = name_space_prefix


            class IfrsInterfaceSummary(Entity):
                """
                IGMP IFRS Interface summary
                
                .. attribute:: configuration_count
                
                	Configuration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Interface Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.IfrsInterfaceSummary, self).__init__()

                    self.yang_name = "ifrs-interface-summary"
                    self.yang_parent_name = "default-context"

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configuration_count",
                                    "interface_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.IfrsInterfaceSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.IfrsInterfaceSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configuration_count.is_set or
                        self.interface_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configuration_count.yfilter != YFilter.not_set or
                        self.interface_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interface-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configuration_count.get_name_leafdata())
                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configuration-count" or name == "interface-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configuration-count"):
                        self.configuration_count = value
                        self.configuration_count.value_namespace = name_space
                        self.configuration_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-count"):
                        self.interface_count = value
                        self.interface_count.value_namespace = name_space
                        self.interface_count.value_namespace_prefix = name_space_prefix


            class GlobalInterfaceTable(Entity):
                """
                IGMP Global Interface 
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GlobalInterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.GlobalInterfaceTable, self).__init__()

                    self.yang_name = "global-interface-table"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.GlobalInterfaceTable, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.GlobalInterfaceTable, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "global-interface-table"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/global-interface-table/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-interface-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.GlobalInterfaceTable.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SsmMapDetails(Entity):
                """
                SSM Map Detail
                
                .. attribute:: ssm_map_detail
                
                	SSM Map Detail Table information
                	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.SsmMapDetails, self).__init__()

                    self.yang_name = "ssm-map-details"
                    self.yang_parent_name = "default-context"

                    self.ssm_map_detail = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.SsmMapDetails, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.SsmMapDetails, self).__setattr__(name, value)


                class SsmMapDetail(Entity):
                    """
                    SSM Map Detail Table information
                    
                    .. attribute:: elapsed_time
                    
                    	Elapsed time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: expiration_time
                    
                    	Expiration Time in Seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: map_info
                    
                    	Basic Map Info
                    	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo>`
                    
                    .. attribute:: query_interval
                    
                    	Query interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response_pending
                    
                    	Response Pending
                    	**type**\:  bool
                    
                    .. attribute:: sources
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources>`
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail, self).__init__()

                        self.yang_name = "ssm-map-detail"
                        self.yang_parent_name = "ssm-map-details"

                        self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                        self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.query_interval = YLeaf(YType.uint32, "query-interval")

                        self.response_pending = YLeaf(YType.boolean, "response-pending")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.map_info = Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                        self.map_info.parent = self
                        self._children_name_map["map_info"] = "map-info"
                        self._children_yang_names.add("map-info")

                        self.sources = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("elapsed_time",
                                        "expiration_time",
                                        "group_address",
                                        "query_interval",
                                        "response_pending",
                                        "ssm_map_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)


                    class MapInfo(Entity):
                        """
                        Basic Map Info
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                            self.yang_name = "map-info"
                            self.yang_parent_name = "ssm-map-detail"

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.group_address_xr = Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("map_type",
                                            "source_counts") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "map-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-map-details/ssm-map-detail/map-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.map_type.is_set or
                                self.source_counts.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.map_type.yfilter != YFilter.not_set or
                                self.source_counts.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "map-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-map-details/ssm-map-detail/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.map_type.get_name_leafdata())
                            if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_counts.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "map-type" or name == "source-counts"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "map-type"):
                                self.map_type = value
                                self.map_type.value_namespace = name_space
                                self.map_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-counts"):
                                self.source_counts = value
                                self.source_counts.value_namespace = name_space
                                self.source_counts.value_namespace_prefix = name_space_prefix


                    class Sources(Entity):
                        """
                        List of sources
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                            self.yang_name = "sources"
                            self.yang_parent_name = "ssm-map-detail"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sources" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-map-details/ssm-map-detail/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.sources:
                            if (c.has_data()):
                                return True
                        return (
                            self.elapsed_time.is_set or
                            self.expiration_time.is_set or
                            self.group_address.is_set or
                            self.query_interval.is_set or
                            self.response_pending.is_set or
                            self.ssm_map_type.is_set or
                            (self.map_info is not None and self.map_info.has_data()))

                    def has_operation(self):
                        for c in self.sources:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.expiration_time.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.response_pending.yfilter != YFilter.not_set or
                            self.ssm_map_type.yfilter != YFilter.not_set or
                            (self.map_info is not None and self.map_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map-detail" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-map-details/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiration_time.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.response_pending.is_set or self.response_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response_pending.get_name_leafdata())
                        if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "map-info"):
                            if (self.map_info is None):
                                self.map_info = Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                                self.map_info.parent = self
                                self._children_name_map["map_info"] = "map-info"
                            return self.map_info

                        if (child_yang_name == "sources"):
                            for c in self.sources:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.sources.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "map-info" or name == "sources" or name == "elapsed-time" or name == "expiration-time" or name == "group-address" or name == "query-interval" or name == "response-pending" or name == "ssm-map-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiration-time"):
                            self.expiration_time = value
                            self.expiration_time.value_namespace = name_space
                            self.expiration_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "response-pending"):
                            self.response_pending = value
                            self.response_pending.value_namespace = name_space
                            self.response_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssm-map-type"):
                            self.ssm_map_type = value
                            self.ssm_map_type.value_namespace = name_space
                            self.ssm_map_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ssm_map_detail:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ssm_map_detail:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ssm-map-details" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ssm-map-detail"):
                        for c in self.ssm_map_detail:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ssm_map_detail.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ssm-map-detail"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceStateOffs(Entity):
                """
                IGMP Interface state off
                
                .. attribute:: interface_state_off
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.InterfaceStateOffs, self).__init__()

                    self.yang_name = "interface-state-offs"
                    self.yang_parent_name = "default-context"

                    self.interface_state_off = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Mld.Active.DefaultContext.InterfaceStateOffs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Mld.Active.DefaultContext.InterfaceStateOffs, self).__setattr__(name, value)


                class InterfaceStateOff(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                        self.yang_name = "interface-state-off"
                        self.yang_parent_name = "interface-state-offs"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/interface-state-offs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_state_off:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_state_off:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-state-offs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-state-off"):
                        for c in self.interface_state_off:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_state_off.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-state-off"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.detail_groups is not None and self.detail_groups.has_data()) or
                    (self.explicit_groups is not None and self.explicit_groups.has_data()) or
                    (self.global_interface_table is not None and self.global_interface_table.has_data()) or
                    (self.group_summary is not None and self.group_summary.has_data()) or
                    (self.groups is not None and self.groups.has_data()) or
                    (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_data()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                    (self.interface_state_offs is not None and self.interface_state_offs.has_data()) or
                    (self.interface_state_ons is not None and self.interface_state_ons.has_data()) or
                    (self.interface_table is not None and self.interface_table.has_data()) or
                    (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_data()) or
                    (self.non_active_groups is not None and self.non_active_groups.has_data()) or
                    (self.ranges is not None and self.ranges.has_data()) or
                    (self.ssm_map_details is not None and self.ssm_map_details.has_data()) or
                    (self.ssm_maps is not None and self.ssm_maps.has_data()) or
                    (self.summary is not None and self.summary.has_data()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.detail_groups is not None and self.detail_groups.has_operation()) or
                    (self.explicit_groups is not None and self.explicit_groups.has_operation()) or
                    (self.global_interface_table is not None and self.global_interface_table.has_operation()) or
                    (self.group_summary is not None and self.group_summary.has_operation()) or
                    (self.groups is not None and self.groups.has_operation()) or
                    (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_operation()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                    (self.interface_state_offs is not None and self.interface_state_offs.has_operation()) or
                    (self.interface_state_ons is not None and self.interface_state_ons.has_operation()) or
                    (self.interface_table is not None and self.interface_table.has_operation()) or
                    (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_operation()) or
                    (self.non_active_groups is not None and self.non_active_groups.has_operation()) or
                    (self.ranges is not None and self.ranges.has_operation()) or
                    (self.ssm_map_details is not None and self.ssm_map_details.has_operation()) or
                    (self.ssm_maps is not None and self.ssm_maps.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "default-context" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "detail-groups"):
                    if (self.detail_groups is None):
                        self.detail_groups = Mld.Active.DefaultContext.DetailGroups()
                        self.detail_groups.parent = self
                        self._children_name_map["detail_groups"] = "detail-groups"
                    return self.detail_groups

                if (child_yang_name == "explicit-groups"):
                    if (self.explicit_groups is None):
                        self.explicit_groups = Mld.Active.DefaultContext.ExplicitGroups()
                        self.explicit_groups.parent = self
                        self._children_name_map["explicit_groups"] = "explicit-groups"
                    return self.explicit_groups

                if (child_yang_name == "global-interface-table"):
                    if (self.global_interface_table is None):
                        self.global_interface_table = Mld.Active.DefaultContext.GlobalInterfaceTable()
                        self.global_interface_table.parent = self
                        self._children_name_map["global_interface_table"] = "global-interface-table"
                    return self.global_interface_table

                if (child_yang_name == "group-summary"):
                    if (self.group_summary is None):
                        self.group_summary = Mld.Active.DefaultContext.GroupSummary()
                        self.group_summary.parent = self
                        self._children_name_map["group_summary"] = "group-summary"
                    return self.group_summary

                if (child_yang_name == "groups"):
                    if (self.groups is None):
                        self.groups = Mld.Active.DefaultContext.Groups()
                        self.groups.parent = self
                        self._children_name_map["groups"] = "groups"
                    return self.groups

                if (child_yang_name == "ifrs-interface-summary"):
                    if (self.ifrs_interface_summary is None):
                        self.ifrs_interface_summary = Mld.Active.DefaultContext.IfrsInterfaceSummary()
                        self.ifrs_interface_summary.parent = self
                        self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    return self.ifrs_interface_summary

                if (child_yang_name == "ifrs-interfaces"):
                    if (self.ifrs_interfaces is None):
                        self.ifrs_interfaces = Mld.Active.DefaultContext.IfrsInterfaces()
                        self.ifrs_interfaces.parent = self
                        self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    return self.ifrs_interfaces

                if (child_yang_name == "interface-state-offs"):
                    if (self.interface_state_offs is None):
                        self.interface_state_offs = Mld.Active.DefaultContext.InterfaceStateOffs()
                        self.interface_state_offs.parent = self
                        self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    return self.interface_state_offs

                if (child_yang_name == "interface-state-ons"):
                    if (self.interface_state_ons is None):
                        self.interface_state_ons = Mld.Active.DefaultContext.InterfaceStateOns()
                        self.interface_state_ons.parent = self
                        self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    return self.interface_state_ons

                if (child_yang_name == "interface-table"):
                    if (self.interface_table is None):
                        self.interface_table = Mld.Active.DefaultContext.InterfaceTable()
                        self.interface_table.parent = self
                        self._children_name_map["interface_table"] = "interface-table"
                    return self.interface_table

                if (child_yang_name == "interface-unicast-qos-adjusts"):
                    if (self.interface_unicast_qos_adjusts is None):
                        self.interface_unicast_qos_adjusts = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts()
                        self.interface_unicast_qos_adjusts.parent = self
                        self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    return self.interface_unicast_qos_adjusts

                if (child_yang_name == "non-active-groups"):
                    if (self.non_active_groups is None):
                        self.non_active_groups = Mld.Active.DefaultContext.NonActiveGroups()
                        self.non_active_groups.parent = self
                        self._children_name_map["non_active_groups"] = "non-active-groups"
                    return self.non_active_groups

                if (child_yang_name == "ranges"):
                    if (self.ranges is None):
                        self.ranges = Mld.Active.DefaultContext.Ranges()
                        self.ranges.parent = self
                        self._children_name_map["ranges"] = "ranges"
                    return self.ranges

                if (child_yang_name == "ssm-map-details"):
                    if (self.ssm_map_details is None):
                        self.ssm_map_details = Mld.Active.DefaultContext.SsmMapDetails()
                        self.ssm_map_details.parent = self
                        self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    return self.ssm_map_details

                if (child_yang_name == "ssm-maps"):
                    if (self.ssm_maps is None):
                        self.ssm_maps = Mld.Active.DefaultContext.SsmMaps()
                        self.ssm_maps.parent = self
                        self._children_name_map["ssm_maps"] = "ssm-maps"
                    return self.ssm_maps

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Mld.Active.DefaultContext.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                if (child_yang_name == "traffic-counters"):
                    if (self.traffic_counters is None):
                        self.traffic_counters = Mld.Active.DefaultContext.TrafficCounters()
                        self.traffic_counters.parent = self
                        self._children_name_map["traffic_counters"] = "traffic-counters"
                    return self.traffic_counters

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "detail-groups" or name == "explicit-groups" or name == "global-interface-table" or name == "group-summary" or name == "groups" or name == "ifrs-interface-summary" or name == "ifrs-interfaces" or name == "interface-state-offs" or name == "interface-state-ons" or name == "interface-table" or name == "interface-unicast-qos-adjusts" or name == "non-active-groups" or name == "ranges" or name == "ssm-map-details" or name == "ssm-maps" or name == "summary" or name == "traffic-counters"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.default_context is not None and self.default_context.has_data()) or
                (self.process is not None and self.process.has_data()) or
                (self.vrfs is not None and self.vrfs.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.default_context is not None and self.default_context.has_operation()) or
                (self.process is not None and self.process.has_operation()) or
                (self.vrfs is not None and self.vrfs.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "active" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "default-context"):
                if (self.default_context is None):
                    self.default_context = Mld.Active.DefaultContext()
                    self.default_context.parent = self
                    self._children_name_map["default_context"] = "default-context"
                return self.default_context

            if (child_yang_name == "process"):
                if (self.process is None):
                    self.process = Mld.Active.Process()
                    self.process.parent = self
                    self._children_name_map["process"] = "process"
                return self.process

            if (child_yang_name == "vrfs"):
                if (self.vrfs is None):
                    self.vrfs = Mld.Active.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                return self.vrfs

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "default-context" or name == "process" or name == "vrfs"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.active is not None and self.active.has_data()) or
            (self.standby is not None and self.standby.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.active is not None and self.active.has_operation()) or
            (self.standby is not None and self.standby.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:mld" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "active"):
            if (self.active is None):
                self.active = Mld.Active()
                self.active.parent = self
                self._children_name_map["active"] = "active"
            return self.active

        if (child_yang_name == "standby"):
            if (self.standby is None):
                self.standby = Mld.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"
            return self.standby

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "active" or name == "standby"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Mld()
        return self._top_entity

class Igmp(Entity):
    """
    igmp
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby>`
    
    

    """

    _prefix = 'ipv4-igmp-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Igmp, self).__init__()
        self._top_entity = None

        self.yang_name = "igmp"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-igmp-oper"

        self.active = Igmp.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = Igmp.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-igmp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Igmp.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "igmp"

            self.default_context = Igmp.Standby.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Igmp.Standby.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Igmp.Standby.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF table Names
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Standby.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "standby"

                self.vrf = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Igmp.Standby.Vrfs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Igmp.Standby.Vrfs, self).__setattr__(name, value)


            class Vrf(Entity):
                """
                VRF table Names
                
                .. attribute:: vrf_name  <key>
                
                	VRF name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: detail_groups
                
                	IGMP Detail Group Database
                	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups>`
                
                .. attribute:: explicit_groups
                
                	IGMP Explicit Group Database
                	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups>`
                
                .. attribute:: global_interface_table
                
                	IGMP Global Interface 
                	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable>`
                
                .. attribute:: group_summary
                
                	IGMP Groups Summary
                	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GroupSummary>`
                
                .. attribute:: groups
                
                	IGMP Group Database Table
                	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Groups>`
                
                .. attribute:: ifrs_interface_summary
                
                	IGMP IFRS Interface summary
                	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary>`
                
                .. attribute:: ifrs_interfaces
                
                	IGMP Interface specific
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: interface_state_offs
                
                	IGMP Interface state off
                	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs>`
                
                .. attribute:: interface_state_ons
                
                	IGMP Interface state on
                	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOns>`
                
                .. attribute:: interface_table
                
                	IGMP Interface specific Table
                	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceTable>`
                
                .. attribute:: interface_unicast_qos_adjusts
                
                	IGMP Interface Unicast\-Qos\-Adjust
                	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts>`
                
                .. attribute:: non_active_groups
                
                	IGMP Non\-Active Groups Information
                	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.NonActiveGroups>`
                
                .. attribute:: ranges
                
                	Range table
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: ssm_map_details
                
                	SSM Map Detail
                	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMapDetails>`
                
                .. attribute:: ssm_maps
                
                	SSM Map Table
                	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMaps>`
                
                .. attribute:: summary
                
                	IGMP Summary Information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: traffic_counters
                
                	IGMP Message Traffic Counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.TrafficCounters>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.detail_groups = Igmp.Standby.Vrfs.Vrf.DetailGroups()
                    self.detail_groups.parent = self
                    self._children_name_map["detail_groups"] = "detail-groups"
                    self._children_yang_names.add("detail-groups")

                    self.explicit_groups = Igmp.Standby.Vrfs.Vrf.ExplicitGroups()
                    self.explicit_groups.parent = self
                    self._children_name_map["explicit_groups"] = "explicit-groups"
                    self._children_yang_names.add("explicit-groups")

                    self.global_interface_table = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable()
                    self.global_interface_table.parent = self
                    self._children_name_map["global_interface_table"] = "global-interface-table"
                    self._children_yang_names.add("global-interface-table")

                    self.group_summary = Igmp.Standby.Vrfs.Vrf.GroupSummary()
                    self.group_summary.parent = self
                    self._children_name_map["group_summary"] = "group-summary"
                    self._children_yang_names.add("group-summary")

                    self.groups = Igmp.Standby.Vrfs.Vrf.Groups()
                    self.groups.parent = self
                    self._children_name_map["groups"] = "groups"
                    self._children_yang_names.add("groups")

                    self.ifrs_interface_summary = Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary()
                    self.ifrs_interface_summary.parent = self
                    self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    self._children_yang_names.add("ifrs-interface-summary")

                    self.ifrs_interfaces = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.interface_state_offs = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs()
                    self.interface_state_offs.parent = self
                    self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    self._children_yang_names.add("interface-state-offs")

                    self.interface_state_ons = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns()
                    self.interface_state_ons.parent = self
                    self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    self._children_yang_names.add("interface-state-ons")

                    self.interface_table = Igmp.Standby.Vrfs.Vrf.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                    self._children_yang_names.add("interface-table")

                    self.interface_unicast_qos_adjusts = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                    self.interface_unicast_qos_adjusts.parent = self
                    self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    self._children_yang_names.add("interface-unicast-qos-adjusts")

                    self.non_active_groups = Igmp.Standby.Vrfs.Vrf.NonActiveGroups()
                    self.non_active_groups.parent = self
                    self._children_name_map["non_active_groups"] = "non-active-groups"
                    self._children_yang_names.add("non-active-groups")

                    self.ranges = Igmp.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.ssm_map_details = Igmp.Standby.Vrfs.Vrf.SsmMapDetails()
                    self.ssm_map_details.parent = self
                    self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    self._children_yang_names.add("ssm-map-details")

                    self.ssm_maps = Igmp.Standby.Vrfs.Vrf.SsmMaps()
                    self.ssm_maps.parent = self
                    self._children_name_map["ssm_maps"] = "ssm-maps"
                    self._children_yang_names.add("ssm-maps")

                    self.summary = Igmp.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.traffic_counters = Igmp.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vrf_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.Vrfs.Vrf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.Vrfs.Vrf, self).__setattr__(name, value)


                class Summary(Entity):
                    """
                    IGMP Summary Information
                    
                    .. attribute:: disabled_interface_count
                    
                    	No. of disabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: enabled_interface_count
                    
                    	No. of enabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Maximum and current groups accepted for each interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Summary.Interface>`
                    
                    .. attribute:: is_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: robustness
                    
                    	Robustness variable
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: supported_interfaces
                    
                    	No. of supported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_mte_config_count
                    
                    	No. of static group commands
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsupported_interfaces
                    
                    	No. of unsupported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"

                        self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                        self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                        self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                        self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                        self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("disabled_interface_count",
                                        "enabled_interface_count",
                                        "group_count",
                                        "group_limit",
                                        "is_disabled",
                                        "node_low_memory",
                                        "robustness",
                                        "supported_interfaces",
                                        "tunnel_mte_config_count",
                                        "unsupported_interfaces") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.Summary, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Maximum and current groups accepted for each
                        interface
                        
                        .. attribute:: group_count
                        
                        	Current groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_limit
                        
                        	Maximum groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: on_off
                        
                        	Enabled/Disabled
                        	**type**\:  bool
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent if handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Time elapsed since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.group_limit = YLeaf(YType.uint32, "group-limit")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.on_off = YLeaf(YType.boolean, "on-off")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_count",
                                            "group_limit",
                                            "interface_name",
                                            "on_off",
                                            "parent_ifhandle",
                                            "router_uptime_in_seconds",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.Summary.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.Summary.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.group_count.is_set or
                                self.group_limit.is_set or
                                self.interface_name.is_set or
                                self.on_off.is_set or
                                self.parent_ifhandle.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.group_limit.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.on_off.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_limit.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.on_off.is_set or self.on_off.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.on_off.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-count" or name == "group-limit" or name == "interface-name" or name == "on-off" or name == "parent-ifhandle" or name == "router-uptime-in-seconds" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-limit"):
                                self.group_limit = value
                                self.group_limit.value_namespace = name_space
                                self.group_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "on-off"):
                                self.on_off = value
                                self.on_off.value_namespace = name_space
                                self.on_off.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.disabled_interface_count.is_set or
                            self.enabled_interface_count.is_set or
                            self.group_count.is_set or
                            self.group_limit.is_set or
                            self.is_disabled.is_set or
                            self.node_low_memory.is_set or
                            self.robustness.is_set or
                            self.supported_interfaces.is_set or
                            self.tunnel_mte_config_count.is_set or
                            self.unsupported_interfaces.is_set)

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.disabled_interface_count.yfilter != YFilter.not_set or
                            self.enabled_interface_count.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.group_limit.yfilter != YFilter.not_set or
                            self.is_disabled.yfilter != YFilter.not_set or
                            self.node_low_memory.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.supported_interfaces.yfilter != YFilter.not_set or
                            self.tunnel_mte_config_count.yfilter != YFilter.not_set or
                            self.unsupported_interfaces.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.disabled_interface_count.is_set or self.disabled_interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disabled_interface_count.get_name_leafdata())
                        if (self.enabled_interface_count.is_set or self.enabled_interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enabled_interface_count.get_name_leafdata())
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_limit.get_name_leafdata())
                        if (self.is_disabled.is_set or self.is_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_disabled.get_name_leafdata())
                        if (self.node_low_memory.is_set or self.node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_low_memory.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.supported_interfaces.is_set or self.supported_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.supported_interfaces.get_name_leafdata())
                        if (self.tunnel_mte_config_count.is_set or self.tunnel_mte_config_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_mte_config_count.get_name_leafdata())
                        if (self.unsupported_interfaces.is_set or self.unsupported_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unsupported_interfaces.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.Summary.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "disabled-interface-count" or name == "enabled-interface-count" or name == "group-count" or name == "group-limit" or name == "is-disabled" or name == "node-low-memory" or name == "robustness" or name == "supported-interfaces" or name == "tunnel-mte-config-count" or name == "unsupported-interfaces"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "disabled-interface-count"):
                            self.disabled_interface_count = value
                            self.disabled_interface_count.value_namespace = name_space
                            self.disabled_interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "enabled-interface-count"):
                            self.enabled_interface_count = value
                            self.enabled_interface_count.value_namespace = name_space
                            self.enabled_interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-limit"):
                            self.group_limit = value
                            self.group_limit.value_namespace = name_space
                            self.group_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-disabled"):
                            self.is_disabled = value
                            self.is_disabled.value_namespace = name_space
                            self.is_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-low-memory"):
                            self.node_low_memory = value
                            self.node_low_memory.value_namespace = name_space
                            self.node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "supported-interfaces"):
                            self.supported_interfaces = value
                            self.supported_interfaces.value_namespace = name_space
                            self.supported_interfaces.value_namespace_prefix = name_space_prefix
                        if(value_path == "tunnel-mte-config-count"):
                            self.tunnel_mte_config_count = value
                            self.tunnel_mte_config_count.value_namespace = name_space
                            self.tunnel_mte_config_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "unsupported-interfaces"):
                            self.unsupported_interfaces = value
                            self.unsupported_interfaces.value_namespace = name_space
                            self.unsupported_interfaces.value_namespace_prefix = name_space_prefix


                class InterfaceStateOns(Entity):
                    """
                    IGMP Interface state on
                    
                    .. attribute:: interface_state_on
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns, self).__init__()

                        self.yang_name = "interface-state-ons"
                        self.yang_parent_name = "vrf"

                        self.interface_state_on = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns, self).__setattr__(name, value)


                    class InterfaceStateOn(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__init__()

                            self.yang_name = "interface-state-on"
                            self.yang_parent_name = "interface-state-ons"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_state_on:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_state_on:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-ons" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-state-on"):
                            for c in self.interface_state_on:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_state_on.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-state-on"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class DetailGroups(Entity):
                    """
                    IGMP Detail Group Database
                    
                    .. attribute:: detail_group
                    
                    	IGMP Detail Group Entry Information
                    	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.DetailGroups, self).__init__()

                        self.yang_name = "detail-groups"
                        self.yang_parent_name = "vrf"

                        self.detail_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.DetailGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.DetailGroups, self).__setattr__(name, value)


                    class DetailGroup(Entity):
                        """
                        IGMP Detail Group Entry Information
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_host_exclude_mode
                        
                        	Group host filter mode
                        	**type**\:  bool
                        
                        .. attribute:: is_router_exclude_mode
                        
                        	Group router filter mode
                        	**type**\:  bool
                        
                        .. attribute:: source
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup, self).__init__()

                            self.yang_name = "detail-group"
                            self.yang_parent_name = "detail-groups"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                            self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.source = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "interface_name",
                                            "is_host_exclude_mode",
                                            "is_router_exclude_mode",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup, self).__setattr__(name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "detail-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "explicit_tracking_enabled",
                                                "interface_name_xr",
                                                "is_added",
                                                "is_low_memory",
                                                "is_self_join",
                                                "is_suppressed",
                                                "older_host_version1_timer",
                                                "older_host_version2_timer",
                                                "router_filter_mode",
                                                "row_status",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "last-reporter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.explicit_tracking_enabled.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_added.is_set or
                                    self.is_low_memory.is_set or
                                    self.is_self_join.is_set or
                                    self.is_suppressed.is_set or
                                    self.older_host_version1_timer.is_set or
                                    self.older_host_version2_timer.is_set or
                                    self.router_filter_mode.is_set or
                                    self.row_status.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.last_reporter is not None and self.last_reporter.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_low_memory.yfilter != YFilter.not_set or
                                    self.is_self_join.yfilter != YFilter.not_set or
                                    self.is_suppressed.yfilter != YFilter.not_set or
                                    self.older_host_version1_timer.yfilter != YFilter.not_set or
                                    self.older_host_version2_timer.yfilter != YFilter.not_set or
                                    self.router_filter_mode.yfilter != YFilter.not_set or
                                    self.row_status.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                                if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_self_join.get_name_leafdata())
                                if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                                if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                                if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                                if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                                if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.row_status.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "last-reporter"):
                                    if (self.last_reporter is None):
                                        self.last_reporter = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                        self.last_reporter.parent = self
                                        self._children_name_map["last_reporter"] = "last-reporter"
                                    return self.last_reporter

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "explicit-tracking-enabled"):
                                    self.explicit_tracking_enabled = value
                                    self.explicit_tracking_enabled.value_namespace = name_space
                                    self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-low-memory"):
                                    self.is_low_memory = value
                                    self.is_low_memory.value_namespace = name_space
                                    self.is_low_memory.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-self-join"):
                                    self.is_self_join = value
                                    self.is_self_join.value_namespace = name_space
                                    self.is_self_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-suppressed"):
                                    self.is_suppressed = value
                                    self.is_suppressed.value_namespace = name_space
                                    self.is_suppressed.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version1-timer"):
                                    self.older_host_version1_timer = value
                                    self.older_host_version1_timer.value_namespace = name_space
                                    self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version2-timer"):
                                    self.older_host_version2_timer = value
                                    self.older_host_version2_timer.value_namespace = name_space
                                    self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-filter-mode"):
                                    self.router_filter_mode = value
                                    self.router_filter_mode.value_namespace = name_space
                                    self.router_filter_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "row-status"):
                                    self.row_status = value
                                    self.row_status.value_namespace = name_space
                                    self.row_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix


                        class Source(Entity):
                            """
                            List of sources
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: flags
                            
                            	Source flags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_forward
                            
                            	Should we forward on this entry
                            	**type**\:  bool
                            
                            .. attribute:: is_local
                            
                            	Is this a local source
                            	**type**\:  bool
                            
                            .. attribute:: is_remote
                            
                            	Is this a remote source
                            	**type**\:  bool
                            
                            .. attribute:: is_we_report
                            
                            	Should we report the source
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "detail-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.flags = YLeaf(YType.int32, "flags")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_forward = YLeaf(YType.boolean, "is-forward")

                                self.is_local = YLeaf(YType.boolean, "is-local")

                                self.is_remote = YLeaf(YType.boolean, "is-remote")

                                self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.source_address = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "flags",
                                                "is_added",
                                                "is_forward",
                                                "is_local",
                                                "is_remote",
                                                "is_we_report",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.flags.is_set or
                                    self.is_added.is_set or
                                    self.is_forward.is_set or
                                    self.is_local.is_set or
                                    self.is_remote.is_set or
                                    self.is_we_report.is_set or
                                    self.uptime.is_set or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.flags.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_forward.yfilter != YFilter.not_set or
                                    self.is_local.yfilter != YFilter.not_set or
                                    self.is_remote.yfilter != YFilter.not_set or
                                    self.is_we_report.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_forward.is_set or self.is_forward.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_forward.get_name_leafdata())
                                if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_local.get_name_leafdata())
                                if (self.is_remote.is_set or self.is_remote.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_remote.get_name_leafdata())
                                if (self.is_we_report.is_set or self.is_we_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_we_report.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "source-address" or name == "expiration-time" or name == "flags" or name == "is-added" or name == "is-forward" or name == "is-local" or name == "is-remote" or name == "is-we-report" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "flags"):
                                    self.flags = value
                                    self.flags.value_namespace = name_space
                                    self.flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-forward"):
                                    self.is_forward = value
                                    self.is_forward.value_namespace = name_space
                                    self.is_forward.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-local"):
                                    self.is_local = value
                                    self.is_local.value_namespace = name_space
                                    self.is_local.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-remote"):
                                    self.is_remote = value
                                    self.is_remote.value_namespace = name_space
                                    self.is_remote.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-we-report"):
                                    self.is_we_report = value
                                    self.is_we_report.value_namespace = name_space
                                    self.is_we_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.source:
                                if (c.has_data()):
                                    return True
                            return (
                                self.group_address.is_set or
                                self.interface_name.is_set or
                                self.is_host_exclude_mode.is_set or
                                self.is_router_exclude_mode.is_set or
                                self.source_address.is_set or
                                (self.group_info is not None and self.group_info.has_data()))

                        def has_operation(self):
                            for c in self.source:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_host_exclude_mode.yfilter != YFilter.not_set or
                                self.is_router_exclude_mode.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group_info is not None and self.group_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "detail-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_host_exclude_mode.is_set or self.is_host_exclude_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_host_exclude_mode.get_name_leafdata())
                            if (self.is_router_exclude_mode.is_set or self.is_router_exclude_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_exclude_mode.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-info"):
                                if (self.group_info is None):
                                    self.group_info = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                                    self.group_info.parent = self
                                    self._children_name_map["group_info"] = "group-info"
                                return self.group_info

                            if (child_yang_name == "source"):
                                for c in self.source:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.source.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-info" or name == "source" or name == "group-address" or name == "interface-name" or name == "is-host-exclude-mode" or name == "is-router-exclude-mode" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-host-exclude-mode"):
                                self.is_host_exclude_mode = value
                                self.is_host_exclude_mode.value_namespace = name_space
                                self.is_host_exclude_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-exclude-mode"):
                                self.is_router_exclude_mode = value
                                self.is_router_exclude_mode.value_namespace = name_space
                                self.is_router_exclude_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.detail_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.detail_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "detail-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "detail-group"):
                            for c in self.detail_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.detail_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "detail-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NonActiveGroups(Entity):
                    """
                    IGMP Non\-Active Groups Information
                    
                    .. attribute:: non_active_groups
                    
                    	List of non\-active groups
                    	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "vrf"

                        self.non_active_groups = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups, self).__setattr__(name, value)


                    class NonActiveGroups(Entity):
                        """
                        List of non\-active groups
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress>`
                        
                        .. attribute:: interface
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: reason_for_non_activity
                        
                        	Reason for group join not being processed
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__init__()

                            self.yang_name = "non-active-groups"
                            self.yang_parent_name = "non-active-groups"

                            self.interface = YLeaf(YType.str, "interface")

                            self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                            self.group_address = Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface",
                                            "reason_for_non_activity") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "non-active-groups"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "non-active-groups"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface.is_set or
                                self.reason_for_non_activity.is_set or
                                (self.group_address is not None and self.group_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface.yfilter != YFilter.not_set or
                                self.reason_for_non_activity.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "non-active-groups" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface.get_name_leafdata())
                            if (self.reason_for_non_activity.is_set or self.reason_for_non_activity.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reason_for_non_activity.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "source-address" or name == "interface" or name == "reason-for-non-activity"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface"):
                                self.interface = value
                                self.interface.value_namespace = name_space
                                self.interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "reason-for-non-activity"):
                                self.reason_for_non_activity = value
                                self.reason_for_non_activity.value_namespace = name_space
                                self.reason_for_non_activity.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.non_active_groups:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.non_active_groups:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "non-active-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "non-active-groups"):
                            for c in self.non_active_groups:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.non_active_groups.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "non-active-groups"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SsmMaps(Entity):
                    """
                    SSM Map Table
                    
                    .. attribute:: ssm_map
                    
                    	SSM Map information
                    	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.SsmMaps, self).__init__()

                        self.yang_name = "ssm-maps"
                        self.yang_parent_name = "vrf"

                        self.ssm_map = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.SsmMaps, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.SsmMaps, self).__setattr__(name, value)


                    class SsmMap(Entity):
                        """
                        SSM Map information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap, self).__init__()

                            self.yang_name = "ssm-map"
                            self.yang_parent_name = "ssm-maps"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.group_address_xr = Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "map_type",
                                            "source_counts",
                                            "ssm_map_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "ssm-map"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.map_type.is_set or
                                self.source_counts.is_set or
                                self.ssm_map_type.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.map_type.yfilter != YFilter.not_set or
                                self.source_counts.yfilter != YFilter.not_set or
                                self.ssm_map_type.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ssm-map" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.map_type.get_name_leafdata())
                            if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_counts.get_name_leafdata())
                            if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "group-address" or name == "map-type" or name == "source-counts" or name == "ssm-map-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "map-type"):
                                self.map_type = value
                                self.map_type.value_namespace = name_space
                                self.map_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-counts"):
                                self.source_counts = value
                                self.source_counts.value_namespace = name_space
                                self.source_counts.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssm-map-type"):
                                self.ssm_map_type = value
                                self.ssm_map_type.value_namespace = name_space
                                self.ssm_map_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ssm_map:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ssm_map:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-maps" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ssm-map"):
                            for c in self.ssm_map:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ssm_map.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ssm-map"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class ExplicitGroups(Entity):
                    """
                    IGMP Explicit Group Database
                    
                    .. attribute:: explicit_group
                    
                    	IGMP Explicit Group Entry Information
                    	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups, self).__init__()

                        self.yang_name = "explicit-groups"
                        self.yang_parent_name = "vrf"

                        self.explicit_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups, self).__setattr__(name, value)


                    class ExplicitGroup(Entity):
                        """
                        IGMP Explicit Group Entry Information
                        
                        .. attribute:: exclude_hosts
                        
                        	No. of hosts who are excluded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo>`
                        
                        .. attribute:: host
                        
                        	List of hosts
                        	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host>`
                        
                        .. attribute:: include_hosts
                        
                        	No. of hosts who are included
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__init__()

                            self.yang_name = "explicit-group"
                            self.yang_parent_name = "explicit-groups"

                            self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.host = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("exclude_hosts",
                                            "group_address",
                                            "include_hosts",
                                            "interface_name",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "explicit-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "explicit_tracking_enabled",
                                                "interface_name_xr",
                                                "is_added",
                                                "is_low_memory",
                                                "is_self_join",
                                                "is_suppressed",
                                                "older_host_version1_timer",
                                                "older_host_version2_timer",
                                                "router_filter_mode",
                                                "row_status",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "last-reporter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.explicit_tracking_enabled.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_added.is_set or
                                    self.is_low_memory.is_set or
                                    self.is_self_join.is_set or
                                    self.is_suppressed.is_set or
                                    self.older_host_version1_timer.is_set or
                                    self.older_host_version2_timer.is_set or
                                    self.router_filter_mode.is_set or
                                    self.row_status.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.last_reporter is not None and self.last_reporter.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_low_memory.yfilter != YFilter.not_set or
                                    self.is_self_join.yfilter != YFilter.not_set or
                                    self.is_suppressed.yfilter != YFilter.not_set or
                                    self.older_host_version1_timer.yfilter != YFilter.not_set or
                                    self.older_host_version2_timer.yfilter != YFilter.not_set or
                                    self.router_filter_mode.yfilter != YFilter.not_set or
                                    self.row_status.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                                if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_self_join.get_name_leafdata())
                                if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                                if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                                if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                                if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                                if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.row_status.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "last-reporter"):
                                    if (self.last_reporter is None):
                                        self.last_reporter = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                        self.last_reporter.parent = self
                                        self._children_name_map["last_reporter"] = "last-reporter"
                                    return self.last_reporter

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "explicit-tracking-enabled"):
                                    self.explicit_tracking_enabled = value
                                    self.explicit_tracking_enabled.value_namespace = name_space
                                    self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-low-memory"):
                                    self.is_low_memory = value
                                    self.is_low_memory.value_namespace = name_space
                                    self.is_low_memory.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-self-join"):
                                    self.is_self_join = value
                                    self.is_self_join.value_namespace = name_space
                                    self.is_self_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-suppressed"):
                                    self.is_suppressed = value
                                    self.is_suppressed.value_namespace = name_space
                                    self.is_suppressed.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version1-timer"):
                                    self.older_host_version1_timer = value
                                    self.older_host_version1_timer.value_namespace = name_space
                                    self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version2-timer"):
                                    self.older_host_version2_timer = value
                                    self.older_host_version2_timer.value_namespace = name_space
                                    self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-filter-mode"):
                                    self.router_filter_mode = value
                                    self.router_filter_mode.value_namespace = name_space
                                    self.router_filter_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "row-status"):
                                    self.row_status = value
                                    self.row_status.value_namespace = name_space
                                    self.row_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix


                        class Host(Entity):
                            """
                            List of hosts
                            
                            .. attribute:: address
                            
                            	Host Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address>`
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_exclude
                            
                            	Exclude flag set
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	First 3 source addresses
                            	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                            
                            .. attribute:: source_count
                            
                            	No. of sources in entry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "explicit-group"

                                self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                                self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                                self.source_count = YLeaf(YType.uint32, "source-count")

                                self.uptime = YLeaf(YType.uint32, "uptime")

                                self.address = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.source_address = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "is_exclude",
                                                "source_count",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)


                            class Address(Entity):
                                """
                                Host Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "host"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                First 3 source addresses
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "host"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.source_address:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.expiration_time.is_set or
                                    self.is_exclude.is_set or
                                    self.source_count.is_set or
                                    self.uptime.is_set or
                                    (self.address is not None and self.address.has_data()))

                            def has_operation(self):
                                for c in self.source_address:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.is_exclude.yfilter != YFilter.not_set or
                                    self.source_count.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.address is not None and self.address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "host" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.is_exclude.is_set or self.is_exclude.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_exclude.get_name_leafdata())
                                if (self.source_count.is_set or self.source_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_count.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "address"):
                                    if (self.address is None):
                                        self.address = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                    return self.address

                                if (child_yang_name == "source-address"):
                                    for c in self.source_address:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.source_address.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "source-address" or name == "expiration-time" or name == "is-exclude" or name == "source-count" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-exclude"):
                                    self.is_exclude = value
                                    self.is_exclude.value_namespace = name_space
                                    self.is_exclude.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-count"):
                                    self.source_count = value
                                    self.source_count.value_namespace = name_space
                                    self.source_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.host:
                                if (c.has_data()):
                                    return True
                            return (
                                self.exclude_hosts.is_set or
                                self.group_address.is_set or
                                self.include_hosts.is_set or
                                self.interface_name.is_set or
                                self.source_address.is_set or
                                (self.group_info is not None and self.group_info.has_data()))

                        def has_operation(self):
                            for c in self.host:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.exclude_hosts.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.include_hosts.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group_info is not None and self.group_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "explicit-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.exclude_hosts.is_set or self.exclude_hosts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.exclude_hosts.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.include_hosts.is_set or self.include_hosts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.include_hosts.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-info"):
                                if (self.group_info is None):
                                    self.group_info = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                                    self.group_info.parent = self
                                    self._children_name_map["group_info"] = "group-info"
                                return self.group_info

                            if (child_yang_name == "host"):
                                for c in self.host:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.host.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-info" or name == "host" or name == "exclude-hosts" or name == "group-address" or name == "include-hosts" or name == "interface-name" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "exclude-hosts"):
                                self.exclude_hosts = value
                                self.exclude_hosts.value_namespace = name_space
                                self.exclude_hosts.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "include-hosts"):
                                self.include_hosts = value
                                self.include_hosts.value_namespace = name_space
                                self.include_hosts.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.explicit_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.explicit_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "explicit-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "explicit-group"):
                            for c in self.explicit_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.explicit_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "explicit-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceTable(Entity):
                    """
                    IGMP Interface specific Table
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.InterfaceTable, self).__init__()

                        self.yang_name = "interface-table"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceTable, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-table"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceUnicastQosAdjusts(Entity):
                    """
                    IGMP Interface Unicast\-Qos\-Adjust
                    
                    .. attribute:: interface_unicast_qos_adjust
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjusts"
                        self.yang_parent_name = "vrf"

                        self.interface_unicast_qos_adjust = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)


                    class InterfaceUnicastQosAdjust(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_virtual_access
                        
                        	Is VirtualAccess Interface
                        	**type**\:  bool
                        
                        .. attribute:: rate
                        
                        	Overall rate in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: rate_decrements
                        
                        	Count of rate decrements
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rate_increments
                        
                        	Count of rate increments
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update
                        
                        	List of updates
                        	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                            self.yang_name = "interface-unicast-qos-adjust"
                            self.yang_parent_name = "interface-unicast-qos-adjusts"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                            self.rate = YLeaf(YType.uint32, "rate")

                            self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                            self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                            self.update = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "is_virtual_access",
                                            "rate",
                                            "rate_decrements",
                                            "rate_increments") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)


                        class Update(Entity):
                            """
                            List of updates
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                            
                            .. attribute:: is_add
                            
                            	Is this a rate increment
                            	**type**\:  bool
                            
                            .. attribute:: received_time
                            
                            	Time this update is received
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                            
                            .. attribute:: weight
                            
                            	Weight from policy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                                self.yang_name = "update"
                                self.yang_parent_name = "interface-unicast-qos-adjust"

                                self.is_add = YLeaf(YType.boolean, "is-add")

                                self.received_time = YLeaf(YType.uint64, "received-time")

                                self.weight = YLeaf(YType.uint32, "weight")

                                self.group_address = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                                self._children_yang_names.add("group-address")

                                self.source_address = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_add",
                                                "received_time",
                                                "weight") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)


                            class SourceAddress(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "update"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GroupAddress(Entity):
                                """
                                Group address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                    self.yang_name = "group-address"
                                    self.yang_parent_name = "update"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.is_add.is_set or
                                    self.received_time.is_set or
                                    self.weight.is_set or
                                    (self.group_address is not None and self.group_address.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_add.yfilter != YFilter.not_set or
                                    self.received_time.yfilter != YFilter.not_set or
                                    self.weight.yfilter != YFilter.not_set or
                                    (self.group_address is not None and self.group_address.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "update" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_add.is_set or self.is_add.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_add.get_name_leafdata())
                                if (self.received_time.is_set or self.received_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_time.get_name_leafdata())
                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address"):
                                    if (self.group_address is None):
                                        self.group_address = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                        self.group_address.parent = self
                                        self._children_name_map["group_address"] = "group-address"
                                    return self.group_address

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address" or name == "source-address" or name == "is-add" or name == "received-time" or name == "weight"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-add"):
                                    self.is_add = value
                                    self.is_add.value_namespace = name_space
                                    self.is_add.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-time"):
                                    self.received_time = value
                                    self.received_time.value_namespace = name_space
                                    self.received_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "weight"):
                                    self.weight = value
                                    self.weight.value_namespace = name_space
                                    self.weight.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.update:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.is_virtual_access.is_set or
                                self.rate.is_set or
                                self.rate_decrements.is_set or
                                self.rate_increments.is_set)

                        def has_operation(self):
                            for c in self.update:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_virtual_access.yfilter != YFilter.not_set or
                                self.rate.yfilter != YFilter.not_set or
                                self.rate_decrements.yfilter != YFilter.not_set or
                                self.rate_increments.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_virtual_access.is_set or self.is_virtual_access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_virtual_access.get_name_leafdata())
                            if (self.rate.is_set or self.rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate.get_name_leafdata())
                            if (self.rate_decrements.is_set or self.rate_decrements.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate_decrements.get_name_leafdata())
                            if (self.rate_increments.is_set or self.rate_increments.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate_increments.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "update"):
                                for c in self.update:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.update.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "update" or name == "interface-name" or name == "is-virtual-access" or name == "rate" or name == "rate-decrements" or name == "rate-increments"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-virtual-access"):
                                self.is_virtual_access = value
                                self.is_virtual_access.value_namespace = name_space
                                self.is_virtual_access.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate"):
                                self.rate = value
                                self.rate.value_namespace = name_space
                                self.rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate-decrements"):
                                self.rate_decrements = value
                                self.rate_decrements.value_namespace = name_space
                                self.rate_decrements.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate-increments"):
                                self.rate_increments = value
                                self.rate_increments.value_namespace = name_space
                                self.rate_increments.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_unicast_qos_adjust:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_unicast_qos_adjust:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-unicast-qos-adjusts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-unicast-qos-adjust"):
                            for c in self.interface_unicast_qos_adjust:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_unicast_qos_adjust.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-unicast-qos-adjust"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Ranges(Entity):
                    """
                    Range table
                    
                    .. attribute:: range
                    
                    	Range information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"

                        self.range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.Ranges, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.Ranges, self).__setattr__(name, value)


                    class Range(Entity):
                        """
                        Range information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr>`
                        
                        .. attribute:: group_mask
                        
                        	Group Mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_stale
                        
                        	Is the entry stale
                        	**type**\:  bool
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.group_mask = YLeaf(YType.int32, "group-mask")

                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.group_address_xr = Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "group_mask",
                                            "is_stale",
                                            "prefix_length",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.group_mask.is_set or
                                self.is_stale.is_set or
                                self.prefix_length.is_set or
                                self.protocol.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.group_mask.yfilter != YFilter.not_set or
                                self.is_stale.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.group_mask.is_set or self.group_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_mask.get_name_leafdata())
                            if (self.is_stale.is_set or self.is_stale.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_stale.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "group-address" or name == "group-mask" or name == "is-stale" or name == "prefix-length" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-mask"):
                                self.group_mask = value
                                self.group_mask.value_namespace = name_space
                                self.group_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-stale"):
                                self.is_stale = value
                                self.is_stale.value_namespace = name_space
                                self.is_stale.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.range:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.range:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ranges" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "range"):
                            for c in self.range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.Ranges.Range()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.range.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "range"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class IfrsInterfaces(Entity):
                    """
                    IGMP Interface specific
                    
                    .. attribute:: ifrs_interface
                    
                    	IGMP IFRS Interface
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"

                        self.ifrs_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)


                    class IfrsInterface(Entity):
                        """
                        IGMP IFRS Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	IFRS Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: igmp_interface_entry
                        
                        	IGMP interface entry
                        	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                        
                        .. attribute:: join_group_count
                        
                        	Join group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                            self.igmp_interface_entry = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                            self.igmp_interface_entry.parent = self
                            self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            self._children_yang_names.add("igmp-interface-entry")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "join_group_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                        class IgmpInterfaceEntry(Entity):
                            """
                            IGMP interface entry
                            
                            .. attribute:: address
                            
                            	IP address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                            
                            .. attribute:: configuration_mcast_vrf_error
                            
                            	Is mcast error
                            	**type**\:  bool
                            
                            .. attribute:: configuration_mcast_vrf_set
                            
                            	Is mcast set
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_error
                            
                            	CFG vrf error
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_set
                            
                            	CFG vrf set
                            	**type**\:  bool
                            
                            .. attribute:: group_joins
                            
                            	No. of group joins
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_leaves
                            
                            	No. of group leaves
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: host_version
                            
                            	IGMP Host version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: igmp_version
                            
                            	IGMP Router version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_configurationverify
                            
                            	CFG verify
                            	**type**\:  bool
                            
                            .. attribute:: is_identity_present
                            
                            	Subscriber ID or Address available from AAA
                            	**type**\:  bool
                            
                            .. attribute:: is_im_state_registered
                            
                            	Im state registered
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_up
                            
                            	Is interface up
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_enabled
                            
                            	Is IP enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_las_registered
                            
                            	LAS registered
                            	**type**\:  bool
                            
                            .. attribute:: is_las_request
                            
                            	LAS req
                            	**type**\:  bool
                            
                            .. attribute:: is_querier
                            
                            	Are we querier
                            	**type**\:  bool
                            
                            .. attribute:: is_router_enabled
                            
                            	Is Router functionality enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_subscriber
                            
                            	Subscriber interface
                            	**type**\:  bool
                            
                            .. attribute:: las_get_address_count
                            
                            	LAS get addr count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_add_update_count
                            
                            	LAS LL add update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_registration_count
                            
                            	LAS reg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_remove_update_count
                            
                            	LAS LL remove update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_null_update_count
                            
                            	LAS Null update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_unregistration_count
                            
                            	LAS unreg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_update_count
                            
                            	LAS Update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_member_query_interval
                            
                            	Last Member Query Interval
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: location
                            
                            	Location
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_tuple_count
                            
                            	MTE Tuple count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_vrf_id
                            
                            	MTE VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_ifhandle
                            
                            	Parent If Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: proxy_interface
                            
                            	Proxy interface index
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: querier_address
                            
                            	Address of the Querier
                            	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                            
                            .. attribute:: querier_uptime
                            
                            	Time since the last querier took over
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_interval
                            
                            	Query Interval value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: query_maximum_response_time
                            
                            	Max Response Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_timeout
                            
                            	Query Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: robustness
                            
                            	Robustness Variable value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_uptime_in_seconds
                            
                            	Uptime since router enabled event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	Interface state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: subscriber_address
                            
                            	Address of subscriber
                            	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                            
                            .. attribute:: subscriber_id
                            
                            	ID string of subscriber
                            	**type**\:  str
                            
                            	**length:** 0..257
                            
                            .. attribute:: subscriber_mode
                            
                            	Subscriber mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_query_in_seconds
                            
                            	Time elapsed since last query
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_report_in_seconds
                            
                            	Time elapsed since last report
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_active_groups
                            
                            	Actual number of groups on interface
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_id
                            
                            	VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_state
                            
                            	Vrf State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                                self.yang_name = "igmp-interface-entry"
                                self.yang_parent_name = "ifrs-interface"

                                self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                                self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                                self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                                self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                                self.group_joins = YLeaf(YType.uint32, "group-joins")

                                self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                                self.host_version = YLeaf(YType.uint8, "host-version")

                                self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                                self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                                self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                                self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                                self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                                self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                                self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                                self.is_querier = YLeaf(YType.boolean, "is-querier")

                                self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                                self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                                self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                                self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                                self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                                self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                                self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                                self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                                self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                                self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                                self.location = YLeaf(YType.uint32, "location")

                                self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                                self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                                self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                                self.query_interval = YLeaf(YType.uint16, "query-interval")

                                self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                                self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                                self.robustness = YLeaf(YType.uint32, "robustness")

                                self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                                self.state = YLeaf(YType.uint32, "state")

                                self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                                self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                                self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                                self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                                self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                                self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                                self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                                self.address = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.querier_address = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                                self._children_yang_names.add("querier-address")

                                self.subscriber_address = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                                self._children_yang_names.add("subscriber-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configuration_mcast_vrf_error",
                                                "configuration_mcast_vrf_set",
                                                "configurationvrf_error",
                                                "configurationvrf_set",
                                                "group_joins",
                                                "group_leaves",
                                                "host_version",
                                                "igmp_version",
                                                "interface_name_xr",
                                                "is_configurationverify",
                                                "is_identity_present",
                                                "is_im_state_registered",
                                                "is_interface_up",
                                                "is_ip_enabled",
                                                "is_las_registered",
                                                "is_las_request",
                                                "is_querier",
                                                "is_router_enabled",
                                                "is_subscriber",
                                                "las_get_address_count",
                                                "las_ll_add_update_count",
                                                "las_ll_registration_count",
                                                "las_ll_remove_update_count",
                                                "las_null_update_count",
                                                "las_unregistration_count",
                                                "las_update_count",
                                                "last_member_query_interval",
                                                "location",
                                                "mte_tuple_count",
                                                "mte_vrf_id",
                                                "mtu",
                                                "parent_ifhandle",
                                                "prefix_length",
                                                "proxy_interface",
                                                "querier_uptime",
                                                "query_interval",
                                                "query_maximum_response_time",
                                                "query_timeout",
                                                "robustness",
                                                "router_uptime_in_seconds",
                                                "state",
                                                "subscriber_id",
                                                "subscriber_mode",
                                                "time_since_last_query_in_seconds",
                                                "time_since_last_report_in_seconds",
                                                "total_active_groups",
                                                "vrf_id",
                                                "vrf_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)


                            class Address(Entity):
                                """
                                IP address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class QuerierAddress(Entity):
                                """
                                Address of the Querier
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                    self.yang_name = "querier-address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "querier-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SubscriberAddress(Entity):
                                """
                                Address of subscriber
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                    self.yang_name = "subscriber-address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.configuration_mcast_vrf_error.is_set or
                                    self.configuration_mcast_vrf_set.is_set or
                                    self.configurationvrf_error.is_set or
                                    self.configurationvrf_set.is_set or
                                    self.group_joins.is_set or
                                    self.group_leaves.is_set or
                                    self.host_version.is_set or
                                    self.igmp_version.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_configurationverify.is_set or
                                    self.is_identity_present.is_set or
                                    self.is_im_state_registered.is_set or
                                    self.is_interface_up.is_set or
                                    self.is_ip_enabled.is_set or
                                    self.is_las_registered.is_set or
                                    self.is_las_request.is_set or
                                    self.is_querier.is_set or
                                    self.is_router_enabled.is_set or
                                    self.is_subscriber.is_set or
                                    self.las_get_address_count.is_set or
                                    self.las_ll_add_update_count.is_set or
                                    self.las_ll_registration_count.is_set or
                                    self.las_ll_remove_update_count.is_set or
                                    self.las_null_update_count.is_set or
                                    self.las_unregistration_count.is_set or
                                    self.las_update_count.is_set or
                                    self.last_member_query_interval.is_set or
                                    self.location.is_set or
                                    self.mte_tuple_count.is_set or
                                    self.mte_vrf_id.is_set or
                                    self.mtu.is_set or
                                    self.parent_ifhandle.is_set or
                                    self.prefix_length.is_set or
                                    self.proxy_interface.is_set or
                                    self.querier_uptime.is_set or
                                    self.query_interval.is_set or
                                    self.query_maximum_response_time.is_set or
                                    self.query_timeout.is_set or
                                    self.robustness.is_set or
                                    self.router_uptime_in_seconds.is_set or
                                    self.state.is_set or
                                    self.subscriber_id.is_set or
                                    self.subscriber_mode.is_set or
                                    self.time_since_last_query_in_seconds.is_set or
                                    self.time_since_last_report_in_seconds.is_set or
                                    self.total_active_groups.is_set or
                                    self.vrf_id.is_set or
                                    self.vrf_state.is_set or
                                    (self.address is not None and self.address.has_data()) or
                                    (self.querier_address is not None and self.querier_address.has_data()) or
                                    (self.subscriber_address is not None and self.subscriber_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                    self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                    self.configurationvrf_error.yfilter != YFilter.not_set or
                                    self.configurationvrf_set.yfilter != YFilter.not_set or
                                    self.group_joins.yfilter != YFilter.not_set or
                                    self.group_leaves.yfilter != YFilter.not_set or
                                    self.host_version.yfilter != YFilter.not_set or
                                    self.igmp_version.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_configurationverify.yfilter != YFilter.not_set or
                                    self.is_identity_present.yfilter != YFilter.not_set or
                                    self.is_im_state_registered.yfilter != YFilter.not_set or
                                    self.is_interface_up.yfilter != YFilter.not_set or
                                    self.is_ip_enabled.yfilter != YFilter.not_set or
                                    self.is_las_registered.yfilter != YFilter.not_set or
                                    self.is_las_request.yfilter != YFilter.not_set or
                                    self.is_querier.yfilter != YFilter.not_set or
                                    self.is_router_enabled.yfilter != YFilter.not_set or
                                    self.is_subscriber.yfilter != YFilter.not_set or
                                    self.las_get_address_count.yfilter != YFilter.not_set or
                                    self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                    self.las_ll_registration_count.yfilter != YFilter.not_set or
                                    self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                    self.las_null_update_count.yfilter != YFilter.not_set or
                                    self.las_unregistration_count.yfilter != YFilter.not_set or
                                    self.las_update_count.yfilter != YFilter.not_set or
                                    self.last_member_query_interval.yfilter != YFilter.not_set or
                                    self.location.yfilter != YFilter.not_set or
                                    self.mte_tuple_count.yfilter != YFilter.not_set or
                                    self.mte_vrf_id.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.parent_ifhandle.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.proxy_interface.yfilter != YFilter.not_set or
                                    self.querier_uptime.yfilter != YFilter.not_set or
                                    self.query_interval.yfilter != YFilter.not_set or
                                    self.query_maximum_response_time.yfilter != YFilter.not_set or
                                    self.query_timeout.yfilter != YFilter.not_set or
                                    self.robustness.yfilter != YFilter.not_set or
                                    self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.subscriber_id.yfilter != YFilter.not_set or
                                    self.subscriber_mode.yfilter != YFilter.not_set or
                                    self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                    self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                    self.total_active_groups.yfilter != YFilter.not_set or
                                    self.vrf_id.yfilter != YFilter.not_set or
                                    self.vrf_state.yfilter != YFilter.not_set or
                                    (self.address is not None and self.address.has_operation()) or
                                    (self.querier_address is not None and self.querier_address.has_operation()) or
                                    (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "igmp-interface-entry" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                                if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                                if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                                if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                                if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_joins.get_name_leafdata())
                                if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_leaves.get_name_leafdata())
                                if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.host_version.get_name_leafdata())
                                if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_version.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                                if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                                if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                                if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                                if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                                if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                                if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_las_request.get_name_leafdata())
                                if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_querier.get_name_leafdata())
                                if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                                if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                                if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                                if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                                if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                                if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                                if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                                if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                                if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_update_count.get_name_leafdata())
                                if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                                if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.location.get_name_leafdata())
                                if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                                if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                                if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                                if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_interval.get_name_leafdata())
                                if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                                if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_timeout.get_name_leafdata())
                                if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.robustness.get_name_leafdata())
                                if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                                if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                                if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                                if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                                if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                                if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_id.get_name_leafdata())
                                if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "address"):
                                    if (self.address is None):
                                        self.address = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                    return self.address

                                if (child_yang_name == "querier-address"):
                                    if (self.querier_address is None):
                                        self.querier_address = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                        self.querier_address.parent = self
                                        self._children_name_map["querier_address"] = "querier-address"
                                    return self.querier_address

                                if (child_yang_name == "subscriber-address"):
                                    if (self.subscriber_address is None):
                                        self.subscriber_address = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                        self.subscriber_address.parent = self
                                        self._children_name_map["subscriber_address"] = "subscriber-address"
                                    return self.subscriber_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configuration-mcast-vrf-error"):
                                    self.configuration_mcast_vrf_error = value
                                    self.configuration_mcast_vrf_error.value_namespace = name_space
                                    self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "configuration-mcast-vrf-set"):
                                    self.configuration_mcast_vrf_set = value
                                    self.configuration_mcast_vrf_set.value_namespace = name_space
                                    self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "configurationvrf-error"):
                                    self.configurationvrf_error = value
                                    self.configurationvrf_error.value_namespace = name_space
                                    self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "configurationvrf-set"):
                                    self.configurationvrf_set = value
                                    self.configurationvrf_set.value_namespace = name_space
                                    self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-joins"):
                                    self.group_joins = value
                                    self.group_joins.value_namespace = name_space
                                    self.group_joins.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-leaves"):
                                    self.group_leaves = value
                                    self.group_leaves.value_namespace = name_space
                                    self.group_leaves.value_namespace_prefix = name_space_prefix
                                if(value_path == "host-version"):
                                    self.host_version = value
                                    self.host_version.value_namespace = name_space
                                    self.host_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-version"):
                                    self.igmp_version = value
                                    self.igmp_version.value_namespace = name_space
                                    self.igmp_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-configurationverify"):
                                    self.is_configurationverify = value
                                    self.is_configurationverify.value_namespace = name_space
                                    self.is_configurationverify.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-identity-present"):
                                    self.is_identity_present = value
                                    self.is_identity_present.value_namespace = name_space
                                    self.is_identity_present.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-im-state-registered"):
                                    self.is_im_state_registered = value
                                    self.is_im_state_registered.value_namespace = name_space
                                    self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-interface-up"):
                                    self.is_interface_up = value
                                    self.is_interface_up.value_namespace = name_space
                                    self.is_interface_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ip-enabled"):
                                    self.is_ip_enabled = value
                                    self.is_ip_enabled.value_namespace = name_space
                                    self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-las-registered"):
                                    self.is_las_registered = value
                                    self.is_las_registered.value_namespace = name_space
                                    self.is_las_registered.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-las-request"):
                                    self.is_las_request = value
                                    self.is_las_request.value_namespace = name_space
                                    self.is_las_request.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-querier"):
                                    self.is_querier = value
                                    self.is_querier.value_namespace = name_space
                                    self.is_querier.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-router-enabled"):
                                    self.is_router_enabled = value
                                    self.is_router_enabled.value_namespace = name_space
                                    self.is_router_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-subscriber"):
                                    self.is_subscriber = value
                                    self.is_subscriber.value_namespace = name_space
                                    self.is_subscriber.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-get-address-count"):
                                    self.las_get_address_count = value
                                    self.las_get_address_count.value_namespace = name_space
                                    self.las_get_address_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-add-update-count"):
                                    self.las_ll_add_update_count = value
                                    self.las_ll_add_update_count.value_namespace = name_space
                                    self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-registration-count"):
                                    self.las_ll_registration_count = value
                                    self.las_ll_registration_count.value_namespace = name_space
                                    self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-remove-update-count"):
                                    self.las_ll_remove_update_count = value
                                    self.las_ll_remove_update_count.value_namespace = name_space
                                    self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-null-update-count"):
                                    self.las_null_update_count = value
                                    self.las_null_update_count.value_namespace = name_space
                                    self.las_null_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-unregistration-count"):
                                    self.las_unregistration_count = value
                                    self.las_unregistration_count.value_namespace = name_space
                                    self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-update-count"):
                                    self.las_update_count = value
                                    self.las_update_count.value_namespace = name_space
                                    self.las_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-member-query-interval"):
                                    self.last_member_query_interval = value
                                    self.last_member_query_interval.value_namespace = name_space
                                    self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "location"):
                                    self.location = value
                                    self.location.value_namespace = name_space
                                    self.location.value_namespace_prefix = name_space_prefix
                                if(value_path == "mte-tuple-count"):
                                    self.mte_tuple_count = value
                                    self.mte_tuple_count.value_namespace = name_space
                                    self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "mte-vrf-id"):
                                    self.mte_vrf_id = value
                                    self.mte_vrf_id.value_namespace = name_space
                                    self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "parent-ifhandle"):
                                    self.parent_ifhandle = value
                                    self.parent_ifhandle.value_namespace = name_space
                                    self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "proxy-interface"):
                                    self.proxy_interface = value
                                    self.proxy_interface.value_namespace = name_space
                                    self.proxy_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "querier-uptime"):
                                    self.querier_uptime = value
                                    self.querier_uptime.value_namespace = name_space
                                    self.querier_uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-interval"):
                                    self.query_interval = value
                                    self.query_interval.value_namespace = name_space
                                    self.query_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-maximum-response-time"):
                                    self.query_maximum_response_time = value
                                    self.query_maximum_response_time.value_namespace = name_space
                                    self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-timeout"):
                                    self.query_timeout = value
                                    self.query_timeout.value_namespace = name_space
                                    self.query_timeout.value_namespace_prefix = name_space_prefix
                                if(value_path == "robustness"):
                                    self.robustness = value
                                    self.robustness.value_namespace = name_space
                                    self.robustness.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-uptime-in-seconds"):
                                    self.router_uptime_in_seconds = value
                                    self.router_uptime_in_seconds.value_namespace = name_space
                                    self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-id"):
                                    self.subscriber_id = value
                                    self.subscriber_id.value_namespace = name_space
                                    self.subscriber_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-mode"):
                                    self.subscriber_mode = value
                                    self.subscriber_mode.value_namespace = name_space
                                    self.subscriber_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-last-query-in-seconds"):
                                    self.time_since_last_query_in_seconds = value
                                    self.time_since_last_query_in_seconds.value_namespace = name_space
                                    self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-last-report-in-seconds"):
                                    self.time_since_last_report_in_seconds = value
                                    self.time_since_last_report_in_seconds.value_namespace = name_space
                                    self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "total-active-groups"):
                                    self.total_active_groups = value
                                    self.total_active_groups.value_namespace = name_space
                                    self.total_active_groups.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-id"):
                                    self.vrf_id = value
                                    self.vrf_id.value_namespace = name_space
                                    self.vrf_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-state"):
                                    self.vrf_state = value
                                    self.vrf_state.value_namespace = name_space
                                    self.vrf_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.join_group_count.is_set or
                                (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.join_group_count.yfilter != YFilter.not_set or
                                (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.join_group_count.is_set or self.join_group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_group_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "igmp-interface-entry"):
                                if (self.igmp_interface_entry is None):
                                    self.igmp_interface_entry = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                                    self.igmp_interface_entry.parent = self
                                    self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                                return self.igmp_interface_entry

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "igmp-interface-entry" or name == "interface-name" or name == "join-group-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-group-count"):
                                self.join_group_count = value
                                self.join_group_count.value_namespace = name_space
                                self.join_group_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ifrs_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ifrs_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ifrs-interface"):
                            for c in self.ifrs_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ifrs_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ifrs-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TrafficCounters(Entity):
                    """
                    IGMP Message Traffic Counters
                    
                    .. attribute:: auxillary_data_length_errors
                    
                    	AuxDataLen errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bad_scope_errors
                    
                    	BadScope errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_errors
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_errors
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: get_packet_failure
                    
                    	Packet get failed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_disabled_idb
                    
                    	Packet received on disabled idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_dvmrp
                    
                    	DVMRP packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_leaves
                    
                    	Leaves in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_martian_address
                    
                    	Packets received with Martian Address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_mtrace
                    
                    	Mtrace packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_assigned_vrf_id
                    
                    	Packets received with no assigned vrf id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb
                    
                    	Packets received without idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_platform_support_mtrace
                    
                    	mtrace packets without platform support
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_in_idb
                    
                    	Packets received on idb without VRF
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_mtrace
                    
                    	mtrace packets with no vrf associated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim
                    
                    	PIM packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_queries
                    
                    	Query packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_reports
                    
                    	Reports in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_address_errors
                    
                    	Invalid Source Address errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: miscellaneous_errors
                    
                    	Packets dropped for other reasons
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_dvmrp
                    
                    	DVMRP packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_leaves
                    
                    	Leaves out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_mtrace
                    
                    	Mtrace packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_no_parent_interface_handle
                    
                    	Failures setting 2nd ifhandle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_pim
                    
                    	PIM packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_queries
                    
                    	Query packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_reports
                    
                    	Reports out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_input_errors
                    
                    	Incoming Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_output_errors
                    
                    	Outgoing Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_in
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_out
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: receive_socket_errors
                    
                    	Socket errors on reception
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_errors
                    
                    	Socket errors on send
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"

                        self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                        self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                        self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_errors = YLeaf(YType.uint32, "format-errors")

                        self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                        self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                        self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                        self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                        self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                        self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                        self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                        self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                        self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                        self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                        self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                        self.input_pim = YLeaf(YType.uint32, "input-pim")

                        self.input_queries = YLeaf(YType.uint32, "input-queries")

                        self.input_reports = YLeaf(YType.uint32, "input-reports")

                        self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                        self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                        self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                        self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                        self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                        self.output_pim = YLeaf(YType.uint32, "output-pim")

                        self.output_queries = YLeaf(YType.uint32, "output-queries")

                        self.output_reports = YLeaf(YType.uint32, "output-reports")

                        self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                        self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                        self.packets_in = YLeaf(YType.uint32, "packets-in")

                        self.packets_out = YLeaf(YType.uint32, "packets-out")

                        self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                        self.socket_errors = YLeaf(YType.uint32, "socket-errors")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("auxillary_data_length_errors",
                                        "bad_scope_errors",
                                        "checksum_errors",
                                        "elapsed_time",
                                        "format_errors",
                                        "get_packet_failure",
                                        "input_disabled_idb",
                                        "input_dvmrp",
                                        "input_leaves",
                                        "input_martian_address",
                                        "input_mtrace",
                                        "input_no_assigned_vrf_id",
                                        "input_no_idb",
                                        "input_no_platform_support_mtrace",
                                        "input_no_vrf_in_idb",
                                        "input_no_vrf_mtrace",
                                        "input_pim",
                                        "input_queries",
                                        "input_reports",
                                        "invalid_source_address_errors",
                                        "miscellaneous_errors",
                                        "no_socket_connection",
                                        "output_dvmrp",
                                        "output_leaves",
                                        "output_mtrace",
                                        "output_no_parent_interface_handle",
                                        "output_pim",
                                        "output_queries",
                                        "output_reports",
                                        "packet_manager_input_errors",
                                        "packet_manager_output_errors",
                                        "packets_in",
                                        "packets_out",
                                        "receive_socket_errors",
                                        "socket_errors") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.auxillary_data_length_errors.is_set or
                            self.bad_scope_errors.is_set or
                            self.checksum_errors.is_set or
                            self.elapsed_time.is_set or
                            self.format_errors.is_set or
                            self.get_packet_failure.is_set or
                            self.input_disabled_idb.is_set or
                            self.input_dvmrp.is_set or
                            self.input_leaves.is_set or
                            self.input_martian_address.is_set or
                            self.input_mtrace.is_set or
                            self.input_no_assigned_vrf_id.is_set or
                            self.input_no_idb.is_set or
                            self.input_no_platform_support_mtrace.is_set or
                            self.input_no_vrf_in_idb.is_set or
                            self.input_no_vrf_mtrace.is_set or
                            self.input_pim.is_set or
                            self.input_queries.is_set or
                            self.input_reports.is_set or
                            self.invalid_source_address_errors.is_set or
                            self.miscellaneous_errors.is_set or
                            self.no_socket_connection.is_set or
                            self.output_dvmrp.is_set or
                            self.output_leaves.is_set or
                            self.output_mtrace.is_set or
                            self.output_no_parent_interface_handle.is_set or
                            self.output_pim.is_set or
                            self.output_queries.is_set or
                            self.output_reports.is_set or
                            self.packet_manager_input_errors.is_set or
                            self.packet_manager_output_errors.is_set or
                            self.packets_in.is_set or
                            self.packets_out.is_set or
                            self.receive_socket_errors.is_set or
                            self.socket_errors.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.auxillary_data_length_errors.yfilter != YFilter.not_set or
                            self.bad_scope_errors.yfilter != YFilter.not_set or
                            self.checksum_errors.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.format_errors.yfilter != YFilter.not_set or
                            self.get_packet_failure.yfilter != YFilter.not_set or
                            self.input_disabled_idb.yfilter != YFilter.not_set or
                            self.input_dvmrp.yfilter != YFilter.not_set or
                            self.input_leaves.yfilter != YFilter.not_set or
                            self.input_martian_address.yfilter != YFilter.not_set or
                            self.input_mtrace.yfilter != YFilter.not_set or
                            self.input_no_assigned_vrf_id.yfilter != YFilter.not_set or
                            self.input_no_idb.yfilter != YFilter.not_set or
                            self.input_no_platform_support_mtrace.yfilter != YFilter.not_set or
                            self.input_no_vrf_in_idb.yfilter != YFilter.not_set or
                            self.input_no_vrf_mtrace.yfilter != YFilter.not_set or
                            self.input_pim.yfilter != YFilter.not_set or
                            self.input_queries.yfilter != YFilter.not_set or
                            self.input_reports.yfilter != YFilter.not_set or
                            self.invalid_source_address_errors.yfilter != YFilter.not_set or
                            self.miscellaneous_errors.yfilter != YFilter.not_set or
                            self.no_socket_connection.yfilter != YFilter.not_set or
                            self.output_dvmrp.yfilter != YFilter.not_set or
                            self.output_leaves.yfilter != YFilter.not_set or
                            self.output_mtrace.yfilter != YFilter.not_set or
                            self.output_no_parent_interface_handle.yfilter != YFilter.not_set or
                            self.output_pim.yfilter != YFilter.not_set or
                            self.output_queries.yfilter != YFilter.not_set or
                            self.output_reports.yfilter != YFilter.not_set or
                            self.packet_manager_input_errors.yfilter != YFilter.not_set or
                            self.packet_manager_output_errors.yfilter != YFilter.not_set or
                            self.packets_in.yfilter != YFilter.not_set or
                            self.packets_out.yfilter != YFilter.not_set or
                            self.receive_socket_errors.yfilter != YFilter.not_set or
                            self.socket_errors.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "traffic-counters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.auxillary_data_length_errors.is_set or self.auxillary_data_length_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auxillary_data_length_errors.get_name_leafdata())
                        if (self.bad_scope_errors.is_set or self.bad_scope_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bad_scope_errors.get_name_leafdata())
                        if (self.checksum_errors.is_set or self.checksum_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checksum_errors.get_name_leafdata())
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.format_errors.is_set or self.format_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.format_errors.get_name_leafdata())
                        if (self.get_packet_failure.is_set or self.get_packet_failure.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.get_packet_failure.get_name_leafdata())
                        if (self.input_disabled_idb.is_set or self.input_disabled_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_disabled_idb.get_name_leafdata())
                        if (self.input_dvmrp.is_set or self.input_dvmrp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_dvmrp.get_name_leafdata())
                        if (self.input_leaves.is_set or self.input_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_leaves.get_name_leafdata())
                        if (self.input_martian_address.is_set or self.input_martian_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_martian_address.get_name_leafdata())
                        if (self.input_mtrace.is_set or self.input_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_mtrace.get_name_leafdata())
                        if (self.input_no_assigned_vrf_id.is_set or self.input_no_assigned_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_assigned_vrf_id.get_name_leafdata())
                        if (self.input_no_idb.is_set or self.input_no_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_idb.get_name_leafdata())
                        if (self.input_no_platform_support_mtrace.is_set or self.input_no_platform_support_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_platform_support_mtrace.get_name_leafdata())
                        if (self.input_no_vrf_in_idb.is_set or self.input_no_vrf_in_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_in_idb.get_name_leafdata())
                        if (self.input_no_vrf_mtrace.is_set or self.input_no_vrf_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_mtrace.get_name_leafdata())
                        if (self.input_pim.is_set or self.input_pim.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_pim.get_name_leafdata())
                        if (self.input_queries.is_set or self.input_queries.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_queries.get_name_leafdata())
                        if (self.input_reports.is_set or self.input_reports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_reports.get_name_leafdata())
                        if (self.invalid_source_address_errors.is_set or self.invalid_source_address_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_source_address_errors.get_name_leafdata())
                        if (self.miscellaneous_errors.is_set or self.miscellaneous_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.miscellaneous_errors.get_name_leafdata())
                        if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                        if (self.output_dvmrp.is_set or self.output_dvmrp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_dvmrp.get_name_leafdata())
                        if (self.output_leaves.is_set or self.output_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_leaves.get_name_leafdata())
                        if (self.output_mtrace.is_set or self.output_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_mtrace.get_name_leafdata())
                        if (self.output_no_parent_interface_handle.is_set or self.output_no_parent_interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_no_parent_interface_handle.get_name_leafdata())
                        if (self.output_pim.is_set or self.output_pim.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_pim.get_name_leafdata())
                        if (self.output_queries.is_set or self.output_queries.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_queries.get_name_leafdata())
                        if (self.output_reports.is_set or self.output_reports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_reports.get_name_leafdata())
                        if (self.packet_manager_input_errors.is_set or self.packet_manager_input_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_manager_input_errors.get_name_leafdata())
                        if (self.packet_manager_output_errors.is_set or self.packet_manager_output_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_manager_output_errors.get_name_leafdata())
                        if (self.packets_in.is_set or self.packets_in.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_in.get_name_leafdata())
                        if (self.packets_out.is_set or self.packets_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_out.get_name_leafdata())
                        if (self.receive_socket_errors.is_set or self.receive_socket_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.receive_socket_errors.get_name_leafdata())
                        if (self.socket_errors.is_set or self.socket_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.socket_errors.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auxillary-data-length-errors" or name == "bad-scope-errors" or name == "checksum-errors" or name == "elapsed-time" or name == "format-errors" or name == "get-packet-failure" or name == "input-disabled-idb" or name == "input-dvmrp" or name == "input-leaves" or name == "input-martian-address" or name == "input-mtrace" or name == "input-no-assigned-vrf-id" or name == "input-no-idb" or name == "input-no-platform-support-mtrace" or name == "input-no-vrf-in-idb" or name == "input-no-vrf-mtrace" or name == "input-pim" or name == "input-queries" or name == "input-reports" or name == "invalid-source-address-errors" or name == "miscellaneous-errors" or name == "no-socket-connection" or name == "output-dvmrp" or name == "output-leaves" or name == "output-mtrace" or name == "output-no-parent-interface-handle" or name == "output-pim" or name == "output-queries" or name == "output-reports" or name == "packet-manager-input-errors" or name == "packet-manager-output-errors" or name == "packets-in" or name == "packets-out" or name == "receive-socket-errors" or name == "socket-errors"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "auxillary-data-length-errors"):
                            self.auxillary_data_length_errors = value
                            self.auxillary_data_length_errors.value_namespace = name_space
                            self.auxillary_data_length_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "bad-scope-errors"):
                            self.bad_scope_errors = value
                            self.bad_scope_errors.value_namespace = name_space
                            self.bad_scope_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "checksum-errors"):
                            self.checksum_errors = value
                            self.checksum_errors.value_namespace = name_space
                            self.checksum_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "format-errors"):
                            self.format_errors = value
                            self.format_errors.value_namespace = name_space
                            self.format_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "get-packet-failure"):
                            self.get_packet_failure = value
                            self.get_packet_failure.value_namespace = name_space
                            self.get_packet_failure.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-disabled-idb"):
                            self.input_disabled_idb = value
                            self.input_disabled_idb.value_namespace = name_space
                            self.input_disabled_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-dvmrp"):
                            self.input_dvmrp = value
                            self.input_dvmrp.value_namespace = name_space
                            self.input_dvmrp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-leaves"):
                            self.input_leaves = value
                            self.input_leaves.value_namespace = name_space
                            self.input_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-martian-address"):
                            self.input_martian_address = value
                            self.input_martian_address.value_namespace = name_space
                            self.input_martian_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-mtrace"):
                            self.input_mtrace = value
                            self.input_mtrace.value_namespace = name_space
                            self.input_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-assigned-vrf-id"):
                            self.input_no_assigned_vrf_id = value
                            self.input_no_assigned_vrf_id.value_namespace = name_space
                            self.input_no_assigned_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-idb"):
                            self.input_no_idb = value
                            self.input_no_idb.value_namespace = name_space
                            self.input_no_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-platform-support-mtrace"):
                            self.input_no_platform_support_mtrace = value
                            self.input_no_platform_support_mtrace.value_namespace = name_space
                            self.input_no_platform_support_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-in-idb"):
                            self.input_no_vrf_in_idb = value
                            self.input_no_vrf_in_idb.value_namespace = name_space
                            self.input_no_vrf_in_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-mtrace"):
                            self.input_no_vrf_mtrace = value
                            self.input_no_vrf_mtrace.value_namespace = name_space
                            self.input_no_vrf_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-pim"):
                            self.input_pim = value
                            self.input_pim.value_namespace = name_space
                            self.input_pim.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-queries"):
                            self.input_queries = value
                            self.input_queries.value_namespace = name_space
                            self.input_queries.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-reports"):
                            self.input_reports = value
                            self.input_reports.value_namespace = name_space
                            self.input_reports.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-source-address-errors"):
                            self.invalid_source_address_errors = value
                            self.invalid_source_address_errors.value_namespace = name_space
                            self.invalid_source_address_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "miscellaneous-errors"):
                            self.miscellaneous_errors = value
                            self.miscellaneous_errors.value_namespace = name_space
                            self.miscellaneous_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-socket-connection"):
                            self.no_socket_connection = value
                            self.no_socket_connection.value_namespace = name_space
                            self.no_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-dvmrp"):
                            self.output_dvmrp = value
                            self.output_dvmrp.value_namespace = name_space
                            self.output_dvmrp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-leaves"):
                            self.output_leaves = value
                            self.output_leaves.value_namespace = name_space
                            self.output_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-mtrace"):
                            self.output_mtrace = value
                            self.output_mtrace.value_namespace = name_space
                            self.output_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-no-parent-interface-handle"):
                            self.output_no_parent_interface_handle = value
                            self.output_no_parent_interface_handle.value_namespace = name_space
                            self.output_no_parent_interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-pim"):
                            self.output_pim = value
                            self.output_pim.value_namespace = name_space
                            self.output_pim.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-queries"):
                            self.output_queries = value
                            self.output_queries.value_namespace = name_space
                            self.output_queries.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-reports"):
                            self.output_reports = value
                            self.output_reports.value_namespace = name_space
                            self.output_reports.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-manager-input-errors"):
                            self.packet_manager_input_errors = value
                            self.packet_manager_input_errors.value_namespace = name_space
                            self.packet_manager_input_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-manager-output-errors"):
                            self.packet_manager_output_errors = value
                            self.packet_manager_output_errors.value_namespace = name_space
                            self.packet_manager_output_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "packets-in"):
                            self.packets_in = value
                            self.packets_in.value_namespace = name_space
                            self.packets_in.value_namespace_prefix = name_space_prefix
                        if(value_path == "packets-out"):
                            self.packets_out = value
                            self.packets_out.value_namespace = name_space
                            self.packets_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "receive-socket-errors"):
                            self.receive_socket_errors = value
                            self.receive_socket_errors.value_namespace = name_space
                            self.receive_socket_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "socket-errors"):
                            self.socket_errors = value
                            self.socket_errors.value_namespace = name_space
                            self.socket_errors.value_namespace_prefix = name_space_prefix


                class Groups(Entity):
                    """
                    IGMP Group Database Table
                    
                    .. attribute:: group
                    
                    	IGMP Group Entry Information
                    	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Groups.Group>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.Groups, self).__init__()

                        self.yang_name = "groups"
                        self.yang_parent_name = "vrf"

                        self.group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.Groups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.Groups, self).__setattr__(name, value)


                    class Group(Entity):
                        """
                        IGMP Group Entry Information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.Groups.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "groups"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "group_address",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.Groups.Group, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.Groups.Group, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.group_address.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "group-address" or name == "interface-name" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group"):
                            for c in self.group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.Groups.Group()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupSummary(Entity):
                    """
                    IGMP Groups Summary
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groutes
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: sg_routes
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.GroupSummary, self).__init__()

                        self.yang_name = "group-summary"
                        self.yang_parent_name = "vrf"

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.groutes = YLeaf(YType.uint32, "groutes")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.sg_routes = YLeaf(YType.uint32, "sg-routes")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_count",
                                        "groutes",
                                        "is_low_memory",
                                        "sg_routes") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.GroupSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.GroupSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.group_count.is_set or
                            self.groutes.is_set or
                            self.is_low_memory.is_set or
                            self.sg_routes.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.groutes.yfilter != YFilter.not_set or
                            self.is_low_memory.yfilter != YFilter.not_set or
                            self.sg_routes.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.groutes.is_set or self.groutes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groutes.get_name_leafdata())
                        if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                        if (self.sg_routes.is_set or self.sg_routes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_routes.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-count" or name == "groutes" or name == "is-low-memory" or name == "sg-routes"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "groutes"):
                            self.groutes = value
                            self.groutes.value_namespace = name_space
                            self.groutes.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-low-memory"):
                            self.is_low_memory = value
                            self.is_low_memory.value_namespace = name_space
                            self.is_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-routes"):
                            self.sg_routes = value
                            self.sg_routes.value_namespace = name_space
                            self.sg_routes.value_namespace_prefix = name_space_prefix


                class IfrsInterfaceSummary(Entity):
                    """
                    IGMP IFRS Interface summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary, self).__init__()

                        self.yang_name = "ifrs-interface-summary"
                        self.yang_parent_name = "vrf"

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("configuration_count",
                                        "interface_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.configuration_count.is_set or
                            self.interface_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.configuration_count.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_count.get_name_leafdata())
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "configuration-count" or name == "interface-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "configuration-count"):
                            self.configuration_count = value
                            self.configuration_count.value_namespace = name_space
                            self.configuration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix


                class GlobalInterfaceTable(Entity):
                    """
                    IGMP Global Interface 
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable, self).__init__()

                        self.yang_name = "global-interface-table"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "global-interface-table"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "global-interface-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SsmMapDetails(Entity):
                    """
                    SSM Map Detail
                    
                    .. attribute:: ssm_map_detail
                    
                    	SSM Map Detail Table information
                    	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails, self).__init__()

                        self.yang_name = "ssm-map-details"
                        self.yang_parent_name = "vrf"

                        self.ssm_map_detail = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails, self).__setattr__(name, value)


                    class SsmMapDetail(Entity):
                        """
                        SSM Map Detail Table information
                        
                        .. attribute:: elapsed_time
                        
                        	Elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: expiration_time
                        
                        	Expiration Time in Seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: map_info
                        
                        	Basic Map Info
                        	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo>`
                        
                        .. attribute:: query_interval
                        
                        	Query interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: response_pending
                        
                        	Response Pending
                        	**type**\:  bool
                        
                        .. attribute:: sources
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources>`
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__init__()

                            self.yang_name = "ssm-map-detail"
                            self.yang_parent_name = "ssm-map-details"

                            self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.query_interval = YLeaf(YType.uint32, "query-interval")

                            self.response_pending = YLeaf(YType.boolean, "response-pending")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.map_info = Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                            self.map_info.parent = self
                            self._children_name_map["map_info"] = "map-info"
                            self._children_yang_names.add("map-info")

                            self.sources = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("elapsed_time",
                                            "expiration_time",
                                            "group_address",
                                            "query_interval",
                                            "response_pending",
                                            "ssm_map_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)


                        class MapInfo(Entity):
                            """
                            Basic Map Info
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                            
                            .. attribute:: map_type
                            
                            	Map Type of group
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_counts
                            
                            	Count of Sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                                self.yang_name = "map-info"
                                self.yang_parent_name = "ssm-map-detail"

                                self.map_type = YLeaf(YType.uint32, "map-type")

                                self.source_counts = YLeaf(YType.uint32, "source-counts")

                                self.group_address_xr = Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("map_type",
                                                "source_counts") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "map-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.map_type.is_set or
                                    self.source_counts.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.map_type.yfilter != YFilter.not_set or
                                    self.source_counts.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "map-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.map_type.get_name_leafdata())
                                if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_counts.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "map-type" or name == "source-counts"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "map-type"):
                                    self.map_type = value
                                    self.map_type.value_namespace = name_space
                                    self.map_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-counts"):
                                    self.source_counts = value
                                    self.source_counts.value_namespace = name_space
                                    self.source_counts.value_namespace_prefix = name_space_prefix


                        class Sources(Entity):
                            """
                            List of sources
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                                self.yang_name = "sources"
                                self.yang_parent_name = "ssm-map-detail"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sources" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sources:
                                if (c.has_data()):
                                    return True
                            return (
                                self.elapsed_time.is_set or
                                self.expiration_time.is_set or
                                self.group_address.is_set or
                                self.query_interval.is_set or
                                self.response_pending.is_set or
                                self.ssm_map_type.is_set or
                                (self.map_info is not None and self.map_info.has_data()))

                        def has_operation(self):
                            for c in self.sources:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.elapsed_time.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.response_pending.yfilter != YFilter.not_set or
                                self.ssm_map_type.yfilter != YFilter.not_set or
                                (self.map_info is not None and self.map_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ssm-map-detail" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.response_pending.is_set or self.response_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.response_pending.get_name_leafdata())
                            if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "map-info"):
                                if (self.map_info is None):
                                    self.map_info = Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                                    self.map_info.parent = self
                                    self._children_name_map["map_info"] = "map-info"
                                return self.map_info

                            if (child_yang_name == "sources"):
                                for c in self.sources:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sources.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "map-info" or name == "sources" or name == "elapsed-time" or name == "expiration-time" or name == "group-address" or name == "query-interval" or name == "response-pending" or name == "ssm-map-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "elapsed-time"):
                                self.elapsed_time = value
                                self.elapsed_time.value_namespace = name_space
                                self.elapsed_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "response-pending"):
                                self.response_pending = value
                                self.response_pending.value_namespace = name_space
                                self.response_pending.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssm-map-type"):
                                self.ssm_map_type = value
                                self.ssm_map_type.value_namespace = name_space
                                self.ssm_map_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ssm_map_detail:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ssm_map_detail:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map-details" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ssm-map-detail"):
                            for c in self.ssm_map_detail:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ssm_map_detail.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ssm-map-detail"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceStateOffs(Entity):
                    """
                    IGMP Interface state off
                    
                    .. attribute:: interface_state_off
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs, self).__init__()

                        self.yang_name = "interface-state-offs"
                        self.yang_parent_name = "vrf"

                        self.interface_state_off = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs, self).__setattr__(name, value)


                    class InterfaceStateOff(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                            self.yang_name = "interface-state-off"
                            self.yang_parent_name = "interface-state-offs"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_state_off:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_state_off:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-offs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-state-off"):
                            for c in self.interface_state_off:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_state_off.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-state-off"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.vrf_name.is_set or
                        (self.detail_groups is not None and self.detail_groups.has_data()) or
                        (self.explicit_groups is not None and self.explicit_groups.has_data()) or
                        (self.global_interface_table is not None and self.global_interface_table.has_data()) or
                        (self.group_summary is not None and self.group_summary.has_data()) or
                        (self.groups is not None and self.groups.has_data()) or
                        (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_data()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                        (self.interface_state_offs is not None and self.interface_state_offs.has_data()) or
                        (self.interface_state_ons is not None and self.interface_state_ons.has_data()) or
                        (self.interface_table is not None and self.interface_table.has_data()) or
                        (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_data()) or
                        (self.non_active_groups is not None and self.non_active_groups.has_data()) or
                        (self.ranges is not None and self.ranges.has_data()) or
                        (self.ssm_map_details is not None and self.ssm_map_details.has_data()) or
                        (self.ssm_maps is not None and self.ssm_maps.has_data()) or
                        (self.summary is not None and self.summary.has_data()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vrf_name.yfilter != YFilter.not_set or
                        (self.detail_groups is not None and self.detail_groups.has_operation()) or
                        (self.explicit_groups is not None and self.explicit_groups.has_operation()) or
                        (self.global_interface_table is not None and self.global_interface_table.has_operation()) or
                        (self.group_summary is not None and self.group_summary.has_operation()) or
                        (self.groups is not None and self.groups.has_operation()) or
                        (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_operation()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                        (self.interface_state_offs is not None and self.interface_state_offs.has_operation()) or
                        (self.interface_state_ons is not None and self.interface_state_ons.has_operation()) or
                        (self.interface_table is not None and self.interface_table.has_operation()) or
                        (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_operation()) or
                        (self.non_active_groups is not None and self.non_active_groups.has_operation()) or
                        (self.ranges is not None and self.ranges.has_operation()) or
                        (self.ssm_map_details is not None and self.ssm_map_details.has_operation()) or
                        (self.ssm_maps is not None and self.ssm_maps.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/vrfs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "detail-groups"):
                        if (self.detail_groups is None):
                            self.detail_groups = Igmp.Standby.Vrfs.Vrf.DetailGroups()
                            self.detail_groups.parent = self
                            self._children_name_map["detail_groups"] = "detail-groups"
                        return self.detail_groups

                    if (child_yang_name == "explicit-groups"):
                        if (self.explicit_groups is None):
                            self.explicit_groups = Igmp.Standby.Vrfs.Vrf.ExplicitGroups()
                            self.explicit_groups.parent = self
                            self._children_name_map["explicit_groups"] = "explicit-groups"
                        return self.explicit_groups

                    if (child_yang_name == "global-interface-table"):
                        if (self.global_interface_table is None):
                            self.global_interface_table = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable()
                            self.global_interface_table.parent = self
                            self._children_name_map["global_interface_table"] = "global-interface-table"
                        return self.global_interface_table

                    if (child_yang_name == "group-summary"):
                        if (self.group_summary is None):
                            self.group_summary = Igmp.Standby.Vrfs.Vrf.GroupSummary()
                            self.group_summary.parent = self
                            self._children_name_map["group_summary"] = "group-summary"
                        return self.group_summary

                    if (child_yang_name == "groups"):
                        if (self.groups is None):
                            self.groups = Igmp.Standby.Vrfs.Vrf.Groups()
                            self.groups.parent = self
                            self._children_name_map["groups"] = "groups"
                        return self.groups

                    if (child_yang_name == "ifrs-interface-summary"):
                        if (self.ifrs_interface_summary is None):
                            self.ifrs_interface_summary = Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary()
                            self.ifrs_interface_summary.parent = self
                            self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                        return self.ifrs_interface_summary

                    if (child_yang_name == "ifrs-interfaces"):
                        if (self.ifrs_interfaces is None):
                            self.ifrs_interfaces = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces()
                            self.ifrs_interfaces.parent = self
                            self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                        return self.ifrs_interfaces

                    if (child_yang_name == "interface-state-offs"):
                        if (self.interface_state_offs is None):
                            self.interface_state_offs = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs()
                            self.interface_state_offs.parent = self
                            self._children_name_map["interface_state_offs"] = "interface-state-offs"
                        return self.interface_state_offs

                    if (child_yang_name == "interface-state-ons"):
                        if (self.interface_state_ons is None):
                            self.interface_state_ons = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns()
                            self.interface_state_ons.parent = self
                            self._children_name_map["interface_state_ons"] = "interface-state-ons"
                        return self.interface_state_ons

                    if (child_yang_name == "interface-table"):
                        if (self.interface_table is None):
                            self.interface_table = Igmp.Standby.Vrfs.Vrf.InterfaceTable()
                            self.interface_table.parent = self
                            self._children_name_map["interface_table"] = "interface-table"
                        return self.interface_table

                    if (child_yang_name == "interface-unicast-qos-adjusts"):
                        if (self.interface_unicast_qos_adjusts is None):
                            self.interface_unicast_qos_adjusts = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                            self.interface_unicast_qos_adjusts.parent = self
                            self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                        return self.interface_unicast_qos_adjusts

                    if (child_yang_name == "non-active-groups"):
                        if (self.non_active_groups is None):
                            self.non_active_groups = Igmp.Standby.Vrfs.Vrf.NonActiveGroups()
                            self.non_active_groups.parent = self
                            self._children_name_map["non_active_groups"] = "non-active-groups"
                        return self.non_active_groups

                    if (child_yang_name == "ranges"):
                        if (self.ranges is None):
                            self.ranges = Igmp.Standby.Vrfs.Vrf.Ranges()
                            self.ranges.parent = self
                            self._children_name_map["ranges"] = "ranges"
                        return self.ranges

                    if (child_yang_name == "ssm-map-details"):
                        if (self.ssm_map_details is None):
                            self.ssm_map_details = Igmp.Standby.Vrfs.Vrf.SsmMapDetails()
                            self.ssm_map_details.parent = self
                            self._children_name_map["ssm_map_details"] = "ssm-map-details"
                        return self.ssm_map_details

                    if (child_yang_name == "ssm-maps"):
                        if (self.ssm_maps is None):
                            self.ssm_maps = Igmp.Standby.Vrfs.Vrf.SsmMaps()
                            self.ssm_maps.parent = self
                            self._children_name_map["ssm_maps"] = "ssm-maps"
                        return self.ssm_maps

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = Igmp.Standby.Vrfs.Vrf.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    if (child_yang_name == "traffic-counters"):
                        if (self.traffic_counters is None):
                            self.traffic_counters = Igmp.Standby.Vrfs.Vrf.TrafficCounters()
                            self.traffic_counters.parent = self
                            self._children_name_map["traffic_counters"] = "traffic-counters"
                        return self.traffic_counters

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "detail-groups" or name == "explicit-groups" or name == "global-interface-table" or name == "group-summary" or name == "groups" or name == "ifrs-interface-summary" or name == "ifrs-interfaces" or name == "interface-state-offs" or name == "interface-state-ons" or name == "interface-table" or name == "interface-unicast-qos-adjusts" or name == "non-active-groups" or name == "ranges" or name == "ssm-map-details" or name == "ssm-maps" or name == "summary" or name == "traffic-counters" or name == "vrf-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vrf-name"):
                        self.vrf_name = value
                        self.vrf_name.value_namespace = name_space
                        self.vrf_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.vrf:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.vrf:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrfs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "vrf"):
                    for c in self.vrf:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Igmp.Standby.Vrfs.Vrf()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.vrf.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "vrf"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Process(Entity):
            """
            Process
            
            .. attribute:: amt_gatewaies
            
            	Table containing AMT Gateway DataBase information
            	**type**\:   :py:class:`AmtGatewaies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.AmtGatewaies>`
            
            .. attribute:: amt_summary
            
            	MRIB RouteDB Expiry Information
            	**type**\:   :py:class:`AmtSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.AmtSummary>`
            
            .. attribute:: bvi_statistics
            
            	IGMP BVI Stats
            	**type**\:   :py:class:`BviStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.BviStatistics>`
            
            .. attribute:: nsf
            
            	NSF Information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.Nsr>`
            
            .. attribute:: unicast_qos_adjust_stats
            
            	IGMP Unicast\-Qos\-Adjust Statistics
            	**type**\:   :py:class:`UnicastQosAdjustStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.UnicastQosAdjustStats>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Standby.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "standby"

                self.amt_gatewaies = Igmp.Standby.Process.AmtGatewaies()
                self.amt_gatewaies.parent = self
                self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                self._children_yang_names.add("amt-gatewaies")

                self.amt_summary = Igmp.Standby.Process.AmtSummary()
                self.amt_summary.parent = self
                self._children_name_map["amt_summary"] = "amt-summary"
                self._children_yang_names.add("amt-summary")

                self.bvi_statistics = Igmp.Standby.Process.BviStatistics()
                self.bvi_statistics.parent = self
                self._children_name_map["bvi_statistics"] = "bvi-statistics"
                self._children_yang_names.add("bvi-statistics")

                self.nsf = Igmp.Standby.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Igmp.Standby.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.unicast_qos_adjust_stats = Igmp.Standby.Process.UnicastQosAdjustStats()
                self.unicast_qos_adjust_stats.parent = self
                self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                self._children_yang_names.add("unicast-qos-adjust-stats")


            class AmtSummary(Entity):
                """
                MRIB RouteDB Expiry Information
                
                .. attribute:: anycast_prefix
                
                	Robustness variable
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: gateway_count
                
                	Number of AMT Gateway
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_acl_configured
                
                	ACL configured under AMT
                	**type**\:  bool
                
                .. attribute:: is_gateway_simulation
                
                	AMT Gateway Simulation
                	**type**\:  bool
                
                .. attribute:: is_ou_of_resource
                
                	AMT Out Of Resource
                	**type**\:  bool
                
                .. attribute:: max_gateway
                
                	Maximum Gateway allowed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mtu
                
                	AMT Tunnel MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: prefix_length
                
                	Advertize AMT prefix length
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: query_interval
                
                	AMT Query interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: relay_address
                
                	Advertaisment for AMT Relay address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: tos
                
                	Type Of Service value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ttl
                
                	Time To Live value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_configured_maximum
                
                	AMT Tunnel configured Maximum
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_count
                
                	AMT Tunnel Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.AmtSummary, self).__init__()

                    self.yang_name = "amt-summary"
                    self.yang_parent_name = "process"

                    self.anycast_prefix = YLeaf(YType.str, "anycast-prefix")

                    self.gateway_count = YLeaf(YType.uint32, "gateway-count")

                    self.is_acl_configured = YLeaf(YType.boolean, "is-acl-configured")

                    self.is_gateway_simulation = YLeaf(YType.boolean, "is-gateway-simulation")

                    self.is_ou_of_resource = YLeaf(YType.boolean, "is-ou-of-resource")

                    self.max_gateway = YLeaf(YType.uint32, "max-gateway")

                    self.mtu = YLeaf(YType.uint32, "mtu")

                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                    self.query_interval = YLeaf(YType.uint32, "query-interval")

                    self.relay_address = YLeaf(YType.str, "relay-address")

                    self.tos = YLeaf(YType.uint32, "tos")

                    self.ttl = YLeaf(YType.uint32, "ttl")

                    self.tunnel_configured_maximum = YLeaf(YType.uint32, "tunnel-configured-maximum")

                    self.tunnel_count = YLeaf(YType.uint32, "tunnel-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("anycast_prefix",
                                    "gateway_count",
                                    "is_acl_configured",
                                    "is_gateway_simulation",
                                    "is_ou_of_resource",
                                    "max_gateway",
                                    "mtu",
                                    "prefix_length",
                                    "query_interval",
                                    "relay_address",
                                    "tos",
                                    "ttl",
                                    "tunnel_configured_maximum",
                                    "tunnel_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.Process.AmtSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.Process.AmtSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.anycast_prefix.is_set or
                        self.gateway_count.is_set or
                        self.is_acl_configured.is_set or
                        self.is_gateway_simulation.is_set or
                        self.is_ou_of_resource.is_set or
                        self.max_gateway.is_set or
                        self.mtu.is_set or
                        self.prefix_length.is_set or
                        self.query_interval.is_set or
                        self.relay_address.is_set or
                        self.tos.is_set or
                        self.ttl.is_set or
                        self.tunnel_configured_maximum.is_set or
                        self.tunnel_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.anycast_prefix.yfilter != YFilter.not_set or
                        self.gateway_count.yfilter != YFilter.not_set or
                        self.is_acl_configured.yfilter != YFilter.not_set or
                        self.is_gateway_simulation.yfilter != YFilter.not_set or
                        self.is_ou_of_resource.yfilter != YFilter.not_set or
                        self.max_gateway.yfilter != YFilter.not_set or
                        self.mtu.yfilter != YFilter.not_set or
                        self.prefix_length.yfilter != YFilter.not_set or
                        self.query_interval.yfilter != YFilter.not_set or
                        self.relay_address.yfilter != YFilter.not_set or
                        self.tos.yfilter != YFilter.not_set or
                        self.ttl.yfilter != YFilter.not_set or
                        self.tunnel_configured_maximum.yfilter != YFilter.not_set or
                        self.tunnel_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "amt-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.anycast_prefix.is_set or self.anycast_prefix.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_prefix.get_name_leafdata())
                    if (self.gateway_count.is_set or self.gateway_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gateway_count.get_name_leafdata())
                    if (self.is_acl_configured.is_set or self.is_acl_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_acl_configured.get_name_leafdata())
                    if (self.is_gateway_simulation.is_set or self.is_gateway_simulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_gateway_simulation.get_name_leafdata())
                    if (self.is_ou_of_resource.is_set or self.is_ou_of_resource.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ou_of_resource.get_name_leafdata())
                    if (self.max_gateway.is_set or self.max_gateway.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.max_gateway.get_name_leafdata())
                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mtu.get_name_leafdata())
                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                    if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.query_interval.get_name_leafdata())
                    if (self.relay_address.is_set or self.relay_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.relay_address.get_name_leafdata())
                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tos.get_name_leafdata())
                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ttl.get_name_leafdata())
                    if (self.tunnel_configured_maximum.is_set or self.tunnel_configured_maximum.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_configured_maximum.get_name_leafdata())
                    if (self.tunnel_count.is_set or self.tunnel_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "anycast-prefix" or name == "gateway-count" or name == "is-acl-configured" or name == "is-gateway-simulation" or name == "is-ou-of-resource" or name == "max-gateway" or name == "mtu" or name == "prefix-length" or name == "query-interval" or name == "relay-address" or name == "tos" or name == "ttl" or name == "tunnel-configured-maximum" or name == "tunnel-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "anycast-prefix"):
                        self.anycast_prefix = value
                        self.anycast_prefix.value_namespace = name_space
                        self.anycast_prefix.value_namespace_prefix = name_space_prefix
                    if(value_path == "gateway-count"):
                        self.gateway_count = value
                        self.gateway_count.value_namespace = name_space
                        self.gateway_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-acl-configured"):
                        self.is_acl_configured = value
                        self.is_acl_configured.value_namespace = name_space
                        self.is_acl_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-gateway-simulation"):
                        self.is_gateway_simulation = value
                        self.is_gateway_simulation.value_namespace = name_space
                        self.is_gateway_simulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ou-of-resource"):
                        self.is_ou_of_resource = value
                        self.is_ou_of_resource.value_namespace = name_space
                        self.is_ou_of_resource.value_namespace_prefix = name_space_prefix
                    if(value_path == "max-gateway"):
                        self.max_gateway = value
                        self.max_gateway.value_namespace = name_space
                        self.max_gateway.value_namespace_prefix = name_space_prefix
                    if(value_path == "mtu"):
                        self.mtu = value
                        self.mtu.value_namespace = name_space
                        self.mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "prefix-length"):
                        self.prefix_length = value
                        self.prefix_length.value_namespace = name_space
                        self.prefix_length.value_namespace_prefix = name_space_prefix
                    if(value_path == "query-interval"):
                        self.query_interval = value
                        self.query_interval.value_namespace = name_space
                        self.query_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "relay-address"):
                        self.relay_address = value
                        self.relay_address.value_namespace = name_space
                        self.relay_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "tos"):
                        self.tos = value
                        self.tos.value_namespace = name_space
                        self.tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ttl"):
                        self.ttl = value
                        self.ttl.value_namespace = name_space
                        self.ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-configured-maximum"):
                        self.tunnel_configured_maximum = value
                        self.tunnel_configured_maximum.value_namespace = name_space
                        self.tunnel_configured_maximum.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-count"):
                        self.tunnel_count = value
                        self.tunnel_count.value_namespace = name_space
                        self.tunnel_count.value_namespace_prefix = name_space_prefix


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: collab_conv_done
                
                	Collaborators convergence done
                	**type**\:  bool
                
                .. attribute:: count_proc_connection_dn
                
                	No. of times process connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_proc_connection_up
                
                	No. of times process connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_proc
                
                	Time when process came up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_dn
                
                	Time when process connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_up
                
                	Time when process connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_proc_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"

                    self.collab_conv_done = YLeaf(YType.boolean, "collab-conv-done")

                    self.count_proc_connection_dn = YLeaf(YType.uint32, "count-proc-connection-dn")

                    self.count_proc_connection_up = YLeaf(YType.uint32, "count-proc-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_proc = YLeaf(YType.uint64, "last-proc")

                    self.last_proc_connection_dn = YLeaf(YType.uint64, "last-proc-connection-dn")

                    self.last_proc_connection_up = YLeaf(YType.uint64, "last-proc-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_proc_connected = YLeaf(YType.boolean, "partner-proc-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.state = YLeaf(YType.uint8, "state")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("collab_conv_done",
                                    "count_proc_connection_dn",
                                    "count_proc_connection_up",
                                    "count_rmf_not_ready",
                                    "count_rmf_ready",
                                    "last_proc",
                                    "last_proc_connection_dn",
                                    "last_proc_connection_up",
                                    "last_rmf_not_ready",
                                    "last_rmf_ready",
                                    "partner_proc_connected",
                                    "rmf_notification_done",
                                    "state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.Process.Nsr, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.Process.Nsr, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.collab_conv_done.is_set or
                        self.count_proc_connection_dn.is_set or
                        self.count_proc_connection_up.is_set or
                        self.count_rmf_not_ready.is_set or
                        self.count_rmf_ready.is_set or
                        self.last_proc.is_set or
                        self.last_proc_connection_dn.is_set or
                        self.last_proc_connection_up.is_set or
                        self.last_rmf_not_ready.is_set or
                        self.last_rmf_ready.is_set or
                        self.partner_proc_connected.is_set or
                        self.rmf_notification_done.is_set or
                        self.state.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.collab_conv_done.yfilter != YFilter.not_set or
                        self.count_proc_connection_dn.yfilter != YFilter.not_set or
                        self.count_proc_connection_up.yfilter != YFilter.not_set or
                        self.count_rmf_not_ready.yfilter != YFilter.not_set or
                        self.count_rmf_ready.yfilter != YFilter.not_set or
                        self.last_proc.yfilter != YFilter.not_set or
                        self.last_proc_connection_dn.yfilter != YFilter.not_set or
                        self.last_proc_connection_up.yfilter != YFilter.not_set or
                        self.last_rmf_not_ready.yfilter != YFilter.not_set or
                        self.last_rmf_ready.yfilter != YFilter.not_set or
                        self.partner_proc_connected.yfilter != YFilter.not_set or
                        self.rmf_notification_done.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.collab_conv_done.is_set or self.collab_conv_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collab_conv_done.get_name_leafdata())
                    if (self.count_proc_connection_dn.is_set or self.count_proc_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_proc_connection_dn.get_name_leafdata())
                    if (self.count_proc_connection_up.is_set or self.count_proc_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_proc_connection_up.get_name_leafdata())
                    if (self.count_rmf_not_ready.is_set or self.count_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_not_ready.get_name_leafdata())
                    if (self.count_rmf_ready.is_set or self.count_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_ready.get_name_leafdata())
                    if (self.last_proc.is_set or self.last_proc.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc.get_name_leafdata())
                    if (self.last_proc_connection_dn.is_set or self.last_proc_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc_connection_dn.get_name_leafdata())
                    if (self.last_proc_connection_up.is_set or self.last_proc_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc_connection_up.get_name_leafdata())
                    if (self.last_rmf_not_ready.is_set or self.last_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_not_ready.get_name_leafdata())
                    if (self.last_rmf_ready.is_set or self.last_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_ready.get_name_leafdata())
                    if (self.partner_proc_connected.is_set or self.partner_proc_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_proc_connected.get_name_leafdata())
                    if (self.rmf_notification_done.is_set or self.rmf_notification_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_notification_done.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "collab-conv-done" or name == "count-proc-connection-dn" or name == "count-proc-connection-up" or name == "count-rmf-not-ready" or name == "count-rmf-ready" or name == "last-proc" or name == "last-proc-connection-dn" or name == "last-proc-connection-up" or name == "last-rmf-not-ready" or name == "last-rmf-ready" or name == "partner-proc-connected" or name == "rmf-notification-done" or name == "state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "collab-conv-done"):
                        self.collab_conv_done = value
                        self.collab_conv_done.value_namespace = name_space
                        self.collab_conv_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-proc-connection-dn"):
                        self.count_proc_connection_dn = value
                        self.count_proc_connection_dn.value_namespace = name_space
                        self.count_proc_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-proc-connection-up"):
                        self.count_proc_connection_up = value
                        self.count_proc_connection_up.value_namespace = name_space
                        self.count_proc_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-not-ready"):
                        self.count_rmf_not_ready = value
                        self.count_rmf_not_ready.value_namespace = name_space
                        self.count_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-ready"):
                        self.count_rmf_ready = value
                        self.count_rmf_ready.value_namespace = name_space
                        self.count_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc"):
                        self.last_proc = value
                        self.last_proc.value_namespace = name_space
                        self.last_proc.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc-connection-dn"):
                        self.last_proc_connection_dn = value
                        self.last_proc_connection_dn.value_namespace = name_space
                        self.last_proc_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc-connection-up"):
                        self.last_proc_connection_up = value
                        self.last_proc_connection_up.value_namespace = name_space
                        self.last_proc_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-not-ready"):
                        self.last_rmf_not_ready = value
                        self.last_rmf_not_ready.value_namespace = name_space
                        self.last_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-ready"):
                        self.last_rmf_ready = value
                        self.last_rmf_ready.value_namespace = name_space
                        self.last_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-proc-connected"):
                        self.partner_proc_connected = value
                        self.partner_proc_connected.value_namespace = name_space
                        self.partner_proc_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-notification-done"):
                        self.rmf_notification_done = value
                        self.rmf_notification_done.value_namespace = name_space
                        self.rmf_notification_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix


            class AmtGatewaies(Entity):
                """
                Table containing AMT Gateway DataBase
                information
                
                .. attribute:: amt_gateway
                
                	AMT Gateway DataBase information
                	**type**\: list of    :py:class:`AmtGateway <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.AmtGatewaies.AmtGateway>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.AmtGatewaies, self).__init__()

                    self.yang_name = "amt-gatewaies"
                    self.yang_parent_name = "process"

                    self.amt_gateway = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.Process.AmtGatewaies, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.Process.AmtGatewaies, self).__setattr__(name, value)


                class AmtGateway(Entity):
                    """
                    AMT Gateway DataBase information
                    
                    .. attribute:: amt_nonce
                    
                    	Nonce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amt_port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amtgw
                    
                    	GW
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: amtnh
                    
                    	AMT NH
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gateway_address
                    
                    	Gateway Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: idb
                    
                    	IDB
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: key_len
                    
                    	Len
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_in
                    
                    	UpdIn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_out
                    
                    	UpdOut
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Process.AmtGatewaies.AmtGateway, self).__init__()

                        self.yang_name = "amt-gateway"
                        self.yang_parent_name = "amt-gatewaies"

                        self.amt_nonce = YLeaf(YType.uint32, "amt-nonce")

                        self.amt_port = YLeaf(YType.uint32, "amt-port")

                        self.amtgw = YLeaf(YType.str, "amtgw")

                        self.amtnh = YLeaf(YType.uint32, "amtnh")

                        self.gateway_address = YLeaf(YType.str, "gateway-address")

                        self.idb = YLeaf(YType.uint64, "idb")

                        self.key_len = YLeaf(YType.uint32, "key-len")

                        self.mem_upd_in = YLeaf(YType.uint32, "mem-upd-in")

                        self.mem_upd_out = YLeaf(YType.uint32, "mem-upd-out")

                        self.port = YLeaf(YType.int32, "port")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("amt_nonce",
                                        "amt_port",
                                        "amtgw",
                                        "amtnh",
                                        "gateway_address",
                                        "idb",
                                        "key_len",
                                        "mem_upd_in",
                                        "mem_upd_out",
                                        "port") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.Process.AmtGatewaies.AmtGateway, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.Process.AmtGatewaies.AmtGateway, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.amt_nonce.is_set or
                            self.amt_port.is_set or
                            self.amtgw.is_set or
                            self.amtnh.is_set or
                            self.gateway_address.is_set or
                            self.idb.is_set or
                            self.key_len.is_set or
                            self.mem_upd_in.is_set or
                            self.mem_upd_out.is_set or
                            self.port.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.amt_nonce.yfilter != YFilter.not_set or
                            self.amt_port.yfilter != YFilter.not_set or
                            self.amtgw.yfilter != YFilter.not_set or
                            self.amtnh.yfilter != YFilter.not_set or
                            self.gateway_address.yfilter != YFilter.not_set or
                            self.idb.yfilter != YFilter.not_set or
                            self.key_len.yfilter != YFilter.not_set or
                            self.mem_upd_in.yfilter != YFilter.not_set or
                            self.mem_upd_out.yfilter != YFilter.not_set or
                            self.port.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "amt-gateway" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/amt-gatewaies/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.amt_nonce.is_set or self.amt_nonce.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amt_nonce.get_name_leafdata())
                        if (self.amt_port.is_set or self.amt_port.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amt_port.get_name_leafdata())
                        if (self.amtgw.is_set or self.amtgw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amtgw.get_name_leafdata())
                        if (self.amtnh.is_set or self.amtnh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amtnh.get_name_leafdata())
                        if (self.gateway_address.is_set or self.gateway_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gateway_address.get_name_leafdata())
                        if (self.idb.is_set or self.idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb.get_name_leafdata())
                        if (self.key_len.is_set or self.key_len.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.key_len.get_name_leafdata())
                        if (self.mem_upd_in.is_set or self.mem_upd_in.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mem_upd_in.get_name_leafdata())
                        if (self.mem_upd_out.is_set or self.mem_upd_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mem_upd_out.get_name_leafdata())
                        if (self.port.is_set or self.port.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "amt-nonce" or name == "amt-port" or name == "amtgw" or name == "amtnh" or name == "gateway-address" or name == "idb" or name == "key-len" or name == "mem-upd-in" or name == "mem-upd-out" or name == "port"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "amt-nonce"):
                            self.amt_nonce = value
                            self.amt_nonce.value_namespace = name_space
                            self.amt_nonce.value_namespace_prefix = name_space_prefix
                        if(value_path == "amt-port"):
                            self.amt_port = value
                            self.amt_port.value_namespace = name_space
                            self.amt_port.value_namespace_prefix = name_space_prefix
                        if(value_path == "amtgw"):
                            self.amtgw = value
                            self.amtgw.value_namespace = name_space
                            self.amtgw.value_namespace_prefix = name_space_prefix
                        if(value_path == "amtnh"):
                            self.amtnh = value
                            self.amtnh.value_namespace = name_space
                            self.amtnh.value_namespace_prefix = name_space_prefix
                        if(value_path == "gateway-address"):
                            self.gateway_address = value
                            self.gateway_address.value_namespace = name_space
                            self.gateway_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb"):
                            self.idb = value
                            self.idb.value_namespace = name_space
                            self.idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "key-len"):
                            self.key_len = value
                            self.key_len.value_namespace = name_space
                            self.key_len.value_namespace_prefix = name_space_prefix
                        if(value_path == "mem-upd-in"):
                            self.mem_upd_in = value
                            self.mem_upd_in.value_namespace = name_space
                            self.mem_upd_in.value_namespace_prefix = name_space_prefix
                        if(value_path == "mem-upd-out"):
                            self.mem_upd_out = value
                            self.mem_upd_out.value_namespace = name_space
                            self.mem_upd_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "port"):
                            self.port = value
                            self.port.value_namespace = name_space
                            self.port.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.amt_gateway:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.amt_gateway:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "amt-gatewaies" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "amt-gateway"):
                        for c in self.amt_gateway:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.Process.AmtGatewaies.AmtGateway()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.amt_gateway.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "amt-gateway"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class UnicastQosAdjustStats(Entity):
                """
                IGMP Unicast\-Qos\-Adjust Statistics
                
                .. attribute:: add_to_batches
                
                	Add to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: batches
                
                	I2Q Rate Batch count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: delete_to_batches
                
                	Delete to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_qos_s_sweeped
                
                	Is QOS Sweeped once 
                	**type**\:  bool
                
                .. attribute:: is_resync_received
                
                	Is Resync request received
                	**type**\:  bool
                
                .. attribute:: is_resync_required
                
                	Is Resync required
                	**type**\:  bool
                
                .. attribute:: is_resync_start_sent
                
                	Is Resync Start message sent
                	**type**\:  bool
                
                .. attribute:: last_download_time
                
                	Time elapsed since Last download to QOS in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: last_sweep_time
                
                	Time elapsed since Last mark and sweep in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: queues
                
                	I2Q Queue count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: received_resync_requests
                
                	Number of Resync request received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_comm_errors
                
                	Send Error due to comms count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_errors
                
                	Number of Send errors in batch
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_partial_errors
                
                	Send Error due to partial issue count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_success
                
                	Send Success count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sent_resync_bulks
                
                	Number of bulks sent for last resync received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.UnicastQosAdjustStats, self).__init__()

                    self.yang_name = "unicast-qos-adjust-stats"
                    self.yang_parent_name = "process"

                    self.add_to_batches = YLeaf(YType.uint32, "add-to-batches")

                    self.batches = YLeaf(YType.uint16, "batches")

                    self.delete_to_batches = YLeaf(YType.uint32, "delete-to-batches")

                    self.is_qos_s_sweeped = YLeaf(YType.boolean, "is-qos-s-sweeped")

                    self.is_resync_received = YLeaf(YType.boolean, "is-resync-received")

                    self.is_resync_required = YLeaf(YType.boolean, "is-resync-required")

                    self.is_resync_start_sent = YLeaf(YType.boolean, "is-resync-start-sent")

                    self.last_download_time = YLeaf(YType.uint64, "last-download-time")

                    self.last_sweep_time = YLeaf(YType.uint64, "last-sweep-time")

                    self.queues = YLeaf(YType.uint16, "queues")

                    self.received_resync_requests = YLeaf(YType.uint32, "received-resync-requests")

                    self.send_comm_errors = YLeaf(YType.uint32, "send-comm-errors")

                    self.send_errors = YLeaf(YType.uint32, "send-errors")

                    self.send_partial_errors = YLeaf(YType.uint32, "send-partial-errors")

                    self.send_success = YLeaf(YType.uint32, "send-success")

                    self.sent_resync_bulks = YLeaf(YType.uint32, "sent-resync-bulks")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("add_to_batches",
                                    "batches",
                                    "delete_to_batches",
                                    "is_qos_s_sweeped",
                                    "is_resync_received",
                                    "is_resync_required",
                                    "is_resync_start_sent",
                                    "last_download_time",
                                    "last_sweep_time",
                                    "queues",
                                    "received_resync_requests",
                                    "send_comm_errors",
                                    "send_errors",
                                    "send_partial_errors",
                                    "send_success",
                                    "sent_resync_bulks") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.Process.UnicastQosAdjustStats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.Process.UnicastQosAdjustStats, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.add_to_batches.is_set or
                        self.batches.is_set or
                        self.delete_to_batches.is_set or
                        self.is_qos_s_sweeped.is_set or
                        self.is_resync_received.is_set or
                        self.is_resync_required.is_set or
                        self.is_resync_start_sent.is_set or
                        self.last_download_time.is_set or
                        self.last_sweep_time.is_set or
                        self.queues.is_set or
                        self.received_resync_requests.is_set or
                        self.send_comm_errors.is_set or
                        self.send_errors.is_set or
                        self.send_partial_errors.is_set or
                        self.send_success.is_set or
                        self.sent_resync_bulks.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.add_to_batches.yfilter != YFilter.not_set or
                        self.batches.yfilter != YFilter.not_set or
                        self.delete_to_batches.yfilter != YFilter.not_set or
                        self.is_qos_s_sweeped.yfilter != YFilter.not_set or
                        self.is_resync_received.yfilter != YFilter.not_set or
                        self.is_resync_required.yfilter != YFilter.not_set or
                        self.is_resync_start_sent.yfilter != YFilter.not_set or
                        self.last_download_time.yfilter != YFilter.not_set or
                        self.last_sweep_time.yfilter != YFilter.not_set or
                        self.queues.yfilter != YFilter.not_set or
                        self.received_resync_requests.yfilter != YFilter.not_set or
                        self.send_comm_errors.yfilter != YFilter.not_set or
                        self.send_errors.yfilter != YFilter.not_set or
                        self.send_partial_errors.yfilter != YFilter.not_set or
                        self.send_success.yfilter != YFilter.not_set or
                        self.sent_resync_bulks.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "unicast-qos-adjust-stats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.add_to_batches.is_set or self.add_to_batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.add_to_batches.get_name_leafdata())
                    if (self.batches.is_set or self.batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.batches.get_name_leafdata())
                    if (self.delete_to_batches.is_set or self.delete_to_batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.delete_to_batches.get_name_leafdata())
                    if (self.is_qos_s_sweeped.is_set or self.is_qos_s_sweeped.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_qos_s_sweeped.get_name_leafdata())
                    if (self.is_resync_received.is_set or self.is_resync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_received.get_name_leafdata())
                    if (self.is_resync_required.is_set or self.is_resync_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_required.get_name_leafdata())
                    if (self.is_resync_start_sent.is_set or self.is_resync_start_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_start_sent.get_name_leafdata())
                    if (self.last_download_time.is_set or self.last_download_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_download_time.get_name_leafdata())
                    if (self.last_sweep_time.is_set or self.last_sweep_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_sweep_time.get_name_leafdata())
                    if (self.queues.is_set or self.queues.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.queues.get_name_leafdata())
                    if (self.received_resync_requests.is_set or self.received_resync_requests.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.received_resync_requests.get_name_leafdata())
                    if (self.send_comm_errors.is_set or self.send_comm_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_comm_errors.get_name_leafdata())
                    if (self.send_errors.is_set or self.send_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_errors.get_name_leafdata())
                    if (self.send_partial_errors.is_set or self.send_partial_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_partial_errors.get_name_leafdata())
                    if (self.send_success.is_set or self.send_success.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_success.get_name_leafdata())
                    if (self.sent_resync_bulks.is_set or self.sent_resync_bulks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sent_resync_bulks.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "add-to-batches" or name == "batches" or name == "delete-to-batches" or name == "is-qos-s-sweeped" or name == "is-resync-received" or name == "is-resync-required" or name == "is-resync-start-sent" or name == "last-download-time" or name == "last-sweep-time" or name == "queues" or name == "received-resync-requests" or name == "send-comm-errors" or name == "send-errors" or name == "send-partial-errors" or name == "send-success" or name == "sent-resync-bulks"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "add-to-batches"):
                        self.add_to_batches = value
                        self.add_to_batches.value_namespace = name_space
                        self.add_to_batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "batches"):
                        self.batches = value
                        self.batches.value_namespace = name_space
                        self.batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "delete-to-batches"):
                        self.delete_to_batches = value
                        self.delete_to_batches.value_namespace = name_space
                        self.delete_to_batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-qos-s-sweeped"):
                        self.is_qos_s_sweeped = value
                        self.is_qos_s_sweeped.value_namespace = name_space
                        self.is_qos_s_sweeped.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-received"):
                        self.is_resync_received = value
                        self.is_resync_received.value_namespace = name_space
                        self.is_resync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-required"):
                        self.is_resync_required = value
                        self.is_resync_required.value_namespace = name_space
                        self.is_resync_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-start-sent"):
                        self.is_resync_start_sent = value
                        self.is_resync_start_sent.value_namespace = name_space
                        self.is_resync_start_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-download-time"):
                        self.last_download_time = value
                        self.last_download_time.value_namespace = name_space
                        self.last_download_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-sweep-time"):
                        self.last_sweep_time = value
                        self.last_sweep_time.value_namespace = name_space
                        self.last_sweep_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "queues"):
                        self.queues = value
                        self.queues.value_namespace = name_space
                        self.queues.value_namespace_prefix = name_space_prefix
                    if(value_path == "received-resync-requests"):
                        self.received_resync_requests = value
                        self.received_resync_requests.value_namespace = name_space
                        self.received_resync_requests.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-comm-errors"):
                        self.send_comm_errors = value
                        self.send_comm_errors.value_namespace = name_space
                        self.send_comm_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-errors"):
                        self.send_errors = value
                        self.send_errors.value_namespace = name_space
                        self.send_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-partial-errors"):
                        self.send_partial_errors = value
                        self.send_partial_errors.value_namespace = name_space
                        self.send_partial_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-success"):
                        self.send_success = value
                        self.send_success.value_namespace = name_space
                        self.send_success.value_namespace_prefix = name_space_prefix
                    if(value_path == "sent-resync-bulks"):
                        self.sent_resync_bulks = value
                        self.sent_resync_bulks.value_namespace = name_space
                        self.sent_resync_bulks.value_namespace_prefix = name_space_prefix


            class BviStatistics(Entity):
                """
                IGMP BVI Stats
                
                .. attribute:: null_buffer_handles
                
                	Number of AIPC NULL buffer handles
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_buffers
                
                	Number of AIPC buffers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_buffers
                
                	Number of AIPC buffers released
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_fail_buffers
                
                	Number of AIPC buffers release failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_igmp_packet_success
                
                	Number of IGMP protocol messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_close_notif
                
                	Number of AIPC close notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_connect_notif
                
                	Number of AIPC connect notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_error_notif
                
                	Number of AIPC error notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_input_wait_notif
                
                	Number of AIPC input waiting notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_lwm_notif
                
                	Number of AIPC LWM notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_open_notif
                
                	Number of AIPC open notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_output_notif
                
                	Number of AIPC output notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_publish_notif
                
                	Number of AIPC publish notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_q_full_notif
                
                	Number of AIPC queue full notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_send_status_notif
                
                	Number of AIPC send status notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_blocks
                
                	Number of AIPC buffers send blocked
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffer_errors
                
                	Number of AIPC transmission errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffers
                
                	Number of AIPC buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_mrouter_buffers
                
                	Number of IGMP Mrouter buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_protocol_buffers
                
                	Number of IGMP protocol buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_buffers
                
                	Number of IGMP Unknown buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_dc
                
                	Number of WTX messages dropped due to disconnect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_nomem
                
                	Number of WTX messages dropped to memory
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_freed
                
                	Number of WTX messages freed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_proto_sent
                
                	Number of WTX messages sent to Protocol
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_recvd
                
                	Number of WTX messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_sent
                
                	Number of WTX messages sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.BviStatistics, self).__init__()

                    self.yang_name = "bvi-statistics"
                    self.yang_parent_name = "process"

                    self.null_buffer_handles = YLeaf(YType.uint32, "null-buffer-handles")

                    self.receive_buffers = YLeaf(YType.uint32, "receive-buffers")

                    self.release_buffers = YLeaf(YType.uint32, "release-buffers")

                    self.release_fail_buffers = YLeaf(YType.uint32, "release-fail-buffers")

                    self.rx_add_mrouter_msg = YLeaf(YType.uint32, "rx-add-mrouter-msg")

                    self.rx_delete_mrouter_msg = YLeaf(YType.uint32, "rx-delete-mrouter-msg")

                    self.rx_igmp_packet_success = YLeaf(YType.uint32, "rx-igmp-packet-success")

                    self.rx_ipc_close_notif = YLeaf(YType.uint32, "rx-ipc-close-notif")

                    self.rx_ipc_connect_notif = YLeaf(YType.uint32, "rx-ipc-connect-notif")

                    self.rx_ipc_error_notif = YLeaf(YType.uint32, "rx-ipc-error-notif")

                    self.rx_ipc_input_wait_notif = YLeaf(YType.uint32, "rx-ipc-input-wait-notif")

                    self.rx_ipc_lwm_notif = YLeaf(YType.uint32, "rx-ipc-lwm-notif")

                    self.rx_ipc_open_notif = YLeaf(YType.uint32, "rx-ipc-open-notif")

                    self.rx_ipc_output_notif = YLeaf(YType.uint32, "rx-ipc-output-notif")

                    self.rx_ipc_publish_notif = YLeaf(YType.uint32, "rx-ipc-publish-notif")

                    self.rx_ipc_q_full_notif = YLeaf(YType.uint32, "rx-ipc-q-full-notif")

                    self.rx_ipc_send_status_notif = YLeaf(YType.uint32, "rx-ipc-send-status-notif")

                    self.rx_sweep_mrouter_msg = YLeaf(YType.uint32, "rx-sweep-mrouter-msg")

                    self.rx_unknown_mrouter_msg = YLeaf(YType.uint32, "rx-unknown-mrouter-msg")

                    self.send_blocks = YLeaf(YType.uint32, "send-blocks")

                    self.tx_add_mrouter_msg = YLeaf(YType.uint32, "tx-add-mrouter-msg")

                    self.tx_buffer_errors = YLeaf(YType.uint32, "tx-buffer-errors")

                    self.tx_buffers = YLeaf(YType.uint32, "tx-buffers")

                    self.tx_delete_mrouter_msg = YLeaf(YType.uint32, "tx-delete-mrouter-msg")

                    self.tx_mrouter_buffers = YLeaf(YType.uint32, "tx-mrouter-buffers")

                    self.tx_protocol_buffers = YLeaf(YType.uint32, "tx-protocol-buffers")

                    self.tx_sweep_mrouter_msg = YLeaf(YType.uint32, "tx-sweep-mrouter-msg")

                    self.tx_unknown_buffers = YLeaf(YType.uint32, "tx-unknown-buffers")

                    self.tx_unknown_mrouter_msg = YLeaf(YType.uint32, "tx-unknown-mrouter-msg")

                    self.wtx_msg_drop_dc = YLeaf(YType.uint32, "wtx-msg-drop-dc")

                    self.wtx_msg_drop_nomem = YLeaf(YType.uint32, "wtx-msg-drop-nomem")

                    self.wtx_msg_freed = YLeaf(YType.uint32, "wtx-msg-freed")

                    self.wtx_msg_proto_sent = YLeaf(YType.uint32, "wtx-msg-proto-sent")

                    self.wtx_msg_recvd = YLeaf(YType.uint32, "wtx-msg-recvd")

                    self.wtx_msg_sent = YLeaf(YType.uint32, "wtx-msg-sent")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("null_buffer_handles",
                                    "receive_buffers",
                                    "release_buffers",
                                    "release_fail_buffers",
                                    "rx_add_mrouter_msg",
                                    "rx_delete_mrouter_msg",
                                    "rx_igmp_packet_success",
                                    "rx_ipc_close_notif",
                                    "rx_ipc_connect_notif",
                                    "rx_ipc_error_notif",
                                    "rx_ipc_input_wait_notif",
                                    "rx_ipc_lwm_notif",
                                    "rx_ipc_open_notif",
                                    "rx_ipc_output_notif",
                                    "rx_ipc_publish_notif",
                                    "rx_ipc_q_full_notif",
                                    "rx_ipc_send_status_notif",
                                    "rx_sweep_mrouter_msg",
                                    "rx_unknown_mrouter_msg",
                                    "send_blocks",
                                    "tx_add_mrouter_msg",
                                    "tx_buffer_errors",
                                    "tx_buffers",
                                    "tx_delete_mrouter_msg",
                                    "tx_mrouter_buffers",
                                    "tx_protocol_buffers",
                                    "tx_sweep_mrouter_msg",
                                    "tx_unknown_buffers",
                                    "tx_unknown_mrouter_msg",
                                    "wtx_msg_drop_dc",
                                    "wtx_msg_drop_nomem",
                                    "wtx_msg_freed",
                                    "wtx_msg_proto_sent",
                                    "wtx_msg_recvd",
                                    "wtx_msg_sent") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.Process.BviStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.Process.BviStatistics, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.null_buffer_handles.is_set or
                        self.receive_buffers.is_set or
                        self.release_buffers.is_set or
                        self.release_fail_buffers.is_set or
                        self.rx_add_mrouter_msg.is_set or
                        self.rx_delete_mrouter_msg.is_set or
                        self.rx_igmp_packet_success.is_set or
                        self.rx_ipc_close_notif.is_set or
                        self.rx_ipc_connect_notif.is_set or
                        self.rx_ipc_error_notif.is_set or
                        self.rx_ipc_input_wait_notif.is_set or
                        self.rx_ipc_lwm_notif.is_set or
                        self.rx_ipc_open_notif.is_set or
                        self.rx_ipc_output_notif.is_set or
                        self.rx_ipc_publish_notif.is_set or
                        self.rx_ipc_q_full_notif.is_set or
                        self.rx_ipc_send_status_notif.is_set or
                        self.rx_sweep_mrouter_msg.is_set or
                        self.rx_unknown_mrouter_msg.is_set or
                        self.send_blocks.is_set or
                        self.tx_add_mrouter_msg.is_set or
                        self.tx_buffer_errors.is_set or
                        self.tx_buffers.is_set or
                        self.tx_delete_mrouter_msg.is_set or
                        self.tx_mrouter_buffers.is_set or
                        self.tx_protocol_buffers.is_set or
                        self.tx_sweep_mrouter_msg.is_set or
                        self.tx_unknown_buffers.is_set or
                        self.tx_unknown_mrouter_msg.is_set or
                        self.wtx_msg_drop_dc.is_set or
                        self.wtx_msg_drop_nomem.is_set or
                        self.wtx_msg_freed.is_set or
                        self.wtx_msg_proto_sent.is_set or
                        self.wtx_msg_recvd.is_set or
                        self.wtx_msg_sent.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.null_buffer_handles.yfilter != YFilter.not_set or
                        self.receive_buffers.yfilter != YFilter.not_set or
                        self.release_buffers.yfilter != YFilter.not_set or
                        self.release_fail_buffers.yfilter != YFilter.not_set or
                        self.rx_add_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_delete_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_igmp_packet_success.yfilter != YFilter.not_set or
                        self.rx_ipc_close_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_connect_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_error_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_input_wait_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_lwm_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_open_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_output_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_publish_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_q_full_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_send_status_notif.yfilter != YFilter.not_set or
                        self.rx_sweep_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_unknown_mrouter_msg.yfilter != YFilter.not_set or
                        self.send_blocks.yfilter != YFilter.not_set or
                        self.tx_add_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_buffer_errors.yfilter != YFilter.not_set or
                        self.tx_buffers.yfilter != YFilter.not_set or
                        self.tx_delete_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_mrouter_buffers.yfilter != YFilter.not_set or
                        self.tx_protocol_buffers.yfilter != YFilter.not_set or
                        self.tx_sweep_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_unknown_buffers.yfilter != YFilter.not_set or
                        self.tx_unknown_mrouter_msg.yfilter != YFilter.not_set or
                        self.wtx_msg_drop_dc.yfilter != YFilter.not_set or
                        self.wtx_msg_drop_nomem.yfilter != YFilter.not_set or
                        self.wtx_msg_freed.yfilter != YFilter.not_set or
                        self.wtx_msg_proto_sent.yfilter != YFilter.not_set or
                        self.wtx_msg_recvd.yfilter != YFilter.not_set or
                        self.wtx_msg_sent.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bvi-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.null_buffer_handles.is_set or self.null_buffer_handles.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.null_buffer_handles.get_name_leafdata())
                    if (self.receive_buffers.is_set or self.receive_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.receive_buffers.get_name_leafdata())
                    if (self.release_buffers.is_set or self.release_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.release_buffers.get_name_leafdata())
                    if (self.release_fail_buffers.is_set or self.release_fail_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.release_fail_buffers.get_name_leafdata())
                    if (self.rx_add_mrouter_msg.is_set or self.rx_add_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_add_mrouter_msg.get_name_leafdata())
                    if (self.rx_delete_mrouter_msg.is_set or self.rx_delete_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_delete_mrouter_msg.get_name_leafdata())
                    if (self.rx_igmp_packet_success.is_set or self.rx_igmp_packet_success.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_igmp_packet_success.get_name_leafdata())
                    if (self.rx_ipc_close_notif.is_set or self.rx_ipc_close_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_close_notif.get_name_leafdata())
                    if (self.rx_ipc_connect_notif.is_set or self.rx_ipc_connect_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_connect_notif.get_name_leafdata())
                    if (self.rx_ipc_error_notif.is_set or self.rx_ipc_error_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_error_notif.get_name_leafdata())
                    if (self.rx_ipc_input_wait_notif.is_set or self.rx_ipc_input_wait_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_input_wait_notif.get_name_leafdata())
                    if (self.rx_ipc_lwm_notif.is_set or self.rx_ipc_lwm_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_lwm_notif.get_name_leafdata())
                    if (self.rx_ipc_open_notif.is_set or self.rx_ipc_open_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_open_notif.get_name_leafdata())
                    if (self.rx_ipc_output_notif.is_set or self.rx_ipc_output_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_output_notif.get_name_leafdata())
                    if (self.rx_ipc_publish_notif.is_set or self.rx_ipc_publish_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_publish_notif.get_name_leafdata())
                    if (self.rx_ipc_q_full_notif.is_set or self.rx_ipc_q_full_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_q_full_notif.get_name_leafdata())
                    if (self.rx_ipc_send_status_notif.is_set or self.rx_ipc_send_status_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_send_status_notif.get_name_leafdata())
                    if (self.rx_sweep_mrouter_msg.is_set or self.rx_sweep_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_sweep_mrouter_msg.get_name_leafdata())
                    if (self.rx_unknown_mrouter_msg.is_set or self.rx_unknown_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_unknown_mrouter_msg.get_name_leafdata())
                    if (self.send_blocks.is_set or self.send_blocks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_blocks.get_name_leafdata())
                    if (self.tx_add_mrouter_msg.is_set or self.tx_add_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_add_mrouter_msg.get_name_leafdata())
                    if (self.tx_buffer_errors.is_set or self.tx_buffer_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_buffer_errors.get_name_leafdata())
                    if (self.tx_buffers.is_set or self.tx_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_buffers.get_name_leafdata())
                    if (self.tx_delete_mrouter_msg.is_set or self.tx_delete_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_delete_mrouter_msg.get_name_leafdata())
                    if (self.tx_mrouter_buffers.is_set or self.tx_mrouter_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_mrouter_buffers.get_name_leafdata())
                    if (self.tx_protocol_buffers.is_set or self.tx_protocol_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_protocol_buffers.get_name_leafdata())
                    if (self.tx_sweep_mrouter_msg.is_set or self.tx_sweep_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_sweep_mrouter_msg.get_name_leafdata())
                    if (self.tx_unknown_buffers.is_set or self.tx_unknown_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_unknown_buffers.get_name_leafdata())
                    if (self.tx_unknown_mrouter_msg.is_set or self.tx_unknown_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_unknown_mrouter_msg.get_name_leafdata())
                    if (self.wtx_msg_drop_dc.is_set or self.wtx_msg_drop_dc.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_drop_dc.get_name_leafdata())
                    if (self.wtx_msg_drop_nomem.is_set or self.wtx_msg_drop_nomem.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_drop_nomem.get_name_leafdata())
                    if (self.wtx_msg_freed.is_set or self.wtx_msg_freed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_freed.get_name_leafdata())
                    if (self.wtx_msg_proto_sent.is_set or self.wtx_msg_proto_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_proto_sent.get_name_leafdata())
                    if (self.wtx_msg_recvd.is_set or self.wtx_msg_recvd.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_recvd.get_name_leafdata())
                    if (self.wtx_msg_sent.is_set or self.wtx_msg_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_sent.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "null-buffer-handles" or name == "receive-buffers" or name == "release-buffers" or name == "release-fail-buffers" or name == "rx-add-mrouter-msg" or name == "rx-delete-mrouter-msg" or name == "rx-igmp-packet-success" or name == "rx-ipc-close-notif" or name == "rx-ipc-connect-notif" or name == "rx-ipc-error-notif" or name == "rx-ipc-input-wait-notif" or name == "rx-ipc-lwm-notif" or name == "rx-ipc-open-notif" or name == "rx-ipc-output-notif" or name == "rx-ipc-publish-notif" or name == "rx-ipc-q-full-notif" or name == "rx-ipc-send-status-notif" or name == "rx-sweep-mrouter-msg" or name == "rx-unknown-mrouter-msg" or name == "send-blocks" or name == "tx-add-mrouter-msg" or name == "tx-buffer-errors" or name == "tx-buffers" or name == "tx-delete-mrouter-msg" or name == "tx-mrouter-buffers" or name == "tx-protocol-buffers" or name == "tx-sweep-mrouter-msg" or name == "tx-unknown-buffers" or name == "tx-unknown-mrouter-msg" or name == "wtx-msg-drop-dc" or name == "wtx-msg-drop-nomem" or name == "wtx-msg-freed" or name == "wtx-msg-proto-sent" or name == "wtx-msg-recvd" or name == "wtx-msg-sent"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "null-buffer-handles"):
                        self.null_buffer_handles = value
                        self.null_buffer_handles.value_namespace = name_space
                        self.null_buffer_handles.value_namespace_prefix = name_space_prefix
                    if(value_path == "receive-buffers"):
                        self.receive_buffers = value
                        self.receive_buffers.value_namespace = name_space
                        self.receive_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "release-buffers"):
                        self.release_buffers = value
                        self.release_buffers.value_namespace = name_space
                        self.release_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "release-fail-buffers"):
                        self.release_fail_buffers = value
                        self.release_fail_buffers.value_namespace = name_space
                        self.release_fail_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-add-mrouter-msg"):
                        self.rx_add_mrouter_msg = value
                        self.rx_add_mrouter_msg.value_namespace = name_space
                        self.rx_add_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-delete-mrouter-msg"):
                        self.rx_delete_mrouter_msg = value
                        self.rx_delete_mrouter_msg.value_namespace = name_space
                        self.rx_delete_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-igmp-packet-success"):
                        self.rx_igmp_packet_success = value
                        self.rx_igmp_packet_success.value_namespace = name_space
                        self.rx_igmp_packet_success.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-close-notif"):
                        self.rx_ipc_close_notif = value
                        self.rx_ipc_close_notif.value_namespace = name_space
                        self.rx_ipc_close_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-connect-notif"):
                        self.rx_ipc_connect_notif = value
                        self.rx_ipc_connect_notif.value_namespace = name_space
                        self.rx_ipc_connect_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-error-notif"):
                        self.rx_ipc_error_notif = value
                        self.rx_ipc_error_notif.value_namespace = name_space
                        self.rx_ipc_error_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-input-wait-notif"):
                        self.rx_ipc_input_wait_notif = value
                        self.rx_ipc_input_wait_notif.value_namespace = name_space
                        self.rx_ipc_input_wait_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-lwm-notif"):
                        self.rx_ipc_lwm_notif = value
                        self.rx_ipc_lwm_notif.value_namespace = name_space
                        self.rx_ipc_lwm_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-open-notif"):
                        self.rx_ipc_open_notif = value
                        self.rx_ipc_open_notif.value_namespace = name_space
                        self.rx_ipc_open_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-output-notif"):
                        self.rx_ipc_output_notif = value
                        self.rx_ipc_output_notif.value_namespace = name_space
                        self.rx_ipc_output_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-publish-notif"):
                        self.rx_ipc_publish_notif = value
                        self.rx_ipc_publish_notif.value_namespace = name_space
                        self.rx_ipc_publish_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-q-full-notif"):
                        self.rx_ipc_q_full_notif = value
                        self.rx_ipc_q_full_notif.value_namespace = name_space
                        self.rx_ipc_q_full_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-send-status-notif"):
                        self.rx_ipc_send_status_notif = value
                        self.rx_ipc_send_status_notif.value_namespace = name_space
                        self.rx_ipc_send_status_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-sweep-mrouter-msg"):
                        self.rx_sweep_mrouter_msg = value
                        self.rx_sweep_mrouter_msg.value_namespace = name_space
                        self.rx_sweep_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-unknown-mrouter-msg"):
                        self.rx_unknown_mrouter_msg = value
                        self.rx_unknown_mrouter_msg.value_namespace = name_space
                        self.rx_unknown_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-blocks"):
                        self.send_blocks = value
                        self.send_blocks.value_namespace = name_space
                        self.send_blocks.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-add-mrouter-msg"):
                        self.tx_add_mrouter_msg = value
                        self.tx_add_mrouter_msg.value_namespace = name_space
                        self.tx_add_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-buffer-errors"):
                        self.tx_buffer_errors = value
                        self.tx_buffer_errors.value_namespace = name_space
                        self.tx_buffer_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-buffers"):
                        self.tx_buffers = value
                        self.tx_buffers.value_namespace = name_space
                        self.tx_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-delete-mrouter-msg"):
                        self.tx_delete_mrouter_msg = value
                        self.tx_delete_mrouter_msg.value_namespace = name_space
                        self.tx_delete_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-mrouter-buffers"):
                        self.tx_mrouter_buffers = value
                        self.tx_mrouter_buffers.value_namespace = name_space
                        self.tx_mrouter_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-protocol-buffers"):
                        self.tx_protocol_buffers = value
                        self.tx_protocol_buffers.value_namespace = name_space
                        self.tx_protocol_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-sweep-mrouter-msg"):
                        self.tx_sweep_mrouter_msg = value
                        self.tx_sweep_mrouter_msg.value_namespace = name_space
                        self.tx_sweep_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-unknown-buffers"):
                        self.tx_unknown_buffers = value
                        self.tx_unknown_buffers.value_namespace = name_space
                        self.tx_unknown_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-unknown-mrouter-msg"):
                        self.tx_unknown_mrouter_msg = value
                        self.tx_unknown_mrouter_msg.value_namespace = name_space
                        self.tx_unknown_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-drop-dc"):
                        self.wtx_msg_drop_dc = value
                        self.wtx_msg_drop_dc.value_namespace = name_space
                        self.wtx_msg_drop_dc.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-drop-nomem"):
                        self.wtx_msg_drop_nomem = value
                        self.wtx_msg_drop_nomem.value_namespace = name_space
                        self.wtx_msg_drop_nomem.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-freed"):
                        self.wtx_msg_freed = value
                        self.wtx_msg_freed.value_namespace = name_space
                        self.wtx_msg_freed.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-proto-sent"):
                        self.wtx_msg_proto_sent = value
                        self.wtx_msg_proto_sent.value_namespace = name_space
                        self.wtx_msg_proto_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-recvd"):
                        self.wtx_msg_recvd = value
                        self.wtx_msg_recvd.value_namespace = name_space
                        self.wtx_msg_recvd.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-sent"):
                        self.wtx_msg_sent = value
                        self.wtx_msg_sent.value_namespace = name_space
                        self.wtx_msg_sent.value_namespace_prefix = name_space_prefix


            class Nsf(Entity):
                """
                NSF Information
                
                .. attribute:: is_multicast_nsf_active
                
                	Is Multicast NSF active
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_min
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_min
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_min
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_time_left
                
                	Multicast NSF time remaining in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_timeout
                
                	Multicast NSF timeout in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"

                    self.is_multicast_nsf_active = YLeaf(YType.boolean, "is-multicast-nsf-active")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_min = YLeaf(YType.int32, "last-icd-notif-recv-min")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_min = YLeaf(YType.int32, "last-nsf-off-min")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_min = YLeaf(YType.int32, "last-nsf-on-min")

                    self.multicast_nsf_time_left = YLeaf(YType.uint32, "multicast-nsf-time-left")

                    self.multicast_nsf_timeout = YLeaf(YType.uint32, "multicast-nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_multicast_nsf_active",
                                    "last_icd_notif_recv",
                                    "last_icd_notif_recv_min",
                                    "last_nsf_off",
                                    "last_nsf_off_min",
                                    "last_nsf_on",
                                    "last_nsf_on_min",
                                    "multicast_nsf_time_left",
                                    "multicast_nsf_timeout",
                                    "respawn_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.Process.Nsf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.Process.Nsf, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_multicast_nsf_active.is_set or
                        self.last_icd_notif_recv.is_set or
                        self.last_icd_notif_recv_min.is_set or
                        self.last_nsf_off.is_set or
                        self.last_nsf_off_min.is_set or
                        self.last_nsf_on.is_set or
                        self.last_nsf_on_min.is_set or
                        self.multicast_nsf_time_left.is_set or
                        self.multicast_nsf_timeout.is_set or
                        self.respawn_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_multicast_nsf_active.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv_min.yfilter != YFilter.not_set or
                        self.last_nsf_off.yfilter != YFilter.not_set or
                        self.last_nsf_off_min.yfilter != YFilter.not_set or
                        self.last_nsf_on.yfilter != YFilter.not_set or
                        self.last_nsf_on_min.yfilter != YFilter.not_set or
                        self.multicast_nsf_time_left.yfilter != YFilter.not_set or
                        self.multicast_nsf_timeout.yfilter != YFilter.not_set or
                        self.respawn_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsf" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_multicast_nsf_active.is_set or self.is_multicast_nsf_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multicast_nsf_active.get_name_leafdata())
                    if (self.last_icd_notif_recv.is_set or self.last_icd_notif_recv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv.get_name_leafdata())
                    if (self.last_icd_notif_recv_min.is_set or self.last_icd_notif_recv_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv_min.get_name_leafdata())
                    if (self.last_nsf_off.is_set or self.last_nsf_off.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off.get_name_leafdata())
                    if (self.last_nsf_off_min.is_set or self.last_nsf_off_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off_min.get_name_leafdata())
                    if (self.last_nsf_on.is_set or self.last_nsf_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on.get_name_leafdata())
                    if (self.last_nsf_on_min.is_set or self.last_nsf_on_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on_min.get_name_leafdata())
                    if (self.multicast_nsf_time_left.is_set or self.multicast_nsf_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.multicast_nsf_time_left.get_name_leafdata())
                    if (self.multicast_nsf_timeout.is_set or self.multicast_nsf_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.multicast_nsf_timeout.get_name_leafdata())
                    if (self.respawn_count.is_set or self.respawn_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.respawn_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-multicast-nsf-active" or name == "last-icd-notif-recv" or name == "last-icd-notif-recv-min" or name == "last-nsf-off" or name == "last-nsf-off-min" or name == "last-nsf-on" or name == "last-nsf-on-min" or name == "multicast-nsf-time-left" or name == "multicast-nsf-timeout" or name == "respawn-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-multicast-nsf-active"):
                        self.is_multicast_nsf_active = value
                        self.is_multicast_nsf_active.value_namespace = name_space
                        self.is_multicast_nsf_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv"):
                        self.last_icd_notif_recv = value
                        self.last_icd_notif_recv.value_namespace = name_space
                        self.last_icd_notif_recv.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv-min"):
                        self.last_icd_notif_recv_min = value
                        self.last_icd_notif_recv_min.value_namespace = name_space
                        self.last_icd_notif_recv_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off"):
                        self.last_nsf_off = value
                        self.last_nsf_off.value_namespace = name_space
                        self.last_nsf_off.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off-min"):
                        self.last_nsf_off_min = value
                        self.last_nsf_off_min.value_namespace = name_space
                        self.last_nsf_off_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on"):
                        self.last_nsf_on = value
                        self.last_nsf_on.value_namespace = name_space
                        self.last_nsf_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on-min"):
                        self.last_nsf_on_min = value
                        self.last_nsf_on_min.value_namespace = name_space
                        self.last_nsf_on_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "multicast-nsf-time-left"):
                        self.multicast_nsf_time_left = value
                        self.multicast_nsf_time_left.value_namespace = name_space
                        self.multicast_nsf_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "multicast-nsf-timeout"):
                        self.multicast_nsf_timeout = value
                        self.multicast_nsf_timeout.value_namespace = name_space
                        self.multicast_nsf_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "respawn-count"):
                        self.respawn_count = value
                        self.respawn_count.value_namespace = name_space
                        self.respawn_count.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.amt_gatewaies is not None and self.amt_gatewaies.has_data()) or
                    (self.amt_summary is not None and self.amt_summary.has_data()) or
                    (self.bvi_statistics is not None and self.bvi_statistics.has_data()) or
                    (self.nsf is not None and self.nsf.has_data()) or
                    (self.nsr is not None and self.nsr.has_data()) or
                    (self.unicast_qos_adjust_stats is not None and self.unicast_qos_adjust_stats.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.amt_gatewaies is not None and self.amt_gatewaies.has_operation()) or
                    (self.amt_summary is not None and self.amt_summary.has_operation()) or
                    (self.bvi_statistics is not None and self.bvi_statistics.has_operation()) or
                    (self.nsf is not None and self.nsf.has_operation()) or
                    (self.nsr is not None and self.nsr.has_operation()) or
                    (self.unicast_qos_adjust_stats is not None and self.unicast_qos_adjust_stats.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "process" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "amt-gatewaies"):
                    if (self.amt_gatewaies is None):
                        self.amt_gatewaies = Igmp.Standby.Process.AmtGatewaies()
                        self.amt_gatewaies.parent = self
                        self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                    return self.amt_gatewaies

                if (child_yang_name == "amt-summary"):
                    if (self.amt_summary is None):
                        self.amt_summary = Igmp.Standby.Process.AmtSummary()
                        self.amt_summary.parent = self
                        self._children_name_map["amt_summary"] = "amt-summary"
                    return self.amt_summary

                if (child_yang_name == "bvi-statistics"):
                    if (self.bvi_statistics is None):
                        self.bvi_statistics = Igmp.Standby.Process.BviStatistics()
                        self.bvi_statistics.parent = self
                        self._children_name_map["bvi_statistics"] = "bvi-statistics"
                    return self.bvi_statistics

                if (child_yang_name == "nsf"):
                    if (self.nsf is None):
                        self.nsf = Igmp.Standby.Process.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"
                    return self.nsf

                if (child_yang_name == "nsr"):
                    if (self.nsr is None):
                        self.nsr = Igmp.Standby.Process.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                    return self.nsr

                if (child_yang_name == "unicast-qos-adjust-stats"):
                    if (self.unicast_qos_adjust_stats is None):
                        self.unicast_qos_adjust_stats = Igmp.Standby.Process.UnicastQosAdjustStats()
                        self.unicast_qos_adjust_stats.parent = self
                        self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                    return self.unicast_qos_adjust_stats

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "amt-gatewaies" or name == "amt-summary" or name == "bvi-statistics" or name == "nsf" or name == "nsr" or name == "unicast-qos-adjust-stats"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: detail_groups
            
            	IGMP Detail Group Database
            	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups>`
            
            .. attribute:: explicit_groups
            
            	IGMP Explicit Group Database
            	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups>`
            
            .. attribute:: global_interface_table
            
            	IGMP Global Interface 
            	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GlobalInterfaceTable>`
            
            .. attribute:: group_summary
            
            	IGMP Groups Summary
            	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GroupSummary>`
            
            .. attribute:: groups
            
            	IGMP Group Database Table
            	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Groups>`
            
            .. attribute:: ifrs_interface_summary
            
            	IGMP IFRS Interface summary
            	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaceSummary>`
            
            .. attribute:: ifrs_interfaces
            
            	IGMP Interface specific
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: interface_state_offs
            
            	IGMP Interface state off
            	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOffs>`
            
            .. attribute:: interface_state_ons
            
            	IGMP Interface state on
            	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOns>`
            
            .. attribute:: interface_table
            
            	IGMP Interface specific Table
            	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceTable>`
            
            .. attribute:: interface_unicast_qos_adjusts
            
            	IGMP Interface Unicast\-Qos\-Adjust
            	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts>`
            
            .. attribute:: non_active_groups
            
            	IGMP Non\-Active Groups Information
            	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.NonActiveGroups>`
            
            .. attribute:: ranges
            
            	Range table
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Ranges>`
            
            .. attribute:: ssm_map_details
            
            	SSM Map Detail
            	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMapDetails>`
            
            .. attribute:: ssm_maps
            
            	SSM Map Table
            	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMaps>`
            
            .. attribute:: summary
            
            	IGMP Summary Information
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Summary>`
            
            .. attribute:: traffic_counters
            
            	IGMP Message Traffic Counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.TrafficCounters>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Standby.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "standby"

                self.detail_groups = Igmp.Standby.DefaultContext.DetailGroups()
                self.detail_groups.parent = self
                self._children_name_map["detail_groups"] = "detail-groups"
                self._children_yang_names.add("detail-groups")

                self.explicit_groups = Igmp.Standby.DefaultContext.ExplicitGroups()
                self.explicit_groups.parent = self
                self._children_name_map["explicit_groups"] = "explicit-groups"
                self._children_yang_names.add("explicit-groups")

                self.global_interface_table = Igmp.Standby.DefaultContext.GlobalInterfaceTable()
                self.global_interface_table.parent = self
                self._children_name_map["global_interface_table"] = "global-interface-table"
                self._children_yang_names.add("global-interface-table")

                self.group_summary = Igmp.Standby.DefaultContext.GroupSummary()
                self.group_summary.parent = self
                self._children_name_map["group_summary"] = "group-summary"
                self._children_yang_names.add("group-summary")

                self.groups = Igmp.Standby.DefaultContext.Groups()
                self.groups.parent = self
                self._children_name_map["groups"] = "groups"
                self._children_yang_names.add("groups")

                self.ifrs_interface_summary = Igmp.Standby.DefaultContext.IfrsInterfaceSummary()
                self.ifrs_interface_summary.parent = self
                self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                self._children_yang_names.add("ifrs-interface-summary")

                self.ifrs_interfaces = Igmp.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.interface_state_offs = Igmp.Standby.DefaultContext.InterfaceStateOffs()
                self.interface_state_offs.parent = self
                self._children_name_map["interface_state_offs"] = "interface-state-offs"
                self._children_yang_names.add("interface-state-offs")

                self.interface_state_ons = Igmp.Standby.DefaultContext.InterfaceStateOns()
                self.interface_state_ons.parent = self
                self._children_name_map["interface_state_ons"] = "interface-state-ons"
                self._children_yang_names.add("interface-state-ons")

                self.interface_table = Igmp.Standby.DefaultContext.InterfaceTable()
                self.interface_table.parent = self
                self._children_name_map["interface_table"] = "interface-table"
                self._children_yang_names.add("interface-table")

                self.interface_unicast_qos_adjusts = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts()
                self.interface_unicast_qos_adjusts.parent = self
                self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                self._children_yang_names.add("interface-unicast-qos-adjusts")

                self.non_active_groups = Igmp.Standby.DefaultContext.NonActiveGroups()
                self.non_active_groups.parent = self
                self._children_name_map["non_active_groups"] = "non-active-groups"
                self._children_yang_names.add("non-active-groups")

                self.ranges = Igmp.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.ssm_map_details = Igmp.Standby.DefaultContext.SsmMapDetails()
                self.ssm_map_details.parent = self
                self._children_name_map["ssm_map_details"] = "ssm-map-details"
                self._children_yang_names.add("ssm-map-details")

                self.ssm_maps = Igmp.Standby.DefaultContext.SsmMaps()
                self.ssm_maps.parent = self
                self._children_name_map["ssm_maps"] = "ssm-maps"
                self._children_yang_names.add("ssm-maps")

                self.summary = Igmp.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.traffic_counters = Igmp.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")


            class Summary(Entity):
                """
                IGMP Summary Information
                
                .. attribute:: disabled_interface_count
                
                	No. of disabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: enabled_interface_count
                
                	No. of enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_limit
                
                	Maximum groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Maximum and current groups accepted for each interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Summary.Interface>`
                
                .. attribute:: is_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: robustness
                
                	Robustness variable
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: supported_interfaces
                
                	No. of supported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_mte_config_count
                
                	No. of static group commands
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsupported_interfaces
                
                	No. of unsupported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"

                    self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                    self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.group_limit = YLeaf(YType.uint32, "group-limit")

                    self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                    self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                    self.robustness = YLeaf(YType.uint32, "robustness")

                    self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                    self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                    self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("disabled_interface_count",
                                    "enabled_interface_count",
                                    "group_count",
                                    "group_limit",
                                    "is_disabled",
                                    "node_low_memory",
                                    "robustness",
                                    "supported_interfaces",
                                    "tunnel_mte_config_count",
                                    "unsupported_interfaces") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.Summary, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    Maximum and current groups accepted for each
                    interface
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: on_off
                    
                    	Enabled/Disabled
                    	**type**\:  bool
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent if handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Time elapsed since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.Summary.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "summary"

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.on_off = YLeaf(YType.boolean, "on-off")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_count",
                                        "group_limit",
                                        "interface_name",
                                        "on_off",
                                        "parent_ifhandle",
                                        "router_uptime_in_seconds",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.Summary.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.Summary.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.group_count.is_set or
                            self.group_limit.is_set or
                            self.interface_name.is_set or
                            self.on_off.is_set or
                            self.parent_ifhandle.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.group_limit.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.on_off.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/summary/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_limit.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.on_off.is_set or self.on_off.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.on_off.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-count" or name == "group-limit" or name == "interface-name" or name == "on-off" or name == "parent-ifhandle" or name == "router-uptime-in-seconds" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-limit"):
                            self.group_limit = value
                            self.group_limit.value_namespace = name_space
                            self.group_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "on-off"):
                            self.on_off = value
                            self.on_off.value_namespace = name_space
                            self.on_off.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.disabled_interface_count.is_set or
                        self.enabled_interface_count.is_set or
                        self.group_count.is_set or
                        self.group_limit.is_set or
                        self.is_disabled.is_set or
                        self.node_low_memory.is_set or
                        self.robustness.is_set or
                        self.supported_interfaces.is_set or
                        self.tunnel_mte_config_count.is_set or
                        self.unsupported_interfaces.is_set)

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.disabled_interface_count.yfilter != YFilter.not_set or
                        self.enabled_interface_count.yfilter != YFilter.not_set or
                        self.group_count.yfilter != YFilter.not_set or
                        self.group_limit.yfilter != YFilter.not_set or
                        self.is_disabled.yfilter != YFilter.not_set or
                        self.node_low_memory.yfilter != YFilter.not_set or
                        self.robustness.yfilter != YFilter.not_set or
                        self.supported_interfaces.yfilter != YFilter.not_set or
                        self.tunnel_mte_config_count.yfilter != YFilter.not_set or
                        self.unsupported_interfaces.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.disabled_interface_count.is_set or self.disabled_interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disabled_interface_count.get_name_leafdata())
                    if (self.enabled_interface_count.is_set or self.enabled_interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enabled_interface_count.get_name_leafdata())
                    if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_count.get_name_leafdata())
                    if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_limit.get_name_leafdata())
                    if (self.is_disabled.is_set or self.is_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_disabled.get_name_leafdata())
                    if (self.node_low_memory.is_set or self.node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.node_low_memory.get_name_leafdata())
                    if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.robustness.get_name_leafdata())
                    if (self.supported_interfaces.is_set or self.supported_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.supported_interfaces.get_name_leafdata())
                    if (self.tunnel_mte_config_count.is_set or self.tunnel_mte_config_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_mte_config_count.get_name_leafdata())
                    if (self.unsupported_interfaces.is_set or self.unsupported_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unsupported_interfaces.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.Summary.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "disabled-interface-count" or name == "enabled-interface-count" or name == "group-count" or name == "group-limit" or name == "is-disabled" or name == "node-low-memory" or name == "robustness" or name == "supported-interfaces" or name == "tunnel-mte-config-count" or name == "unsupported-interfaces"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "disabled-interface-count"):
                        self.disabled_interface_count = value
                        self.disabled_interface_count.value_namespace = name_space
                        self.disabled_interface_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "enabled-interface-count"):
                        self.enabled_interface_count = value
                        self.enabled_interface_count.value_namespace = name_space
                        self.enabled_interface_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-count"):
                        self.group_count = value
                        self.group_count.value_namespace = name_space
                        self.group_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-limit"):
                        self.group_limit = value
                        self.group_limit.value_namespace = name_space
                        self.group_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-disabled"):
                        self.is_disabled = value
                        self.is_disabled.value_namespace = name_space
                        self.is_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "node-low-memory"):
                        self.node_low_memory = value
                        self.node_low_memory.value_namespace = name_space
                        self.node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "robustness"):
                        self.robustness = value
                        self.robustness.value_namespace = name_space
                        self.robustness.value_namespace_prefix = name_space_prefix
                    if(value_path == "supported-interfaces"):
                        self.supported_interfaces = value
                        self.supported_interfaces.value_namespace = name_space
                        self.supported_interfaces.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-mte-config-count"):
                        self.tunnel_mte_config_count = value
                        self.tunnel_mte_config_count.value_namespace = name_space
                        self.tunnel_mte_config_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "unsupported-interfaces"):
                        self.unsupported_interfaces = value
                        self.unsupported_interfaces.value_namespace = name_space
                        self.unsupported_interfaces.value_namespace_prefix = name_space_prefix


            class InterfaceStateOns(Entity):
                """
                IGMP Interface state on
                
                .. attribute:: interface_state_on
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.InterfaceStateOns, self).__init__()

                    self.yang_name = "interface-state-ons"
                    self.yang_parent_name = "default-context"

                    self.interface_state_on = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.InterfaceStateOns, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.InterfaceStateOns, self).__setattr__(name, value)


                class InterfaceStateOn(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__init__()

                        self.yang_name = "interface-state-on"
                        self.yang_parent_name = "interface-state-ons"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/interface-state-ons/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_state_on:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_state_on:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-state-ons" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-state-on"):
                        for c in self.interface_state_on:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_state_on.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-state-on"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class DetailGroups(Entity):
                """
                IGMP Detail Group Database
                
                .. attribute:: detail_group
                
                	IGMP Detail Group Entry Information
                	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.DetailGroups, self).__init__()

                    self.yang_name = "detail-groups"
                    self.yang_parent_name = "default-context"

                    self.detail_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.DetailGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.DetailGroups, self).__setattr__(name, value)


                class DetailGroup(Entity):
                    """
                    IGMP Detail Group Entry Information
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_host_exclude_mode
                    
                    	Group host filter mode
                    	**type**\:  bool
                    
                    .. attribute:: is_router_exclude_mode
                    
                    	Group router filter mode
                    	**type**\:  bool
                    
                    .. attribute:: source
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup, self).__init__()

                        self.yang_name = "detail-group"
                        self.yang_parent_name = "detail-groups"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                        self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "interface_name",
                                        "is_host_exclude_mode",
                                        "is_router_exclude_mode",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup, self).__setattr__(name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "detail-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix


                    class Source(Entity):
                        """
                        List of sources
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: flags
                        
                        	Source flags
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_forward
                        
                        	Should we forward on this entry
                        	**type**\:  bool
                        
                        .. attribute:: is_local
                        
                        	Is this a local source
                        	**type**\:  bool
                        
                        .. attribute:: is_remote
                        
                        	Is this a remote source
                        	**type**\:  bool
                        
                        .. attribute:: is_we_report
                        
                        	Should we report the source
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "detail-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.flags = YLeaf(YType.int32, "flags")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_forward = YLeaf(YType.boolean, "is-forward")

                            self.is_local = YLeaf(YType.boolean, "is-local")

                            self.is_remote = YLeaf(YType.boolean, "is-remote")

                            self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.source_address = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "flags",
                                            "is_added",
                                            "is_forward",
                                            "is_local",
                                            "is_remote",
                                            "is_we_report",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/source/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.flags.is_set or
                                self.is_added.is_set or
                                self.is_forward.is_set or
                                self.is_local.is_set or
                                self.is_remote.is_set or
                                self.is_we_report.is_set or
                                self.uptime.is_set or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.flags.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_forward.yfilter != YFilter.not_set or
                                self.is_local.yfilter != YFilter.not_set or
                                self.is_remote.yfilter != YFilter.not_set or
                                self.is_we_report.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flags.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_forward.is_set or self.is_forward.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_forward.get_name_leafdata())
                            if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_local.get_name_leafdata())
                            if (self.is_remote.is_set or self.is_remote.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_remote.get_name_leafdata())
                            if (self.is_we_report.is_set or self.is_we_report.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_we_report.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "expiration-time" or name == "flags" or name == "is-added" or name == "is-forward" or name == "is-local" or name == "is-remote" or name == "is-we-report" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "flags"):
                                self.flags = value
                                self.flags.value_namespace = name_space
                                self.flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-forward"):
                                self.is_forward = value
                                self.is_forward.value_namespace = name_space
                                self.is_forward.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-local"):
                                self.is_local = value
                                self.is_local.value_namespace = name_space
                                self.is_local.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-remote"):
                                self.is_remote = value
                                self.is_remote.value_namespace = name_space
                                self.is_remote.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-we-report"):
                                self.is_we_report = value
                                self.is_we_report.value_namespace = name_space
                                self.is_we_report.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.source:
                            if (c.has_data()):
                                return True
                        return (
                            self.group_address.is_set or
                            self.interface_name.is_set or
                            self.is_host_exclude_mode.is_set or
                            self.is_router_exclude_mode.is_set or
                            self.source_address.is_set or
                            (self.group_info is not None and self.group_info.has_data()))

                    def has_operation(self):
                        for c in self.source:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_host_exclude_mode.yfilter != YFilter.not_set or
                            self.is_router_exclude_mode.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group_info is not None and self.group_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "detail-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_host_exclude_mode.is_set or self.is_host_exclude_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_host_exclude_mode.get_name_leafdata())
                        if (self.is_router_exclude_mode.is_set or self.is_router_exclude_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_exclude_mode.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-info"):
                            if (self.group_info is None):
                                self.group_info = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                                self.group_info.parent = self
                                self._children_name_map["group_info"] = "group-info"
                            return self.group_info

                        if (child_yang_name == "source"):
                            for c in self.source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-info" or name == "source" or name == "group-address" or name == "interface-name" or name == "is-host-exclude-mode" or name == "is-router-exclude-mode" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-host-exclude-mode"):
                            self.is_host_exclude_mode = value
                            self.is_host_exclude_mode.value_namespace = name_space
                            self.is_host_exclude_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-exclude-mode"):
                            self.is_router_exclude_mode = value
                            self.is_router_exclude_mode.value_namespace = name_space
                            self.is_router_exclude_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.detail_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.detail_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "detail-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "detail-group"):
                        for c in self.detail_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.detail_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "detail-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NonActiveGroups(Entity):
                """
                IGMP Non\-Active Groups Information
                
                .. attribute:: non_active_groups
                
                	List of non\-active groups
                	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.NonActiveGroups, self).__init__()

                    self.yang_name = "non-active-groups"
                    self.yang_parent_name = "default-context"

                    self.non_active_groups = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.NonActiveGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.NonActiveGroups, self).__setattr__(name, value)


                class NonActiveGroups(Entity):
                    """
                    List of non\-active groups
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress>`
                    
                    .. attribute:: interface
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**length:** 0..65
                    
                    .. attribute:: reason_for_non_activity
                    
                    	Reason for group join not being processed
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "non-active-groups"

                        self.interface = YLeaf(YType.str, "interface")

                        self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                        self.group_address = Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                        self.source_address = Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface",
                                        "reason_for_non_activity") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "non-active-groups"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/non-active-groups/non-active-groups/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "non-active-groups"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/non-active-groups/non-active-groups/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface.is_set or
                            self.reason_for_non_activity.is_set or
                            (self.group_address is not None and self.group_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface.yfilter != YFilter.not_set or
                            self.reason_for_non_activity.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "non-active-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/non-active-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface.get_name_leafdata())
                        if (self.reason_for_non_activity.is_set or self.reason_for_non_activity.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reason_for_non_activity.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "source-address" or name == "interface" or name == "reason-for-non-activity"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface"):
                            self.interface = value
                            self.interface.value_namespace = name_space
                            self.interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "reason-for-non-activity"):
                            self.reason_for_non_activity = value
                            self.reason_for_non_activity.value_namespace = name_space
                            self.reason_for_non_activity.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.non_active_groups:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.non_active_groups:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "non-active-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "non-active-groups"):
                        for c in self.non_active_groups:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.non_active_groups.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "non-active-groups"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SsmMaps(Entity):
                """
                SSM Map Table
                
                .. attribute:: ssm_map
                
                	SSM Map information
                	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMaps.SsmMap>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.SsmMaps, self).__init__()

                    self.yang_name = "ssm-maps"
                    self.yang_parent_name = "default-context"

                    self.ssm_map = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.SsmMaps, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.SsmMaps, self).__setattr__(name, value)


                class SsmMap(Entity):
                    """
                    SSM Map information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr>`
                    
                    .. attribute:: map_type
                    
                    	Map Type of group
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_counts
                    
                    	Count of Sources
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.SsmMaps.SsmMap, self).__init__()

                        self.yang_name = "ssm-map"
                        self.yang_parent_name = "ssm-maps"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.map_type = YLeaf(YType.uint32, "map-type")

                        self.source_counts = YLeaf(YType.uint32, "source-counts")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.group_address_xr = Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "map_type",
                                        "source_counts",
                                        "ssm_map_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.SsmMaps.SsmMap, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.SsmMaps.SsmMap, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "ssm-map"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-maps/ssm-map/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.map_type.is_set or
                            self.source_counts.is_set or
                            self.ssm_map_type.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.map_type.yfilter != YFilter.not_set or
                            self.source_counts.yfilter != YFilter.not_set or
                            self.ssm_map_type.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-maps/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.map_type.get_name_leafdata())
                        if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_counts.get_name_leafdata())
                        if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "group-address" or name == "map-type" or name == "source-counts" or name == "ssm-map-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "map-type"):
                            self.map_type = value
                            self.map_type.value_namespace = name_space
                            self.map_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-counts"):
                            self.source_counts = value
                            self.source_counts.value_namespace = name_space
                            self.source_counts.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssm-map-type"):
                            self.ssm_map_type = value
                            self.ssm_map_type.value_namespace = name_space
                            self.ssm_map_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ssm_map:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ssm_map:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ssm-maps" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ssm-map"):
                        for c in self.ssm_map:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.SsmMaps.SsmMap()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ssm_map.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ssm-map"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class ExplicitGroups(Entity):
                """
                IGMP Explicit Group Database
                
                .. attribute:: explicit_group
                
                	IGMP Explicit Group Entry Information
                	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.ExplicitGroups, self).__init__()

                    self.yang_name = "explicit-groups"
                    self.yang_parent_name = "default-context"

                    self.explicit_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.ExplicitGroups, self).__setattr__(name, value)


                class ExplicitGroup(Entity):
                    """
                    IGMP Explicit Group Entry Information
                    
                    .. attribute:: exclude_hosts
                    
                    	No. of hosts who are excluded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo>`
                    
                    .. attribute:: host
                    
                    	List of hosts
                    	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host>`
                    
                    .. attribute:: include_hosts
                    
                    	No. of hosts who are included
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup, self).__init__()

                        self.yang_name = "explicit-group"
                        self.yang_parent_name = "explicit-groups"

                        self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.host = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("exclude_hosts",
                                        "group_address",
                                        "include_hosts",
                                        "interface_name",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "explicit-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix


                    class Host(Entity):
                        """
                        List of hosts
                        
                        .. attribute:: address
                        
                        	Host Address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address>`
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: is_exclude
                        
                        	Exclude flag set
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	First 3 source addresses
                        	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                        
                        .. attribute:: source_count
                        
                        	No. of sources in entry
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "explicit-group"

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                            self.source_count = YLeaf(YType.uint32, "source-count")

                            self.uptime = YLeaf(YType.uint32, "uptime")

                            self.address = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.source_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "is_exclude",
                                            "source_count",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            Host Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "host"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/host/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            First 3 source addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "host"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/host/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.source_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.expiration_time.is_set or
                                self.is_exclude.is_set or
                                self.source_count.is_set or
                                self.uptime.is_set or
                                (self.address is not None and self.address.has_data()))

                        def has_operation(self):
                            for c in self.source_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.is_exclude.yfilter != YFilter.not_set or
                                self.source_count.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "host" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.is_exclude.is_set or self.is_exclude.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_exclude.get_name_leafdata())
                            if (self.source_count.is_set or self.source_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_count.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "source-address"):
                                for c in self.source_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.source_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "source-address" or name == "expiration-time" or name == "is-exclude" or name == "source-count" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-exclude"):
                                self.is_exclude = value
                                self.is_exclude.value_namespace = name_space
                                self.is_exclude.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-count"):
                                self.source_count = value
                                self.source_count.value_namespace = name_space
                                self.source_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.host:
                            if (c.has_data()):
                                return True
                        return (
                            self.exclude_hosts.is_set or
                            self.group_address.is_set or
                            self.include_hosts.is_set or
                            self.interface_name.is_set or
                            self.source_address.is_set or
                            (self.group_info is not None and self.group_info.has_data()))

                    def has_operation(self):
                        for c in self.host:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.exclude_hosts.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.include_hosts.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group_info is not None and self.group_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "explicit-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.exclude_hosts.is_set or self.exclude_hosts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.exclude_hosts.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.include_hosts.is_set or self.include_hosts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.include_hosts.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-info"):
                            if (self.group_info is None):
                                self.group_info = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                                self.group_info.parent = self
                                self._children_name_map["group_info"] = "group-info"
                            return self.group_info

                        if (child_yang_name == "host"):
                            for c in self.host:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.host.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-info" or name == "host" or name == "exclude-hosts" or name == "group-address" or name == "include-hosts" or name == "interface-name" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "exclude-hosts"):
                            self.exclude_hosts = value
                            self.exclude_hosts.value_namespace = name_space
                            self.exclude_hosts.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "include-hosts"):
                            self.include_hosts = value
                            self.include_hosts.value_namespace = name_space
                            self.include_hosts.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.explicit_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.explicit_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "explicit-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "explicit-group"):
                        for c in self.explicit_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.explicit_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "explicit-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceTable(Entity):
                """
                IGMP Interface specific Table
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.InterfaceTable, self).__init__()

                    self.yang_name = "interface-table"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.InterfaceTable, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.InterfaceTable, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.InterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interface-table"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.InterfaceTable.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.InterfaceTable.Interface, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/interface-table/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.InterfaceTable.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceUnicastQosAdjusts(Entity):
                """
                IGMP Interface Unicast\-Qos\-Adjust
                
                .. attribute:: interface_unicast_qos_adjust
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts, self).__init__()

                    self.yang_name = "interface-unicast-qos-adjusts"
                    self.yang_parent_name = "default-context"

                    self.interface_unicast_qos_adjust = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)


                class InterfaceUnicastQosAdjust(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_virtual_access
                    
                    	Is VirtualAccess Interface
                    	**type**\:  bool
                    
                    .. attribute:: rate
                    
                    	Overall rate in Kbps
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: rate_decrements
                    
                    	Count of rate decrements
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rate_increments
                    
                    	Count of rate increments
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update
                    
                    	List of updates
                    	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjust"
                        self.yang_parent_name = "interface-unicast-qos-adjusts"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                        self.rate = YLeaf(YType.uint32, "rate")

                        self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                        self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                        self.update = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_virtual_access",
                                        "rate",
                                        "rate_decrements",
                                        "rate_increments") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)


                    class Update(Entity):
                        """
                        List of updates
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                        
                        .. attribute:: is_add
                        
                        	Is this a rate increment
                        	**type**\:  bool
                        
                        .. attribute:: received_time
                        
                        	Time this update is received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                        
                        .. attribute:: weight
                        
                        	Weight from policy
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                            self.yang_name = "update"
                            self.yang_parent_name = "interface-unicast-qos-adjust"

                            self.is_add = YLeaf(YType.boolean, "is-add")

                            self.received_time = YLeaf(YType.uint64, "received-time")

                            self.weight = YLeaf(YType.uint32, "weight")

                            self.group_address = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("is_add",
                                            "received_time",
                                            "weight") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "update"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddress(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "update"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.is_add.is_set or
                                self.received_time.is_set or
                                self.weight.is_set or
                                (self.group_address is not None and self.group_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.is_add.yfilter != YFilter.not_set or
                                self.received_time.yfilter != YFilter.not_set or
                                self.weight.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "update" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_add.is_set or self.is_add.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_add.get_name_leafdata())
                            if (self.received_time.is_set or self.received_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_time.get_name_leafdata())
                            if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.weight.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "source-address" or name == "is-add" or name == "received-time" or name == "weight"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "is-add"):
                                self.is_add = value
                                self.is_add.value_namespace = name_space
                                self.is_add.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-time"):
                                self.received_time = value
                                self.received_time.value_namespace = name_space
                                self.received_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "weight"):
                                self.weight = value
                                self.weight.value_namespace = name_space
                                self.weight.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.update:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.is_virtual_access.is_set or
                            self.rate.is_set or
                            self.rate_decrements.is_set or
                            self.rate_increments.is_set)

                    def has_operation(self):
                        for c in self.update:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_virtual_access.yfilter != YFilter.not_set or
                            self.rate.yfilter != YFilter.not_set or
                            self.rate_decrements.yfilter != YFilter.not_set or
                            self.rate_increments.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/interface-unicast-qos-adjusts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_virtual_access.is_set or self.is_virtual_access.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_virtual_access.get_name_leafdata())
                        if (self.rate.is_set or self.rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate.get_name_leafdata())
                        if (self.rate_decrements.is_set or self.rate_decrements.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate_decrements.get_name_leafdata())
                        if (self.rate_increments.is_set or self.rate_increments.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate_increments.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "update"):
                            for c in self.update:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.update.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "update" or name == "interface-name" or name == "is-virtual-access" or name == "rate" or name == "rate-decrements" or name == "rate-increments"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-virtual-access"):
                            self.is_virtual_access = value
                            self.is_virtual_access.value_namespace = name_space
                            self.is_virtual_access.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate"):
                            self.rate = value
                            self.rate.value_namespace = name_space
                            self.rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate-decrements"):
                            self.rate_decrements = value
                            self.rate_decrements.value_namespace = name_space
                            self.rate_decrements.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate-increments"):
                            self.rate_increments = value
                            self.rate_increments.value_namespace = name_space
                            self.rate_increments.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_unicast_qos_adjust:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_unicast_qos_adjust:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-unicast-qos-adjusts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-unicast-qos-adjust"):
                        for c in self.interface_unicast_qos_adjust:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_unicast_qos_adjust.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-unicast-qos-adjust"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Ranges(Entity):
                """
                Range table
                
                .. attribute:: range
                
                	Range information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"

                    self.range = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.Ranges, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.Ranges, self).__setattr__(name, value)


                class Range(Entity):
                    """
                    Range information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr>`
                    
                    .. attribute:: group_mask
                    
                    	Group Mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: is_stale
                    
                    	Is the entry stale
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.group_mask = YLeaf(YType.int32, "group-mask")

                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.group_address_xr = Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "group_mask",
                                        "is_stale",
                                        "prefix_length",
                                        "protocol") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.Ranges.Range, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.Ranges.Range, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.group_mask.is_set or
                            self.is_stale.is_set or
                            self.prefix_length.is_set or
                            self.protocol.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.group_mask.yfilter != YFilter.not_set or
                            self.is_stale.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ranges/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.group_mask.is_set or self.group_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_mask.get_name_leafdata())
                        if (self.is_stale.is_set or self.is_stale.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_stale.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "group-address" or name == "group-mask" or name == "is-stale" or name == "prefix-length" or name == "protocol"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-mask"):
                            self.group_mask = value
                            self.group_mask.value_namespace = name_space
                            self.group_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-stale"):
                            self.is_stale = value
                            self.is_stale.value_namespace = name_space
                            self.is_stale.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.range:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.range:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ranges" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "range"):
                        for c in self.range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.Ranges.Range()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.range.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "range"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsInterfaces(Entity):
                """
                IGMP Interface specific
                
                .. attribute:: ifrs_interface
                
                	IGMP IFRS Interface
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"

                    self.ifrs_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)


                class IfrsInterface(Entity):
                    """
                    IGMP IFRS Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	IFRS Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: igmp_interface_entry
                    
                    	IGMP interface entry
                    	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                    
                    .. attribute:: join_group_count
                    
                    	Join group count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                        self.igmp_interface_entry = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                        self.igmp_interface_entry.parent = self
                        self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                        self._children_yang_names.add("igmp-interface-entry")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "join_group_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                    class IgmpInterfaceEntry(Entity):
                        """
                        IGMP interface entry
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                            self.yang_name = "igmp-interface-entry"
                            self.yang_parent_name = "ifrs-interface"

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "igmp-interface-entry" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.join_group_count.is_set or
                            (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.join_group_count.yfilter != YFilter.not_set or
                            (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ifrs-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.join_group_count.is_set or self.join_group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_group_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "igmp-interface-entry"):
                            if (self.igmp_interface_entry is None):
                                self.igmp_interface_entry = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                                self.igmp_interface_entry.parent = self
                                self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            return self.igmp_interface_entry

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "igmp-interface-entry" or name == "interface-name" or name == "join-group-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-group-count"):
                            self.join_group_count = value
                            self.join_group_count.value_namespace = name_space
                            self.join_group_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ifrs_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ifrs_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ifrs-interface"):
                        for c in self.ifrs_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ifrs_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ifrs-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TrafficCounters(Entity):
                """
                IGMP Message Traffic Counters
                
                .. attribute:: auxillary_data_length_errors
                
                	AuxDataLen errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bad_scope_errors
                
                	BadScope errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_errors
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_errors
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: get_packet_failure
                
                	Packet get failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_disabled_idb
                
                	Packet received on disabled idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_dvmrp
                
                	DVMRP packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_leaves
                
                	Leaves in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_martian_address
                
                	Packets received with Martian Address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_mtrace
                
                	Mtrace packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_assigned_vrf_id
                
                	Packets received with no assigned vrf id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb
                
                	Packets received without idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_platform_support_mtrace
                
                	mtrace packets without platform support
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_in_idb
                
                	Packets received on idb without VRF
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_mtrace
                
                	mtrace packets with no vrf associated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim
                
                	PIM packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_queries
                
                	Query packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_reports
                
                	Reports in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_address_errors
                
                	Invalid Source Address errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: miscellaneous_errors
                
                	Packets dropped for other reasons
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_dvmrp
                
                	DVMRP packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_leaves
                
                	Leaves out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_mtrace
                
                	Mtrace packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_no_parent_interface_handle
                
                	Failures setting 2nd ifhandle
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_pim
                
                	PIM packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_queries
                
                	Query packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_reports
                
                	Reports out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_input_errors
                
                	Incoming Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_output_errors
                
                	Outgoing Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_in
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_out
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_socket_errors
                
                	Socket errors on reception
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_errors
                
                	Socket errors on send
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"

                    self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                    self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                    self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_errors = YLeaf(YType.uint32, "format-errors")

                    self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                    self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                    self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                    self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                    self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                    self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                    self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                    self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                    self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                    self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                    self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                    self.input_pim = YLeaf(YType.uint32, "input-pim")

                    self.input_queries = YLeaf(YType.uint32, "input-queries")

                    self.input_reports = YLeaf(YType.uint32, "input-reports")

                    self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                    self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                    self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                    self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                    self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                    self.output_pim = YLeaf(YType.uint32, "output-pim")

                    self.output_queries = YLeaf(YType.uint32, "output-queries")

                    self.output_reports = YLeaf(YType.uint32, "output-reports")

                    self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                    self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                    self.packets_in = YLeaf(YType.uint32, "packets-in")

                    self.packets_out = YLeaf(YType.uint32, "packets-out")

                    self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                    self.socket_errors = YLeaf(YType.uint32, "socket-errors")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("auxillary_data_length_errors",
                                    "bad_scope_errors",
                                    "checksum_errors",
                                    "elapsed_time",
                                    "format_errors",
                                    "get_packet_failure",
                                    "input_disabled_idb",
                                    "input_dvmrp",
                                    "input_leaves",
                                    "input_martian_address",
                                    "input_mtrace",
                                    "input_no_assigned_vrf_id",
                                    "input_no_idb",
                                    "input_no_platform_support_mtrace",
                                    "input_no_vrf_in_idb",
                                    "input_no_vrf_mtrace",
                                    "input_pim",
                                    "input_queries",
                                    "input_reports",
                                    "invalid_source_address_errors",
                                    "miscellaneous_errors",
                                    "no_socket_connection",
                                    "output_dvmrp",
                                    "output_leaves",
                                    "output_mtrace",
                                    "output_no_parent_interface_handle",
                                    "output_pim",
                                    "output_queries",
                                    "output_reports",
                                    "packet_manager_input_errors",
                                    "packet_manager_output_errors",
                                    "packets_in",
                                    "packets_out",
                                    "receive_socket_errors",
                                    "socket_errors") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.TrafficCounters, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.TrafficCounters, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.auxillary_data_length_errors.is_set or
                        self.bad_scope_errors.is_set or
                        self.checksum_errors.is_set or
                        self.elapsed_time.is_set or
                        self.format_errors.is_set or
                        self.get_packet_failure.is_set or
                        self.input_disabled_idb.is_set or
                        self.input_dvmrp.is_set or
                        self.input_leaves.is_set or
                        self.input_martian_address.is_set or
                        self.input_mtrace.is_set or
                        self.input_no_assigned_vrf_id.is_set or
                        self.input_no_idb.is_set or
                        self.input_no_platform_support_mtrace.is_set or
                        self.input_no_vrf_in_idb.is_set or
                        self.input_no_vrf_mtrace.is_set or
                        self.input_pim.is_set or
                        self.input_queries.is_set or
                        self.input_reports.is_set or
                        self.invalid_source_address_errors.is_set or
                        self.miscellaneous_errors.is_set or
                        self.no_socket_connection.is_set or
                        self.output_dvmrp.is_set or
                        self.output_leaves.is_set or
                        self.output_mtrace.is_set or
                        self.output_no_parent_interface_handle.is_set or
                        self.output_pim.is_set or
                        self.output_queries.is_set or
                        self.output_reports.is_set or
                        self.packet_manager_input_errors.is_set or
                        self.packet_manager_output_errors.is_set or
                        self.packets_in.is_set or
                        self.packets_out.is_set or
                        self.receive_socket_errors.is_set or
                        self.socket_errors.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.auxillary_data_length_errors.yfilter != YFilter.not_set or
                        self.bad_scope_errors.yfilter != YFilter.not_set or
                        self.checksum_errors.yfilter != YFilter.not_set or
                        self.elapsed_time.yfilter != YFilter.not_set or
                        self.format_errors.yfilter != YFilter.not_set or
                        self.get_packet_failure.yfilter != YFilter.not_set or
                        self.input_disabled_idb.yfilter != YFilter.not_set or
                        self.input_dvmrp.yfilter != YFilter.not_set or
                        self.input_leaves.yfilter != YFilter.not_set or
                        self.input_martian_address.yfilter != YFilter.not_set or
                        self.input_mtrace.yfilter != YFilter.not_set or
                        self.input_no_assigned_vrf_id.yfilter != YFilter.not_set or
                        self.input_no_idb.yfilter != YFilter.not_set or
                        self.input_no_platform_support_mtrace.yfilter != YFilter.not_set or
                        self.input_no_vrf_in_idb.yfilter != YFilter.not_set or
                        self.input_no_vrf_mtrace.yfilter != YFilter.not_set or
                        self.input_pim.yfilter != YFilter.not_set or
                        self.input_queries.yfilter != YFilter.not_set or
                        self.input_reports.yfilter != YFilter.not_set or
                        self.invalid_source_address_errors.yfilter != YFilter.not_set or
                        self.miscellaneous_errors.yfilter != YFilter.not_set or
                        self.no_socket_connection.yfilter != YFilter.not_set or
                        self.output_dvmrp.yfilter != YFilter.not_set or
                        self.output_leaves.yfilter != YFilter.not_set or
                        self.output_mtrace.yfilter != YFilter.not_set or
                        self.output_no_parent_interface_handle.yfilter != YFilter.not_set or
                        self.output_pim.yfilter != YFilter.not_set or
                        self.output_queries.yfilter != YFilter.not_set or
                        self.output_reports.yfilter != YFilter.not_set or
                        self.packet_manager_input_errors.yfilter != YFilter.not_set or
                        self.packet_manager_output_errors.yfilter != YFilter.not_set or
                        self.packets_in.yfilter != YFilter.not_set or
                        self.packets_out.yfilter != YFilter.not_set or
                        self.receive_socket_errors.yfilter != YFilter.not_set or
                        self.socket_errors.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-counters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.auxillary_data_length_errors.is_set or self.auxillary_data_length_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.auxillary_data_length_errors.get_name_leafdata())
                    if (self.bad_scope_errors.is_set or self.bad_scope_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bad_scope_errors.get_name_leafdata())
                    if (self.checksum_errors.is_set or self.checksum_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checksum_errors.get_name_leafdata())
                    if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                    if (self.format_errors.is_set or self.format_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.format_errors.get_name_leafdata())
                    if (self.get_packet_failure.is_set or self.get_packet_failure.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.get_packet_failure.get_name_leafdata())
                    if (self.input_disabled_idb.is_set or self.input_disabled_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_disabled_idb.get_name_leafdata())
                    if (self.input_dvmrp.is_set or self.input_dvmrp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_dvmrp.get_name_leafdata())
                    if (self.input_leaves.is_set or self.input_leaves.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_leaves.get_name_leafdata())
                    if (self.input_martian_address.is_set or self.input_martian_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_martian_address.get_name_leafdata())
                    if (self.input_mtrace.is_set or self.input_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_mtrace.get_name_leafdata())
                    if (self.input_no_assigned_vrf_id.is_set or self.input_no_assigned_vrf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_assigned_vrf_id.get_name_leafdata())
                    if (self.input_no_idb.is_set or self.input_no_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_idb.get_name_leafdata())
                    if (self.input_no_platform_support_mtrace.is_set or self.input_no_platform_support_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_platform_support_mtrace.get_name_leafdata())
                    if (self.input_no_vrf_in_idb.is_set or self.input_no_vrf_in_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_in_idb.get_name_leafdata())
                    if (self.input_no_vrf_mtrace.is_set or self.input_no_vrf_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_mtrace.get_name_leafdata())
                    if (self.input_pim.is_set or self.input_pim.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_pim.get_name_leafdata())
                    if (self.input_queries.is_set or self.input_queries.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_queries.get_name_leafdata())
                    if (self.input_reports.is_set or self.input_reports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_reports.get_name_leafdata())
                    if (self.invalid_source_address_errors.is_set or self.invalid_source_address_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_source_address_errors.get_name_leafdata())
                    if (self.miscellaneous_errors.is_set or self.miscellaneous_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.miscellaneous_errors.get_name_leafdata())
                    if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                    if (self.output_dvmrp.is_set or self.output_dvmrp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_dvmrp.get_name_leafdata())
                    if (self.output_leaves.is_set or self.output_leaves.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_leaves.get_name_leafdata())
                    if (self.output_mtrace.is_set or self.output_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_mtrace.get_name_leafdata())
                    if (self.output_no_parent_interface_handle.is_set or self.output_no_parent_interface_handle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_no_parent_interface_handle.get_name_leafdata())
                    if (self.output_pim.is_set or self.output_pim.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_pim.get_name_leafdata())
                    if (self.output_queries.is_set or self.output_queries.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_queries.get_name_leafdata())
                    if (self.output_reports.is_set or self.output_reports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_reports.get_name_leafdata())
                    if (self.packet_manager_input_errors.is_set or self.packet_manager_input_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_manager_input_errors.get_name_leafdata())
                    if (self.packet_manager_output_errors.is_set or self.packet_manager_output_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_manager_output_errors.get_name_leafdata())
                    if (self.packets_in.is_set or self.packets_in.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_in.get_name_leafdata())
                    if (self.packets_out.is_set or self.packets_out.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_out.get_name_leafdata())
                    if (self.receive_socket_errors.is_set or self.receive_socket_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.receive_socket_errors.get_name_leafdata())
                    if (self.socket_errors.is_set or self.socket_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.socket_errors.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auxillary-data-length-errors" or name == "bad-scope-errors" or name == "checksum-errors" or name == "elapsed-time" or name == "format-errors" or name == "get-packet-failure" or name == "input-disabled-idb" or name == "input-dvmrp" or name == "input-leaves" or name == "input-martian-address" or name == "input-mtrace" or name == "input-no-assigned-vrf-id" or name == "input-no-idb" or name == "input-no-platform-support-mtrace" or name == "input-no-vrf-in-idb" or name == "input-no-vrf-mtrace" or name == "input-pim" or name == "input-queries" or name == "input-reports" or name == "invalid-source-address-errors" or name == "miscellaneous-errors" or name == "no-socket-connection" or name == "output-dvmrp" or name == "output-leaves" or name == "output-mtrace" or name == "output-no-parent-interface-handle" or name == "output-pim" or name == "output-queries" or name == "output-reports" or name == "packet-manager-input-errors" or name == "packet-manager-output-errors" or name == "packets-in" or name == "packets-out" or name == "receive-socket-errors" or name == "socket-errors"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "auxillary-data-length-errors"):
                        self.auxillary_data_length_errors = value
                        self.auxillary_data_length_errors.value_namespace = name_space
                        self.auxillary_data_length_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "bad-scope-errors"):
                        self.bad_scope_errors = value
                        self.bad_scope_errors.value_namespace = name_space
                        self.bad_scope_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "checksum-errors"):
                        self.checksum_errors = value
                        self.checksum_errors.value_namespace = name_space
                        self.checksum_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "elapsed-time"):
                        self.elapsed_time = value
                        self.elapsed_time.value_namespace = name_space
                        self.elapsed_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "format-errors"):
                        self.format_errors = value
                        self.format_errors.value_namespace = name_space
                        self.format_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "get-packet-failure"):
                        self.get_packet_failure = value
                        self.get_packet_failure.value_namespace = name_space
                        self.get_packet_failure.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-disabled-idb"):
                        self.input_disabled_idb = value
                        self.input_disabled_idb.value_namespace = name_space
                        self.input_disabled_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-dvmrp"):
                        self.input_dvmrp = value
                        self.input_dvmrp.value_namespace = name_space
                        self.input_dvmrp.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-leaves"):
                        self.input_leaves = value
                        self.input_leaves.value_namespace = name_space
                        self.input_leaves.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-martian-address"):
                        self.input_martian_address = value
                        self.input_martian_address.value_namespace = name_space
                        self.input_martian_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-mtrace"):
                        self.input_mtrace = value
                        self.input_mtrace.value_namespace = name_space
                        self.input_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-assigned-vrf-id"):
                        self.input_no_assigned_vrf_id = value
                        self.input_no_assigned_vrf_id.value_namespace = name_space
                        self.input_no_assigned_vrf_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-idb"):
                        self.input_no_idb = value
                        self.input_no_idb.value_namespace = name_space
                        self.input_no_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-platform-support-mtrace"):
                        self.input_no_platform_support_mtrace = value
                        self.input_no_platform_support_mtrace.value_namespace = name_space
                        self.input_no_platform_support_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-in-idb"):
                        self.input_no_vrf_in_idb = value
                        self.input_no_vrf_in_idb.value_namespace = name_space
                        self.input_no_vrf_in_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-mtrace"):
                        self.input_no_vrf_mtrace = value
                        self.input_no_vrf_mtrace.value_namespace = name_space
                        self.input_no_vrf_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-pim"):
                        self.input_pim = value
                        self.input_pim.value_namespace = name_space
                        self.input_pim.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-queries"):
                        self.input_queries = value
                        self.input_queries.value_namespace = name_space
                        self.input_queries.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-reports"):
                        self.input_reports = value
                        self.input_reports.value_namespace = name_space
                        self.input_reports.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-source-address-errors"):
                        self.invalid_source_address_errors = value
                        self.invalid_source_address_errors.value_namespace = name_space
                        self.invalid_source_address_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "miscellaneous-errors"):
                        self.miscellaneous_errors = value
                        self.miscellaneous_errors.value_namespace = name_space
                        self.miscellaneous_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-socket-connection"):
                        self.no_socket_connection = value
                        self.no_socket_connection.value_namespace = name_space
                        self.no_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-dvmrp"):
                        self.output_dvmrp = value
                        self.output_dvmrp.value_namespace = name_space
                        self.output_dvmrp.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-leaves"):
                        self.output_leaves = value
                        self.output_leaves.value_namespace = name_space
                        self.output_leaves.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-mtrace"):
                        self.output_mtrace = value
                        self.output_mtrace.value_namespace = name_space
                        self.output_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-no-parent-interface-handle"):
                        self.output_no_parent_interface_handle = value
                        self.output_no_parent_interface_handle.value_namespace = name_space
                        self.output_no_parent_interface_handle.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-pim"):
                        self.output_pim = value
                        self.output_pim.value_namespace = name_space
                        self.output_pim.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-queries"):
                        self.output_queries = value
                        self.output_queries.value_namespace = name_space
                        self.output_queries.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-reports"):
                        self.output_reports = value
                        self.output_reports.value_namespace = name_space
                        self.output_reports.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-manager-input-errors"):
                        self.packet_manager_input_errors = value
                        self.packet_manager_input_errors.value_namespace = name_space
                        self.packet_manager_input_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-manager-output-errors"):
                        self.packet_manager_output_errors = value
                        self.packet_manager_output_errors.value_namespace = name_space
                        self.packet_manager_output_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "packets-in"):
                        self.packets_in = value
                        self.packets_in.value_namespace = name_space
                        self.packets_in.value_namespace_prefix = name_space_prefix
                    if(value_path == "packets-out"):
                        self.packets_out = value
                        self.packets_out.value_namespace = name_space
                        self.packets_out.value_namespace_prefix = name_space_prefix
                    if(value_path == "receive-socket-errors"):
                        self.receive_socket_errors = value
                        self.receive_socket_errors.value_namespace = name_space
                        self.receive_socket_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "socket-errors"):
                        self.socket_errors = value
                        self.socket_errors.value_namespace = name_space
                        self.socket_errors.value_namespace_prefix = name_space_prefix


            class Groups(Entity):
                """
                IGMP Group Database Table
                
                .. attribute:: group
                
                	IGMP Group Entry Information
                	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Groups.Group>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.Groups, self).__init__()

                    self.yang_name = "groups"
                    self.yang_parent_name = "default-context"

                    self.group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.Groups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.Groups, self).__setattr__(name, value)


                class Group(Entity):
                    """
                    IGMP Group Entry Information
                    
                    .. attribute:: expiration_time
                    
                    	Expiration time in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: explicit_tracking_enabled
                    
                    	Is explicit tracking enabled
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_added
                    
                    	Joined
                    	**type**\:  bool
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: is_self_join
                    
                    	If local system is member of this group on this interface
                    	**type**\:  bool
                    
                    .. attribute:: is_suppressed
                    
                    	Suppressed
                    	**type**\:  bool
                    
                    .. attribute:: last_reporter
                    
                    	Last reporter address
                    	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Groups.Group.LastReporter>`
                    
                    .. attribute:: older_host_version1_timer
                    
                    	IGMP Hostversion1timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: older_host_version2_timer
                    
                    	IGMP Hostversion2timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_filter_mode
                    
                    	Filter mode
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: row_status
                    
                    	interface on or off for the group
                    	**type**\:  str
                    
                    	**length:** 0..16
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Groups.Group.SourceAddress>`
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.Groups.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "groups"

                        self.expiration_time = YLeaf(YType.int32, "expiration-time")

                        self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_added = YLeaf(YType.boolean, "is-added")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                        self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                        self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                        self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                        self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                        self.row_status = YLeaf(YType.str, "row-status")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.last_reporter = Igmp.Standby.DefaultContext.Groups.Group.LastReporter()
                        self.last_reporter.parent = self
                        self._children_name_map["last_reporter"] = "last-reporter"
                        self._children_yang_names.add("last-reporter")

                        self.source_address = Igmp.Standby.DefaultContext.Groups.Group.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("expiration_time",
                                        "explicit_tracking_enabled",
                                        "group_address",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_added",
                                        "is_low_memory",
                                        "is_self_join",
                                        "is_suppressed",
                                        "older_host_version1_timer",
                                        "older_host_version2_timer",
                                        "router_filter_mode",
                                        "row_status",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.Groups.Group, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.Groups.Group, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class LastReporter(Entity):
                        """
                        Last reporter address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.Groups.Group.LastReporter, self).__init__()

                            self.yang_name = "last-reporter"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.Groups.Group.LastReporter, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.Groups.Group.LastReporter, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "last-reporter" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.Groups.Group.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.Groups.Group.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.Groups.Group.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.expiration_time.is_set or
                            self.explicit_tracking_enabled.is_set or
                            self.group_address.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_added.is_set or
                            self.is_low_memory.is_set or
                            self.is_self_join.is_set or
                            self.is_suppressed.is_set or
                            self.older_host_version1_timer.is_set or
                            self.older_host_version2_timer.is_set or
                            self.router_filter_mode.is_set or
                            self.row_status.is_set or
                            self.uptime.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.last_reporter is not None and self.last_reporter.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.expiration_time.yfilter != YFilter.not_set or
                            self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_added.yfilter != YFilter.not_set or
                            self.is_low_memory.yfilter != YFilter.not_set or
                            self.is_self_join.yfilter != YFilter.not_set or
                            self.is_suppressed.yfilter != YFilter.not_set or
                            self.older_host_version1_timer.yfilter != YFilter.not_set or
                            self.older_host_version2_timer.yfilter != YFilter.not_set or
                            self.router_filter_mode.yfilter != YFilter.not_set or
                            self.row_status.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.last_reporter is not None and self.last_reporter.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiration_time.get_name_leafdata())
                        if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_added.get_name_leafdata())
                        if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                        if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_self_join.get_name_leafdata())
                        if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                        if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                        if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                        if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                        if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.row_status.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "last-reporter"):
                            if (self.last_reporter is None):
                                self.last_reporter = Igmp.Standby.DefaultContext.Groups.Group.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                            return self.last_reporter

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Igmp.Standby.DefaultContext.Groups.Group.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "group-address" or name == "interface-name" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "expiration-time"):
                            self.expiration_time = value
                            self.expiration_time.value_namespace = name_space
                            self.expiration_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "explicit-tracking-enabled"):
                            self.explicit_tracking_enabled = value
                            self.explicit_tracking_enabled.value_namespace = name_space
                            self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-added"):
                            self.is_added = value
                            self.is_added.value_namespace = name_space
                            self.is_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-low-memory"):
                            self.is_low_memory = value
                            self.is_low_memory.value_namespace = name_space
                            self.is_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-self-join"):
                            self.is_self_join = value
                            self.is_self_join.value_namespace = name_space
                            self.is_self_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-suppressed"):
                            self.is_suppressed = value
                            self.is_suppressed.value_namespace = name_space
                            self.is_suppressed.value_namespace_prefix = name_space_prefix
                        if(value_path == "older-host-version1-timer"):
                            self.older_host_version1_timer = value
                            self.older_host_version1_timer.value_namespace = name_space
                            self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "older-host-version2-timer"):
                            self.older_host_version2_timer = value
                            self.older_host_version2_timer.value_namespace = name_space
                            self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-filter-mode"):
                            self.router_filter_mode = value
                            self.router_filter_mode.value_namespace = name_space
                            self.router_filter_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "row-status"):
                            self.row_status = value
                            self.row_status.value_namespace = name_space
                            self.row_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group"):
                        for c in self.group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.Groups.Group()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupSummary(Entity):
                """
                IGMP Groups Summary
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groutes
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_low_memory
                
                	Node is running low on memory
                	**type**\:  bool
                
                .. attribute:: sg_routes
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.GroupSummary, self).__init__()

                    self.yang_name = "group-summary"
                    self.yang_parent_name = "default-context"

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.groutes = YLeaf(YType.uint32, "groutes")

                    self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                    self.sg_routes = YLeaf(YType.uint32, "sg-routes")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_count",
                                    "groutes",
                                    "is_low_memory",
                                    "sg_routes") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.GroupSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.GroupSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.group_count.is_set or
                        self.groutes.is_set or
                        self.is_low_memory.is_set or
                        self.sg_routes.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_count.yfilter != YFilter.not_set or
                        self.groutes.yfilter != YFilter.not_set or
                        self.is_low_memory.yfilter != YFilter.not_set or
                        self.sg_routes.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_count.get_name_leafdata())
                    if (self.groutes.is_set or self.groutes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.groutes.get_name_leafdata())
                    if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                    if (self.sg_routes.is_set or self.sg_routes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_routes.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-count" or name == "groutes" or name == "is-low-memory" or name == "sg-routes"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-count"):
                        self.group_count = value
                        self.group_count.value_namespace = name_space
                        self.group_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "groutes"):
                        self.groutes = value
                        self.groutes.value_namespace = name_space
                        self.groutes.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-low-memory"):
                        self.is_low_memory = value
                        self.is_low_memory.value_namespace = name_space
                        self.is_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-routes"):
                        self.sg_routes = value
                        self.sg_routes.value_namespace = name_space
                        self.sg_routes.value_namespace_prefix = name_space_prefix


            class IfrsInterfaceSummary(Entity):
                """
                IGMP IFRS Interface summary
                
                .. attribute:: configuration_count
                
                	Configuration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Interface Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.IfrsInterfaceSummary, self).__init__()

                    self.yang_name = "ifrs-interface-summary"
                    self.yang_parent_name = "default-context"

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configuration_count",
                                    "interface_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.IfrsInterfaceSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.IfrsInterfaceSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configuration_count.is_set or
                        self.interface_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configuration_count.yfilter != YFilter.not_set or
                        self.interface_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interface-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configuration_count.get_name_leafdata())
                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configuration-count" or name == "interface-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configuration-count"):
                        self.configuration_count = value
                        self.configuration_count.value_namespace = name_space
                        self.configuration_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-count"):
                        self.interface_count = value
                        self.interface_count.value_namespace = name_space
                        self.interface_count.value_namespace_prefix = name_space_prefix


            class GlobalInterfaceTable(Entity):
                """
                IGMP Global Interface 
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.GlobalInterfaceTable, self).__init__()

                    self.yang_name = "global-interface-table"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.GlobalInterfaceTable, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.GlobalInterfaceTable, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "global-interface-table"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/global-interface-table/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-interface-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SsmMapDetails(Entity):
                """
                SSM Map Detail
                
                .. attribute:: ssm_map_detail
                
                	SSM Map Detail Table information
                	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.SsmMapDetails, self).__init__()

                    self.yang_name = "ssm-map-details"
                    self.yang_parent_name = "default-context"

                    self.ssm_map_detail = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.SsmMapDetails, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.SsmMapDetails, self).__setattr__(name, value)


                class SsmMapDetail(Entity):
                    """
                    SSM Map Detail Table information
                    
                    .. attribute:: elapsed_time
                    
                    	Elapsed time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: expiration_time
                    
                    	Expiration Time in Seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: map_info
                    
                    	Basic Map Info
                    	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo>`
                    
                    .. attribute:: query_interval
                    
                    	Query interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response_pending
                    
                    	Response Pending
                    	**type**\:  bool
                    
                    .. attribute:: sources
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources>`
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail, self).__init__()

                        self.yang_name = "ssm-map-detail"
                        self.yang_parent_name = "ssm-map-details"

                        self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                        self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.query_interval = YLeaf(YType.uint32, "query-interval")

                        self.response_pending = YLeaf(YType.boolean, "response-pending")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.map_info = Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                        self.map_info.parent = self
                        self._children_name_map["map_info"] = "map-info"
                        self._children_yang_names.add("map-info")

                        self.sources = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("elapsed_time",
                                        "expiration_time",
                                        "group_address",
                                        "query_interval",
                                        "response_pending",
                                        "ssm_map_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)


                    class MapInfo(Entity):
                        """
                        Basic Map Info
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                            self.yang_name = "map-info"
                            self.yang_parent_name = "ssm-map-detail"

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.group_address_xr = Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("map_type",
                                            "source_counts") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "map-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-map-details/ssm-map-detail/map-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.map_type.is_set or
                                self.source_counts.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.map_type.yfilter != YFilter.not_set or
                                self.source_counts.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "map-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-map-details/ssm-map-detail/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.map_type.get_name_leafdata())
                            if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_counts.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "map-type" or name == "source-counts"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "map-type"):
                                self.map_type = value
                                self.map_type.value_namespace = name_space
                                self.map_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-counts"):
                                self.source_counts = value
                                self.source_counts.value_namespace = name_space
                                self.source_counts.value_namespace_prefix = name_space_prefix


                    class Sources(Entity):
                        """
                        List of sources
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                            self.yang_name = "sources"
                            self.yang_parent_name = "ssm-map-detail"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sources" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-map-details/ssm-map-detail/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.sources:
                            if (c.has_data()):
                                return True
                        return (
                            self.elapsed_time.is_set or
                            self.expiration_time.is_set or
                            self.group_address.is_set or
                            self.query_interval.is_set or
                            self.response_pending.is_set or
                            self.ssm_map_type.is_set or
                            (self.map_info is not None and self.map_info.has_data()))

                    def has_operation(self):
                        for c in self.sources:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.expiration_time.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.response_pending.yfilter != YFilter.not_set or
                            self.ssm_map_type.yfilter != YFilter.not_set or
                            (self.map_info is not None and self.map_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map-detail" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-map-details/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiration_time.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.response_pending.is_set or self.response_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response_pending.get_name_leafdata())
                        if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "map-info"):
                            if (self.map_info is None):
                                self.map_info = Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                                self.map_info.parent = self
                                self._children_name_map["map_info"] = "map-info"
                            return self.map_info

                        if (child_yang_name == "sources"):
                            for c in self.sources:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.sources.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "map-info" or name == "sources" or name == "elapsed-time" or name == "expiration-time" or name == "group-address" or name == "query-interval" or name == "response-pending" or name == "ssm-map-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiration-time"):
                            self.expiration_time = value
                            self.expiration_time.value_namespace = name_space
                            self.expiration_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "response-pending"):
                            self.response_pending = value
                            self.response_pending.value_namespace = name_space
                            self.response_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssm-map-type"):
                            self.ssm_map_type = value
                            self.ssm_map_type.value_namespace = name_space
                            self.ssm_map_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ssm_map_detail:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ssm_map_detail:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ssm-map-details" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ssm-map-detail"):
                        for c in self.ssm_map_detail:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ssm_map_detail.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ssm-map-detail"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceStateOffs(Entity):
                """
                IGMP Interface state off
                
                .. attribute:: interface_state_off
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.InterfaceStateOffs, self).__init__()

                    self.yang_name = "interface-state-offs"
                    self.yang_parent_name = "default-context"

                    self.interface_state_off = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Standby.DefaultContext.InterfaceStateOffs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Standby.DefaultContext.InterfaceStateOffs, self).__setattr__(name, value)


                class InterfaceStateOff(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                        self.yang_name = "interface-state-off"
                        self.yang_parent_name = "interface-state-offs"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/interface-state-offs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_state_off:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_state_off:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-state-offs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-state-off"):
                        for c in self.interface_state_off:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_state_off.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-state-off"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.detail_groups is not None and self.detail_groups.has_data()) or
                    (self.explicit_groups is not None and self.explicit_groups.has_data()) or
                    (self.global_interface_table is not None and self.global_interface_table.has_data()) or
                    (self.group_summary is not None and self.group_summary.has_data()) or
                    (self.groups is not None and self.groups.has_data()) or
                    (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_data()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                    (self.interface_state_offs is not None and self.interface_state_offs.has_data()) or
                    (self.interface_state_ons is not None and self.interface_state_ons.has_data()) or
                    (self.interface_table is not None and self.interface_table.has_data()) or
                    (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_data()) or
                    (self.non_active_groups is not None and self.non_active_groups.has_data()) or
                    (self.ranges is not None and self.ranges.has_data()) or
                    (self.ssm_map_details is not None and self.ssm_map_details.has_data()) or
                    (self.ssm_maps is not None and self.ssm_maps.has_data()) or
                    (self.summary is not None and self.summary.has_data()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.detail_groups is not None and self.detail_groups.has_operation()) or
                    (self.explicit_groups is not None and self.explicit_groups.has_operation()) or
                    (self.global_interface_table is not None and self.global_interface_table.has_operation()) or
                    (self.group_summary is not None and self.group_summary.has_operation()) or
                    (self.groups is not None and self.groups.has_operation()) or
                    (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_operation()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                    (self.interface_state_offs is not None and self.interface_state_offs.has_operation()) or
                    (self.interface_state_ons is not None and self.interface_state_ons.has_operation()) or
                    (self.interface_table is not None and self.interface_table.has_operation()) or
                    (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_operation()) or
                    (self.non_active_groups is not None and self.non_active_groups.has_operation()) or
                    (self.ranges is not None and self.ranges.has_operation()) or
                    (self.ssm_map_details is not None and self.ssm_map_details.has_operation()) or
                    (self.ssm_maps is not None and self.ssm_maps.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "default-context" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "detail-groups"):
                    if (self.detail_groups is None):
                        self.detail_groups = Igmp.Standby.DefaultContext.DetailGroups()
                        self.detail_groups.parent = self
                        self._children_name_map["detail_groups"] = "detail-groups"
                    return self.detail_groups

                if (child_yang_name == "explicit-groups"):
                    if (self.explicit_groups is None):
                        self.explicit_groups = Igmp.Standby.DefaultContext.ExplicitGroups()
                        self.explicit_groups.parent = self
                        self._children_name_map["explicit_groups"] = "explicit-groups"
                    return self.explicit_groups

                if (child_yang_name == "global-interface-table"):
                    if (self.global_interface_table is None):
                        self.global_interface_table = Igmp.Standby.DefaultContext.GlobalInterfaceTable()
                        self.global_interface_table.parent = self
                        self._children_name_map["global_interface_table"] = "global-interface-table"
                    return self.global_interface_table

                if (child_yang_name == "group-summary"):
                    if (self.group_summary is None):
                        self.group_summary = Igmp.Standby.DefaultContext.GroupSummary()
                        self.group_summary.parent = self
                        self._children_name_map["group_summary"] = "group-summary"
                    return self.group_summary

                if (child_yang_name == "groups"):
                    if (self.groups is None):
                        self.groups = Igmp.Standby.DefaultContext.Groups()
                        self.groups.parent = self
                        self._children_name_map["groups"] = "groups"
                    return self.groups

                if (child_yang_name == "ifrs-interface-summary"):
                    if (self.ifrs_interface_summary is None):
                        self.ifrs_interface_summary = Igmp.Standby.DefaultContext.IfrsInterfaceSummary()
                        self.ifrs_interface_summary.parent = self
                        self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    return self.ifrs_interface_summary

                if (child_yang_name == "ifrs-interfaces"):
                    if (self.ifrs_interfaces is None):
                        self.ifrs_interfaces = Igmp.Standby.DefaultContext.IfrsInterfaces()
                        self.ifrs_interfaces.parent = self
                        self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    return self.ifrs_interfaces

                if (child_yang_name == "interface-state-offs"):
                    if (self.interface_state_offs is None):
                        self.interface_state_offs = Igmp.Standby.DefaultContext.InterfaceStateOffs()
                        self.interface_state_offs.parent = self
                        self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    return self.interface_state_offs

                if (child_yang_name == "interface-state-ons"):
                    if (self.interface_state_ons is None):
                        self.interface_state_ons = Igmp.Standby.DefaultContext.InterfaceStateOns()
                        self.interface_state_ons.parent = self
                        self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    return self.interface_state_ons

                if (child_yang_name == "interface-table"):
                    if (self.interface_table is None):
                        self.interface_table = Igmp.Standby.DefaultContext.InterfaceTable()
                        self.interface_table.parent = self
                        self._children_name_map["interface_table"] = "interface-table"
                    return self.interface_table

                if (child_yang_name == "interface-unicast-qos-adjusts"):
                    if (self.interface_unicast_qos_adjusts is None):
                        self.interface_unicast_qos_adjusts = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts()
                        self.interface_unicast_qos_adjusts.parent = self
                        self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    return self.interface_unicast_qos_adjusts

                if (child_yang_name == "non-active-groups"):
                    if (self.non_active_groups is None):
                        self.non_active_groups = Igmp.Standby.DefaultContext.NonActiveGroups()
                        self.non_active_groups.parent = self
                        self._children_name_map["non_active_groups"] = "non-active-groups"
                    return self.non_active_groups

                if (child_yang_name == "ranges"):
                    if (self.ranges is None):
                        self.ranges = Igmp.Standby.DefaultContext.Ranges()
                        self.ranges.parent = self
                        self._children_name_map["ranges"] = "ranges"
                    return self.ranges

                if (child_yang_name == "ssm-map-details"):
                    if (self.ssm_map_details is None):
                        self.ssm_map_details = Igmp.Standby.DefaultContext.SsmMapDetails()
                        self.ssm_map_details.parent = self
                        self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    return self.ssm_map_details

                if (child_yang_name == "ssm-maps"):
                    if (self.ssm_maps is None):
                        self.ssm_maps = Igmp.Standby.DefaultContext.SsmMaps()
                        self.ssm_maps.parent = self
                        self._children_name_map["ssm_maps"] = "ssm-maps"
                    return self.ssm_maps

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Igmp.Standby.DefaultContext.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                if (child_yang_name == "traffic-counters"):
                    if (self.traffic_counters is None):
                        self.traffic_counters = Igmp.Standby.DefaultContext.TrafficCounters()
                        self.traffic_counters.parent = self
                        self._children_name_map["traffic_counters"] = "traffic-counters"
                    return self.traffic_counters

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "detail-groups" or name == "explicit-groups" or name == "global-interface-table" or name == "group-summary" or name == "groups" or name == "ifrs-interface-summary" or name == "ifrs-interfaces" or name == "interface-state-offs" or name == "interface-state-ons" or name == "interface-table" or name == "interface-unicast-qos-adjusts" or name == "non-active-groups" or name == "ranges" or name == "ssm-map-details" or name == "ssm-maps" or name == "summary" or name == "traffic-counters"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.default_context is not None and self.default_context.has_data()) or
                (self.process is not None and self.process.has_data()) or
                (self.vrfs is not None and self.vrfs.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.default_context is not None and self.default_context.has_operation()) or
                (self.process is not None and self.process.has_operation()) or
                (self.vrfs is not None and self.vrfs.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "standby" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "default-context"):
                if (self.default_context is None):
                    self.default_context = Igmp.Standby.DefaultContext()
                    self.default_context.parent = self
                    self._children_name_map["default_context"] = "default-context"
                return self.default_context

            if (child_yang_name == "process"):
                if (self.process is None):
                    self.process = Igmp.Standby.Process()
                    self.process.parent = self
                    self._children_name_map["process"] = "process"
                return self.process

            if (child_yang_name == "vrfs"):
                if (self.vrfs is None):
                    self.vrfs = Igmp.Standby.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                return self.vrfs

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "default-context" or name == "process" or name == "vrfs"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-igmp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Igmp.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "igmp"

            self.default_context = Igmp.Active.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Igmp.Active.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Igmp.Active.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF table Names
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Active.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "active"

                self.vrf = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Igmp.Active.Vrfs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Igmp.Active.Vrfs, self).__setattr__(name, value)


            class Vrf(Entity):
                """
                VRF table Names
                
                .. attribute:: vrf_name  <key>
                
                	VRF name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: detail_groups
                
                	IGMP Detail Group Database
                	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups>`
                
                .. attribute:: explicit_groups
                
                	IGMP Explicit Group Database
                	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups>`
                
                .. attribute:: global_interface_table
                
                	IGMP Global Interface 
                	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable>`
                
                .. attribute:: group_summary
                
                	IGMP Groups Summary
                	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GroupSummary>`
                
                .. attribute:: groups
                
                	IGMP Group Database Table
                	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Groups>`
                
                .. attribute:: ifrs_interface_summary
                
                	IGMP IFRS Interface summary
                	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary>`
                
                .. attribute:: ifrs_interfaces
                
                	IGMP Interface specific
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: interface_state_offs
                
                	IGMP Interface state off
                	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOffs>`
                
                .. attribute:: interface_state_ons
                
                	IGMP Interface state on
                	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOns>`
                
                .. attribute:: interface_table
                
                	IGMP Interface specific Table
                	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceTable>`
                
                .. attribute:: interface_unicast_qos_adjusts
                
                	IGMP Interface Unicast\-Qos\-Adjust
                	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts>`
                
                .. attribute:: non_active_groups
                
                	IGMP Non\-Active Groups Information
                	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.NonActiveGroups>`
                
                .. attribute:: ranges
                
                	Range table
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: ssm_map_details
                
                	SSM Map Detail
                	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMapDetails>`
                
                .. attribute:: ssm_maps
                
                	SSM Map Table
                	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMaps>`
                
                .. attribute:: summary
                
                	IGMP Summary Information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: traffic_counters
                
                	IGMP Message Traffic Counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.TrafficCounters>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.detail_groups = Igmp.Active.Vrfs.Vrf.DetailGroups()
                    self.detail_groups.parent = self
                    self._children_name_map["detail_groups"] = "detail-groups"
                    self._children_yang_names.add("detail-groups")

                    self.explicit_groups = Igmp.Active.Vrfs.Vrf.ExplicitGroups()
                    self.explicit_groups.parent = self
                    self._children_name_map["explicit_groups"] = "explicit-groups"
                    self._children_yang_names.add("explicit-groups")

                    self.global_interface_table = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable()
                    self.global_interface_table.parent = self
                    self._children_name_map["global_interface_table"] = "global-interface-table"
                    self._children_yang_names.add("global-interface-table")

                    self.group_summary = Igmp.Active.Vrfs.Vrf.GroupSummary()
                    self.group_summary.parent = self
                    self._children_name_map["group_summary"] = "group-summary"
                    self._children_yang_names.add("group-summary")

                    self.groups = Igmp.Active.Vrfs.Vrf.Groups()
                    self.groups.parent = self
                    self._children_name_map["groups"] = "groups"
                    self._children_yang_names.add("groups")

                    self.ifrs_interface_summary = Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary()
                    self.ifrs_interface_summary.parent = self
                    self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    self._children_yang_names.add("ifrs-interface-summary")

                    self.ifrs_interfaces = Igmp.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.interface_state_offs = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs()
                    self.interface_state_offs.parent = self
                    self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    self._children_yang_names.add("interface-state-offs")

                    self.interface_state_ons = Igmp.Active.Vrfs.Vrf.InterfaceStateOns()
                    self.interface_state_ons.parent = self
                    self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    self._children_yang_names.add("interface-state-ons")

                    self.interface_table = Igmp.Active.Vrfs.Vrf.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                    self._children_yang_names.add("interface-table")

                    self.interface_unicast_qos_adjusts = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                    self.interface_unicast_qos_adjusts.parent = self
                    self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    self._children_yang_names.add("interface-unicast-qos-adjusts")

                    self.non_active_groups = Igmp.Active.Vrfs.Vrf.NonActiveGroups()
                    self.non_active_groups.parent = self
                    self._children_name_map["non_active_groups"] = "non-active-groups"
                    self._children_yang_names.add("non-active-groups")

                    self.ranges = Igmp.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.ssm_map_details = Igmp.Active.Vrfs.Vrf.SsmMapDetails()
                    self.ssm_map_details.parent = self
                    self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    self._children_yang_names.add("ssm-map-details")

                    self.ssm_maps = Igmp.Active.Vrfs.Vrf.SsmMaps()
                    self.ssm_maps.parent = self
                    self._children_name_map["ssm_maps"] = "ssm-maps"
                    self._children_yang_names.add("ssm-maps")

                    self.summary = Igmp.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.traffic_counters = Igmp.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("vrf_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.Vrfs.Vrf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.Vrfs.Vrf, self).__setattr__(name, value)


                class Summary(Entity):
                    """
                    IGMP Summary Information
                    
                    .. attribute:: disabled_interface_count
                    
                    	No. of disabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: enabled_interface_count
                    
                    	No. of enabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Maximum and current groups accepted for each interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Summary.Interface>`
                    
                    .. attribute:: is_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: robustness
                    
                    	Robustness variable
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: supported_interfaces
                    
                    	No. of supported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_mte_config_count
                    
                    	No. of static group commands
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsupported_interfaces
                    
                    	No. of unsupported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"

                        self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                        self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                        self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                        self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                        self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("disabled_interface_count",
                                        "enabled_interface_count",
                                        "group_count",
                                        "group_limit",
                                        "is_disabled",
                                        "node_low_memory",
                                        "robustness",
                                        "supported_interfaces",
                                        "tunnel_mte_config_count",
                                        "unsupported_interfaces") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.Summary, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Maximum and current groups accepted for each
                        interface
                        
                        .. attribute:: group_count
                        
                        	Current groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_limit
                        
                        	Maximum groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: on_off
                        
                        	Enabled/Disabled
                        	**type**\:  bool
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent if handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Time elapsed since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.group_limit = YLeaf(YType.uint32, "group-limit")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.on_off = YLeaf(YType.boolean, "on-off")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_count",
                                            "group_limit",
                                            "interface_name",
                                            "on_off",
                                            "parent_ifhandle",
                                            "router_uptime_in_seconds",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.Summary.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.Summary.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.group_count.is_set or
                                self.group_limit.is_set or
                                self.interface_name.is_set or
                                self.on_off.is_set or
                                self.parent_ifhandle.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_count.yfilter != YFilter.not_set or
                                self.group_limit.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.on_off.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_count.get_name_leafdata())
                            if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_limit.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.on_off.is_set or self.on_off.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.on_off.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-count" or name == "group-limit" or name == "interface-name" or name == "on-off" or name == "parent-ifhandle" or name == "router-uptime-in-seconds" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-count"):
                                self.group_count = value
                                self.group_count.value_namespace = name_space
                                self.group_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-limit"):
                                self.group_limit = value
                                self.group_limit.value_namespace = name_space
                                self.group_limit.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "on-off"):
                                self.on_off = value
                                self.on_off.value_namespace = name_space
                                self.on_off.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return (
                            self.disabled_interface_count.is_set or
                            self.enabled_interface_count.is_set or
                            self.group_count.is_set or
                            self.group_limit.is_set or
                            self.is_disabled.is_set or
                            self.node_low_memory.is_set or
                            self.robustness.is_set or
                            self.supported_interfaces.is_set or
                            self.tunnel_mte_config_count.is_set or
                            self.unsupported_interfaces.is_set)

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.disabled_interface_count.yfilter != YFilter.not_set or
                            self.enabled_interface_count.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.group_limit.yfilter != YFilter.not_set or
                            self.is_disabled.yfilter != YFilter.not_set or
                            self.node_low_memory.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.supported_interfaces.yfilter != YFilter.not_set or
                            self.tunnel_mte_config_count.yfilter != YFilter.not_set or
                            self.unsupported_interfaces.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.disabled_interface_count.is_set or self.disabled_interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.disabled_interface_count.get_name_leafdata())
                        if (self.enabled_interface_count.is_set or self.enabled_interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.enabled_interface_count.get_name_leafdata())
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_limit.get_name_leafdata())
                        if (self.is_disabled.is_set or self.is_disabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_disabled.get_name_leafdata())
                        if (self.node_low_memory.is_set or self.node_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.node_low_memory.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.supported_interfaces.is_set or self.supported_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.supported_interfaces.get_name_leafdata())
                        if (self.tunnel_mte_config_count.is_set or self.tunnel_mte_config_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_mte_config_count.get_name_leafdata())
                        if (self.unsupported_interfaces.is_set or self.unsupported_interfaces.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.unsupported_interfaces.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.Summary.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface" or name == "disabled-interface-count" or name == "enabled-interface-count" or name == "group-count" or name == "group-limit" or name == "is-disabled" or name == "node-low-memory" or name == "robustness" or name == "supported-interfaces" or name == "tunnel-mte-config-count" or name == "unsupported-interfaces"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "disabled-interface-count"):
                            self.disabled_interface_count = value
                            self.disabled_interface_count.value_namespace = name_space
                            self.disabled_interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "enabled-interface-count"):
                            self.enabled_interface_count = value
                            self.enabled_interface_count.value_namespace = name_space
                            self.enabled_interface_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-limit"):
                            self.group_limit = value
                            self.group_limit.value_namespace = name_space
                            self.group_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-disabled"):
                            self.is_disabled = value
                            self.is_disabled.value_namespace = name_space
                            self.is_disabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "node-low-memory"):
                            self.node_low_memory = value
                            self.node_low_memory.value_namespace = name_space
                            self.node_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "supported-interfaces"):
                            self.supported_interfaces = value
                            self.supported_interfaces.value_namespace = name_space
                            self.supported_interfaces.value_namespace_prefix = name_space_prefix
                        if(value_path == "tunnel-mte-config-count"):
                            self.tunnel_mte_config_count = value
                            self.tunnel_mte_config_count.value_namespace = name_space
                            self.tunnel_mte_config_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "unsupported-interfaces"):
                            self.unsupported_interfaces = value
                            self.unsupported_interfaces.value_namespace = name_space
                            self.unsupported_interfaces.value_namespace_prefix = name_space_prefix


                class InterfaceStateOns(Entity):
                    """
                    IGMP Interface state on
                    
                    .. attribute:: interface_state_on
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns, self).__init__()

                        self.yang_name = "interface-state-ons"
                        self.yang_parent_name = "vrf"

                        self.interface_state_on = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns, self).__setattr__(name, value)


                    class InterfaceStateOn(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__init__()

                            self.yang_name = "interface-state-on"
                            self.yang_parent_name = "interface-state-ons"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-on"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_state_on:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_state_on:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-ons" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-state-on"):
                            for c in self.interface_state_on:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_state_on.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-state-on"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class DetailGroups(Entity):
                    """
                    IGMP Detail Group Database
                    
                    .. attribute:: detail_group
                    
                    	IGMP Detail Group Entry Information
                    	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.DetailGroups, self).__init__()

                        self.yang_name = "detail-groups"
                        self.yang_parent_name = "vrf"

                        self.detail_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.DetailGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.DetailGroups, self).__setattr__(name, value)


                    class DetailGroup(Entity):
                        """
                        IGMP Detail Group Entry Information
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_host_exclude_mode
                        
                        	Group host filter mode
                        	**type**\:  bool
                        
                        .. attribute:: is_router_exclude_mode
                        
                        	Group router filter mode
                        	**type**\:  bool
                        
                        .. attribute:: source
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup, self).__init__()

                            self.yang_name = "detail-group"
                            self.yang_parent_name = "detail-groups"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                            self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.source = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "interface_name",
                                            "is_host_exclude_mode",
                                            "is_router_exclude_mode",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup, self).__setattr__(name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "detail-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "explicit_tracking_enabled",
                                                "interface_name_xr",
                                                "is_added",
                                                "is_low_memory",
                                                "is_self_join",
                                                "is_suppressed",
                                                "older_host_version1_timer",
                                                "older_host_version2_timer",
                                                "router_filter_mode",
                                                "row_status",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "last-reporter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.explicit_tracking_enabled.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_added.is_set or
                                    self.is_low_memory.is_set or
                                    self.is_self_join.is_set or
                                    self.is_suppressed.is_set or
                                    self.older_host_version1_timer.is_set or
                                    self.older_host_version2_timer.is_set or
                                    self.router_filter_mode.is_set or
                                    self.row_status.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.last_reporter is not None and self.last_reporter.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_low_memory.yfilter != YFilter.not_set or
                                    self.is_self_join.yfilter != YFilter.not_set or
                                    self.is_suppressed.yfilter != YFilter.not_set or
                                    self.older_host_version1_timer.yfilter != YFilter.not_set or
                                    self.older_host_version2_timer.yfilter != YFilter.not_set or
                                    self.router_filter_mode.yfilter != YFilter.not_set or
                                    self.row_status.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                                if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_self_join.get_name_leafdata())
                                if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                                if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                                if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                                if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                                if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.row_status.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "last-reporter"):
                                    if (self.last_reporter is None):
                                        self.last_reporter = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                        self.last_reporter.parent = self
                                        self._children_name_map["last_reporter"] = "last-reporter"
                                    return self.last_reporter

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "explicit-tracking-enabled"):
                                    self.explicit_tracking_enabled = value
                                    self.explicit_tracking_enabled.value_namespace = name_space
                                    self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-low-memory"):
                                    self.is_low_memory = value
                                    self.is_low_memory.value_namespace = name_space
                                    self.is_low_memory.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-self-join"):
                                    self.is_self_join = value
                                    self.is_self_join.value_namespace = name_space
                                    self.is_self_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-suppressed"):
                                    self.is_suppressed = value
                                    self.is_suppressed.value_namespace = name_space
                                    self.is_suppressed.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version1-timer"):
                                    self.older_host_version1_timer = value
                                    self.older_host_version1_timer.value_namespace = name_space
                                    self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version2-timer"):
                                    self.older_host_version2_timer = value
                                    self.older_host_version2_timer.value_namespace = name_space
                                    self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-filter-mode"):
                                    self.router_filter_mode = value
                                    self.router_filter_mode.value_namespace = name_space
                                    self.router_filter_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "row-status"):
                                    self.row_status = value
                                    self.row_status.value_namespace = name_space
                                    self.row_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix


                        class Source(Entity):
                            """
                            List of sources
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: flags
                            
                            	Source flags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_forward
                            
                            	Should we forward on this entry
                            	**type**\:  bool
                            
                            .. attribute:: is_local
                            
                            	Is this a local source
                            	**type**\:  bool
                            
                            .. attribute:: is_remote
                            
                            	Is this a remote source
                            	**type**\:  bool
                            
                            .. attribute:: is_we_report
                            
                            	Should we report the source
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "detail-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.flags = YLeaf(YType.int32, "flags")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_forward = YLeaf(YType.boolean, "is-forward")

                                self.is_local = YLeaf(YType.boolean, "is-local")

                                self.is_remote = YLeaf(YType.boolean, "is-remote")

                                self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.source_address = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "flags",
                                                "is_added",
                                                "is_forward",
                                                "is_local",
                                                "is_remote",
                                                "is_we_report",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "source"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.flags.is_set or
                                    self.is_added.is_set or
                                    self.is_forward.is_set or
                                    self.is_local.is_set or
                                    self.is_remote.is_set or
                                    self.is_we_report.is_set or
                                    self.uptime.is_set or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.flags.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_forward.yfilter != YFilter.not_set or
                                    self.is_local.yfilter != YFilter.not_set or
                                    self.is_remote.yfilter != YFilter.not_set or
                                    self.is_we_report.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flags.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_forward.is_set or self.is_forward.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_forward.get_name_leafdata())
                                if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_local.get_name_leafdata())
                                if (self.is_remote.is_set or self.is_remote.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_remote.get_name_leafdata())
                                if (self.is_we_report.is_set or self.is_we_report.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_we_report.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "source-address" or name == "expiration-time" or name == "flags" or name == "is-added" or name == "is-forward" or name == "is-local" or name == "is-remote" or name == "is-we-report" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "flags"):
                                    self.flags = value
                                    self.flags.value_namespace = name_space
                                    self.flags.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-forward"):
                                    self.is_forward = value
                                    self.is_forward.value_namespace = name_space
                                    self.is_forward.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-local"):
                                    self.is_local = value
                                    self.is_local.value_namespace = name_space
                                    self.is_local.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-remote"):
                                    self.is_remote = value
                                    self.is_remote.value_namespace = name_space
                                    self.is_remote.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-we-report"):
                                    self.is_we_report = value
                                    self.is_we_report.value_namespace = name_space
                                    self.is_we_report.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.source:
                                if (c.has_data()):
                                    return True
                            return (
                                self.group_address.is_set or
                                self.interface_name.is_set or
                                self.is_host_exclude_mode.is_set or
                                self.is_router_exclude_mode.is_set or
                                self.source_address.is_set or
                                (self.group_info is not None and self.group_info.has_data()))

                        def has_operation(self):
                            for c in self.source:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_host_exclude_mode.yfilter != YFilter.not_set or
                                self.is_router_exclude_mode.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group_info is not None and self.group_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "detail-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_host_exclude_mode.is_set or self.is_host_exclude_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_host_exclude_mode.get_name_leafdata())
                            if (self.is_router_exclude_mode.is_set or self.is_router_exclude_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_exclude_mode.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-info"):
                                if (self.group_info is None):
                                    self.group_info = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                                    self.group_info.parent = self
                                    self._children_name_map["group_info"] = "group-info"
                                return self.group_info

                            if (child_yang_name == "source"):
                                for c in self.source:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.source.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-info" or name == "source" or name == "group-address" or name == "interface-name" or name == "is-host-exclude-mode" or name == "is-router-exclude-mode" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-host-exclude-mode"):
                                self.is_host_exclude_mode = value
                                self.is_host_exclude_mode.value_namespace = name_space
                                self.is_host_exclude_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-exclude-mode"):
                                self.is_router_exclude_mode = value
                                self.is_router_exclude_mode.value_namespace = name_space
                                self.is_router_exclude_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.detail_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.detail_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "detail-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "detail-group"):
                            for c in self.detail_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.detail_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "detail-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class NonActiveGroups(Entity):
                    """
                    IGMP Non\-Active Groups Information
                    
                    .. attribute:: non_active_groups
                    
                    	List of non\-active groups
                    	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "vrf"

                        self.non_active_groups = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.NonActiveGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.NonActiveGroups, self).__setattr__(name, value)


                    class NonActiveGroups(Entity):
                        """
                        List of non\-active groups
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress>`
                        
                        .. attribute:: interface
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: reason_for_non_activity
                        
                        	Reason for group join not being processed
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__init__()

                            self.yang_name = "non-active-groups"
                            self.yang_parent_name = "non-active-groups"

                            self.interface = YLeaf(YType.str, "interface")

                            self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                            self.group_address = Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface",
                                            "reason_for_non_activity") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "non-active-groups"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "non-active-groups"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface.is_set or
                                self.reason_for_non_activity.is_set or
                                (self.group_address is not None and self.group_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface.yfilter != YFilter.not_set or
                                self.reason_for_non_activity.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "non-active-groups" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface.get_name_leafdata())
                            if (self.reason_for_non_activity.is_set or self.reason_for_non_activity.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reason_for_non_activity.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "source-address" or name == "interface" or name == "reason-for-non-activity"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface"):
                                self.interface = value
                                self.interface.value_namespace = name_space
                                self.interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "reason-for-non-activity"):
                                self.reason_for_non_activity = value
                                self.reason_for_non_activity.value_namespace = name_space
                                self.reason_for_non_activity.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.non_active_groups:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.non_active_groups:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "non-active-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "non-active-groups"):
                            for c in self.non_active_groups:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.non_active_groups.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "non-active-groups"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SsmMaps(Entity):
                    """
                    SSM Map Table
                    
                    .. attribute:: ssm_map
                    
                    	SSM Map information
                    	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.SsmMaps, self).__init__()

                        self.yang_name = "ssm-maps"
                        self.yang_parent_name = "vrf"

                        self.ssm_map = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.SsmMaps, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.SsmMaps, self).__setattr__(name, value)


                    class SsmMap(Entity):
                        """
                        SSM Map information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap, self).__init__()

                            self.yang_name = "ssm-map"
                            self.yang_parent_name = "ssm-maps"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.group_address_xr = Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "map_type",
                                            "source_counts",
                                            "ssm_map_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "ssm-map"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.map_type.is_set or
                                self.source_counts.is_set or
                                self.ssm_map_type.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.map_type.yfilter != YFilter.not_set or
                                self.source_counts.yfilter != YFilter.not_set or
                                self.ssm_map_type.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ssm-map" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.map_type.get_name_leafdata())
                            if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_counts.get_name_leafdata())
                            if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "group-address" or name == "map-type" or name == "source-counts" or name == "ssm-map-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "map-type"):
                                self.map_type = value
                                self.map_type.value_namespace = name_space
                                self.map_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-counts"):
                                self.source_counts = value
                                self.source_counts.value_namespace = name_space
                                self.source_counts.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssm-map-type"):
                                self.ssm_map_type = value
                                self.ssm_map_type.value_namespace = name_space
                                self.ssm_map_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ssm_map:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ssm_map:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-maps" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ssm-map"):
                            for c in self.ssm_map:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ssm_map.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ssm-map"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class ExplicitGroups(Entity):
                    """
                    IGMP Explicit Group Database
                    
                    .. attribute:: explicit_group
                    
                    	IGMP Explicit Group Entry Information
                    	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.ExplicitGroups, self).__init__()

                        self.yang_name = "explicit-groups"
                        self.yang_parent_name = "vrf"

                        self.explicit_group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.ExplicitGroups, self).__setattr__(name, value)


                    class ExplicitGroup(Entity):
                        """
                        IGMP Explicit Group Entry Information
                        
                        .. attribute:: exclude_hosts
                        
                        	No. of hosts who are excluded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo>`
                        
                        .. attribute:: host
                        
                        	List of hosts
                        	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host>`
                        
                        .. attribute:: include_hosts
                        
                        	No. of hosts who are included
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__init__()

                            self.yang_name = "explicit-group"
                            self.yang_parent_name = "explicit-groups"

                            self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.host = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("exclude_hosts",
                                            "group_address",
                                            "include_hosts",
                                            "interface_name",
                                            "source_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "explicit-group"

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "explicit_tracking_enabled",
                                                "interface_name_xr",
                                                "is_added",
                                                "is_low_memory",
                                                "is_self_join",
                                                "is_suppressed",
                                                "older_host_version1_timer",
                                                "older_host_version2_timer",
                                                "router_filter_mode",
                                                "row_status",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "last-reporter" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.expiration_time.is_set or
                                    self.explicit_tracking_enabled.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_added.is_set or
                                    self.is_low_memory.is_set or
                                    self.is_self_join.is_set or
                                    self.is_suppressed.is_set or
                                    self.older_host_version1_timer.is_set or
                                    self.older_host_version2_timer.is_set or
                                    self.router_filter_mode.is_set or
                                    self.row_status.is_set or
                                    self.uptime.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                    (self.last_reporter is not None and self.last_reporter.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_added.yfilter != YFilter.not_set or
                                    self.is_low_memory.yfilter != YFilter.not_set or
                                    self.is_self_join.yfilter != YFilter.not_set or
                                    self.is_suppressed.yfilter != YFilter.not_set or
                                    self.older_host_version1_timer.yfilter != YFilter.not_set or
                                    self.older_host_version2_timer.yfilter != YFilter.not_set or
                                    self.router_filter_mode.yfilter != YFilter.not_set or
                                    self.row_status.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                    (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_added.get_name_leafdata())
                                if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                                if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_self_join.get_name_leafdata())
                                if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                                if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                                if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                                if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                                if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.row_status.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                if (child_yang_name == "last-reporter"):
                                    if (self.last_reporter is None):
                                        self.last_reporter = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                        self.last_reporter.parent = self
                                        self._children_name_map["last_reporter"] = "last-reporter"
                                    return self.last_reporter

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "explicit-tracking-enabled"):
                                    self.explicit_tracking_enabled = value
                                    self.explicit_tracking_enabled.value_namespace = name_space
                                    self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-added"):
                                    self.is_added = value
                                    self.is_added.value_namespace = name_space
                                    self.is_added.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-low-memory"):
                                    self.is_low_memory = value
                                    self.is_low_memory.value_namespace = name_space
                                    self.is_low_memory.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-self-join"):
                                    self.is_self_join = value
                                    self.is_self_join.value_namespace = name_space
                                    self.is_self_join.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-suppressed"):
                                    self.is_suppressed = value
                                    self.is_suppressed.value_namespace = name_space
                                    self.is_suppressed.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version1-timer"):
                                    self.older_host_version1_timer = value
                                    self.older_host_version1_timer.value_namespace = name_space
                                    self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "older-host-version2-timer"):
                                    self.older_host_version2_timer = value
                                    self.older_host_version2_timer.value_namespace = name_space
                                    self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-filter-mode"):
                                    self.router_filter_mode = value
                                    self.router_filter_mode.value_namespace = name_space
                                    self.router_filter_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "row-status"):
                                    self.row_status = value
                                    self.row_status.value_namespace = name_space
                                    self.row_status.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix


                        class Host(Entity):
                            """
                            List of hosts
                            
                            .. attribute:: address
                            
                            	Host Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address>`
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_exclude
                            
                            	Exclude flag set
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	First 3 source addresses
                            	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                            
                            .. attribute:: source_count
                            
                            	No. of sources in entry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "explicit-group"

                                self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                                self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                                self.source_count = YLeaf(YType.uint32, "source-count")

                                self.uptime = YLeaf(YType.uint32, "uptime")

                                self.address = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.source_address = YList(self)

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("expiration_time",
                                                "is_exclude",
                                                "source_count",
                                                "uptime") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)


                            class Address(Entity):
                                """
                                Host Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "host"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SourceAddress(Entity):
                                """
                                First 3 source addresses
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "host"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for c in self.source_address:
                                    if (c.has_data()):
                                        return True
                                return (
                                    self.expiration_time.is_set or
                                    self.is_exclude.is_set or
                                    self.source_count.is_set or
                                    self.uptime.is_set or
                                    (self.address is not None and self.address.has_data()))

                            def has_operation(self):
                                for c in self.source_address:
                                    if (c.has_operation()):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.expiration_time.yfilter != YFilter.not_set or
                                    self.is_exclude.yfilter != YFilter.not_set or
                                    self.source_count.yfilter != YFilter.not_set or
                                    self.uptime.yfilter != YFilter.not_set or
                                    (self.address is not None and self.address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "host" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.expiration_time.get_name_leafdata())
                                if (self.is_exclude.is_set or self.is_exclude.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_exclude.get_name_leafdata())
                                if (self.source_count.is_set or self.source_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_count.get_name_leafdata())
                                if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.uptime.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "address"):
                                    if (self.address is None):
                                        self.address = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                    return self.address

                                if (child_yang_name == "source-address"):
                                    for c in self.source_address:
                                        segment = c.get_segment_path()
                                        if (segment_path == segment):
                                            return c
                                    c = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress()
                                    c.parent = self
                                    local_reference_key = "ydk::seg::%s" % segment_path
                                    self._local_refs[local_reference_key] = c
                                    self.source_address.append(c)
                                    return c

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "source-address" or name == "expiration-time" or name == "is-exclude" or name == "source-count" or name == "uptime"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "expiration-time"):
                                    self.expiration_time = value
                                    self.expiration_time.value_namespace = name_space
                                    self.expiration_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-exclude"):
                                    self.is_exclude = value
                                    self.is_exclude.value_namespace = name_space
                                    self.is_exclude.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-count"):
                                    self.source_count = value
                                    self.source_count.value_namespace = name_space
                                    self.source_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "uptime"):
                                    self.uptime = value
                                    self.uptime.value_namespace = name_space
                                    self.uptime.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.host:
                                if (c.has_data()):
                                    return True
                            return (
                                self.exclude_hosts.is_set or
                                self.group_address.is_set or
                                self.include_hosts.is_set or
                                self.interface_name.is_set or
                                self.source_address.is_set or
                                (self.group_info is not None and self.group_info.has_data()))

                        def has_operation(self):
                            for c in self.host:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.exclude_hosts.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.include_hosts.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                (self.group_info is not None and self.group_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "explicit-group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.exclude_hosts.is_set or self.exclude_hosts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.exclude_hosts.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.include_hosts.is_set or self.include_hosts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.include_hosts.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-info"):
                                if (self.group_info is None):
                                    self.group_info = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                                    self.group_info.parent = self
                                    self._children_name_map["group_info"] = "group-info"
                                return self.group_info

                            if (child_yang_name == "host"):
                                for c in self.host:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.host.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-info" or name == "host" or name == "exclude-hosts" or name == "group-address" or name == "include-hosts" or name == "interface-name" or name == "source-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "exclude-hosts"):
                                self.exclude_hosts = value
                                self.exclude_hosts.value_namespace = name_space
                                self.exclude_hosts.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "include-hosts"):
                                self.include_hosts = value
                                self.include_hosts.value_namespace = name_space
                                self.include_hosts.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.explicit_group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.explicit_group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "explicit-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "explicit-group"):
                            for c in self.explicit_group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.explicit_group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "explicit-group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceTable(Entity):
                    """
                    IGMP Interface specific Table
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.InterfaceTable, self).__init__()

                        self.yang_name = "interface-table"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.InterfaceTable, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-table"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceUnicastQosAdjusts(Entity):
                    """
                    IGMP Interface Unicast\-Qos\-Adjust
                    
                    .. attribute:: interface_unicast_qos_adjust
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjusts"
                        self.yang_parent_name = "vrf"

                        self.interface_unicast_qos_adjust = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)


                    class InterfaceUnicastQosAdjust(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_virtual_access
                        
                        	Is VirtualAccess Interface
                        	**type**\:  bool
                        
                        .. attribute:: rate
                        
                        	Overall rate in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: rate_decrements
                        
                        	Count of rate decrements
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rate_increments
                        
                        	Count of rate increments
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update
                        
                        	List of updates
                        	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                            self.yang_name = "interface-unicast-qos-adjust"
                            self.yang_parent_name = "interface-unicast-qos-adjusts"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                            self.rate = YLeaf(YType.uint32, "rate")

                            self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                            self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                            self.update = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "is_virtual_access",
                                            "rate",
                                            "rate_decrements",
                                            "rate_increments") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)


                        class Update(Entity):
                            """
                            List of updates
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                            
                            .. attribute:: is_add
                            
                            	Is this a rate increment
                            	**type**\:  bool
                            
                            .. attribute:: received_time
                            
                            	Time this update is received
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                            
                            .. attribute:: weight
                            
                            	Weight from policy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                                self.yang_name = "update"
                                self.yang_parent_name = "interface-unicast-qos-adjust"

                                self.is_add = YLeaf(YType.boolean, "is-add")

                                self.received_time = YLeaf(YType.uint64, "received-time")

                                self.weight = YLeaf(YType.uint32, "weight")

                                self.group_address = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                                self._children_yang_names.add("group-address")

                                self.source_address = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_add",
                                                "received_time",
                                                "weight") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)


                            class SourceAddress(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "update"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "source-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class GroupAddress(Entity):
                                """
                                Group address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                    self.yang_name = "group-address"
                                    self.yang_parent_name = "update"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.is_add.is_set or
                                    self.received_time.is_set or
                                    self.weight.is_set or
                                    (self.group_address is not None and self.group_address.has_data()) or
                                    (self.source_address is not None and self.source_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_add.yfilter != YFilter.not_set or
                                    self.received_time.yfilter != YFilter.not_set or
                                    self.weight.yfilter != YFilter.not_set or
                                    (self.group_address is not None and self.group_address.has_operation()) or
                                    (self.source_address is not None and self.source_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "update" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_add.is_set or self.is_add.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_add.get_name_leafdata())
                                if (self.received_time.is_set or self.received_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.received_time.get_name_leafdata())
                                if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.weight.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address"):
                                    if (self.group_address is None):
                                        self.group_address = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                        self.group_address.parent = self
                                        self._children_name_map["group_address"] = "group-address"
                                    return self.group_address

                                if (child_yang_name == "source-address"):
                                    if (self.source_address is None):
                                        self.source_address = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                        self.source_address.parent = self
                                        self._children_name_map["source_address"] = "source-address"
                                    return self.source_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address" or name == "source-address" or name == "is-add" or name == "received-time" or name == "weight"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-add"):
                                    self.is_add = value
                                    self.is_add.value_namespace = name_space
                                    self.is_add.value_namespace_prefix = name_space_prefix
                                if(value_path == "received-time"):
                                    self.received_time = value
                                    self.received_time.value_namespace = name_space
                                    self.received_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "weight"):
                                    self.weight = value
                                    self.weight.value_namespace = name_space
                                    self.weight.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.update:
                                if (c.has_data()):
                                    return True
                            return (
                                self.interface_name.is_set or
                                self.is_virtual_access.is_set or
                                self.rate.is_set or
                                self.rate_decrements.is_set or
                                self.rate_increments.is_set)

                        def has_operation(self):
                            for c in self.update:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.is_virtual_access.yfilter != YFilter.not_set or
                                self.rate.yfilter != YFilter.not_set or
                                self.rate_decrements.yfilter != YFilter.not_set or
                                self.rate_increments.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.is_virtual_access.is_set or self.is_virtual_access.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_virtual_access.get_name_leafdata())
                            if (self.rate.is_set or self.rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate.get_name_leafdata())
                            if (self.rate_decrements.is_set or self.rate_decrements.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate_decrements.get_name_leafdata())
                            if (self.rate_increments.is_set or self.rate_increments.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rate_increments.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "update"):
                                for c in self.update:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.update.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "update" or name == "interface-name" or name == "is-virtual-access" or name == "rate" or name == "rate-decrements" or name == "rate-increments"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-virtual-access"):
                                self.is_virtual_access = value
                                self.is_virtual_access.value_namespace = name_space
                                self.is_virtual_access.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate"):
                                self.rate = value
                                self.rate.value_namespace = name_space
                                self.rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate-decrements"):
                                self.rate_decrements = value
                                self.rate_decrements.value_namespace = name_space
                                self.rate_decrements.value_namespace_prefix = name_space_prefix
                            if(value_path == "rate-increments"):
                                self.rate_increments = value
                                self.rate_increments.value_namespace = name_space
                                self.rate_increments.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_unicast_qos_adjust:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_unicast_qos_adjust:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-unicast-qos-adjusts" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-unicast-qos-adjust"):
                            for c in self.interface_unicast_qos_adjust:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_unicast_qos_adjust.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-unicast-qos-adjust"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Ranges(Entity):
                    """
                    Range table
                    
                    .. attribute:: range
                    
                    	Range information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"

                        self.range = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.Ranges, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.Ranges, self).__setattr__(name, value)


                    class Range(Entity):
                        """
                        Range information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr>`
                        
                        .. attribute:: group_mask
                        
                        	Group Mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_stale
                        
                        	Is the entry stale
                        	**type**\:  bool
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.group_mask = YLeaf(YType.int32, "group-mask")

                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.group_address_xr = Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("group_address",
                                            "group_mask",
                                            "is_stale",
                                            "prefix_length",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.Ranges.Range, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "range"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.group_address.is_set or
                                self.group_mask.is_set or
                                self.is_stale.is_set or
                                self.prefix_length.is_set or
                                self.protocol.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.group_mask.yfilter != YFilter.not_set or
                                self.is_stale.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "range" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.group_mask.is_set or self.group_mask.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_mask.get_name_leafdata())
                            if (self.is_stale.is_set or self.is_stale.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_stale.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "group-address" or name == "group-mask" or name == "is-stale" or name == "prefix-length" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-mask"):
                                self.group_mask = value
                                self.group_mask.value_namespace = name_space
                                self.group_mask.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-stale"):
                                self.is_stale = value
                                self.is_stale.value_namespace = name_space
                                self.is_stale.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.range:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.range:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ranges" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "range"):
                            for c in self.range:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.Ranges.Range()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.range.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "range"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class IfrsInterfaces(Entity):
                    """
                    IGMP Interface specific
                    
                    .. attribute:: ifrs_interface
                    
                    	IGMP IFRS Interface
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"

                        self.ifrs_interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces, self).__setattr__(name, value)


                    class IfrsInterface(Entity):
                        """
                        IGMP IFRS Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	IFRS Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: igmp_interface_entry
                        
                        	IGMP interface entry
                        	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                        
                        .. attribute:: join_group_count
                        
                        	Join group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                            self.igmp_interface_entry = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                            self.igmp_interface_entry.parent = self
                            self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            self._children_yang_names.add("igmp-interface-entry")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "join_group_count") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                        class IgmpInterfaceEntry(Entity):
                            """
                            IGMP interface entry
                            
                            .. attribute:: address
                            
                            	IP address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                            
                            .. attribute:: configuration_mcast_vrf_error
                            
                            	Is mcast error
                            	**type**\:  bool
                            
                            .. attribute:: configuration_mcast_vrf_set
                            
                            	Is mcast set
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_error
                            
                            	CFG vrf error
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_set
                            
                            	CFG vrf set
                            	**type**\:  bool
                            
                            .. attribute:: group_joins
                            
                            	No. of group joins
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_leaves
                            
                            	No. of group leaves
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: host_version
                            
                            	IGMP Host version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: igmp_version
                            
                            	IGMP Router version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: is_configurationverify
                            
                            	CFG verify
                            	**type**\:  bool
                            
                            .. attribute:: is_identity_present
                            
                            	Subscriber ID or Address available from AAA
                            	**type**\:  bool
                            
                            .. attribute:: is_im_state_registered
                            
                            	Im state registered
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_up
                            
                            	Is interface up
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_enabled
                            
                            	Is IP enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_las_registered
                            
                            	LAS registered
                            	**type**\:  bool
                            
                            .. attribute:: is_las_request
                            
                            	LAS req
                            	**type**\:  bool
                            
                            .. attribute:: is_querier
                            
                            	Are we querier
                            	**type**\:  bool
                            
                            .. attribute:: is_router_enabled
                            
                            	Is Router functionality enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_subscriber
                            
                            	Subscriber interface
                            	**type**\:  bool
                            
                            .. attribute:: las_get_address_count
                            
                            	LAS get addr count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_add_update_count
                            
                            	LAS LL add update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_registration_count
                            
                            	LAS reg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_remove_update_count
                            
                            	LAS LL remove update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_null_update_count
                            
                            	LAS Null update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_unregistration_count
                            
                            	LAS unreg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_update_count
                            
                            	LAS Update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_member_query_interval
                            
                            	Last Member Query Interval
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: location
                            
                            	Location
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_tuple_count
                            
                            	MTE Tuple count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_vrf_id
                            
                            	MTE VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_ifhandle
                            
                            	Parent If Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: proxy_interface
                            
                            	Proxy interface index
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: querier_address
                            
                            	Address of the Querier
                            	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                            
                            .. attribute:: querier_uptime
                            
                            	Time since the last querier took over
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_interval
                            
                            	Query Interval value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: query_maximum_response_time
                            
                            	Max Response Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_timeout
                            
                            	Query Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: robustness
                            
                            	Robustness Variable value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_uptime_in_seconds
                            
                            	Uptime since router enabled event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	Interface state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: subscriber_address
                            
                            	Address of subscriber
                            	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                            
                            .. attribute:: subscriber_id
                            
                            	ID string of subscriber
                            	**type**\:  str
                            
                            	**length:** 0..257
                            
                            .. attribute:: subscriber_mode
                            
                            	Subscriber mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_query_in_seconds
                            
                            	Time elapsed since last query
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_report_in_seconds
                            
                            	Time elapsed since last report
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_active_groups
                            
                            	Actual number of groups on interface
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_id
                            
                            	VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_state
                            
                            	Vrf State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                                self.yang_name = "igmp-interface-entry"
                                self.yang_parent_name = "ifrs-interface"

                                self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                                self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                                self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                                self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                                self.group_joins = YLeaf(YType.uint32, "group-joins")

                                self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                                self.host_version = YLeaf(YType.uint8, "host-version")

                                self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                                self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                                self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                                self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                                self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                                self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                                self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                                self.is_querier = YLeaf(YType.boolean, "is-querier")

                                self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                                self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                                self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                                self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                                self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                                self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                                self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                                self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                                self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                                self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                                self.location = YLeaf(YType.uint32, "location")

                                self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                                self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                                self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                                self.query_interval = YLeaf(YType.uint16, "query-interval")

                                self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                                self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                                self.robustness = YLeaf(YType.uint32, "robustness")

                                self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                                self.state = YLeaf(YType.uint32, "state")

                                self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                                self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                                self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                                self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                                self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                                self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                                self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                                self.address = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.querier_address = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                                self._children_yang_names.add("querier-address")

                                self.subscriber_address = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                                self._children_yang_names.add("subscriber-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("configuration_mcast_vrf_error",
                                                "configuration_mcast_vrf_set",
                                                "configurationvrf_error",
                                                "configurationvrf_set",
                                                "group_joins",
                                                "group_leaves",
                                                "host_version",
                                                "igmp_version",
                                                "interface_name_xr",
                                                "is_configurationverify",
                                                "is_identity_present",
                                                "is_im_state_registered",
                                                "is_interface_up",
                                                "is_ip_enabled",
                                                "is_las_registered",
                                                "is_las_request",
                                                "is_querier",
                                                "is_router_enabled",
                                                "is_subscriber",
                                                "las_get_address_count",
                                                "las_ll_add_update_count",
                                                "las_ll_registration_count",
                                                "las_ll_remove_update_count",
                                                "las_null_update_count",
                                                "las_unregistration_count",
                                                "las_update_count",
                                                "last_member_query_interval",
                                                "location",
                                                "mte_tuple_count",
                                                "mte_vrf_id",
                                                "mtu",
                                                "parent_ifhandle",
                                                "prefix_length",
                                                "proxy_interface",
                                                "querier_uptime",
                                                "query_interval",
                                                "query_maximum_response_time",
                                                "query_timeout",
                                                "robustness",
                                                "router_uptime_in_seconds",
                                                "state",
                                                "subscriber_id",
                                                "subscriber_mode",
                                                "time_since_last_query_in_seconds",
                                                "time_since_last_report_in_seconds",
                                                "total_active_groups",
                                                "vrf_id",
                                                "vrf_state") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)


                            class Address(Entity):
                                """
                                IP address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class QuerierAddress(Entity):
                                """
                                Address of the Querier
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                    self.yang_name = "querier-address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "querier-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix


                            class SubscriberAddress(Entity):
                                """
                                Address of subscriber
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                    self.yang_name = "subscriber-address"
                                    self.yang_parent_name = "igmp-interface-entry"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "subscriber-address" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.configuration_mcast_vrf_error.is_set or
                                    self.configuration_mcast_vrf_set.is_set or
                                    self.configurationvrf_error.is_set or
                                    self.configurationvrf_set.is_set or
                                    self.group_joins.is_set or
                                    self.group_leaves.is_set or
                                    self.host_version.is_set or
                                    self.igmp_version.is_set or
                                    self.interface_name_xr.is_set or
                                    self.is_configurationverify.is_set or
                                    self.is_identity_present.is_set or
                                    self.is_im_state_registered.is_set or
                                    self.is_interface_up.is_set or
                                    self.is_ip_enabled.is_set or
                                    self.is_las_registered.is_set or
                                    self.is_las_request.is_set or
                                    self.is_querier.is_set or
                                    self.is_router_enabled.is_set or
                                    self.is_subscriber.is_set or
                                    self.las_get_address_count.is_set or
                                    self.las_ll_add_update_count.is_set or
                                    self.las_ll_registration_count.is_set or
                                    self.las_ll_remove_update_count.is_set or
                                    self.las_null_update_count.is_set or
                                    self.las_unregistration_count.is_set or
                                    self.las_update_count.is_set or
                                    self.last_member_query_interval.is_set or
                                    self.location.is_set or
                                    self.mte_tuple_count.is_set or
                                    self.mte_vrf_id.is_set or
                                    self.mtu.is_set or
                                    self.parent_ifhandle.is_set or
                                    self.prefix_length.is_set or
                                    self.proxy_interface.is_set or
                                    self.querier_uptime.is_set or
                                    self.query_interval.is_set or
                                    self.query_maximum_response_time.is_set or
                                    self.query_timeout.is_set or
                                    self.robustness.is_set or
                                    self.router_uptime_in_seconds.is_set or
                                    self.state.is_set or
                                    self.subscriber_id.is_set or
                                    self.subscriber_mode.is_set or
                                    self.time_since_last_query_in_seconds.is_set or
                                    self.time_since_last_report_in_seconds.is_set or
                                    self.total_active_groups.is_set or
                                    self.vrf_id.is_set or
                                    self.vrf_state.is_set or
                                    (self.address is not None and self.address.has_data()) or
                                    (self.querier_address is not None and self.querier_address.has_data()) or
                                    (self.subscriber_address is not None and self.subscriber_address.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                    self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                    self.configurationvrf_error.yfilter != YFilter.not_set or
                                    self.configurationvrf_set.yfilter != YFilter.not_set or
                                    self.group_joins.yfilter != YFilter.not_set or
                                    self.group_leaves.yfilter != YFilter.not_set or
                                    self.host_version.yfilter != YFilter.not_set or
                                    self.igmp_version.yfilter != YFilter.not_set or
                                    self.interface_name_xr.yfilter != YFilter.not_set or
                                    self.is_configurationverify.yfilter != YFilter.not_set or
                                    self.is_identity_present.yfilter != YFilter.not_set or
                                    self.is_im_state_registered.yfilter != YFilter.not_set or
                                    self.is_interface_up.yfilter != YFilter.not_set or
                                    self.is_ip_enabled.yfilter != YFilter.not_set or
                                    self.is_las_registered.yfilter != YFilter.not_set or
                                    self.is_las_request.yfilter != YFilter.not_set or
                                    self.is_querier.yfilter != YFilter.not_set or
                                    self.is_router_enabled.yfilter != YFilter.not_set or
                                    self.is_subscriber.yfilter != YFilter.not_set or
                                    self.las_get_address_count.yfilter != YFilter.not_set or
                                    self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                    self.las_ll_registration_count.yfilter != YFilter.not_set or
                                    self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                    self.las_null_update_count.yfilter != YFilter.not_set or
                                    self.las_unregistration_count.yfilter != YFilter.not_set or
                                    self.las_update_count.yfilter != YFilter.not_set or
                                    self.last_member_query_interval.yfilter != YFilter.not_set or
                                    self.location.yfilter != YFilter.not_set or
                                    self.mte_tuple_count.yfilter != YFilter.not_set or
                                    self.mte_vrf_id.yfilter != YFilter.not_set or
                                    self.mtu.yfilter != YFilter.not_set or
                                    self.parent_ifhandle.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set or
                                    self.proxy_interface.yfilter != YFilter.not_set or
                                    self.querier_uptime.yfilter != YFilter.not_set or
                                    self.query_interval.yfilter != YFilter.not_set or
                                    self.query_maximum_response_time.yfilter != YFilter.not_set or
                                    self.query_timeout.yfilter != YFilter.not_set or
                                    self.robustness.yfilter != YFilter.not_set or
                                    self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                    self.state.yfilter != YFilter.not_set or
                                    self.subscriber_id.yfilter != YFilter.not_set or
                                    self.subscriber_mode.yfilter != YFilter.not_set or
                                    self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                    self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                    self.total_active_groups.yfilter != YFilter.not_set or
                                    self.vrf_id.yfilter != YFilter.not_set or
                                    self.vrf_state.yfilter != YFilter.not_set or
                                    (self.address is not None and self.address.has_operation()) or
                                    (self.querier_address is not None and self.querier_address.has_operation()) or
                                    (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "igmp-interface-entry" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                                if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                                if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                                if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                                if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_joins.get_name_leafdata())
                                if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.group_leaves.get_name_leafdata())
                                if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.host_version.get_name_leafdata())
                                if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.igmp_version.get_name_leafdata())
                                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                                if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                                if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                                if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                                if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                                if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                                if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                                if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_las_request.get_name_leafdata())
                                if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_querier.get_name_leafdata())
                                if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                                if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                                if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                                if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                                if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                                if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                                if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                                if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                                if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.las_update_count.get_name_leafdata())
                                if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                                if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.location.get_name_leafdata())
                                if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                                if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                                if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.mtu.get_name_leafdata())
                                if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())
                                if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                                if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                                if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_interval.get_name_leafdata())
                                if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                                if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.query_timeout.get_name_leafdata())
                                if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.robustness.get_name_leafdata())
                                if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                                if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.state.get_name_leafdata())
                                if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                                if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                                if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                                if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                                if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                                if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_id.get_name_leafdata())
                                if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.vrf_state.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "address"):
                                    if (self.address is None):
                                        self.address = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                        self.address.parent = self
                                        self._children_name_map["address"] = "address"
                                    return self.address

                                if (child_yang_name == "querier-address"):
                                    if (self.querier_address is None):
                                        self.querier_address = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                        self.querier_address.parent = self
                                        self._children_name_map["querier_address"] = "querier-address"
                                    return self.querier_address

                                if (child_yang_name == "subscriber-address"):
                                    if (self.subscriber_address is None):
                                        self.subscriber_address = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                        self.subscriber_address.parent = self
                                        self._children_name_map["subscriber_address"] = "subscriber-address"
                                    return self.subscriber_address

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "configuration-mcast-vrf-error"):
                                    self.configuration_mcast_vrf_error = value
                                    self.configuration_mcast_vrf_error.value_namespace = name_space
                                    self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "configuration-mcast-vrf-set"):
                                    self.configuration_mcast_vrf_set = value
                                    self.configuration_mcast_vrf_set.value_namespace = name_space
                                    self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "configurationvrf-error"):
                                    self.configurationvrf_error = value
                                    self.configurationvrf_error.value_namespace = name_space
                                    self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                                if(value_path == "configurationvrf-set"):
                                    self.configurationvrf_set = value
                                    self.configurationvrf_set.value_namespace = name_space
                                    self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-joins"):
                                    self.group_joins = value
                                    self.group_joins.value_namespace = name_space
                                    self.group_joins.value_namespace_prefix = name_space_prefix
                                if(value_path == "group-leaves"):
                                    self.group_leaves = value
                                    self.group_leaves.value_namespace = name_space
                                    self.group_leaves.value_namespace_prefix = name_space_prefix
                                if(value_path == "host-version"):
                                    self.host_version = value
                                    self.host_version.value_namespace = name_space
                                    self.host_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "igmp-version"):
                                    self.igmp_version = value
                                    self.igmp_version.value_namespace = name_space
                                    self.igmp_version.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-name-xr"):
                                    self.interface_name_xr = value
                                    self.interface_name_xr.value_namespace = name_space
                                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-configurationverify"):
                                    self.is_configurationverify = value
                                    self.is_configurationverify.value_namespace = name_space
                                    self.is_configurationverify.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-identity-present"):
                                    self.is_identity_present = value
                                    self.is_identity_present.value_namespace = name_space
                                    self.is_identity_present.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-im-state-registered"):
                                    self.is_im_state_registered = value
                                    self.is_im_state_registered.value_namespace = name_space
                                    self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-interface-up"):
                                    self.is_interface_up = value
                                    self.is_interface_up.value_namespace = name_space
                                    self.is_interface_up.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-ip-enabled"):
                                    self.is_ip_enabled = value
                                    self.is_ip_enabled.value_namespace = name_space
                                    self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-las-registered"):
                                    self.is_las_registered = value
                                    self.is_las_registered.value_namespace = name_space
                                    self.is_las_registered.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-las-request"):
                                    self.is_las_request = value
                                    self.is_las_request.value_namespace = name_space
                                    self.is_las_request.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-querier"):
                                    self.is_querier = value
                                    self.is_querier.value_namespace = name_space
                                    self.is_querier.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-router-enabled"):
                                    self.is_router_enabled = value
                                    self.is_router_enabled.value_namespace = name_space
                                    self.is_router_enabled.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-subscriber"):
                                    self.is_subscriber = value
                                    self.is_subscriber.value_namespace = name_space
                                    self.is_subscriber.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-get-address-count"):
                                    self.las_get_address_count = value
                                    self.las_get_address_count.value_namespace = name_space
                                    self.las_get_address_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-add-update-count"):
                                    self.las_ll_add_update_count = value
                                    self.las_ll_add_update_count.value_namespace = name_space
                                    self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-registration-count"):
                                    self.las_ll_registration_count = value
                                    self.las_ll_registration_count.value_namespace = name_space
                                    self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-ll-remove-update-count"):
                                    self.las_ll_remove_update_count = value
                                    self.las_ll_remove_update_count.value_namespace = name_space
                                    self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-null-update-count"):
                                    self.las_null_update_count = value
                                    self.las_null_update_count.value_namespace = name_space
                                    self.las_null_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-unregistration-count"):
                                    self.las_unregistration_count = value
                                    self.las_unregistration_count.value_namespace = name_space
                                    self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "las-update-count"):
                                    self.las_update_count = value
                                    self.las_update_count.value_namespace = name_space
                                    self.las_update_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "last-member-query-interval"):
                                    self.last_member_query_interval = value
                                    self.last_member_query_interval.value_namespace = name_space
                                    self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "location"):
                                    self.location = value
                                    self.location.value_namespace = name_space
                                    self.location.value_namespace_prefix = name_space_prefix
                                if(value_path == "mte-tuple-count"):
                                    self.mte_tuple_count = value
                                    self.mte_tuple_count.value_namespace = name_space
                                    self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                                if(value_path == "mte-vrf-id"):
                                    self.mte_vrf_id = value
                                    self.mte_vrf_id.value_namespace = name_space
                                    self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "mtu"):
                                    self.mtu = value
                                    self.mtu.value_namespace = name_space
                                    self.mtu.value_namespace_prefix = name_space_prefix
                                if(value_path == "parent-ifhandle"):
                                    self.parent_ifhandle = value
                                    self.parent_ifhandle.value_namespace = name_space
                                    self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "proxy-interface"):
                                    self.proxy_interface = value
                                    self.proxy_interface.value_namespace = name_space
                                    self.proxy_interface.value_namespace_prefix = name_space_prefix
                                if(value_path == "querier-uptime"):
                                    self.querier_uptime = value
                                    self.querier_uptime.value_namespace = name_space
                                    self.querier_uptime.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-interval"):
                                    self.query_interval = value
                                    self.query_interval.value_namespace = name_space
                                    self.query_interval.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-maximum-response-time"):
                                    self.query_maximum_response_time = value
                                    self.query_maximum_response_time.value_namespace = name_space
                                    self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                                if(value_path == "query-timeout"):
                                    self.query_timeout = value
                                    self.query_timeout.value_namespace = name_space
                                    self.query_timeout.value_namespace_prefix = name_space_prefix
                                if(value_path == "robustness"):
                                    self.robustness = value
                                    self.robustness.value_namespace = name_space
                                    self.robustness.value_namespace_prefix = name_space_prefix
                                if(value_path == "router-uptime-in-seconds"):
                                    self.router_uptime_in_seconds = value
                                    self.router_uptime_in_seconds.value_namespace = name_space
                                    self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "state"):
                                    self.state = value
                                    self.state.value_namespace = name_space
                                    self.state.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-id"):
                                    self.subscriber_id = value
                                    self.subscriber_id.value_namespace = name_space
                                    self.subscriber_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "subscriber-mode"):
                                    self.subscriber_mode = value
                                    self.subscriber_mode.value_namespace = name_space
                                    self.subscriber_mode.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-last-query-in-seconds"):
                                    self.time_since_last_query_in_seconds = value
                                    self.time_since_last_query_in_seconds.value_namespace = name_space
                                    self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "time-since-last-report-in-seconds"):
                                    self.time_since_last_report_in_seconds = value
                                    self.time_since_last_report_in_seconds.value_namespace = name_space
                                    self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                                if(value_path == "total-active-groups"):
                                    self.total_active_groups = value
                                    self.total_active_groups.value_namespace = name_space
                                    self.total_active_groups.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-id"):
                                    self.vrf_id = value
                                    self.vrf_id.value_namespace = name_space
                                    self.vrf_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "vrf-state"):
                                    self.vrf_state = value
                                    self.vrf_state.value_namespace = name_space
                                    self.vrf_state.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.join_group_count.is_set or
                                (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.join_group_count.yfilter != YFilter.not_set or
                                (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.join_group_count.is_set or self.join_group_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.join_group_count.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "igmp-interface-entry"):
                                if (self.igmp_interface_entry is None):
                                    self.igmp_interface_entry = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                                    self.igmp_interface_entry.parent = self
                                    self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                                return self.igmp_interface_entry

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "igmp-interface-entry" or name == "interface-name" or name == "join-group-count"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "join-group-count"):
                                self.join_group_count = value
                                self.join_group_count.value_namespace = name_space
                                self.join_group_count.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ifrs_interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ifrs_interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ifrs-interface"):
                            for c in self.ifrs_interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ifrs_interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ifrs-interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class TrafficCounters(Entity):
                    """
                    IGMP Message Traffic Counters
                    
                    .. attribute:: auxillary_data_length_errors
                    
                    	AuxDataLen errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bad_scope_errors
                    
                    	BadScope errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_errors
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_errors
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: get_packet_failure
                    
                    	Packet get failed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_disabled_idb
                    
                    	Packet received on disabled idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_dvmrp
                    
                    	DVMRP packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_leaves
                    
                    	Leaves in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_martian_address
                    
                    	Packets received with Martian Address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_mtrace
                    
                    	Mtrace packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_assigned_vrf_id
                    
                    	Packets received with no assigned vrf id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb
                    
                    	Packets received without idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_platform_support_mtrace
                    
                    	mtrace packets without platform support
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_in_idb
                    
                    	Packets received on idb without VRF
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_mtrace
                    
                    	mtrace packets with no vrf associated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim
                    
                    	PIM packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_queries
                    
                    	Query packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_reports
                    
                    	Reports in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_address_errors
                    
                    	Invalid Source Address errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: miscellaneous_errors
                    
                    	Packets dropped for other reasons
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_dvmrp
                    
                    	DVMRP packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_leaves
                    
                    	Leaves out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_mtrace
                    
                    	Mtrace packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_no_parent_interface_handle
                    
                    	Failures setting 2nd ifhandle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_pim
                    
                    	PIM packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_queries
                    
                    	Query packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_reports
                    
                    	Reports out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_input_errors
                    
                    	Incoming Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_output_errors
                    
                    	Outgoing Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_in
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_out
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: receive_socket_errors
                    
                    	Socket errors on reception
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_errors
                    
                    	Socket errors on send
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"

                        self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                        self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                        self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_errors = YLeaf(YType.uint32, "format-errors")

                        self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                        self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                        self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                        self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                        self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                        self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                        self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                        self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                        self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                        self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                        self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                        self.input_pim = YLeaf(YType.uint32, "input-pim")

                        self.input_queries = YLeaf(YType.uint32, "input-queries")

                        self.input_reports = YLeaf(YType.uint32, "input-reports")

                        self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                        self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                        self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                        self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                        self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                        self.output_pim = YLeaf(YType.uint32, "output-pim")

                        self.output_queries = YLeaf(YType.uint32, "output-queries")

                        self.output_reports = YLeaf(YType.uint32, "output-reports")

                        self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                        self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                        self.packets_in = YLeaf(YType.uint32, "packets-in")

                        self.packets_out = YLeaf(YType.uint32, "packets-out")

                        self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                        self.socket_errors = YLeaf(YType.uint32, "socket-errors")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("auxillary_data_length_errors",
                                        "bad_scope_errors",
                                        "checksum_errors",
                                        "elapsed_time",
                                        "format_errors",
                                        "get_packet_failure",
                                        "input_disabled_idb",
                                        "input_dvmrp",
                                        "input_leaves",
                                        "input_martian_address",
                                        "input_mtrace",
                                        "input_no_assigned_vrf_id",
                                        "input_no_idb",
                                        "input_no_platform_support_mtrace",
                                        "input_no_vrf_in_idb",
                                        "input_no_vrf_mtrace",
                                        "input_pim",
                                        "input_queries",
                                        "input_reports",
                                        "invalid_source_address_errors",
                                        "miscellaneous_errors",
                                        "no_socket_connection",
                                        "output_dvmrp",
                                        "output_leaves",
                                        "output_mtrace",
                                        "output_no_parent_interface_handle",
                                        "output_pim",
                                        "output_queries",
                                        "output_reports",
                                        "packet_manager_input_errors",
                                        "packet_manager_output_errors",
                                        "packets_in",
                                        "packets_out",
                                        "receive_socket_errors",
                                        "socket_errors") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.TrafficCounters, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.auxillary_data_length_errors.is_set or
                            self.bad_scope_errors.is_set or
                            self.checksum_errors.is_set or
                            self.elapsed_time.is_set or
                            self.format_errors.is_set or
                            self.get_packet_failure.is_set or
                            self.input_disabled_idb.is_set or
                            self.input_dvmrp.is_set or
                            self.input_leaves.is_set or
                            self.input_martian_address.is_set or
                            self.input_mtrace.is_set or
                            self.input_no_assigned_vrf_id.is_set or
                            self.input_no_idb.is_set or
                            self.input_no_platform_support_mtrace.is_set or
                            self.input_no_vrf_in_idb.is_set or
                            self.input_no_vrf_mtrace.is_set or
                            self.input_pim.is_set or
                            self.input_queries.is_set or
                            self.input_reports.is_set or
                            self.invalid_source_address_errors.is_set or
                            self.miscellaneous_errors.is_set or
                            self.no_socket_connection.is_set or
                            self.output_dvmrp.is_set or
                            self.output_leaves.is_set or
                            self.output_mtrace.is_set or
                            self.output_no_parent_interface_handle.is_set or
                            self.output_pim.is_set or
                            self.output_queries.is_set or
                            self.output_reports.is_set or
                            self.packet_manager_input_errors.is_set or
                            self.packet_manager_output_errors.is_set or
                            self.packets_in.is_set or
                            self.packets_out.is_set or
                            self.receive_socket_errors.is_set or
                            self.socket_errors.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.auxillary_data_length_errors.yfilter != YFilter.not_set or
                            self.bad_scope_errors.yfilter != YFilter.not_set or
                            self.checksum_errors.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.format_errors.yfilter != YFilter.not_set or
                            self.get_packet_failure.yfilter != YFilter.not_set or
                            self.input_disabled_idb.yfilter != YFilter.not_set or
                            self.input_dvmrp.yfilter != YFilter.not_set or
                            self.input_leaves.yfilter != YFilter.not_set or
                            self.input_martian_address.yfilter != YFilter.not_set or
                            self.input_mtrace.yfilter != YFilter.not_set or
                            self.input_no_assigned_vrf_id.yfilter != YFilter.not_set or
                            self.input_no_idb.yfilter != YFilter.not_set or
                            self.input_no_platform_support_mtrace.yfilter != YFilter.not_set or
                            self.input_no_vrf_in_idb.yfilter != YFilter.not_set or
                            self.input_no_vrf_mtrace.yfilter != YFilter.not_set or
                            self.input_pim.yfilter != YFilter.not_set or
                            self.input_queries.yfilter != YFilter.not_set or
                            self.input_reports.yfilter != YFilter.not_set or
                            self.invalid_source_address_errors.yfilter != YFilter.not_set or
                            self.miscellaneous_errors.yfilter != YFilter.not_set or
                            self.no_socket_connection.yfilter != YFilter.not_set or
                            self.output_dvmrp.yfilter != YFilter.not_set or
                            self.output_leaves.yfilter != YFilter.not_set or
                            self.output_mtrace.yfilter != YFilter.not_set or
                            self.output_no_parent_interface_handle.yfilter != YFilter.not_set or
                            self.output_pim.yfilter != YFilter.not_set or
                            self.output_queries.yfilter != YFilter.not_set or
                            self.output_reports.yfilter != YFilter.not_set or
                            self.packet_manager_input_errors.yfilter != YFilter.not_set or
                            self.packet_manager_output_errors.yfilter != YFilter.not_set or
                            self.packets_in.yfilter != YFilter.not_set or
                            self.packets_out.yfilter != YFilter.not_set or
                            self.receive_socket_errors.yfilter != YFilter.not_set or
                            self.socket_errors.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "traffic-counters" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.auxillary_data_length_errors.is_set or self.auxillary_data_length_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.auxillary_data_length_errors.get_name_leafdata())
                        if (self.bad_scope_errors.is_set or self.bad_scope_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bad_scope_errors.get_name_leafdata())
                        if (self.checksum_errors.is_set or self.checksum_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.checksum_errors.get_name_leafdata())
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.format_errors.is_set or self.format_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.format_errors.get_name_leafdata())
                        if (self.get_packet_failure.is_set or self.get_packet_failure.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.get_packet_failure.get_name_leafdata())
                        if (self.input_disabled_idb.is_set or self.input_disabled_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_disabled_idb.get_name_leafdata())
                        if (self.input_dvmrp.is_set or self.input_dvmrp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_dvmrp.get_name_leafdata())
                        if (self.input_leaves.is_set or self.input_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_leaves.get_name_leafdata())
                        if (self.input_martian_address.is_set or self.input_martian_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_martian_address.get_name_leafdata())
                        if (self.input_mtrace.is_set or self.input_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_mtrace.get_name_leafdata())
                        if (self.input_no_assigned_vrf_id.is_set or self.input_no_assigned_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_assigned_vrf_id.get_name_leafdata())
                        if (self.input_no_idb.is_set or self.input_no_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_idb.get_name_leafdata())
                        if (self.input_no_platform_support_mtrace.is_set or self.input_no_platform_support_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_platform_support_mtrace.get_name_leafdata())
                        if (self.input_no_vrf_in_idb.is_set or self.input_no_vrf_in_idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_in_idb.get_name_leafdata())
                        if (self.input_no_vrf_mtrace.is_set or self.input_no_vrf_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_no_vrf_mtrace.get_name_leafdata())
                        if (self.input_pim.is_set or self.input_pim.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_pim.get_name_leafdata())
                        if (self.input_queries.is_set or self.input_queries.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_queries.get_name_leafdata())
                        if (self.input_reports.is_set or self.input_reports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.input_reports.get_name_leafdata())
                        if (self.invalid_source_address_errors.is_set or self.invalid_source_address_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.invalid_source_address_errors.get_name_leafdata())
                        if (self.miscellaneous_errors.is_set or self.miscellaneous_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.miscellaneous_errors.get_name_leafdata())
                        if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                        if (self.output_dvmrp.is_set or self.output_dvmrp.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_dvmrp.get_name_leafdata())
                        if (self.output_leaves.is_set or self.output_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_leaves.get_name_leafdata())
                        if (self.output_mtrace.is_set or self.output_mtrace.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_mtrace.get_name_leafdata())
                        if (self.output_no_parent_interface_handle.is_set or self.output_no_parent_interface_handle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_no_parent_interface_handle.get_name_leafdata())
                        if (self.output_pim.is_set or self.output_pim.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_pim.get_name_leafdata())
                        if (self.output_queries.is_set or self.output_queries.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_queries.get_name_leafdata())
                        if (self.output_reports.is_set or self.output_reports.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.output_reports.get_name_leafdata())
                        if (self.packet_manager_input_errors.is_set or self.packet_manager_input_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_manager_input_errors.get_name_leafdata())
                        if (self.packet_manager_output_errors.is_set or self.packet_manager_output_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packet_manager_output_errors.get_name_leafdata())
                        if (self.packets_in.is_set or self.packets_in.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_in.get_name_leafdata())
                        if (self.packets_out.is_set or self.packets_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.packets_out.get_name_leafdata())
                        if (self.receive_socket_errors.is_set or self.receive_socket_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.receive_socket_errors.get_name_leafdata())
                        if (self.socket_errors.is_set or self.socket_errors.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.socket_errors.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "auxillary-data-length-errors" or name == "bad-scope-errors" or name == "checksum-errors" or name == "elapsed-time" or name == "format-errors" or name == "get-packet-failure" or name == "input-disabled-idb" or name == "input-dvmrp" or name == "input-leaves" or name == "input-martian-address" or name == "input-mtrace" or name == "input-no-assigned-vrf-id" or name == "input-no-idb" or name == "input-no-platform-support-mtrace" or name == "input-no-vrf-in-idb" or name == "input-no-vrf-mtrace" or name == "input-pim" or name == "input-queries" or name == "input-reports" or name == "invalid-source-address-errors" or name == "miscellaneous-errors" or name == "no-socket-connection" or name == "output-dvmrp" or name == "output-leaves" or name == "output-mtrace" or name == "output-no-parent-interface-handle" or name == "output-pim" or name == "output-queries" or name == "output-reports" or name == "packet-manager-input-errors" or name == "packet-manager-output-errors" or name == "packets-in" or name == "packets-out" or name == "receive-socket-errors" or name == "socket-errors"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "auxillary-data-length-errors"):
                            self.auxillary_data_length_errors = value
                            self.auxillary_data_length_errors.value_namespace = name_space
                            self.auxillary_data_length_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "bad-scope-errors"):
                            self.bad_scope_errors = value
                            self.bad_scope_errors.value_namespace = name_space
                            self.bad_scope_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "checksum-errors"):
                            self.checksum_errors = value
                            self.checksum_errors.value_namespace = name_space
                            self.checksum_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "format-errors"):
                            self.format_errors = value
                            self.format_errors.value_namespace = name_space
                            self.format_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "get-packet-failure"):
                            self.get_packet_failure = value
                            self.get_packet_failure.value_namespace = name_space
                            self.get_packet_failure.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-disabled-idb"):
                            self.input_disabled_idb = value
                            self.input_disabled_idb.value_namespace = name_space
                            self.input_disabled_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-dvmrp"):
                            self.input_dvmrp = value
                            self.input_dvmrp.value_namespace = name_space
                            self.input_dvmrp.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-leaves"):
                            self.input_leaves = value
                            self.input_leaves.value_namespace = name_space
                            self.input_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-martian-address"):
                            self.input_martian_address = value
                            self.input_martian_address.value_namespace = name_space
                            self.input_martian_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-mtrace"):
                            self.input_mtrace = value
                            self.input_mtrace.value_namespace = name_space
                            self.input_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-assigned-vrf-id"):
                            self.input_no_assigned_vrf_id = value
                            self.input_no_assigned_vrf_id.value_namespace = name_space
                            self.input_no_assigned_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-idb"):
                            self.input_no_idb = value
                            self.input_no_idb.value_namespace = name_space
                            self.input_no_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-platform-support-mtrace"):
                            self.input_no_platform_support_mtrace = value
                            self.input_no_platform_support_mtrace.value_namespace = name_space
                            self.input_no_platform_support_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-in-idb"):
                            self.input_no_vrf_in_idb = value
                            self.input_no_vrf_in_idb.value_namespace = name_space
                            self.input_no_vrf_in_idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-no-vrf-mtrace"):
                            self.input_no_vrf_mtrace = value
                            self.input_no_vrf_mtrace.value_namespace = name_space
                            self.input_no_vrf_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-pim"):
                            self.input_pim = value
                            self.input_pim.value_namespace = name_space
                            self.input_pim.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-queries"):
                            self.input_queries = value
                            self.input_queries.value_namespace = name_space
                            self.input_queries.value_namespace_prefix = name_space_prefix
                        if(value_path == "input-reports"):
                            self.input_reports = value
                            self.input_reports.value_namespace = name_space
                            self.input_reports.value_namespace_prefix = name_space_prefix
                        if(value_path == "invalid-source-address-errors"):
                            self.invalid_source_address_errors = value
                            self.invalid_source_address_errors.value_namespace = name_space
                            self.invalid_source_address_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "miscellaneous-errors"):
                            self.miscellaneous_errors = value
                            self.miscellaneous_errors.value_namespace = name_space
                            self.miscellaneous_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "no-socket-connection"):
                            self.no_socket_connection = value
                            self.no_socket_connection.value_namespace = name_space
                            self.no_socket_connection.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-dvmrp"):
                            self.output_dvmrp = value
                            self.output_dvmrp.value_namespace = name_space
                            self.output_dvmrp.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-leaves"):
                            self.output_leaves = value
                            self.output_leaves.value_namespace = name_space
                            self.output_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-mtrace"):
                            self.output_mtrace = value
                            self.output_mtrace.value_namespace = name_space
                            self.output_mtrace.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-no-parent-interface-handle"):
                            self.output_no_parent_interface_handle = value
                            self.output_no_parent_interface_handle.value_namespace = name_space
                            self.output_no_parent_interface_handle.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-pim"):
                            self.output_pim = value
                            self.output_pim.value_namespace = name_space
                            self.output_pim.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-queries"):
                            self.output_queries = value
                            self.output_queries.value_namespace = name_space
                            self.output_queries.value_namespace_prefix = name_space_prefix
                        if(value_path == "output-reports"):
                            self.output_reports = value
                            self.output_reports.value_namespace = name_space
                            self.output_reports.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-manager-input-errors"):
                            self.packet_manager_input_errors = value
                            self.packet_manager_input_errors.value_namespace = name_space
                            self.packet_manager_input_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "packet-manager-output-errors"):
                            self.packet_manager_output_errors = value
                            self.packet_manager_output_errors.value_namespace = name_space
                            self.packet_manager_output_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "packets-in"):
                            self.packets_in = value
                            self.packets_in.value_namespace = name_space
                            self.packets_in.value_namespace_prefix = name_space_prefix
                        if(value_path == "packets-out"):
                            self.packets_out = value
                            self.packets_out.value_namespace = name_space
                            self.packets_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "receive-socket-errors"):
                            self.receive_socket_errors = value
                            self.receive_socket_errors.value_namespace = name_space
                            self.receive_socket_errors.value_namespace_prefix = name_space_prefix
                        if(value_path == "socket-errors"):
                            self.socket_errors = value
                            self.socket_errors.value_namespace = name_space
                            self.socket_errors.value_namespace_prefix = name_space_prefix


                class Groups(Entity):
                    """
                    IGMP Group Database Table
                    
                    .. attribute:: group
                    
                    	IGMP Group Entry Information
                    	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Groups.Group>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.Groups, self).__init__()

                        self.yang_name = "groups"
                        self.yang_parent_name = "vrf"

                        self.group = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.Groups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.Groups, self).__setattr__(name, value)


                    class Group(Entity):
                        """
                        IGMP Group Entry Information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.Groups.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "groups"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "group_address",
                                            "interface_name",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.Groups.Group, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.Groups.Group, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.group_address.is_set or
                                self.interface_name.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "group-address" or name == "interface-name" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.group:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.group:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group"):
                            for c in self.group:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.Groups.Group()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.group.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class GroupSummary(Entity):
                    """
                    IGMP Groups Summary
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groutes
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: sg_routes
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.GroupSummary, self).__init__()

                        self.yang_name = "group-summary"
                        self.yang_parent_name = "vrf"

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.groutes = YLeaf(YType.uint32, "groutes")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.sg_routes = YLeaf(YType.uint32, "sg-routes")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_count",
                                        "groutes",
                                        "is_low_memory",
                                        "sg_routes") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.GroupSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.GroupSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.group_count.is_set or
                            self.groutes.is_set or
                            self.is_low_memory.is_set or
                            self.sg_routes.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.groutes.yfilter != YFilter.not_set or
                            self.is_low_memory.yfilter != YFilter.not_set or
                            self.sg_routes.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.groutes.is_set or self.groutes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.groutes.get_name_leafdata())
                        if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                        if (self.sg_routes.is_set or self.sg_routes.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sg_routes.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-count" or name == "groutes" or name == "is-low-memory" or name == "sg-routes"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "groutes"):
                            self.groutes = value
                            self.groutes.value_namespace = name_space
                            self.groutes.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-low-memory"):
                            self.is_low_memory = value
                            self.is_low_memory.value_namespace = name_space
                            self.is_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "sg-routes"):
                            self.sg_routes = value
                            self.sg_routes.value_namespace = name_space
                            self.sg_routes.value_namespace_prefix = name_space_prefix


                class IfrsInterfaceSummary(Entity):
                    """
                    IGMP IFRS Interface summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary, self).__init__()

                        self.yang_name = "ifrs-interface-summary"
                        self.yang_parent_name = "vrf"

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("configuration_count",
                                        "interface_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.configuration_count.is_set or
                            self.interface_count.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.configuration_count.yfilter != YFilter.not_set or
                            self.interface_count.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface-summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_count.get_name_leafdata())
                        if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "configuration-count" or name == "interface-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "configuration-count"):
                            self.configuration_count = value
                            self.configuration_count.value_namespace = name_space
                            self.configuration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-count"):
                            self.interface_count = value
                            self.interface_count.value_namespace = name_space
                            self.interface_count.value_namespace_prefix = name_space_prefix


                class GlobalInterfaceTable(Entity):
                    """
                    IGMP Global Interface 
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable, self).__init__()

                        self.yang_name = "global-interface-table"
                        self.yang_parent_name = "vrf"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "global-interface-table"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "global-interface-table" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class SsmMapDetails(Entity):
                    """
                    SSM Map Detail
                    
                    .. attribute:: ssm_map_detail
                    
                    	SSM Map Detail Table information
                    	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.SsmMapDetails, self).__init__()

                        self.yang_name = "ssm-map-details"
                        self.yang_parent_name = "vrf"

                        self.ssm_map_detail = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.SsmMapDetails, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.SsmMapDetails, self).__setattr__(name, value)


                    class SsmMapDetail(Entity):
                        """
                        SSM Map Detail Table information
                        
                        .. attribute:: elapsed_time
                        
                        	Elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: expiration_time
                        
                        	Expiration Time in Seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: map_info
                        
                        	Basic Map Info
                        	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo>`
                        
                        .. attribute:: query_interval
                        
                        	Query interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: response_pending
                        
                        	Response Pending
                        	**type**\:  bool
                        
                        .. attribute:: sources
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources>`
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__init__()

                            self.yang_name = "ssm-map-detail"
                            self.yang_parent_name = "ssm-map-details"

                            self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.query_interval = YLeaf(YType.uint32, "query-interval")

                            self.response_pending = YLeaf(YType.boolean, "response-pending")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.map_info = Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                            self.map_info.parent = self
                            self._children_name_map["map_info"] = "map-info"
                            self._children_yang_names.add("map-info")

                            self.sources = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("elapsed_time",
                                            "expiration_time",
                                            "group_address",
                                            "query_interval",
                                            "response_pending",
                                            "ssm_map_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)


                        class MapInfo(Entity):
                            """
                            Basic Map Info
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                            
                            .. attribute:: map_type
                            
                            	Map Type of group
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_counts
                            
                            	Count of Sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                                self.yang_name = "map-info"
                                self.yang_parent_name = "ssm-map-detail"

                                self.map_type = YLeaf(YType.uint32, "map-type")

                                self.source_counts = YLeaf(YType.uint32, "source-counts")

                                self.group_address_xr = Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("map_type",
                                                "source_counts") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "map-info"

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("af_name",
                                                    "ipv4_address",
                                                    "ipv6_address") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.af_name.is_set or
                                        self.ipv4_address.is_set or
                                        self.ipv6_address.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.af_name.yfilter != YFilter.not_set or
                                        self.ipv4_address.yfilter != YFilter.not_set or
                                        self.ipv6_address.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "group-address-xr" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.af_name.get_name_leafdata())
                                    if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                    if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "af-name"):
                                        self.af_name = value
                                        self.af_name.value_namespace = name_space
                                        self.af_name.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv4-address"):
                                        self.ipv4_address = value
                                        self.ipv4_address.value_namespace = name_space
                                        self.ipv4_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ipv6-address"):
                                        self.ipv6_address = value
                                        self.ipv6_address.value_namespace = name_space
                                        self.ipv6_address.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.map_type.is_set or
                                    self.source_counts.is_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.map_type.yfilter != YFilter.not_set or
                                    self.source_counts.yfilter != YFilter.not_set or
                                    (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "map-info" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.map_type.get_name_leafdata())
                                if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source_counts.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "group-address-xr"):
                                    if (self.group_address_xr is None):
                                        self.group_address_xr = Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                        self.group_address_xr.parent = self
                                        self._children_name_map["group_address_xr"] = "group-address-xr"
                                    return self.group_address_xr

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "group-address-xr" or name == "map-type" or name == "source-counts"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "map-type"):
                                    self.map_type = value
                                    self.map_type.value_namespace = name_space
                                    self.map_type.value_namespace_prefix = name_space_prefix
                                if(value_path == "source-counts"):
                                    self.source_counts = value
                                    self.source_counts.value_namespace = name_space
                                    self.source_counts.value_namespace_prefix = name_space_prefix


                        class Sources(Entity):
                            """
                            List of sources
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                                self.yang_name = "sources"
                                self.yang_parent_name = "ssm-map-detail"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "sources" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.sources:
                                if (c.has_data()):
                                    return True
                            return (
                                self.elapsed_time.is_set or
                                self.expiration_time.is_set or
                                self.group_address.is_set or
                                self.query_interval.is_set or
                                self.response_pending.is_set or
                                self.ssm_map_type.is_set or
                                (self.map_info is not None and self.map_info.has_data()))

                        def has_operation(self):
                            for c in self.sources:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.elapsed_time.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.group_address.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.response_pending.yfilter != YFilter.not_set or
                                self.ssm_map_type.yfilter != YFilter.not_set or
                                (self.map_info is not None and self.map_info.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ssm-map-detail" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_address.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.response_pending.is_set or self.response_pending.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.response_pending.get_name_leafdata())
                            if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "map-info"):
                                if (self.map_info is None):
                                    self.map_info = Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                                    self.map_info.parent = self
                                    self._children_name_map["map_info"] = "map-info"
                                return self.map_info

                            if (child_yang_name == "sources"):
                                for c in self.sources:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.sources.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "map-info" or name == "sources" or name == "elapsed-time" or name == "expiration-time" or name == "group-address" or name == "query-interval" or name == "response-pending" or name == "ssm-map-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "elapsed-time"):
                                self.elapsed_time = value
                                self.elapsed_time.value_namespace = name_space
                                self.elapsed_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-address"):
                                self.group_address = value
                                self.group_address.value_namespace = name_space
                                self.group_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "response-pending"):
                                self.response_pending = value
                                self.response_pending.value_namespace = name_space
                                self.response_pending.value_namespace_prefix = name_space_prefix
                            if(value_path == "ssm-map-type"):
                                self.ssm_map_type = value
                                self.ssm_map_type.value_namespace = name_space
                                self.ssm_map_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ssm_map_detail:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.ssm_map_detail:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map-details" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ssm-map-detail"):
                            for c in self.ssm_map_detail:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ssm_map_detail.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ssm-map-detail"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class InterfaceStateOffs(Entity):
                    """
                    IGMP Interface state off
                    
                    .. attribute:: interface_state_off
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs, self).__init__()

                        self.yang_name = "interface-state-offs"
                        self.yang_parent_name = "vrf"

                        self.interface_state_off = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs, self).__setattr__(name, value)


                    class InterfaceStateOff(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                            self.yang_name = "interface-state-off"
                            self.yang_parent_name = "interface-state-offs"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-off"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface_state_off:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface_state_off:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-offs" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface-state-off"):
                            for c in self.interface_state_off:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface_state_off.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface-state-off"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.vrf_name.is_set or
                        (self.detail_groups is not None and self.detail_groups.has_data()) or
                        (self.explicit_groups is not None and self.explicit_groups.has_data()) or
                        (self.global_interface_table is not None and self.global_interface_table.has_data()) or
                        (self.group_summary is not None and self.group_summary.has_data()) or
                        (self.groups is not None and self.groups.has_data()) or
                        (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_data()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                        (self.interface_state_offs is not None and self.interface_state_offs.has_data()) or
                        (self.interface_state_ons is not None and self.interface_state_ons.has_data()) or
                        (self.interface_table is not None and self.interface_table.has_data()) or
                        (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_data()) or
                        (self.non_active_groups is not None and self.non_active_groups.has_data()) or
                        (self.ranges is not None and self.ranges.has_data()) or
                        (self.ssm_map_details is not None and self.ssm_map_details.has_data()) or
                        (self.ssm_maps is not None and self.ssm_maps.has_data()) or
                        (self.summary is not None and self.summary.has_data()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.vrf_name.yfilter != YFilter.not_set or
                        (self.detail_groups is not None and self.detail_groups.has_operation()) or
                        (self.explicit_groups is not None and self.explicit_groups.has_operation()) or
                        (self.global_interface_table is not None and self.global_interface_table.has_operation()) or
                        (self.group_summary is not None and self.group_summary.has_operation()) or
                        (self.groups is not None and self.groups.has_operation()) or
                        (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_operation()) or
                        (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                        (self.interface_state_offs is not None and self.interface_state_offs.has_operation()) or
                        (self.interface_state_ons is not None and self.interface_state_ons.has_operation()) or
                        (self.interface_table is not None and self.interface_table.has_operation()) or
                        (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_operation()) or
                        (self.non_active_groups is not None and self.non_active_groups.has_operation()) or
                        (self.ranges is not None and self.ranges.has_operation()) or
                        (self.ssm_map_details is not None and self.ssm_map_details.has_operation()) or
                        (self.ssm_maps is not None and self.ssm_maps.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()) or
                        (self.traffic_counters is not None and self.traffic_counters.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "vrf" + "[vrf-name='" + self.vrf_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/vrfs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrf_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "detail-groups"):
                        if (self.detail_groups is None):
                            self.detail_groups = Igmp.Active.Vrfs.Vrf.DetailGroups()
                            self.detail_groups.parent = self
                            self._children_name_map["detail_groups"] = "detail-groups"
                        return self.detail_groups

                    if (child_yang_name == "explicit-groups"):
                        if (self.explicit_groups is None):
                            self.explicit_groups = Igmp.Active.Vrfs.Vrf.ExplicitGroups()
                            self.explicit_groups.parent = self
                            self._children_name_map["explicit_groups"] = "explicit-groups"
                        return self.explicit_groups

                    if (child_yang_name == "global-interface-table"):
                        if (self.global_interface_table is None):
                            self.global_interface_table = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable()
                            self.global_interface_table.parent = self
                            self._children_name_map["global_interface_table"] = "global-interface-table"
                        return self.global_interface_table

                    if (child_yang_name == "group-summary"):
                        if (self.group_summary is None):
                            self.group_summary = Igmp.Active.Vrfs.Vrf.GroupSummary()
                            self.group_summary.parent = self
                            self._children_name_map["group_summary"] = "group-summary"
                        return self.group_summary

                    if (child_yang_name == "groups"):
                        if (self.groups is None):
                            self.groups = Igmp.Active.Vrfs.Vrf.Groups()
                            self.groups.parent = self
                            self._children_name_map["groups"] = "groups"
                        return self.groups

                    if (child_yang_name == "ifrs-interface-summary"):
                        if (self.ifrs_interface_summary is None):
                            self.ifrs_interface_summary = Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary()
                            self.ifrs_interface_summary.parent = self
                            self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                        return self.ifrs_interface_summary

                    if (child_yang_name == "ifrs-interfaces"):
                        if (self.ifrs_interfaces is None):
                            self.ifrs_interfaces = Igmp.Active.Vrfs.Vrf.IfrsInterfaces()
                            self.ifrs_interfaces.parent = self
                            self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                        return self.ifrs_interfaces

                    if (child_yang_name == "interface-state-offs"):
                        if (self.interface_state_offs is None):
                            self.interface_state_offs = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs()
                            self.interface_state_offs.parent = self
                            self._children_name_map["interface_state_offs"] = "interface-state-offs"
                        return self.interface_state_offs

                    if (child_yang_name == "interface-state-ons"):
                        if (self.interface_state_ons is None):
                            self.interface_state_ons = Igmp.Active.Vrfs.Vrf.InterfaceStateOns()
                            self.interface_state_ons.parent = self
                            self._children_name_map["interface_state_ons"] = "interface-state-ons"
                        return self.interface_state_ons

                    if (child_yang_name == "interface-table"):
                        if (self.interface_table is None):
                            self.interface_table = Igmp.Active.Vrfs.Vrf.InterfaceTable()
                            self.interface_table.parent = self
                            self._children_name_map["interface_table"] = "interface-table"
                        return self.interface_table

                    if (child_yang_name == "interface-unicast-qos-adjusts"):
                        if (self.interface_unicast_qos_adjusts is None):
                            self.interface_unicast_qos_adjusts = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                            self.interface_unicast_qos_adjusts.parent = self
                            self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                        return self.interface_unicast_qos_adjusts

                    if (child_yang_name == "non-active-groups"):
                        if (self.non_active_groups is None):
                            self.non_active_groups = Igmp.Active.Vrfs.Vrf.NonActiveGroups()
                            self.non_active_groups.parent = self
                            self._children_name_map["non_active_groups"] = "non-active-groups"
                        return self.non_active_groups

                    if (child_yang_name == "ranges"):
                        if (self.ranges is None):
                            self.ranges = Igmp.Active.Vrfs.Vrf.Ranges()
                            self.ranges.parent = self
                            self._children_name_map["ranges"] = "ranges"
                        return self.ranges

                    if (child_yang_name == "ssm-map-details"):
                        if (self.ssm_map_details is None):
                            self.ssm_map_details = Igmp.Active.Vrfs.Vrf.SsmMapDetails()
                            self.ssm_map_details.parent = self
                            self._children_name_map["ssm_map_details"] = "ssm-map-details"
                        return self.ssm_map_details

                    if (child_yang_name == "ssm-maps"):
                        if (self.ssm_maps is None):
                            self.ssm_maps = Igmp.Active.Vrfs.Vrf.SsmMaps()
                            self.ssm_maps.parent = self
                            self._children_name_map["ssm_maps"] = "ssm-maps"
                        return self.ssm_maps

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = Igmp.Active.Vrfs.Vrf.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    if (child_yang_name == "traffic-counters"):
                        if (self.traffic_counters is None):
                            self.traffic_counters = Igmp.Active.Vrfs.Vrf.TrafficCounters()
                            self.traffic_counters.parent = self
                            self._children_name_map["traffic_counters"] = "traffic-counters"
                        return self.traffic_counters

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "detail-groups" or name == "explicit-groups" or name == "global-interface-table" or name == "group-summary" or name == "groups" or name == "ifrs-interface-summary" or name == "ifrs-interfaces" or name == "interface-state-offs" or name == "interface-state-ons" or name == "interface-table" or name == "interface-unicast-qos-adjusts" or name == "non-active-groups" or name == "ranges" or name == "ssm-map-details" or name == "ssm-maps" or name == "summary" or name == "traffic-counters" or name == "vrf-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "vrf-name"):
                        self.vrf_name = value
                        self.vrf_name.value_namespace = name_space
                        self.vrf_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.vrf:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.vrf:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "vrfs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "vrf"):
                    for c in self.vrf:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Igmp.Active.Vrfs.Vrf()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.vrf.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "vrf"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Process(Entity):
            """
            Process
            
            .. attribute:: amt_gatewaies
            
            	Table containing AMT Gateway DataBase information
            	**type**\:   :py:class:`AmtGatewaies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.AmtGatewaies>`
            
            .. attribute:: amt_summary
            
            	MRIB RouteDB Expiry Information
            	**type**\:   :py:class:`AmtSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.AmtSummary>`
            
            .. attribute:: bvi_statistics
            
            	IGMP BVI Stats
            	**type**\:   :py:class:`BviStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.BviStatistics>`
            
            .. attribute:: nsf
            
            	NSF Information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.Nsr>`
            
            .. attribute:: unicast_qos_adjust_stats
            
            	IGMP Unicast\-Qos\-Adjust Statistics
            	**type**\:   :py:class:`UnicastQosAdjustStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.UnicastQosAdjustStats>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Active.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "active"

                self.amt_gatewaies = Igmp.Active.Process.AmtGatewaies()
                self.amt_gatewaies.parent = self
                self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                self._children_yang_names.add("amt-gatewaies")

                self.amt_summary = Igmp.Active.Process.AmtSummary()
                self.amt_summary.parent = self
                self._children_name_map["amt_summary"] = "amt-summary"
                self._children_yang_names.add("amt-summary")

                self.bvi_statistics = Igmp.Active.Process.BviStatistics()
                self.bvi_statistics.parent = self
                self._children_name_map["bvi_statistics"] = "bvi-statistics"
                self._children_yang_names.add("bvi-statistics")

                self.nsf = Igmp.Active.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Igmp.Active.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.unicast_qos_adjust_stats = Igmp.Active.Process.UnicastQosAdjustStats()
                self.unicast_qos_adjust_stats.parent = self
                self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                self._children_yang_names.add("unicast-qos-adjust-stats")


            class AmtSummary(Entity):
                """
                MRIB RouteDB Expiry Information
                
                .. attribute:: anycast_prefix
                
                	Robustness variable
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: gateway_count
                
                	Number of AMT Gateway
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_acl_configured
                
                	ACL configured under AMT
                	**type**\:  bool
                
                .. attribute:: is_gateway_simulation
                
                	AMT Gateway Simulation
                	**type**\:  bool
                
                .. attribute:: is_ou_of_resource
                
                	AMT Out Of Resource
                	**type**\:  bool
                
                .. attribute:: max_gateway
                
                	Maximum Gateway allowed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mtu
                
                	AMT Tunnel MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: prefix_length
                
                	Advertize AMT prefix length
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: query_interval
                
                	AMT Query interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: relay_address
                
                	Advertaisment for AMT Relay address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: tos
                
                	Type Of Service value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ttl
                
                	Time To Live value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_configured_maximum
                
                	AMT Tunnel configured Maximum
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_count
                
                	AMT Tunnel Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.AmtSummary, self).__init__()

                    self.yang_name = "amt-summary"
                    self.yang_parent_name = "process"

                    self.anycast_prefix = YLeaf(YType.str, "anycast-prefix")

                    self.gateway_count = YLeaf(YType.uint32, "gateway-count")

                    self.is_acl_configured = YLeaf(YType.boolean, "is-acl-configured")

                    self.is_gateway_simulation = YLeaf(YType.boolean, "is-gateway-simulation")

                    self.is_ou_of_resource = YLeaf(YType.boolean, "is-ou-of-resource")

                    self.max_gateway = YLeaf(YType.uint32, "max-gateway")

                    self.mtu = YLeaf(YType.uint32, "mtu")

                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                    self.query_interval = YLeaf(YType.uint32, "query-interval")

                    self.relay_address = YLeaf(YType.str, "relay-address")

                    self.tos = YLeaf(YType.uint32, "tos")

                    self.ttl = YLeaf(YType.uint32, "ttl")

                    self.tunnel_configured_maximum = YLeaf(YType.uint32, "tunnel-configured-maximum")

                    self.tunnel_count = YLeaf(YType.uint32, "tunnel-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("anycast_prefix",
                                    "gateway_count",
                                    "is_acl_configured",
                                    "is_gateway_simulation",
                                    "is_ou_of_resource",
                                    "max_gateway",
                                    "mtu",
                                    "prefix_length",
                                    "query_interval",
                                    "relay_address",
                                    "tos",
                                    "ttl",
                                    "tunnel_configured_maximum",
                                    "tunnel_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.Process.AmtSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.Process.AmtSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.anycast_prefix.is_set or
                        self.gateway_count.is_set or
                        self.is_acl_configured.is_set or
                        self.is_gateway_simulation.is_set or
                        self.is_ou_of_resource.is_set or
                        self.max_gateway.is_set or
                        self.mtu.is_set or
                        self.prefix_length.is_set or
                        self.query_interval.is_set or
                        self.relay_address.is_set or
                        self.tos.is_set or
                        self.ttl.is_set or
                        self.tunnel_configured_maximum.is_set or
                        self.tunnel_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.anycast_prefix.yfilter != YFilter.not_set or
                        self.gateway_count.yfilter != YFilter.not_set or
                        self.is_acl_configured.yfilter != YFilter.not_set or
                        self.is_gateway_simulation.yfilter != YFilter.not_set or
                        self.is_ou_of_resource.yfilter != YFilter.not_set or
                        self.max_gateway.yfilter != YFilter.not_set or
                        self.mtu.yfilter != YFilter.not_set or
                        self.prefix_length.yfilter != YFilter.not_set or
                        self.query_interval.yfilter != YFilter.not_set or
                        self.relay_address.yfilter != YFilter.not_set or
                        self.tos.yfilter != YFilter.not_set or
                        self.ttl.yfilter != YFilter.not_set or
                        self.tunnel_configured_maximum.yfilter != YFilter.not_set or
                        self.tunnel_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "amt-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.anycast_prefix.is_set or self.anycast_prefix.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.anycast_prefix.get_name_leafdata())
                    if (self.gateway_count.is_set or self.gateway_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.gateway_count.get_name_leafdata())
                    if (self.is_acl_configured.is_set or self.is_acl_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_acl_configured.get_name_leafdata())
                    if (self.is_gateway_simulation.is_set or self.is_gateway_simulation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_gateway_simulation.get_name_leafdata())
                    if (self.is_ou_of_resource.is_set or self.is_ou_of_resource.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ou_of_resource.get_name_leafdata())
                    if (self.max_gateway.is_set or self.max_gateway.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.max_gateway.get_name_leafdata())
                    if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.mtu.get_name_leafdata())
                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.prefix_length.get_name_leafdata())
                    if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.query_interval.get_name_leafdata())
                    if (self.relay_address.is_set or self.relay_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.relay_address.get_name_leafdata())
                    if (self.tos.is_set or self.tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tos.get_name_leafdata())
                    if (self.ttl.is_set or self.ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ttl.get_name_leafdata())
                    if (self.tunnel_configured_maximum.is_set or self.tunnel_configured_maximum.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_configured_maximum.get_name_leafdata())
                    if (self.tunnel_count.is_set or self.tunnel_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "anycast-prefix" or name == "gateway-count" or name == "is-acl-configured" or name == "is-gateway-simulation" or name == "is-ou-of-resource" or name == "max-gateway" or name == "mtu" or name == "prefix-length" or name == "query-interval" or name == "relay-address" or name == "tos" or name == "ttl" or name == "tunnel-configured-maximum" or name == "tunnel-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "anycast-prefix"):
                        self.anycast_prefix = value
                        self.anycast_prefix.value_namespace = name_space
                        self.anycast_prefix.value_namespace_prefix = name_space_prefix
                    if(value_path == "gateway-count"):
                        self.gateway_count = value
                        self.gateway_count.value_namespace = name_space
                        self.gateway_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-acl-configured"):
                        self.is_acl_configured = value
                        self.is_acl_configured.value_namespace = name_space
                        self.is_acl_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-gateway-simulation"):
                        self.is_gateway_simulation = value
                        self.is_gateway_simulation.value_namespace = name_space
                        self.is_gateway_simulation.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-ou-of-resource"):
                        self.is_ou_of_resource = value
                        self.is_ou_of_resource.value_namespace = name_space
                        self.is_ou_of_resource.value_namespace_prefix = name_space_prefix
                    if(value_path == "max-gateway"):
                        self.max_gateway = value
                        self.max_gateway.value_namespace = name_space
                        self.max_gateway.value_namespace_prefix = name_space_prefix
                    if(value_path == "mtu"):
                        self.mtu = value
                        self.mtu.value_namespace = name_space
                        self.mtu.value_namespace_prefix = name_space_prefix
                    if(value_path == "prefix-length"):
                        self.prefix_length = value
                        self.prefix_length.value_namespace = name_space
                        self.prefix_length.value_namespace_prefix = name_space_prefix
                    if(value_path == "query-interval"):
                        self.query_interval = value
                        self.query_interval.value_namespace = name_space
                        self.query_interval.value_namespace_prefix = name_space_prefix
                    if(value_path == "relay-address"):
                        self.relay_address = value
                        self.relay_address.value_namespace = name_space
                        self.relay_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "tos"):
                        self.tos = value
                        self.tos.value_namespace = name_space
                        self.tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ttl"):
                        self.ttl = value
                        self.ttl.value_namespace = name_space
                        self.ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-configured-maximum"):
                        self.tunnel_configured_maximum = value
                        self.tunnel_configured_maximum.value_namespace = name_space
                        self.tunnel_configured_maximum.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-count"):
                        self.tunnel_count = value
                        self.tunnel_count.value_namespace = name_space
                        self.tunnel_count.value_namespace_prefix = name_space_prefix


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: collab_conv_done
                
                	Collaborators convergence done
                	**type**\:  bool
                
                .. attribute:: count_proc_connection_dn
                
                	No. of times process connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_proc_connection_up
                
                	No. of times process connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_proc
                
                	Time when process came up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_dn
                
                	Time when process connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_up
                
                	Time when process connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_proc_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"

                    self.collab_conv_done = YLeaf(YType.boolean, "collab-conv-done")

                    self.count_proc_connection_dn = YLeaf(YType.uint32, "count-proc-connection-dn")

                    self.count_proc_connection_up = YLeaf(YType.uint32, "count-proc-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_proc = YLeaf(YType.uint64, "last-proc")

                    self.last_proc_connection_dn = YLeaf(YType.uint64, "last-proc-connection-dn")

                    self.last_proc_connection_up = YLeaf(YType.uint64, "last-proc-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_proc_connected = YLeaf(YType.boolean, "partner-proc-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.state = YLeaf(YType.uint8, "state")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("collab_conv_done",
                                    "count_proc_connection_dn",
                                    "count_proc_connection_up",
                                    "count_rmf_not_ready",
                                    "count_rmf_ready",
                                    "last_proc",
                                    "last_proc_connection_dn",
                                    "last_proc_connection_up",
                                    "last_rmf_not_ready",
                                    "last_rmf_ready",
                                    "partner_proc_connected",
                                    "rmf_notification_done",
                                    "state") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.Process.Nsr, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.Process.Nsr, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.collab_conv_done.is_set or
                        self.count_proc_connection_dn.is_set or
                        self.count_proc_connection_up.is_set or
                        self.count_rmf_not_ready.is_set or
                        self.count_rmf_ready.is_set or
                        self.last_proc.is_set or
                        self.last_proc_connection_dn.is_set or
                        self.last_proc_connection_up.is_set or
                        self.last_rmf_not_ready.is_set or
                        self.last_rmf_ready.is_set or
                        self.partner_proc_connected.is_set or
                        self.rmf_notification_done.is_set or
                        self.state.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.collab_conv_done.yfilter != YFilter.not_set or
                        self.count_proc_connection_dn.yfilter != YFilter.not_set or
                        self.count_proc_connection_up.yfilter != YFilter.not_set or
                        self.count_rmf_not_ready.yfilter != YFilter.not_set or
                        self.count_rmf_ready.yfilter != YFilter.not_set or
                        self.last_proc.yfilter != YFilter.not_set or
                        self.last_proc_connection_dn.yfilter != YFilter.not_set or
                        self.last_proc_connection_up.yfilter != YFilter.not_set or
                        self.last_rmf_not_ready.yfilter != YFilter.not_set or
                        self.last_rmf_ready.yfilter != YFilter.not_set or
                        self.partner_proc_connected.yfilter != YFilter.not_set or
                        self.rmf_notification_done.yfilter != YFilter.not_set or
                        self.state.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsr" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.collab_conv_done.is_set or self.collab_conv_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.collab_conv_done.get_name_leafdata())
                    if (self.count_proc_connection_dn.is_set or self.count_proc_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_proc_connection_dn.get_name_leafdata())
                    if (self.count_proc_connection_up.is_set or self.count_proc_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_proc_connection_up.get_name_leafdata())
                    if (self.count_rmf_not_ready.is_set or self.count_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_not_ready.get_name_leafdata())
                    if (self.count_rmf_ready.is_set or self.count_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.count_rmf_ready.get_name_leafdata())
                    if (self.last_proc.is_set or self.last_proc.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc.get_name_leafdata())
                    if (self.last_proc_connection_dn.is_set or self.last_proc_connection_dn.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc_connection_dn.get_name_leafdata())
                    if (self.last_proc_connection_up.is_set or self.last_proc_connection_up.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_proc_connection_up.get_name_leafdata())
                    if (self.last_rmf_not_ready.is_set or self.last_rmf_not_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_not_ready.get_name_leafdata())
                    if (self.last_rmf_ready.is_set or self.last_rmf_ready.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_rmf_ready.get_name_leafdata())
                    if (self.partner_proc_connected.is_set or self.partner_proc_connected.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.partner_proc_connected.get_name_leafdata())
                    if (self.rmf_notification_done.is_set or self.rmf_notification_done.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rmf_notification_done.get_name_leafdata())
                    if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.state.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "collab-conv-done" or name == "count-proc-connection-dn" or name == "count-proc-connection-up" or name == "count-rmf-not-ready" or name == "count-rmf-ready" or name == "last-proc" or name == "last-proc-connection-dn" or name == "last-proc-connection-up" or name == "last-rmf-not-ready" or name == "last-rmf-ready" or name == "partner-proc-connected" or name == "rmf-notification-done" or name == "state"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "collab-conv-done"):
                        self.collab_conv_done = value
                        self.collab_conv_done.value_namespace = name_space
                        self.collab_conv_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-proc-connection-dn"):
                        self.count_proc_connection_dn = value
                        self.count_proc_connection_dn.value_namespace = name_space
                        self.count_proc_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-proc-connection-up"):
                        self.count_proc_connection_up = value
                        self.count_proc_connection_up.value_namespace = name_space
                        self.count_proc_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-not-ready"):
                        self.count_rmf_not_ready = value
                        self.count_rmf_not_ready.value_namespace = name_space
                        self.count_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "count-rmf-ready"):
                        self.count_rmf_ready = value
                        self.count_rmf_ready.value_namespace = name_space
                        self.count_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc"):
                        self.last_proc = value
                        self.last_proc.value_namespace = name_space
                        self.last_proc.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc-connection-dn"):
                        self.last_proc_connection_dn = value
                        self.last_proc_connection_dn.value_namespace = name_space
                        self.last_proc_connection_dn.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-proc-connection-up"):
                        self.last_proc_connection_up = value
                        self.last_proc_connection_up.value_namespace = name_space
                        self.last_proc_connection_up.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-not-ready"):
                        self.last_rmf_not_ready = value
                        self.last_rmf_not_ready.value_namespace = name_space
                        self.last_rmf_not_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-rmf-ready"):
                        self.last_rmf_ready = value
                        self.last_rmf_ready.value_namespace = name_space
                        self.last_rmf_ready.value_namespace_prefix = name_space_prefix
                    if(value_path == "partner-proc-connected"):
                        self.partner_proc_connected = value
                        self.partner_proc_connected.value_namespace = name_space
                        self.partner_proc_connected.value_namespace_prefix = name_space_prefix
                    if(value_path == "rmf-notification-done"):
                        self.rmf_notification_done = value
                        self.rmf_notification_done.value_namespace = name_space
                        self.rmf_notification_done.value_namespace_prefix = name_space_prefix
                    if(value_path == "state"):
                        self.state = value
                        self.state.value_namespace = name_space
                        self.state.value_namespace_prefix = name_space_prefix


            class AmtGatewaies(Entity):
                """
                Table containing AMT Gateway DataBase
                information
                
                .. attribute:: amt_gateway
                
                	AMT Gateway DataBase information
                	**type**\: list of    :py:class:`AmtGateway <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.AmtGatewaies.AmtGateway>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.AmtGatewaies, self).__init__()

                    self.yang_name = "amt-gatewaies"
                    self.yang_parent_name = "process"

                    self.amt_gateway = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.Process.AmtGatewaies, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.Process.AmtGatewaies, self).__setattr__(name, value)


                class AmtGateway(Entity):
                    """
                    AMT Gateway DataBase information
                    
                    .. attribute:: amt_nonce
                    
                    	Nonce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amt_port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amtgw
                    
                    	GW
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: amtnh
                    
                    	AMT NH
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gateway_address
                    
                    	Gateway Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: idb
                    
                    	IDB
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: key_len
                    
                    	Len
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_in
                    
                    	UpdIn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_out
                    
                    	UpdOut
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Process.AmtGatewaies.AmtGateway, self).__init__()

                        self.yang_name = "amt-gateway"
                        self.yang_parent_name = "amt-gatewaies"

                        self.amt_nonce = YLeaf(YType.uint32, "amt-nonce")

                        self.amt_port = YLeaf(YType.uint32, "amt-port")

                        self.amtgw = YLeaf(YType.str, "amtgw")

                        self.amtnh = YLeaf(YType.uint32, "amtnh")

                        self.gateway_address = YLeaf(YType.str, "gateway-address")

                        self.idb = YLeaf(YType.uint64, "idb")

                        self.key_len = YLeaf(YType.uint32, "key-len")

                        self.mem_upd_in = YLeaf(YType.uint32, "mem-upd-in")

                        self.mem_upd_out = YLeaf(YType.uint32, "mem-upd-out")

                        self.port = YLeaf(YType.int32, "port")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("amt_nonce",
                                        "amt_port",
                                        "amtgw",
                                        "amtnh",
                                        "gateway_address",
                                        "idb",
                                        "key_len",
                                        "mem_upd_in",
                                        "mem_upd_out",
                                        "port") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.Process.AmtGatewaies.AmtGateway, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.Process.AmtGatewaies.AmtGateway, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.amt_nonce.is_set or
                            self.amt_port.is_set or
                            self.amtgw.is_set or
                            self.amtnh.is_set or
                            self.gateway_address.is_set or
                            self.idb.is_set or
                            self.key_len.is_set or
                            self.mem_upd_in.is_set or
                            self.mem_upd_out.is_set or
                            self.port.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.amt_nonce.yfilter != YFilter.not_set or
                            self.amt_port.yfilter != YFilter.not_set or
                            self.amtgw.yfilter != YFilter.not_set or
                            self.amtnh.yfilter != YFilter.not_set or
                            self.gateway_address.yfilter != YFilter.not_set or
                            self.idb.yfilter != YFilter.not_set or
                            self.key_len.yfilter != YFilter.not_set or
                            self.mem_upd_in.yfilter != YFilter.not_set or
                            self.mem_upd_out.yfilter != YFilter.not_set or
                            self.port.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "amt-gateway" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/amt-gatewaies/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.amt_nonce.is_set or self.amt_nonce.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amt_nonce.get_name_leafdata())
                        if (self.amt_port.is_set or self.amt_port.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amt_port.get_name_leafdata())
                        if (self.amtgw.is_set or self.amtgw.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amtgw.get_name_leafdata())
                        if (self.amtnh.is_set or self.amtnh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.amtnh.get_name_leafdata())
                        if (self.gateway_address.is_set or self.gateway_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.gateway_address.get_name_leafdata())
                        if (self.idb.is_set or self.idb.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.idb.get_name_leafdata())
                        if (self.key_len.is_set or self.key_len.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.key_len.get_name_leafdata())
                        if (self.mem_upd_in.is_set or self.mem_upd_in.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mem_upd_in.get_name_leafdata())
                        if (self.mem_upd_out.is_set or self.mem_upd_out.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mem_upd_out.get_name_leafdata())
                        if (self.port.is_set or self.port.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.port.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "amt-nonce" or name == "amt-port" or name == "amtgw" or name == "amtnh" or name == "gateway-address" or name == "idb" or name == "key-len" or name == "mem-upd-in" or name == "mem-upd-out" or name == "port"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "amt-nonce"):
                            self.amt_nonce = value
                            self.amt_nonce.value_namespace = name_space
                            self.amt_nonce.value_namespace_prefix = name_space_prefix
                        if(value_path == "amt-port"):
                            self.amt_port = value
                            self.amt_port.value_namespace = name_space
                            self.amt_port.value_namespace_prefix = name_space_prefix
                        if(value_path == "amtgw"):
                            self.amtgw = value
                            self.amtgw.value_namespace = name_space
                            self.amtgw.value_namespace_prefix = name_space_prefix
                        if(value_path == "amtnh"):
                            self.amtnh = value
                            self.amtnh.value_namespace = name_space
                            self.amtnh.value_namespace_prefix = name_space_prefix
                        if(value_path == "gateway-address"):
                            self.gateway_address = value
                            self.gateway_address.value_namespace = name_space
                            self.gateway_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "idb"):
                            self.idb = value
                            self.idb.value_namespace = name_space
                            self.idb.value_namespace_prefix = name_space_prefix
                        if(value_path == "key-len"):
                            self.key_len = value
                            self.key_len.value_namespace = name_space
                            self.key_len.value_namespace_prefix = name_space_prefix
                        if(value_path == "mem-upd-in"):
                            self.mem_upd_in = value
                            self.mem_upd_in.value_namespace = name_space
                            self.mem_upd_in.value_namespace_prefix = name_space_prefix
                        if(value_path == "mem-upd-out"):
                            self.mem_upd_out = value
                            self.mem_upd_out.value_namespace = name_space
                            self.mem_upd_out.value_namespace_prefix = name_space_prefix
                        if(value_path == "port"):
                            self.port = value
                            self.port.value_namespace = name_space
                            self.port.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.amt_gateway:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.amt_gateway:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "amt-gatewaies" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "amt-gateway"):
                        for c in self.amt_gateway:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.Process.AmtGatewaies.AmtGateway()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.amt_gateway.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "amt-gateway"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class UnicastQosAdjustStats(Entity):
                """
                IGMP Unicast\-Qos\-Adjust Statistics
                
                .. attribute:: add_to_batches
                
                	Add to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: batches
                
                	I2Q Rate Batch count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: delete_to_batches
                
                	Delete to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_qos_s_sweeped
                
                	Is QOS Sweeped once 
                	**type**\:  bool
                
                .. attribute:: is_resync_received
                
                	Is Resync request received
                	**type**\:  bool
                
                .. attribute:: is_resync_required
                
                	Is Resync required
                	**type**\:  bool
                
                .. attribute:: is_resync_start_sent
                
                	Is Resync Start message sent
                	**type**\:  bool
                
                .. attribute:: last_download_time
                
                	Time elapsed since Last download to QOS in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: last_sweep_time
                
                	Time elapsed since Last mark and sweep in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: queues
                
                	I2Q Queue count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: received_resync_requests
                
                	Number of Resync request received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_comm_errors
                
                	Send Error due to comms count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_errors
                
                	Number of Send errors in batch
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_partial_errors
                
                	Send Error due to partial issue count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_success
                
                	Send Success count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sent_resync_bulks
                
                	Number of bulks sent for last resync received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.UnicastQosAdjustStats, self).__init__()

                    self.yang_name = "unicast-qos-adjust-stats"
                    self.yang_parent_name = "process"

                    self.add_to_batches = YLeaf(YType.uint32, "add-to-batches")

                    self.batches = YLeaf(YType.uint16, "batches")

                    self.delete_to_batches = YLeaf(YType.uint32, "delete-to-batches")

                    self.is_qos_s_sweeped = YLeaf(YType.boolean, "is-qos-s-sweeped")

                    self.is_resync_received = YLeaf(YType.boolean, "is-resync-received")

                    self.is_resync_required = YLeaf(YType.boolean, "is-resync-required")

                    self.is_resync_start_sent = YLeaf(YType.boolean, "is-resync-start-sent")

                    self.last_download_time = YLeaf(YType.uint64, "last-download-time")

                    self.last_sweep_time = YLeaf(YType.uint64, "last-sweep-time")

                    self.queues = YLeaf(YType.uint16, "queues")

                    self.received_resync_requests = YLeaf(YType.uint32, "received-resync-requests")

                    self.send_comm_errors = YLeaf(YType.uint32, "send-comm-errors")

                    self.send_errors = YLeaf(YType.uint32, "send-errors")

                    self.send_partial_errors = YLeaf(YType.uint32, "send-partial-errors")

                    self.send_success = YLeaf(YType.uint32, "send-success")

                    self.sent_resync_bulks = YLeaf(YType.uint32, "sent-resync-bulks")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("add_to_batches",
                                    "batches",
                                    "delete_to_batches",
                                    "is_qos_s_sweeped",
                                    "is_resync_received",
                                    "is_resync_required",
                                    "is_resync_start_sent",
                                    "last_download_time",
                                    "last_sweep_time",
                                    "queues",
                                    "received_resync_requests",
                                    "send_comm_errors",
                                    "send_errors",
                                    "send_partial_errors",
                                    "send_success",
                                    "sent_resync_bulks") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.Process.UnicastQosAdjustStats, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.Process.UnicastQosAdjustStats, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.add_to_batches.is_set or
                        self.batches.is_set or
                        self.delete_to_batches.is_set or
                        self.is_qos_s_sweeped.is_set or
                        self.is_resync_received.is_set or
                        self.is_resync_required.is_set or
                        self.is_resync_start_sent.is_set or
                        self.last_download_time.is_set or
                        self.last_sweep_time.is_set or
                        self.queues.is_set or
                        self.received_resync_requests.is_set or
                        self.send_comm_errors.is_set or
                        self.send_errors.is_set or
                        self.send_partial_errors.is_set or
                        self.send_success.is_set or
                        self.sent_resync_bulks.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.add_to_batches.yfilter != YFilter.not_set or
                        self.batches.yfilter != YFilter.not_set or
                        self.delete_to_batches.yfilter != YFilter.not_set or
                        self.is_qos_s_sweeped.yfilter != YFilter.not_set or
                        self.is_resync_received.yfilter != YFilter.not_set or
                        self.is_resync_required.yfilter != YFilter.not_set or
                        self.is_resync_start_sent.yfilter != YFilter.not_set or
                        self.last_download_time.yfilter != YFilter.not_set or
                        self.last_sweep_time.yfilter != YFilter.not_set or
                        self.queues.yfilter != YFilter.not_set or
                        self.received_resync_requests.yfilter != YFilter.not_set or
                        self.send_comm_errors.yfilter != YFilter.not_set or
                        self.send_errors.yfilter != YFilter.not_set or
                        self.send_partial_errors.yfilter != YFilter.not_set or
                        self.send_success.yfilter != YFilter.not_set or
                        self.sent_resync_bulks.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "unicast-qos-adjust-stats" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.add_to_batches.is_set or self.add_to_batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.add_to_batches.get_name_leafdata())
                    if (self.batches.is_set or self.batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.batches.get_name_leafdata())
                    if (self.delete_to_batches.is_set or self.delete_to_batches.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.delete_to_batches.get_name_leafdata())
                    if (self.is_qos_s_sweeped.is_set or self.is_qos_s_sweeped.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_qos_s_sweeped.get_name_leafdata())
                    if (self.is_resync_received.is_set or self.is_resync_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_received.get_name_leafdata())
                    if (self.is_resync_required.is_set or self.is_resync_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_required.get_name_leafdata())
                    if (self.is_resync_start_sent.is_set or self.is_resync_start_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync_start_sent.get_name_leafdata())
                    if (self.last_download_time.is_set or self.last_download_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_download_time.get_name_leafdata())
                    if (self.last_sweep_time.is_set or self.last_sweep_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_sweep_time.get_name_leafdata())
                    if (self.queues.is_set or self.queues.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.queues.get_name_leafdata())
                    if (self.received_resync_requests.is_set or self.received_resync_requests.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.received_resync_requests.get_name_leafdata())
                    if (self.send_comm_errors.is_set or self.send_comm_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_comm_errors.get_name_leafdata())
                    if (self.send_errors.is_set or self.send_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_errors.get_name_leafdata())
                    if (self.send_partial_errors.is_set or self.send_partial_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_partial_errors.get_name_leafdata())
                    if (self.send_success.is_set or self.send_success.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_success.get_name_leafdata())
                    if (self.sent_resync_bulks.is_set or self.sent_resync_bulks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sent_resync_bulks.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "add-to-batches" or name == "batches" or name == "delete-to-batches" or name == "is-qos-s-sweeped" or name == "is-resync-received" or name == "is-resync-required" or name == "is-resync-start-sent" or name == "last-download-time" or name == "last-sweep-time" or name == "queues" or name == "received-resync-requests" or name == "send-comm-errors" or name == "send-errors" or name == "send-partial-errors" or name == "send-success" or name == "sent-resync-bulks"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "add-to-batches"):
                        self.add_to_batches = value
                        self.add_to_batches.value_namespace = name_space
                        self.add_to_batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "batches"):
                        self.batches = value
                        self.batches.value_namespace = name_space
                        self.batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "delete-to-batches"):
                        self.delete_to_batches = value
                        self.delete_to_batches.value_namespace = name_space
                        self.delete_to_batches.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-qos-s-sweeped"):
                        self.is_qos_s_sweeped = value
                        self.is_qos_s_sweeped.value_namespace = name_space
                        self.is_qos_s_sweeped.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-received"):
                        self.is_resync_received = value
                        self.is_resync_received.value_namespace = name_space
                        self.is_resync_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-required"):
                        self.is_resync_required = value
                        self.is_resync_required.value_namespace = name_space
                        self.is_resync_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync-start-sent"):
                        self.is_resync_start_sent = value
                        self.is_resync_start_sent.value_namespace = name_space
                        self.is_resync_start_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-download-time"):
                        self.last_download_time = value
                        self.last_download_time.value_namespace = name_space
                        self.last_download_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-sweep-time"):
                        self.last_sweep_time = value
                        self.last_sweep_time.value_namespace = name_space
                        self.last_sweep_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "queues"):
                        self.queues = value
                        self.queues.value_namespace = name_space
                        self.queues.value_namespace_prefix = name_space_prefix
                    if(value_path == "received-resync-requests"):
                        self.received_resync_requests = value
                        self.received_resync_requests.value_namespace = name_space
                        self.received_resync_requests.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-comm-errors"):
                        self.send_comm_errors = value
                        self.send_comm_errors.value_namespace = name_space
                        self.send_comm_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-errors"):
                        self.send_errors = value
                        self.send_errors.value_namespace = name_space
                        self.send_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-partial-errors"):
                        self.send_partial_errors = value
                        self.send_partial_errors.value_namespace = name_space
                        self.send_partial_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-success"):
                        self.send_success = value
                        self.send_success.value_namespace = name_space
                        self.send_success.value_namespace_prefix = name_space_prefix
                    if(value_path == "sent-resync-bulks"):
                        self.sent_resync_bulks = value
                        self.sent_resync_bulks.value_namespace = name_space
                        self.sent_resync_bulks.value_namespace_prefix = name_space_prefix


            class BviStatistics(Entity):
                """
                IGMP BVI Stats
                
                .. attribute:: null_buffer_handles
                
                	Number of AIPC NULL buffer handles
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_buffers
                
                	Number of AIPC buffers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_buffers
                
                	Number of AIPC buffers released
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_fail_buffers
                
                	Number of AIPC buffers release failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_igmp_packet_success
                
                	Number of IGMP protocol messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_close_notif
                
                	Number of AIPC close notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_connect_notif
                
                	Number of AIPC connect notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_error_notif
                
                	Number of AIPC error notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_input_wait_notif
                
                	Number of AIPC input waiting notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_lwm_notif
                
                	Number of AIPC LWM notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_open_notif
                
                	Number of AIPC open notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_output_notif
                
                	Number of AIPC output notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_publish_notif
                
                	Number of AIPC publish notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_q_full_notif
                
                	Number of AIPC queue full notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_send_status_notif
                
                	Number of AIPC send status notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_blocks
                
                	Number of AIPC buffers send blocked
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffer_errors
                
                	Number of AIPC transmission errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffers
                
                	Number of AIPC buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_mrouter_buffers
                
                	Number of IGMP Mrouter buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_protocol_buffers
                
                	Number of IGMP protocol buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_buffers
                
                	Number of IGMP Unknown buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_dc
                
                	Number of WTX messages dropped due to disconnect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_nomem
                
                	Number of WTX messages dropped to memory
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_freed
                
                	Number of WTX messages freed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_proto_sent
                
                	Number of WTX messages sent to Protocol
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_recvd
                
                	Number of WTX messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_sent
                
                	Number of WTX messages sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.BviStatistics, self).__init__()

                    self.yang_name = "bvi-statistics"
                    self.yang_parent_name = "process"

                    self.null_buffer_handles = YLeaf(YType.uint32, "null-buffer-handles")

                    self.receive_buffers = YLeaf(YType.uint32, "receive-buffers")

                    self.release_buffers = YLeaf(YType.uint32, "release-buffers")

                    self.release_fail_buffers = YLeaf(YType.uint32, "release-fail-buffers")

                    self.rx_add_mrouter_msg = YLeaf(YType.uint32, "rx-add-mrouter-msg")

                    self.rx_delete_mrouter_msg = YLeaf(YType.uint32, "rx-delete-mrouter-msg")

                    self.rx_igmp_packet_success = YLeaf(YType.uint32, "rx-igmp-packet-success")

                    self.rx_ipc_close_notif = YLeaf(YType.uint32, "rx-ipc-close-notif")

                    self.rx_ipc_connect_notif = YLeaf(YType.uint32, "rx-ipc-connect-notif")

                    self.rx_ipc_error_notif = YLeaf(YType.uint32, "rx-ipc-error-notif")

                    self.rx_ipc_input_wait_notif = YLeaf(YType.uint32, "rx-ipc-input-wait-notif")

                    self.rx_ipc_lwm_notif = YLeaf(YType.uint32, "rx-ipc-lwm-notif")

                    self.rx_ipc_open_notif = YLeaf(YType.uint32, "rx-ipc-open-notif")

                    self.rx_ipc_output_notif = YLeaf(YType.uint32, "rx-ipc-output-notif")

                    self.rx_ipc_publish_notif = YLeaf(YType.uint32, "rx-ipc-publish-notif")

                    self.rx_ipc_q_full_notif = YLeaf(YType.uint32, "rx-ipc-q-full-notif")

                    self.rx_ipc_send_status_notif = YLeaf(YType.uint32, "rx-ipc-send-status-notif")

                    self.rx_sweep_mrouter_msg = YLeaf(YType.uint32, "rx-sweep-mrouter-msg")

                    self.rx_unknown_mrouter_msg = YLeaf(YType.uint32, "rx-unknown-mrouter-msg")

                    self.send_blocks = YLeaf(YType.uint32, "send-blocks")

                    self.tx_add_mrouter_msg = YLeaf(YType.uint32, "tx-add-mrouter-msg")

                    self.tx_buffer_errors = YLeaf(YType.uint32, "tx-buffer-errors")

                    self.tx_buffers = YLeaf(YType.uint32, "tx-buffers")

                    self.tx_delete_mrouter_msg = YLeaf(YType.uint32, "tx-delete-mrouter-msg")

                    self.tx_mrouter_buffers = YLeaf(YType.uint32, "tx-mrouter-buffers")

                    self.tx_protocol_buffers = YLeaf(YType.uint32, "tx-protocol-buffers")

                    self.tx_sweep_mrouter_msg = YLeaf(YType.uint32, "tx-sweep-mrouter-msg")

                    self.tx_unknown_buffers = YLeaf(YType.uint32, "tx-unknown-buffers")

                    self.tx_unknown_mrouter_msg = YLeaf(YType.uint32, "tx-unknown-mrouter-msg")

                    self.wtx_msg_drop_dc = YLeaf(YType.uint32, "wtx-msg-drop-dc")

                    self.wtx_msg_drop_nomem = YLeaf(YType.uint32, "wtx-msg-drop-nomem")

                    self.wtx_msg_freed = YLeaf(YType.uint32, "wtx-msg-freed")

                    self.wtx_msg_proto_sent = YLeaf(YType.uint32, "wtx-msg-proto-sent")

                    self.wtx_msg_recvd = YLeaf(YType.uint32, "wtx-msg-recvd")

                    self.wtx_msg_sent = YLeaf(YType.uint32, "wtx-msg-sent")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("null_buffer_handles",
                                    "receive_buffers",
                                    "release_buffers",
                                    "release_fail_buffers",
                                    "rx_add_mrouter_msg",
                                    "rx_delete_mrouter_msg",
                                    "rx_igmp_packet_success",
                                    "rx_ipc_close_notif",
                                    "rx_ipc_connect_notif",
                                    "rx_ipc_error_notif",
                                    "rx_ipc_input_wait_notif",
                                    "rx_ipc_lwm_notif",
                                    "rx_ipc_open_notif",
                                    "rx_ipc_output_notif",
                                    "rx_ipc_publish_notif",
                                    "rx_ipc_q_full_notif",
                                    "rx_ipc_send_status_notif",
                                    "rx_sweep_mrouter_msg",
                                    "rx_unknown_mrouter_msg",
                                    "send_blocks",
                                    "tx_add_mrouter_msg",
                                    "tx_buffer_errors",
                                    "tx_buffers",
                                    "tx_delete_mrouter_msg",
                                    "tx_mrouter_buffers",
                                    "tx_protocol_buffers",
                                    "tx_sweep_mrouter_msg",
                                    "tx_unknown_buffers",
                                    "tx_unknown_mrouter_msg",
                                    "wtx_msg_drop_dc",
                                    "wtx_msg_drop_nomem",
                                    "wtx_msg_freed",
                                    "wtx_msg_proto_sent",
                                    "wtx_msg_recvd",
                                    "wtx_msg_sent") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.Process.BviStatistics, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.Process.BviStatistics, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.null_buffer_handles.is_set or
                        self.receive_buffers.is_set or
                        self.release_buffers.is_set or
                        self.release_fail_buffers.is_set or
                        self.rx_add_mrouter_msg.is_set or
                        self.rx_delete_mrouter_msg.is_set or
                        self.rx_igmp_packet_success.is_set or
                        self.rx_ipc_close_notif.is_set or
                        self.rx_ipc_connect_notif.is_set or
                        self.rx_ipc_error_notif.is_set or
                        self.rx_ipc_input_wait_notif.is_set or
                        self.rx_ipc_lwm_notif.is_set or
                        self.rx_ipc_open_notif.is_set or
                        self.rx_ipc_output_notif.is_set or
                        self.rx_ipc_publish_notif.is_set or
                        self.rx_ipc_q_full_notif.is_set or
                        self.rx_ipc_send_status_notif.is_set or
                        self.rx_sweep_mrouter_msg.is_set or
                        self.rx_unknown_mrouter_msg.is_set or
                        self.send_blocks.is_set or
                        self.tx_add_mrouter_msg.is_set or
                        self.tx_buffer_errors.is_set or
                        self.tx_buffers.is_set or
                        self.tx_delete_mrouter_msg.is_set or
                        self.tx_mrouter_buffers.is_set or
                        self.tx_protocol_buffers.is_set or
                        self.tx_sweep_mrouter_msg.is_set or
                        self.tx_unknown_buffers.is_set or
                        self.tx_unknown_mrouter_msg.is_set or
                        self.wtx_msg_drop_dc.is_set or
                        self.wtx_msg_drop_nomem.is_set or
                        self.wtx_msg_freed.is_set or
                        self.wtx_msg_proto_sent.is_set or
                        self.wtx_msg_recvd.is_set or
                        self.wtx_msg_sent.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.null_buffer_handles.yfilter != YFilter.not_set or
                        self.receive_buffers.yfilter != YFilter.not_set or
                        self.release_buffers.yfilter != YFilter.not_set or
                        self.release_fail_buffers.yfilter != YFilter.not_set or
                        self.rx_add_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_delete_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_igmp_packet_success.yfilter != YFilter.not_set or
                        self.rx_ipc_close_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_connect_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_error_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_input_wait_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_lwm_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_open_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_output_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_publish_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_q_full_notif.yfilter != YFilter.not_set or
                        self.rx_ipc_send_status_notif.yfilter != YFilter.not_set or
                        self.rx_sweep_mrouter_msg.yfilter != YFilter.not_set or
                        self.rx_unknown_mrouter_msg.yfilter != YFilter.not_set or
                        self.send_blocks.yfilter != YFilter.not_set or
                        self.tx_add_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_buffer_errors.yfilter != YFilter.not_set or
                        self.tx_buffers.yfilter != YFilter.not_set or
                        self.tx_delete_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_mrouter_buffers.yfilter != YFilter.not_set or
                        self.tx_protocol_buffers.yfilter != YFilter.not_set or
                        self.tx_sweep_mrouter_msg.yfilter != YFilter.not_set or
                        self.tx_unknown_buffers.yfilter != YFilter.not_set or
                        self.tx_unknown_mrouter_msg.yfilter != YFilter.not_set or
                        self.wtx_msg_drop_dc.yfilter != YFilter.not_set or
                        self.wtx_msg_drop_nomem.yfilter != YFilter.not_set or
                        self.wtx_msg_freed.yfilter != YFilter.not_set or
                        self.wtx_msg_proto_sent.yfilter != YFilter.not_set or
                        self.wtx_msg_recvd.yfilter != YFilter.not_set or
                        self.wtx_msg_sent.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bvi-statistics" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.null_buffer_handles.is_set or self.null_buffer_handles.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.null_buffer_handles.get_name_leafdata())
                    if (self.receive_buffers.is_set or self.receive_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.receive_buffers.get_name_leafdata())
                    if (self.release_buffers.is_set or self.release_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.release_buffers.get_name_leafdata())
                    if (self.release_fail_buffers.is_set or self.release_fail_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.release_fail_buffers.get_name_leafdata())
                    if (self.rx_add_mrouter_msg.is_set or self.rx_add_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_add_mrouter_msg.get_name_leafdata())
                    if (self.rx_delete_mrouter_msg.is_set or self.rx_delete_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_delete_mrouter_msg.get_name_leafdata())
                    if (self.rx_igmp_packet_success.is_set or self.rx_igmp_packet_success.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_igmp_packet_success.get_name_leafdata())
                    if (self.rx_ipc_close_notif.is_set or self.rx_ipc_close_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_close_notif.get_name_leafdata())
                    if (self.rx_ipc_connect_notif.is_set or self.rx_ipc_connect_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_connect_notif.get_name_leafdata())
                    if (self.rx_ipc_error_notif.is_set or self.rx_ipc_error_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_error_notif.get_name_leafdata())
                    if (self.rx_ipc_input_wait_notif.is_set or self.rx_ipc_input_wait_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_input_wait_notif.get_name_leafdata())
                    if (self.rx_ipc_lwm_notif.is_set or self.rx_ipc_lwm_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_lwm_notif.get_name_leafdata())
                    if (self.rx_ipc_open_notif.is_set or self.rx_ipc_open_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_open_notif.get_name_leafdata())
                    if (self.rx_ipc_output_notif.is_set or self.rx_ipc_output_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_output_notif.get_name_leafdata())
                    if (self.rx_ipc_publish_notif.is_set or self.rx_ipc_publish_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_publish_notif.get_name_leafdata())
                    if (self.rx_ipc_q_full_notif.is_set or self.rx_ipc_q_full_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_q_full_notif.get_name_leafdata())
                    if (self.rx_ipc_send_status_notif.is_set or self.rx_ipc_send_status_notif.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_ipc_send_status_notif.get_name_leafdata())
                    if (self.rx_sweep_mrouter_msg.is_set or self.rx_sweep_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_sweep_mrouter_msg.get_name_leafdata())
                    if (self.rx_unknown_mrouter_msg.is_set or self.rx_unknown_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rx_unknown_mrouter_msg.get_name_leafdata())
                    if (self.send_blocks.is_set or self.send_blocks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.send_blocks.get_name_leafdata())
                    if (self.tx_add_mrouter_msg.is_set or self.tx_add_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_add_mrouter_msg.get_name_leafdata())
                    if (self.tx_buffer_errors.is_set or self.tx_buffer_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_buffer_errors.get_name_leafdata())
                    if (self.tx_buffers.is_set or self.tx_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_buffers.get_name_leafdata())
                    if (self.tx_delete_mrouter_msg.is_set or self.tx_delete_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_delete_mrouter_msg.get_name_leafdata())
                    if (self.tx_mrouter_buffers.is_set or self.tx_mrouter_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_mrouter_buffers.get_name_leafdata())
                    if (self.tx_protocol_buffers.is_set or self.tx_protocol_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_protocol_buffers.get_name_leafdata())
                    if (self.tx_sweep_mrouter_msg.is_set or self.tx_sweep_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_sweep_mrouter_msg.get_name_leafdata())
                    if (self.tx_unknown_buffers.is_set or self.tx_unknown_buffers.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_unknown_buffers.get_name_leafdata())
                    if (self.tx_unknown_mrouter_msg.is_set or self.tx_unknown_mrouter_msg.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tx_unknown_mrouter_msg.get_name_leafdata())
                    if (self.wtx_msg_drop_dc.is_set or self.wtx_msg_drop_dc.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_drop_dc.get_name_leafdata())
                    if (self.wtx_msg_drop_nomem.is_set or self.wtx_msg_drop_nomem.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_drop_nomem.get_name_leafdata())
                    if (self.wtx_msg_freed.is_set or self.wtx_msg_freed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_freed.get_name_leafdata())
                    if (self.wtx_msg_proto_sent.is_set or self.wtx_msg_proto_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_proto_sent.get_name_leafdata())
                    if (self.wtx_msg_recvd.is_set or self.wtx_msg_recvd.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_recvd.get_name_leafdata())
                    if (self.wtx_msg_sent.is_set or self.wtx_msg_sent.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.wtx_msg_sent.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "null-buffer-handles" or name == "receive-buffers" or name == "release-buffers" or name == "release-fail-buffers" or name == "rx-add-mrouter-msg" or name == "rx-delete-mrouter-msg" or name == "rx-igmp-packet-success" or name == "rx-ipc-close-notif" or name == "rx-ipc-connect-notif" or name == "rx-ipc-error-notif" or name == "rx-ipc-input-wait-notif" or name == "rx-ipc-lwm-notif" or name == "rx-ipc-open-notif" or name == "rx-ipc-output-notif" or name == "rx-ipc-publish-notif" or name == "rx-ipc-q-full-notif" or name == "rx-ipc-send-status-notif" or name == "rx-sweep-mrouter-msg" or name == "rx-unknown-mrouter-msg" or name == "send-blocks" or name == "tx-add-mrouter-msg" or name == "tx-buffer-errors" or name == "tx-buffers" or name == "tx-delete-mrouter-msg" or name == "tx-mrouter-buffers" or name == "tx-protocol-buffers" or name == "tx-sweep-mrouter-msg" or name == "tx-unknown-buffers" or name == "tx-unknown-mrouter-msg" or name == "wtx-msg-drop-dc" or name == "wtx-msg-drop-nomem" or name == "wtx-msg-freed" or name == "wtx-msg-proto-sent" or name == "wtx-msg-recvd" or name == "wtx-msg-sent"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "null-buffer-handles"):
                        self.null_buffer_handles = value
                        self.null_buffer_handles.value_namespace = name_space
                        self.null_buffer_handles.value_namespace_prefix = name_space_prefix
                    if(value_path == "receive-buffers"):
                        self.receive_buffers = value
                        self.receive_buffers.value_namespace = name_space
                        self.receive_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "release-buffers"):
                        self.release_buffers = value
                        self.release_buffers.value_namespace = name_space
                        self.release_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "release-fail-buffers"):
                        self.release_fail_buffers = value
                        self.release_fail_buffers.value_namespace = name_space
                        self.release_fail_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-add-mrouter-msg"):
                        self.rx_add_mrouter_msg = value
                        self.rx_add_mrouter_msg.value_namespace = name_space
                        self.rx_add_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-delete-mrouter-msg"):
                        self.rx_delete_mrouter_msg = value
                        self.rx_delete_mrouter_msg.value_namespace = name_space
                        self.rx_delete_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-igmp-packet-success"):
                        self.rx_igmp_packet_success = value
                        self.rx_igmp_packet_success.value_namespace = name_space
                        self.rx_igmp_packet_success.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-close-notif"):
                        self.rx_ipc_close_notif = value
                        self.rx_ipc_close_notif.value_namespace = name_space
                        self.rx_ipc_close_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-connect-notif"):
                        self.rx_ipc_connect_notif = value
                        self.rx_ipc_connect_notif.value_namespace = name_space
                        self.rx_ipc_connect_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-error-notif"):
                        self.rx_ipc_error_notif = value
                        self.rx_ipc_error_notif.value_namespace = name_space
                        self.rx_ipc_error_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-input-wait-notif"):
                        self.rx_ipc_input_wait_notif = value
                        self.rx_ipc_input_wait_notif.value_namespace = name_space
                        self.rx_ipc_input_wait_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-lwm-notif"):
                        self.rx_ipc_lwm_notif = value
                        self.rx_ipc_lwm_notif.value_namespace = name_space
                        self.rx_ipc_lwm_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-open-notif"):
                        self.rx_ipc_open_notif = value
                        self.rx_ipc_open_notif.value_namespace = name_space
                        self.rx_ipc_open_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-output-notif"):
                        self.rx_ipc_output_notif = value
                        self.rx_ipc_output_notif.value_namespace = name_space
                        self.rx_ipc_output_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-publish-notif"):
                        self.rx_ipc_publish_notif = value
                        self.rx_ipc_publish_notif.value_namespace = name_space
                        self.rx_ipc_publish_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-q-full-notif"):
                        self.rx_ipc_q_full_notif = value
                        self.rx_ipc_q_full_notif.value_namespace = name_space
                        self.rx_ipc_q_full_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-ipc-send-status-notif"):
                        self.rx_ipc_send_status_notif = value
                        self.rx_ipc_send_status_notif.value_namespace = name_space
                        self.rx_ipc_send_status_notif.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-sweep-mrouter-msg"):
                        self.rx_sweep_mrouter_msg = value
                        self.rx_sweep_mrouter_msg.value_namespace = name_space
                        self.rx_sweep_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "rx-unknown-mrouter-msg"):
                        self.rx_unknown_mrouter_msg = value
                        self.rx_unknown_mrouter_msg.value_namespace = name_space
                        self.rx_unknown_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "send-blocks"):
                        self.send_blocks = value
                        self.send_blocks.value_namespace = name_space
                        self.send_blocks.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-add-mrouter-msg"):
                        self.tx_add_mrouter_msg = value
                        self.tx_add_mrouter_msg.value_namespace = name_space
                        self.tx_add_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-buffer-errors"):
                        self.tx_buffer_errors = value
                        self.tx_buffer_errors.value_namespace = name_space
                        self.tx_buffer_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-buffers"):
                        self.tx_buffers = value
                        self.tx_buffers.value_namespace = name_space
                        self.tx_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-delete-mrouter-msg"):
                        self.tx_delete_mrouter_msg = value
                        self.tx_delete_mrouter_msg.value_namespace = name_space
                        self.tx_delete_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-mrouter-buffers"):
                        self.tx_mrouter_buffers = value
                        self.tx_mrouter_buffers.value_namespace = name_space
                        self.tx_mrouter_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-protocol-buffers"):
                        self.tx_protocol_buffers = value
                        self.tx_protocol_buffers.value_namespace = name_space
                        self.tx_protocol_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-sweep-mrouter-msg"):
                        self.tx_sweep_mrouter_msg = value
                        self.tx_sweep_mrouter_msg.value_namespace = name_space
                        self.tx_sweep_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-unknown-buffers"):
                        self.tx_unknown_buffers = value
                        self.tx_unknown_buffers.value_namespace = name_space
                        self.tx_unknown_buffers.value_namespace_prefix = name_space_prefix
                    if(value_path == "tx-unknown-mrouter-msg"):
                        self.tx_unknown_mrouter_msg = value
                        self.tx_unknown_mrouter_msg.value_namespace = name_space
                        self.tx_unknown_mrouter_msg.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-drop-dc"):
                        self.wtx_msg_drop_dc = value
                        self.wtx_msg_drop_dc.value_namespace = name_space
                        self.wtx_msg_drop_dc.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-drop-nomem"):
                        self.wtx_msg_drop_nomem = value
                        self.wtx_msg_drop_nomem.value_namespace = name_space
                        self.wtx_msg_drop_nomem.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-freed"):
                        self.wtx_msg_freed = value
                        self.wtx_msg_freed.value_namespace = name_space
                        self.wtx_msg_freed.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-proto-sent"):
                        self.wtx_msg_proto_sent = value
                        self.wtx_msg_proto_sent.value_namespace = name_space
                        self.wtx_msg_proto_sent.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-recvd"):
                        self.wtx_msg_recvd = value
                        self.wtx_msg_recvd.value_namespace = name_space
                        self.wtx_msg_recvd.value_namespace_prefix = name_space_prefix
                    if(value_path == "wtx-msg-sent"):
                        self.wtx_msg_sent = value
                        self.wtx_msg_sent.value_namespace = name_space
                        self.wtx_msg_sent.value_namespace_prefix = name_space_prefix


            class Nsf(Entity):
                """
                NSF Information
                
                .. attribute:: is_multicast_nsf_active
                
                	Is Multicast NSF active
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_min
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_min
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_min
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_time_left
                
                	Multicast NSF time remaining in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_timeout
                
                	Multicast NSF timeout in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"

                    self.is_multicast_nsf_active = YLeaf(YType.boolean, "is-multicast-nsf-active")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_min = YLeaf(YType.int32, "last-icd-notif-recv-min")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_min = YLeaf(YType.int32, "last-nsf-off-min")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_min = YLeaf(YType.int32, "last-nsf-on-min")

                    self.multicast_nsf_time_left = YLeaf(YType.uint32, "multicast-nsf-time-left")

                    self.multicast_nsf_timeout = YLeaf(YType.uint32, "multicast-nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_multicast_nsf_active",
                                    "last_icd_notif_recv",
                                    "last_icd_notif_recv_min",
                                    "last_nsf_off",
                                    "last_nsf_off_min",
                                    "last_nsf_on",
                                    "last_nsf_on_min",
                                    "multicast_nsf_time_left",
                                    "multicast_nsf_timeout",
                                    "respawn_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.Process.Nsf, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.Process.Nsf, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_multicast_nsf_active.is_set or
                        self.last_icd_notif_recv.is_set or
                        self.last_icd_notif_recv_min.is_set or
                        self.last_nsf_off.is_set or
                        self.last_nsf_off_min.is_set or
                        self.last_nsf_on.is_set or
                        self.last_nsf_on_min.is_set or
                        self.multicast_nsf_time_left.is_set or
                        self.multicast_nsf_timeout.is_set or
                        self.respawn_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_multicast_nsf_active.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv.yfilter != YFilter.not_set or
                        self.last_icd_notif_recv_min.yfilter != YFilter.not_set or
                        self.last_nsf_off.yfilter != YFilter.not_set or
                        self.last_nsf_off_min.yfilter != YFilter.not_set or
                        self.last_nsf_on.yfilter != YFilter.not_set or
                        self.last_nsf_on_min.yfilter != YFilter.not_set or
                        self.multicast_nsf_time_left.yfilter != YFilter.not_set or
                        self.multicast_nsf_timeout.yfilter != YFilter.not_set or
                        self.respawn_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "nsf" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_multicast_nsf_active.is_set or self.is_multicast_nsf_active.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_multicast_nsf_active.get_name_leafdata())
                    if (self.last_icd_notif_recv.is_set or self.last_icd_notif_recv.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv.get_name_leafdata())
                    if (self.last_icd_notif_recv_min.is_set or self.last_icd_notif_recv_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_icd_notif_recv_min.get_name_leafdata())
                    if (self.last_nsf_off.is_set or self.last_nsf_off.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off.get_name_leafdata())
                    if (self.last_nsf_off_min.is_set or self.last_nsf_off_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_off_min.get_name_leafdata())
                    if (self.last_nsf_on.is_set or self.last_nsf_on.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on.get_name_leafdata())
                    if (self.last_nsf_on_min.is_set or self.last_nsf_on_min.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.last_nsf_on_min.get_name_leafdata())
                    if (self.multicast_nsf_time_left.is_set or self.multicast_nsf_time_left.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.multicast_nsf_time_left.get_name_leafdata())
                    if (self.multicast_nsf_timeout.is_set or self.multicast_nsf_timeout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.multicast_nsf_timeout.get_name_leafdata())
                    if (self.respawn_count.is_set or self.respawn_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.respawn_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-multicast-nsf-active" or name == "last-icd-notif-recv" or name == "last-icd-notif-recv-min" or name == "last-nsf-off" or name == "last-nsf-off-min" or name == "last-nsf-on" or name == "last-nsf-on-min" or name == "multicast-nsf-time-left" or name == "multicast-nsf-timeout" or name == "respawn-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-multicast-nsf-active"):
                        self.is_multicast_nsf_active = value
                        self.is_multicast_nsf_active.value_namespace = name_space
                        self.is_multicast_nsf_active.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv"):
                        self.last_icd_notif_recv = value
                        self.last_icd_notif_recv.value_namespace = name_space
                        self.last_icd_notif_recv.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-icd-notif-recv-min"):
                        self.last_icd_notif_recv_min = value
                        self.last_icd_notif_recv_min.value_namespace = name_space
                        self.last_icd_notif_recv_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off"):
                        self.last_nsf_off = value
                        self.last_nsf_off.value_namespace = name_space
                        self.last_nsf_off.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-off-min"):
                        self.last_nsf_off_min = value
                        self.last_nsf_off_min.value_namespace = name_space
                        self.last_nsf_off_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on"):
                        self.last_nsf_on = value
                        self.last_nsf_on.value_namespace = name_space
                        self.last_nsf_on.value_namespace_prefix = name_space_prefix
                    if(value_path == "last-nsf-on-min"):
                        self.last_nsf_on_min = value
                        self.last_nsf_on_min.value_namespace = name_space
                        self.last_nsf_on_min.value_namespace_prefix = name_space_prefix
                    if(value_path == "multicast-nsf-time-left"):
                        self.multicast_nsf_time_left = value
                        self.multicast_nsf_time_left.value_namespace = name_space
                        self.multicast_nsf_time_left.value_namespace_prefix = name_space_prefix
                    if(value_path == "multicast-nsf-timeout"):
                        self.multicast_nsf_timeout = value
                        self.multicast_nsf_timeout.value_namespace = name_space
                        self.multicast_nsf_timeout.value_namespace_prefix = name_space_prefix
                    if(value_path == "respawn-count"):
                        self.respawn_count = value
                        self.respawn_count.value_namespace = name_space
                        self.respawn_count.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    (self.amt_gatewaies is not None and self.amt_gatewaies.has_data()) or
                    (self.amt_summary is not None and self.amt_summary.has_data()) or
                    (self.bvi_statistics is not None and self.bvi_statistics.has_data()) or
                    (self.nsf is not None and self.nsf.has_data()) or
                    (self.nsr is not None and self.nsr.has_data()) or
                    (self.unicast_qos_adjust_stats is not None and self.unicast_qos_adjust_stats.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.amt_gatewaies is not None and self.amt_gatewaies.has_operation()) or
                    (self.amt_summary is not None and self.amt_summary.has_operation()) or
                    (self.bvi_statistics is not None and self.bvi_statistics.has_operation()) or
                    (self.nsf is not None and self.nsf.has_operation()) or
                    (self.nsr is not None and self.nsr.has_operation()) or
                    (self.unicast_qos_adjust_stats is not None and self.unicast_qos_adjust_stats.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "process" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "amt-gatewaies"):
                    if (self.amt_gatewaies is None):
                        self.amt_gatewaies = Igmp.Active.Process.AmtGatewaies()
                        self.amt_gatewaies.parent = self
                        self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                    return self.amt_gatewaies

                if (child_yang_name == "amt-summary"):
                    if (self.amt_summary is None):
                        self.amt_summary = Igmp.Active.Process.AmtSummary()
                        self.amt_summary.parent = self
                        self._children_name_map["amt_summary"] = "amt-summary"
                    return self.amt_summary

                if (child_yang_name == "bvi-statistics"):
                    if (self.bvi_statistics is None):
                        self.bvi_statistics = Igmp.Active.Process.BviStatistics()
                        self.bvi_statistics.parent = self
                        self._children_name_map["bvi_statistics"] = "bvi-statistics"
                    return self.bvi_statistics

                if (child_yang_name == "nsf"):
                    if (self.nsf is None):
                        self.nsf = Igmp.Active.Process.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"
                    return self.nsf

                if (child_yang_name == "nsr"):
                    if (self.nsr is None):
                        self.nsr = Igmp.Active.Process.Nsr()
                        self.nsr.parent = self
                        self._children_name_map["nsr"] = "nsr"
                    return self.nsr

                if (child_yang_name == "unicast-qos-adjust-stats"):
                    if (self.unicast_qos_adjust_stats is None):
                        self.unicast_qos_adjust_stats = Igmp.Active.Process.UnicastQosAdjustStats()
                        self.unicast_qos_adjust_stats.parent = self
                        self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                    return self.unicast_qos_adjust_stats

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "amt-gatewaies" or name == "amt-summary" or name == "bvi-statistics" or name == "nsf" or name == "nsr" or name == "unicast-qos-adjust-stats"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: detail_groups
            
            	IGMP Detail Group Database
            	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups>`
            
            .. attribute:: explicit_groups
            
            	IGMP Explicit Group Database
            	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups>`
            
            .. attribute:: global_interface_table
            
            	IGMP Global Interface 
            	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GlobalInterfaceTable>`
            
            .. attribute:: group_summary
            
            	IGMP Groups Summary
            	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GroupSummary>`
            
            .. attribute:: groups
            
            	IGMP Group Database Table
            	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Groups>`
            
            .. attribute:: ifrs_interface_summary
            
            	IGMP IFRS Interface summary
            	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaceSummary>`
            
            .. attribute:: ifrs_interfaces
            
            	IGMP Interface specific
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: interface_state_offs
            
            	IGMP Interface state off
            	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOffs>`
            
            .. attribute:: interface_state_ons
            
            	IGMP Interface state on
            	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOns>`
            
            .. attribute:: interface_table
            
            	IGMP Interface specific Table
            	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceTable>`
            
            .. attribute:: interface_unicast_qos_adjusts
            
            	IGMP Interface Unicast\-Qos\-Adjust
            	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts>`
            
            .. attribute:: non_active_groups
            
            	IGMP Non\-Active Groups Information
            	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.NonActiveGroups>`
            
            .. attribute:: ranges
            
            	Range table
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Ranges>`
            
            .. attribute:: ssm_map_details
            
            	SSM Map Detail
            	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMapDetails>`
            
            .. attribute:: ssm_maps
            
            	SSM Map Table
            	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMaps>`
            
            .. attribute:: summary
            
            	IGMP Summary Information
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Summary>`
            
            .. attribute:: traffic_counters
            
            	IGMP Message Traffic Counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.TrafficCounters>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Active.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "active"

                self.detail_groups = Igmp.Active.DefaultContext.DetailGroups()
                self.detail_groups.parent = self
                self._children_name_map["detail_groups"] = "detail-groups"
                self._children_yang_names.add("detail-groups")

                self.explicit_groups = Igmp.Active.DefaultContext.ExplicitGroups()
                self.explicit_groups.parent = self
                self._children_name_map["explicit_groups"] = "explicit-groups"
                self._children_yang_names.add("explicit-groups")

                self.global_interface_table = Igmp.Active.DefaultContext.GlobalInterfaceTable()
                self.global_interface_table.parent = self
                self._children_name_map["global_interface_table"] = "global-interface-table"
                self._children_yang_names.add("global-interface-table")

                self.group_summary = Igmp.Active.DefaultContext.GroupSummary()
                self.group_summary.parent = self
                self._children_name_map["group_summary"] = "group-summary"
                self._children_yang_names.add("group-summary")

                self.groups = Igmp.Active.DefaultContext.Groups()
                self.groups.parent = self
                self._children_name_map["groups"] = "groups"
                self._children_yang_names.add("groups")

                self.ifrs_interface_summary = Igmp.Active.DefaultContext.IfrsInterfaceSummary()
                self.ifrs_interface_summary.parent = self
                self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                self._children_yang_names.add("ifrs-interface-summary")

                self.ifrs_interfaces = Igmp.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.interface_state_offs = Igmp.Active.DefaultContext.InterfaceStateOffs()
                self.interface_state_offs.parent = self
                self._children_name_map["interface_state_offs"] = "interface-state-offs"
                self._children_yang_names.add("interface-state-offs")

                self.interface_state_ons = Igmp.Active.DefaultContext.InterfaceStateOns()
                self.interface_state_ons.parent = self
                self._children_name_map["interface_state_ons"] = "interface-state-ons"
                self._children_yang_names.add("interface-state-ons")

                self.interface_table = Igmp.Active.DefaultContext.InterfaceTable()
                self.interface_table.parent = self
                self._children_name_map["interface_table"] = "interface-table"
                self._children_yang_names.add("interface-table")

                self.interface_unicast_qos_adjusts = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts()
                self.interface_unicast_qos_adjusts.parent = self
                self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                self._children_yang_names.add("interface-unicast-qos-adjusts")

                self.non_active_groups = Igmp.Active.DefaultContext.NonActiveGroups()
                self.non_active_groups.parent = self
                self._children_name_map["non_active_groups"] = "non-active-groups"
                self._children_yang_names.add("non-active-groups")

                self.ranges = Igmp.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.ssm_map_details = Igmp.Active.DefaultContext.SsmMapDetails()
                self.ssm_map_details.parent = self
                self._children_name_map["ssm_map_details"] = "ssm-map-details"
                self._children_yang_names.add("ssm-map-details")

                self.ssm_maps = Igmp.Active.DefaultContext.SsmMaps()
                self.ssm_maps.parent = self
                self._children_name_map["ssm_maps"] = "ssm-maps"
                self._children_yang_names.add("ssm-maps")

                self.summary = Igmp.Active.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.traffic_counters = Igmp.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")


            class Summary(Entity):
                """
                IGMP Summary Information
                
                .. attribute:: disabled_interface_count
                
                	No. of disabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: enabled_interface_count
                
                	No. of enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_limit
                
                	Maximum groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Maximum and current groups accepted for each interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Summary.Interface>`
                
                .. attribute:: is_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: robustness
                
                	Robustness variable
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: supported_interfaces
                
                	No. of supported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_mte_config_count
                
                	No. of static group commands
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsupported_interfaces
                
                	No. of unsupported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"

                    self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                    self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.group_limit = YLeaf(YType.uint32, "group-limit")

                    self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                    self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                    self.robustness = YLeaf(YType.uint32, "robustness")

                    self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                    self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                    self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("disabled_interface_count",
                                    "enabled_interface_count",
                                    "group_count",
                                    "group_limit",
                                    "is_disabled",
                                    "node_low_memory",
                                    "robustness",
                                    "supported_interfaces",
                                    "tunnel_mte_config_count",
                                    "unsupported_interfaces") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.Summary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.Summary, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    Maximum and current groups accepted for each
                    interface
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: on_off
                    
                    	Enabled/Disabled
                    	**type**\:  bool
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent if handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Time elapsed since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.Summary.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "summary"

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.on_off = YLeaf(YType.boolean, "on-off")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_count",
                                        "group_limit",
                                        "interface_name",
                                        "on_off",
                                        "parent_ifhandle",
                                        "router_uptime_in_seconds",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.Summary.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.Summary.Interface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.group_count.is_set or
                            self.group_limit.is_set or
                            self.interface_name.is_set or
                            self.on_off.is_set or
                            self.parent_ifhandle.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_count.yfilter != YFilter.not_set or
                            self.group_limit.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.on_off.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/summary/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_count.get_name_leafdata())
                        if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_limit.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.on_off.is_set or self.on_off.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.on_off.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-count" or name == "group-limit" or name == "interface-name" or name == "on-off" or name == "parent-ifhandle" or name == "router-uptime-in-seconds" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-count"):
                            self.group_count = value
                            self.group_count.value_namespace = name_space
                            self.group_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-limit"):
                            self.group_limit = value
                            self.group_limit.value_namespace = name_space
                            self.group_limit.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "on-off"):
                            self.on_off = value
                            self.on_off.value_namespace = name_space
                            self.on_off.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return (
                        self.disabled_interface_count.is_set or
                        self.enabled_interface_count.is_set or
                        self.group_count.is_set or
                        self.group_limit.is_set or
                        self.is_disabled.is_set or
                        self.node_low_memory.is_set or
                        self.robustness.is_set or
                        self.supported_interfaces.is_set or
                        self.tunnel_mte_config_count.is_set or
                        self.unsupported_interfaces.is_set)

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.disabled_interface_count.yfilter != YFilter.not_set or
                        self.enabled_interface_count.yfilter != YFilter.not_set or
                        self.group_count.yfilter != YFilter.not_set or
                        self.group_limit.yfilter != YFilter.not_set or
                        self.is_disabled.yfilter != YFilter.not_set or
                        self.node_low_memory.yfilter != YFilter.not_set or
                        self.robustness.yfilter != YFilter.not_set or
                        self.supported_interfaces.yfilter != YFilter.not_set or
                        self.tunnel_mte_config_count.yfilter != YFilter.not_set or
                        self.unsupported_interfaces.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.disabled_interface_count.is_set or self.disabled_interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.disabled_interface_count.get_name_leafdata())
                    if (self.enabled_interface_count.is_set or self.enabled_interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.enabled_interface_count.get_name_leafdata())
                    if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_count.get_name_leafdata())
                    if (self.group_limit.is_set or self.group_limit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_limit.get_name_leafdata())
                    if (self.is_disabled.is_set or self.is_disabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_disabled.get_name_leafdata())
                    if (self.node_low_memory.is_set or self.node_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.node_low_memory.get_name_leafdata())
                    if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.robustness.get_name_leafdata())
                    if (self.supported_interfaces.is_set or self.supported_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.supported_interfaces.get_name_leafdata())
                    if (self.tunnel_mte_config_count.is_set or self.tunnel_mte_config_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tunnel_mte_config_count.get_name_leafdata())
                    if (self.unsupported_interfaces.is_set or self.unsupported_interfaces.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.unsupported_interfaces.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.Summary.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface" or name == "disabled-interface-count" or name == "enabled-interface-count" or name == "group-count" or name == "group-limit" or name == "is-disabled" or name == "node-low-memory" or name == "robustness" or name == "supported-interfaces" or name == "tunnel-mte-config-count" or name == "unsupported-interfaces"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "disabled-interface-count"):
                        self.disabled_interface_count = value
                        self.disabled_interface_count.value_namespace = name_space
                        self.disabled_interface_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "enabled-interface-count"):
                        self.enabled_interface_count = value
                        self.enabled_interface_count.value_namespace = name_space
                        self.enabled_interface_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-count"):
                        self.group_count = value
                        self.group_count.value_namespace = name_space
                        self.group_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "group-limit"):
                        self.group_limit = value
                        self.group_limit.value_namespace = name_space
                        self.group_limit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-disabled"):
                        self.is_disabled = value
                        self.is_disabled.value_namespace = name_space
                        self.is_disabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "node-low-memory"):
                        self.node_low_memory = value
                        self.node_low_memory.value_namespace = name_space
                        self.node_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "robustness"):
                        self.robustness = value
                        self.robustness.value_namespace = name_space
                        self.robustness.value_namespace_prefix = name_space_prefix
                    if(value_path == "supported-interfaces"):
                        self.supported_interfaces = value
                        self.supported_interfaces.value_namespace = name_space
                        self.supported_interfaces.value_namespace_prefix = name_space_prefix
                    if(value_path == "tunnel-mte-config-count"):
                        self.tunnel_mte_config_count = value
                        self.tunnel_mte_config_count.value_namespace = name_space
                        self.tunnel_mte_config_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "unsupported-interfaces"):
                        self.unsupported_interfaces = value
                        self.unsupported_interfaces.value_namespace = name_space
                        self.unsupported_interfaces.value_namespace_prefix = name_space_prefix


            class InterfaceStateOns(Entity):
                """
                IGMP Interface state on
                
                .. attribute:: interface_state_on
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.InterfaceStateOns, self).__init__()

                    self.yang_name = "interface-state-ons"
                    self.yang_parent_name = "default-context"

                    self.interface_state_on = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.InterfaceStateOns, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.InterfaceStateOns, self).__setattr__(name, value)


                class InterfaceStateOn(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__init__()

                        self.yang_name = "interface-state-on"
                        self.yang_parent_name = "interface-state-ons"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-on"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/interface-state-ons/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_state_on:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_state_on:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-state-ons" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-state-on"):
                        for c in self.interface_state_on:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_state_on.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-state-on"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class DetailGroups(Entity):
                """
                IGMP Detail Group Database
                
                .. attribute:: detail_group
                
                	IGMP Detail Group Entry Information
                	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.DetailGroups, self).__init__()

                    self.yang_name = "detail-groups"
                    self.yang_parent_name = "default-context"

                    self.detail_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.DetailGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.DetailGroups, self).__setattr__(name, value)


                class DetailGroup(Entity):
                    """
                    IGMP Detail Group Entry Information
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_host_exclude_mode
                    
                    	Group host filter mode
                    	**type**\:  bool
                    
                    .. attribute:: is_router_exclude_mode
                    
                    	Group router filter mode
                    	**type**\:  bool
                    
                    .. attribute:: source
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup, self).__init__()

                        self.yang_name = "detail-group"
                        self.yang_parent_name = "detail-groups"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                        self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.source = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "interface_name",
                                        "is_host_exclude_mode",
                                        "is_router_exclude_mode",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup, self).__setattr__(name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "detail-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix


                    class Source(Entity):
                        """
                        List of sources
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: flags
                        
                        	Source flags
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_forward
                        
                        	Should we forward on this entry
                        	**type**\:  bool
                        
                        .. attribute:: is_local
                        
                        	Is this a local source
                        	**type**\:  bool
                        
                        .. attribute:: is_remote
                        
                        	Is this a remote source
                        	**type**\:  bool
                        
                        .. attribute:: is_we_report
                        
                        	Should we report the source
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "detail-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.flags = YLeaf(YType.int32, "flags")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_forward = YLeaf(YType.boolean, "is-forward")

                            self.is_local = YLeaf(YType.boolean, "is-local")

                            self.is_remote = YLeaf(YType.boolean, "is-remote")

                            self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.source_address = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "flags",
                                            "is_added",
                                            "is_forward",
                                            "is_local",
                                            "is_remote",
                                            "is_we_report",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "source"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/source/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.flags.is_set or
                                self.is_added.is_set or
                                self.is_forward.is_set or
                                self.is_local.is_set or
                                self.is_remote.is_set or
                                self.is_we_report.is_set or
                                self.uptime.is_set or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.flags.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_forward.yfilter != YFilter.not_set or
                                self.is_local.yfilter != YFilter.not_set or
                                self.is_remote.yfilter != YFilter.not_set or
                                self.is_we_report.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.flags.is_set or self.flags.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flags.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_forward.is_set or self.is_forward.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_forward.get_name_leafdata())
                            if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_local.get_name_leafdata())
                            if (self.is_remote.is_set or self.is_remote.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_remote.get_name_leafdata())
                            if (self.is_we_report.is_set or self.is_we_report.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_we_report.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "expiration-time" or name == "flags" or name == "is-added" or name == "is-forward" or name == "is-local" or name == "is-remote" or name == "is-we-report" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "flags"):
                                self.flags = value
                                self.flags.value_namespace = name_space
                                self.flags.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-forward"):
                                self.is_forward = value
                                self.is_forward.value_namespace = name_space
                                self.is_forward.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-local"):
                                self.is_local = value
                                self.is_local.value_namespace = name_space
                                self.is_local.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-remote"):
                                self.is_remote = value
                                self.is_remote.value_namespace = name_space
                                self.is_remote.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-we-report"):
                                self.is_we_report = value
                                self.is_we_report.value_namespace = name_space
                                self.is_we_report.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.source:
                            if (c.has_data()):
                                return True
                        return (
                            self.group_address.is_set or
                            self.interface_name.is_set or
                            self.is_host_exclude_mode.is_set or
                            self.is_router_exclude_mode.is_set or
                            self.source_address.is_set or
                            (self.group_info is not None and self.group_info.has_data()))

                    def has_operation(self):
                        for c in self.source:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_host_exclude_mode.yfilter != YFilter.not_set or
                            self.is_router_exclude_mode.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group_info is not None and self.group_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "detail-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_host_exclude_mode.is_set or self.is_host_exclude_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_host_exclude_mode.get_name_leafdata())
                        if (self.is_router_exclude_mode.is_set or self.is_router_exclude_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_exclude_mode.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-info"):
                            if (self.group_info is None):
                                self.group_info = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                                self.group_info.parent = self
                                self._children_name_map["group_info"] = "group-info"
                            return self.group_info

                        if (child_yang_name == "source"):
                            for c in self.source:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.source.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-info" or name == "source" or name == "group-address" or name == "interface-name" or name == "is-host-exclude-mode" or name == "is-router-exclude-mode" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-host-exclude-mode"):
                            self.is_host_exclude_mode = value
                            self.is_host_exclude_mode.value_namespace = name_space
                            self.is_host_exclude_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-exclude-mode"):
                            self.is_router_exclude_mode = value
                            self.is_router_exclude_mode.value_namespace = name_space
                            self.is_router_exclude_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.detail_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.detail_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "detail-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "detail-group"):
                        for c in self.detail_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.DetailGroups.DetailGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.detail_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "detail-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class NonActiveGroups(Entity):
                """
                IGMP Non\-Active Groups Information
                
                .. attribute:: non_active_groups
                
                	List of non\-active groups
                	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.NonActiveGroups, self).__init__()

                    self.yang_name = "non-active-groups"
                    self.yang_parent_name = "default-context"

                    self.non_active_groups = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.NonActiveGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.NonActiveGroups, self).__setattr__(name, value)


                class NonActiveGroups(Entity):
                    """
                    List of non\-active groups
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress>`
                    
                    .. attribute:: interface
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**length:** 0..65
                    
                    .. attribute:: reason_for_non_activity
                    
                    	Reason for group join not being processed
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "non-active-groups"

                        self.interface = YLeaf(YType.str, "interface")

                        self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                        self.group_address = Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                        self.source_address = Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface",
                                        "reason_for_non_activity") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups, self).__setattr__(name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "non-active-groups"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/non-active-groups/non-active-groups/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "non-active-groups"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/non-active-groups/non-active-groups/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface.is_set or
                            self.reason_for_non_activity.is_set or
                            (self.group_address is not None and self.group_address.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface.yfilter != YFilter.not_set or
                            self.reason_for_non_activity.yfilter != YFilter.not_set or
                            (self.group_address is not None and self.group_address.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "non-active-groups" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/non-active-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface.is_set or self.interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface.get_name_leafdata())
                        if (self.reason_for_non_activity.is_set or self.reason_for_non_activity.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reason_for_non_activity.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address"):
                            if (self.group_address is None):
                                self.group_address = Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                            return self.group_address

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address" or name == "source-address" or name == "interface" or name == "reason-for-non-activity"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface"):
                            self.interface = value
                            self.interface.value_namespace = name_space
                            self.interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "reason-for-non-activity"):
                            self.reason_for_non_activity = value
                            self.reason_for_non_activity.value_namespace = name_space
                            self.reason_for_non_activity.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.non_active_groups:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.non_active_groups:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "non-active-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "non-active-groups"):
                        for c in self.non_active_groups:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.non_active_groups.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "non-active-groups"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SsmMaps(Entity):
                """
                SSM Map Table
                
                .. attribute:: ssm_map
                
                	SSM Map information
                	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMaps.SsmMap>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.SsmMaps, self).__init__()

                    self.yang_name = "ssm-maps"
                    self.yang_parent_name = "default-context"

                    self.ssm_map = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.SsmMaps, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.SsmMaps, self).__setattr__(name, value)


                class SsmMap(Entity):
                    """
                    SSM Map information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr>`
                    
                    .. attribute:: map_type
                    
                    	Map Type of group
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_counts
                    
                    	Count of Sources
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.SsmMaps.SsmMap, self).__init__()

                        self.yang_name = "ssm-map"
                        self.yang_parent_name = "ssm-maps"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.map_type = YLeaf(YType.uint32, "map-type")

                        self.source_counts = YLeaf(YType.uint32, "source-counts")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.group_address_xr = Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "map_type",
                                        "source_counts",
                                        "ssm_map_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.SsmMaps.SsmMap, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.SsmMaps.SsmMap, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "ssm-map"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-maps/ssm-map/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.map_type.is_set or
                            self.source_counts.is_set or
                            self.ssm_map_type.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.map_type.yfilter != YFilter.not_set or
                            self.source_counts.yfilter != YFilter.not_set or
                            self.ssm_map_type.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-maps/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.map_type.get_name_leafdata())
                        if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_counts.get_name_leafdata())
                        if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "group-address" or name == "map-type" or name == "source-counts" or name == "ssm-map-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "map-type"):
                            self.map_type = value
                            self.map_type.value_namespace = name_space
                            self.map_type.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-counts"):
                            self.source_counts = value
                            self.source_counts.value_namespace = name_space
                            self.source_counts.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssm-map-type"):
                            self.ssm_map_type = value
                            self.ssm_map_type.value_namespace = name_space
                            self.ssm_map_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ssm_map:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ssm_map:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ssm-maps" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ssm-map"):
                        for c in self.ssm_map:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.SsmMaps.SsmMap()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ssm_map.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ssm-map"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class ExplicitGroups(Entity):
                """
                IGMP Explicit Group Database
                
                .. attribute:: explicit_group
                
                	IGMP Explicit Group Entry Information
                	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.ExplicitGroups, self).__init__()

                    self.yang_name = "explicit-groups"
                    self.yang_parent_name = "default-context"

                    self.explicit_group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.ExplicitGroups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.ExplicitGroups, self).__setattr__(name, value)


                class ExplicitGroup(Entity):
                    """
                    IGMP Explicit Group Entry Information
                    
                    .. attribute:: exclude_hosts
                    
                    	No. of hosts who are excluded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo>`
                    
                    .. attribute:: host
                    
                    	List of hosts
                    	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host>`
                    
                    .. attribute:: include_hosts
                    
                    	No. of hosts who are included
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup, self).__init__()

                        self.yang_name = "explicit-group"
                        self.yang_parent_name = "explicit-groups"

                        self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.host = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("exclude_hosts",
                                        "group_address",
                                        "include_hosts",
                                        "interface_name",
                                        "source_address") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup, self).__setattr__(name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "explicit-group"

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "explicit_tracking_enabled",
                                            "interface_name_xr",
                                            "is_added",
                                            "is_low_memory",
                                            "is_self_join",
                                            "is_suppressed",
                                            "older_host_version1_timer",
                                            "older_host_version2_timer",
                                            "router_filter_mode",
                                            "row_status",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "last-reporter" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/group-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.expiration_time.is_set or
                                self.explicit_tracking_enabled.is_set or
                                self.interface_name_xr.is_set or
                                self.is_added.is_set or
                                self.is_low_memory.is_set or
                                self.is_self_join.is_set or
                                self.is_suppressed.is_set or
                                self.older_host_version1_timer.is_set or
                                self.older_host_version2_timer.is_set or
                                self.router_filter_mode.is_set or
                                self.row_status.is_set or
                                self.uptime.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                                (self.last_reporter is not None and self.last_reporter.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_added.yfilter != YFilter.not_set or
                                self.is_low_memory.yfilter != YFilter.not_set or
                                self.is_self_join.yfilter != YFilter.not_set or
                                self.is_suppressed.yfilter != YFilter.not_set or
                                self.older_host_version1_timer.yfilter != YFilter.not_set or
                                self.older_host_version2_timer.yfilter != YFilter.not_set or
                                self.router_filter_mode.yfilter != YFilter.not_set or
                                self.row_status.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                                (self.last_reporter is not None and self.last_reporter.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_added.get_name_leafdata())
                            if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                            if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_self_join.get_name_leafdata())
                            if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                            if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                            if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                            if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                            if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.row_status.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            if (child_yang_name == "last-reporter"):
                                if (self.last_reporter is None):
                                    self.last_reporter = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                    self.last_reporter.parent = self
                                    self._children_name_map["last_reporter"] = "last-reporter"
                                return self.last_reporter

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "explicit-tracking-enabled"):
                                self.explicit_tracking_enabled = value
                                self.explicit_tracking_enabled.value_namespace = name_space
                                self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-added"):
                                self.is_added = value
                                self.is_added.value_namespace = name_space
                                self.is_added.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-low-memory"):
                                self.is_low_memory = value
                                self.is_low_memory.value_namespace = name_space
                                self.is_low_memory.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-self-join"):
                                self.is_self_join = value
                                self.is_self_join.value_namespace = name_space
                                self.is_self_join.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-suppressed"):
                                self.is_suppressed = value
                                self.is_suppressed.value_namespace = name_space
                                self.is_suppressed.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version1-timer"):
                                self.older_host_version1_timer = value
                                self.older_host_version1_timer.value_namespace = name_space
                                self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "older-host-version2-timer"):
                                self.older_host_version2_timer = value
                                self.older_host_version2_timer.value_namespace = name_space
                                self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-filter-mode"):
                                self.router_filter_mode = value
                                self.router_filter_mode.value_namespace = name_space
                                self.router_filter_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "row-status"):
                                self.row_status = value
                                self.row_status.value_namespace = name_space
                                self.row_status.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix


                    class Host(Entity):
                        """
                        List of hosts
                        
                        .. attribute:: address
                        
                        	Host Address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address>`
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: is_exclude
                        
                        	Exclude flag set
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	First 3 source addresses
                        	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                        
                        .. attribute:: source_count
                        
                        	No. of sources in entry
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "explicit-group"

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                            self.source_count = YLeaf(YType.uint32, "source-count")

                            self.uptime = YLeaf(YType.uint32, "uptime")

                            self.address = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.source_address = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("expiration_time",
                                            "is_exclude",
                                            "source_count",
                                            "uptime") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            Host Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "host"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/host/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SourceAddress(Entity):
                            """
                            First 3 source addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "host"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/host/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            for c in self.source_address:
                                if (c.has_data()):
                                    return True
                            return (
                                self.expiration_time.is_set or
                                self.is_exclude.is_set or
                                self.source_count.is_set or
                                self.uptime.is_set or
                                (self.address is not None and self.address.has_data()))

                        def has_operation(self):
                            for c in self.source_address:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.expiration_time.yfilter != YFilter.not_set or
                                self.is_exclude.yfilter != YFilter.not_set or
                                self.source_count.yfilter != YFilter.not_set or
                                self.uptime.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "host" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.expiration_time.get_name_leafdata())
                            if (self.is_exclude.is_set or self.is_exclude.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_exclude.get_name_leafdata())
                            if (self.source_count.is_set or self.source_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_count.get_name_leafdata())
                            if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.uptime.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "source-address"):
                                for c in self.source_address:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.source_address.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "source-address" or name == "expiration-time" or name == "is-exclude" or name == "source-count" or name == "uptime"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "expiration-time"):
                                self.expiration_time = value
                                self.expiration_time.value_namespace = name_space
                                self.expiration_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-exclude"):
                                self.is_exclude = value
                                self.is_exclude.value_namespace = name_space
                                self.is_exclude.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-count"):
                                self.source_count = value
                                self.source_count.value_namespace = name_space
                                self.source_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "uptime"):
                                self.uptime = value
                                self.uptime.value_namespace = name_space
                                self.uptime.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.host:
                            if (c.has_data()):
                                return True
                        return (
                            self.exclude_hosts.is_set or
                            self.group_address.is_set or
                            self.include_hosts.is_set or
                            self.interface_name.is_set or
                            self.source_address.is_set or
                            (self.group_info is not None and self.group_info.has_data()))

                    def has_operation(self):
                        for c in self.host:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.exclude_hosts.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.include_hosts.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.source_address.yfilter != YFilter.not_set or
                            (self.group_info is not None and self.group_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "explicit-group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.exclude_hosts.is_set or self.exclude_hosts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.exclude_hosts.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.include_hosts.is_set or self.include_hosts.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.include_hosts.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.source_address.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-info"):
                            if (self.group_info is None):
                                self.group_info = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                                self.group_info.parent = self
                                self._children_name_map["group_info"] = "group-info"
                            return self.group_info

                        if (child_yang_name == "host"):
                            for c in self.host:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.host.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-info" or name == "host" or name == "exclude-hosts" or name == "group-address" or name == "include-hosts" or name == "interface-name" or name == "source-address"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "exclude-hosts"):
                            self.exclude_hosts = value
                            self.exclude_hosts.value_namespace = name_space
                            self.exclude_hosts.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "include-hosts"):
                            self.include_hosts = value
                            self.include_hosts.value_namespace = name_space
                            self.include_hosts.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "source-address"):
                            self.source_address = value
                            self.source_address.value_namespace = name_space
                            self.source_address.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.explicit_group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.explicit_group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "explicit-groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "explicit-group"):
                        for c in self.explicit_group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.explicit_group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "explicit-group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceTable(Entity):
                """
                IGMP Interface specific Table
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.InterfaceTable, self).__init__()

                    self.yang_name = "interface-table"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.InterfaceTable, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.InterfaceTable, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.InterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interface-table"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Active.DefaultContext.InterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.InterfaceTable.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.InterfaceTable.Interface, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.InterfaceTable.Interface.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.InterfaceTable.Interface.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/interface-table/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Igmp.Active.DefaultContext.InterfaceTable.Interface.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.InterfaceTable.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceUnicastQosAdjusts(Entity):
                """
                IGMP Interface Unicast\-Qos\-Adjust
                
                .. attribute:: interface_unicast_qos_adjust
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts, self).__init__()

                    self.yang_name = "interface-unicast-qos-adjusts"
                    self.yang_parent_name = "default-context"

                    self.interface_unicast_qos_adjust = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts, self).__setattr__(name, value)


                class InterfaceUnicastQosAdjust(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_virtual_access
                    
                    	Is VirtualAccess Interface
                    	**type**\:  bool
                    
                    .. attribute:: rate
                    
                    	Overall rate in Kbps
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: rate_decrements
                    
                    	Count of rate decrements
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rate_increments
                    
                    	Count of rate increments
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update
                    
                    	List of updates
                    	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjust"
                        self.yang_parent_name = "interface-unicast-qos-adjusts"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                        self.rate = YLeaf(YType.uint32, "rate")

                        self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                        self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                        self.update = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "is_virtual_access",
                                        "rate",
                                        "rate_decrements",
                                        "rate_increments") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__setattr__(name, value)


                    class Update(Entity):
                        """
                        List of updates
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                        
                        .. attribute:: is_add
                        
                        	Is this a rate increment
                        	**type**\:  bool
                        
                        .. attribute:: received_time
                        
                        	Time this update is received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                        
                        .. attribute:: weight
                        
                        	Weight from policy
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                            self.yang_name = "update"
                            self.yang_parent_name = "interface-unicast-qos-adjust"

                            self.is_add = YLeaf(YType.boolean, "is-add")

                            self.received_time = YLeaf(YType.uint64, "received-time")

                            self.weight = YLeaf(YType.uint32, "weight")

                            self.group_address = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("is_add",
                                            "received_time",
                                            "weight") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__setattr__(name, value)


                        class SourceAddress(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "update"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "source-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class GroupAddress(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "update"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.is_add.is_set or
                                self.received_time.is_set or
                                self.weight.is_set or
                                (self.group_address is not None and self.group_address.has_data()) or
                                (self.source_address is not None and self.source_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.is_add.yfilter != YFilter.not_set or
                                self.received_time.yfilter != YFilter.not_set or
                                self.weight.yfilter != YFilter.not_set or
                                (self.group_address is not None and self.group_address.has_operation()) or
                                (self.source_address is not None and self.source_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "update" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.is_add.is_set or self.is_add.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_add.get_name_leafdata())
                            if (self.received_time.is_set or self.received_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.received_time.get_name_leafdata())
                            if (self.weight.is_set or self.weight.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.weight.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address"):
                                if (self.group_address is None):
                                    self.group_address = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                    self.group_address.parent = self
                                    self._children_name_map["group_address"] = "group-address"
                                return self.group_address

                            if (child_yang_name == "source-address"):
                                if (self.source_address is None):
                                    self.source_address = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                    self.source_address.parent = self
                                    self._children_name_map["source_address"] = "source-address"
                                return self.source_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address" or name == "source-address" or name == "is-add" or name == "received-time" or name == "weight"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "is-add"):
                                self.is_add = value
                                self.is_add.value_namespace = name_space
                                self.is_add.value_namespace_prefix = name_space_prefix
                            if(value_path == "received-time"):
                                self.received_time = value
                                self.received_time.value_namespace = name_space
                                self.received_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "weight"):
                                self.weight = value
                                self.weight.value_namespace = name_space
                                self.weight.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.update:
                            if (c.has_data()):
                                return True
                        return (
                            self.interface_name.is_set or
                            self.is_virtual_access.is_set or
                            self.rate.is_set or
                            self.rate_decrements.is_set or
                            self.rate_increments.is_set)

                    def has_operation(self):
                        for c in self.update:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.is_virtual_access.yfilter != YFilter.not_set or
                            self.rate.yfilter != YFilter.not_set or
                            self.rate_decrements.yfilter != YFilter.not_set or
                            self.rate_increments.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/interface-unicast-qos-adjusts/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.is_virtual_access.is_set or self.is_virtual_access.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_virtual_access.get_name_leafdata())
                        if (self.rate.is_set or self.rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate.get_name_leafdata())
                        if (self.rate_decrements.is_set or self.rate_decrements.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate_decrements.get_name_leafdata())
                        if (self.rate_increments.is_set or self.rate_increments.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.rate_increments.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "update"):
                            for c in self.update:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.update.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "update" or name == "interface-name" or name == "is-virtual-access" or name == "rate" or name == "rate-decrements" or name == "rate-increments"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-virtual-access"):
                            self.is_virtual_access = value
                            self.is_virtual_access.value_namespace = name_space
                            self.is_virtual_access.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate"):
                            self.rate = value
                            self.rate.value_namespace = name_space
                            self.rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate-decrements"):
                            self.rate_decrements = value
                            self.rate_decrements.value_namespace = name_space
                            self.rate_decrements.value_namespace_prefix = name_space_prefix
                        if(value_path == "rate-increments"):
                            self.rate_increments = value
                            self.rate_increments.value_namespace = name_space
                            self.rate_increments.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_unicast_qos_adjust:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_unicast_qos_adjust:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-unicast-qos-adjusts" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-unicast-qos-adjust"):
                        for c in self.interface_unicast_qos_adjust:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_unicast_qos_adjust.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-unicast-qos-adjust"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Ranges(Entity):
                """
                Range table
                
                .. attribute:: range
                
                	Range information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"

                    self.range = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.Ranges, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.Ranges, self).__setattr__(name, value)


                class Range(Entity):
                    """
                    Range information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr>`
                    
                    .. attribute:: group_mask
                    
                    	Group Mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: is_stale
                    
                    	Is the entry stale
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.group_mask = YLeaf(YType.int32, "group-mask")

                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.group_address_xr = Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("group_address",
                                        "group_mask",
                                        "is_stale",
                                        "prefix_length",
                                        "protocol") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.Ranges.Range, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.Ranges.Range, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "range"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ranges/range/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.group_address.is_set or
                            self.group_mask.is_set or
                            self.is_stale.is_set or
                            self.prefix_length.is_set or
                            self.protocol.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.group_mask.yfilter != YFilter.not_set or
                            self.is_stale.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.protocol.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "range" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ranges/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.group_mask.is_set or self.group_mask.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_mask.get_name_leafdata())
                        if (self.is_stale.is_set or self.is_stale.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_stale.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.protocol.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "group-address" or name == "group-mask" or name == "is-stale" or name == "prefix-length" or name == "protocol"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-mask"):
                            self.group_mask = value
                            self.group_mask.value_namespace = name_space
                            self.group_mask.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-stale"):
                            self.is_stale = value
                            self.is_stale.value_namespace = name_space
                            self.is_stale.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "protocol"):
                            self.protocol = value
                            self.protocol.value_namespace = name_space
                            self.protocol.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.range:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.range:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ranges" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "range"):
                        for c in self.range:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.Ranges.Range()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.range.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "range"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class IfrsInterfaces(Entity):
                """
                IGMP Interface specific
                
                .. attribute:: ifrs_interface
                
                	IGMP IFRS Interface
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"

                    self.ifrs_interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.IfrsInterfaces, self).__setattr__(name, value)


                class IfrsInterface(Entity):
                    """
                    IGMP IFRS Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	IFRS Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: igmp_interface_entry
                    
                    	IGMP interface entry
                    	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                    
                    .. attribute:: join_group_count
                    
                    	Join group count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                        self.igmp_interface_entry = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                        self.igmp_interface_entry.parent = self
                        self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                        self._children_yang_names.add("igmp-interface-entry")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "join_group_count") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__setattr__(name, value)


                    class IgmpInterfaceEntry(Entity):
                        """
                        IGMP interface entry
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                            self.yang_name = "igmp-interface-entry"
                            self.yang_parent_name = "ifrs-interface"

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("configuration_mcast_vrf_error",
                                            "configuration_mcast_vrf_set",
                                            "configurationvrf_error",
                                            "configurationvrf_set",
                                            "group_joins",
                                            "group_leaves",
                                            "host_version",
                                            "igmp_version",
                                            "interface_name_xr",
                                            "is_configurationverify",
                                            "is_identity_present",
                                            "is_im_state_registered",
                                            "is_interface_up",
                                            "is_ip_enabled",
                                            "is_las_registered",
                                            "is_las_request",
                                            "is_querier",
                                            "is_router_enabled",
                                            "is_subscriber",
                                            "las_get_address_count",
                                            "las_ll_add_update_count",
                                            "las_ll_registration_count",
                                            "las_ll_remove_update_count",
                                            "las_null_update_count",
                                            "las_unregistration_count",
                                            "las_update_count",
                                            "last_member_query_interval",
                                            "location",
                                            "mte_tuple_count",
                                            "mte_vrf_id",
                                            "mtu",
                                            "parent_ifhandle",
                                            "prefix_length",
                                            "proxy_interface",
                                            "querier_uptime",
                                            "query_interval",
                                            "query_maximum_response_time",
                                            "query_timeout",
                                            "robustness",
                                            "router_uptime_in_seconds",
                                            "state",
                                            "subscriber_id",
                                            "subscriber_mode",
                                            "time_since_last_query_in_seconds",
                                            "time_since_last_report_in_seconds",
                                            "total_active_groups",
                                            "vrf_id",
                                            "vrf_state") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__setattr__(name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "querier-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "igmp-interface-entry"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "subscriber-address" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.configuration_mcast_vrf_error.is_set or
                                self.configuration_mcast_vrf_set.is_set or
                                self.configurationvrf_error.is_set or
                                self.configurationvrf_set.is_set or
                                self.group_joins.is_set or
                                self.group_leaves.is_set or
                                self.host_version.is_set or
                                self.igmp_version.is_set or
                                self.interface_name_xr.is_set or
                                self.is_configurationverify.is_set or
                                self.is_identity_present.is_set or
                                self.is_im_state_registered.is_set or
                                self.is_interface_up.is_set or
                                self.is_ip_enabled.is_set or
                                self.is_las_registered.is_set or
                                self.is_las_request.is_set or
                                self.is_querier.is_set or
                                self.is_router_enabled.is_set or
                                self.is_subscriber.is_set or
                                self.las_get_address_count.is_set or
                                self.las_ll_add_update_count.is_set or
                                self.las_ll_registration_count.is_set or
                                self.las_ll_remove_update_count.is_set or
                                self.las_null_update_count.is_set or
                                self.las_unregistration_count.is_set or
                                self.las_update_count.is_set or
                                self.last_member_query_interval.is_set or
                                self.location.is_set or
                                self.mte_tuple_count.is_set or
                                self.mte_vrf_id.is_set or
                                self.mtu.is_set or
                                self.parent_ifhandle.is_set or
                                self.prefix_length.is_set or
                                self.proxy_interface.is_set or
                                self.querier_uptime.is_set or
                                self.query_interval.is_set or
                                self.query_maximum_response_time.is_set or
                                self.query_timeout.is_set or
                                self.robustness.is_set or
                                self.router_uptime_in_seconds.is_set or
                                self.state.is_set or
                                self.subscriber_id.is_set or
                                self.subscriber_mode.is_set or
                                self.time_since_last_query_in_seconds.is_set or
                                self.time_since_last_report_in_seconds.is_set or
                                self.total_active_groups.is_set or
                                self.vrf_id.is_set or
                                self.vrf_state.is_set or
                                (self.address is not None and self.address.has_data()) or
                                (self.querier_address is not None and self.querier_address.has_data()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                                self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                                self.configurationvrf_error.yfilter != YFilter.not_set or
                                self.configurationvrf_set.yfilter != YFilter.not_set or
                                self.group_joins.yfilter != YFilter.not_set or
                                self.group_leaves.yfilter != YFilter.not_set or
                                self.host_version.yfilter != YFilter.not_set or
                                self.igmp_version.yfilter != YFilter.not_set or
                                self.interface_name_xr.yfilter != YFilter.not_set or
                                self.is_configurationverify.yfilter != YFilter.not_set or
                                self.is_identity_present.yfilter != YFilter.not_set or
                                self.is_im_state_registered.yfilter != YFilter.not_set or
                                self.is_interface_up.yfilter != YFilter.not_set or
                                self.is_ip_enabled.yfilter != YFilter.not_set or
                                self.is_las_registered.yfilter != YFilter.not_set or
                                self.is_las_request.yfilter != YFilter.not_set or
                                self.is_querier.yfilter != YFilter.not_set or
                                self.is_router_enabled.yfilter != YFilter.not_set or
                                self.is_subscriber.yfilter != YFilter.not_set or
                                self.las_get_address_count.yfilter != YFilter.not_set or
                                self.las_ll_add_update_count.yfilter != YFilter.not_set or
                                self.las_ll_registration_count.yfilter != YFilter.not_set or
                                self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                                self.las_null_update_count.yfilter != YFilter.not_set or
                                self.las_unregistration_count.yfilter != YFilter.not_set or
                                self.las_update_count.yfilter != YFilter.not_set or
                                self.last_member_query_interval.yfilter != YFilter.not_set or
                                self.location.yfilter != YFilter.not_set or
                                self.mte_tuple_count.yfilter != YFilter.not_set or
                                self.mte_vrf_id.yfilter != YFilter.not_set or
                                self.mtu.yfilter != YFilter.not_set or
                                self.parent_ifhandle.yfilter != YFilter.not_set or
                                self.prefix_length.yfilter != YFilter.not_set or
                                self.proxy_interface.yfilter != YFilter.not_set or
                                self.querier_uptime.yfilter != YFilter.not_set or
                                self.query_interval.yfilter != YFilter.not_set or
                                self.query_maximum_response_time.yfilter != YFilter.not_set or
                                self.query_timeout.yfilter != YFilter.not_set or
                                self.robustness.yfilter != YFilter.not_set or
                                self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                                self.state.yfilter != YFilter.not_set or
                                self.subscriber_id.yfilter != YFilter.not_set or
                                self.subscriber_mode.yfilter != YFilter.not_set or
                                self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                                self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                                self.total_active_groups.yfilter != YFilter.not_set or
                                self.vrf_id.yfilter != YFilter.not_set or
                                self.vrf_state.yfilter != YFilter.not_set or
                                (self.address is not None and self.address.has_operation()) or
                                (self.querier_address is not None and self.querier_address.has_operation()) or
                                (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "igmp-interface-entry" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                            if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                            if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                            if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                            if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_joins.get_name_leafdata())
                            if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.group_leaves.get_name_leafdata())
                            if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.host_version.get_name_leafdata())
                            if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.igmp_version.get_name_leafdata())
                            if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                            if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                            if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                            if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                            if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                            if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                            if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                            if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_las_request.get_name_leafdata())
                            if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_querier.get_name_leafdata())
                            if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                            if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                            if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                            if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                            if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                            if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                            if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                            if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                            if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.las_update_count.get_name_leafdata())
                            if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                            if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.location.get_name_leafdata())
                            if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                            if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                            if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.mtu.get_name_leafdata())
                            if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                            if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.prefix_length.get_name_leafdata())
                            if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                            if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                            if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_interval.get_name_leafdata())
                            if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                            if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.query_timeout.get_name_leafdata())
                            if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.robustness.get_name_leafdata())
                            if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                            if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.state.get_name_leafdata())
                            if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                            if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                            if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                            if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                            if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                            if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_id.get_name_leafdata())
                            if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.vrf_state.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "address"):
                                if (self.address is None):
                                    self.address = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                    self.address.parent = self
                                    self._children_name_map["address"] = "address"
                                return self.address

                            if (child_yang_name == "querier-address"):
                                if (self.querier_address is None):
                                    self.querier_address = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                    self.querier_address.parent = self
                                    self._children_name_map["querier_address"] = "querier-address"
                                return self.querier_address

                            if (child_yang_name == "subscriber-address"):
                                if (self.subscriber_address is None):
                                    self.subscriber_address = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                    self.subscriber_address.parent = self
                                    self._children_name_map["subscriber_address"] = "subscriber-address"
                                return self.subscriber_address

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "configuration-mcast-vrf-error"):
                                self.configuration_mcast_vrf_error = value
                                self.configuration_mcast_vrf_error.value_namespace = name_space
                                self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configuration-mcast-vrf-set"):
                                self.configuration_mcast_vrf_set = value
                                self.configuration_mcast_vrf_set.value_namespace = name_space
                                self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-error"):
                                self.configurationvrf_error = value
                                self.configurationvrf_error.value_namespace = name_space
                                self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                            if(value_path == "configurationvrf-set"):
                                self.configurationvrf_set = value
                                self.configurationvrf_set.value_namespace = name_space
                                self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-joins"):
                                self.group_joins = value
                                self.group_joins.value_namespace = name_space
                                self.group_joins.value_namespace_prefix = name_space_prefix
                            if(value_path == "group-leaves"):
                                self.group_leaves = value
                                self.group_leaves.value_namespace = name_space
                                self.group_leaves.value_namespace_prefix = name_space_prefix
                            if(value_path == "host-version"):
                                self.host_version = value
                                self.host_version.value_namespace = name_space
                                self.host_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "igmp-version"):
                                self.igmp_version = value
                                self.igmp_version.value_namespace = name_space
                                self.igmp_version.value_namespace_prefix = name_space_prefix
                            if(value_path == "interface-name-xr"):
                                self.interface_name_xr = value
                                self.interface_name_xr.value_namespace = name_space
                                self.interface_name_xr.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-configurationverify"):
                                self.is_configurationverify = value
                                self.is_configurationverify.value_namespace = name_space
                                self.is_configurationverify.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-identity-present"):
                                self.is_identity_present = value
                                self.is_identity_present.value_namespace = name_space
                                self.is_identity_present.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-im-state-registered"):
                                self.is_im_state_registered = value
                                self.is_im_state_registered.value_namespace = name_space
                                self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-interface-up"):
                                self.is_interface_up = value
                                self.is_interface_up.value_namespace = name_space
                                self.is_interface_up.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-ip-enabled"):
                                self.is_ip_enabled = value
                                self.is_ip_enabled.value_namespace = name_space
                                self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-registered"):
                                self.is_las_registered = value
                                self.is_las_registered.value_namespace = name_space
                                self.is_las_registered.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-las-request"):
                                self.is_las_request = value
                                self.is_las_request.value_namespace = name_space
                                self.is_las_request.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-querier"):
                                self.is_querier = value
                                self.is_querier.value_namespace = name_space
                                self.is_querier.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-router-enabled"):
                                self.is_router_enabled = value
                                self.is_router_enabled.value_namespace = name_space
                                self.is_router_enabled.value_namespace_prefix = name_space_prefix
                            if(value_path == "is-subscriber"):
                                self.is_subscriber = value
                                self.is_subscriber.value_namespace = name_space
                                self.is_subscriber.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-get-address-count"):
                                self.las_get_address_count = value
                                self.las_get_address_count.value_namespace = name_space
                                self.las_get_address_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-add-update-count"):
                                self.las_ll_add_update_count = value
                                self.las_ll_add_update_count.value_namespace = name_space
                                self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-registration-count"):
                                self.las_ll_registration_count = value
                                self.las_ll_registration_count.value_namespace = name_space
                                self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-ll-remove-update-count"):
                                self.las_ll_remove_update_count = value
                                self.las_ll_remove_update_count.value_namespace = name_space
                                self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-null-update-count"):
                                self.las_null_update_count = value
                                self.las_null_update_count.value_namespace = name_space
                                self.las_null_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-unregistration-count"):
                                self.las_unregistration_count = value
                                self.las_unregistration_count.value_namespace = name_space
                                self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "las-update-count"):
                                self.las_update_count = value
                                self.las_update_count.value_namespace = name_space
                                self.las_update_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "last-member-query-interval"):
                                self.last_member_query_interval = value
                                self.last_member_query_interval.value_namespace = name_space
                                self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "location"):
                                self.location = value
                                self.location.value_namespace = name_space
                                self.location.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-tuple-count"):
                                self.mte_tuple_count = value
                                self.mte_tuple_count.value_namespace = name_space
                                self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                            if(value_path == "mte-vrf-id"):
                                self.mte_vrf_id = value
                                self.mte_vrf_id.value_namespace = name_space
                                self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "mtu"):
                                self.mtu = value
                                self.mtu.value_namespace = name_space
                                self.mtu.value_namespace_prefix = name_space_prefix
                            if(value_path == "parent-ifhandle"):
                                self.parent_ifhandle = value
                                self.parent_ifhandle.value_namespace = name_space
                                self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                            if(value_path == "prefix-length"):
                                self.prefix_length = value
                                self.prefix_length.value_namespace = name_space
                                self.prefix_length.value_namespace_prefix = name_space_prefix
                            if(value_path == "proxy-interface"):
                                self.proxy_interface = value
                                self.proxy_interface.value_namespace = name_space
                                self.proxy_interface.value_namespace_prefix = name_space_prefix
                            if(value_path == "querier-uptime"):
                                self.querier_uptime = value
                                self.querier_uptime.value_namespace = name_space
                                self.querier_uptime.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-interval"):
                                self.query_interval = value
                                self.query_interval.value_namespace = name_space
                                self.query_interval.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-maximum-response-time"):
                                self.query_maximum_response_time = value
                                self.query_maximum_response_time.value_namespace = name_space
                                self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                            if(value_path == "query-timeout"):
                                self.query_timeout = value
                                self.query_timeout.value_namespace = name_space
                                self.query_timeout.value_namespace_prefix = name_space_prefix
                            if(value_path == "robustness"):
                                self.robustness = value
                                self.robustness.value_namespace = name_space
                                self.robustness.value_namespace_prefix = name_space_prefix
                            if(value_path == "router-uptime-in-seconds"):
                                self.router_uptime_in_seconds = value
                                self.router_uptime_in_seconds.value_namespace = name_space
                                self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "state"):
                                self.state = value
                                self.state.value_namespace = name_space
                                self.state.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-id"):
                                self.subscriber_id = value
                                self.subscriber_id.value_namespace = name_space
                                self.subscriber_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "subscriber-mode"):
                                self.subscriber_mode = value
                                self.subscriber_mode.value_namespace = name_space
                                self.subscriber_mode.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-query-in-seconds"):
                                self.time_since_last_query_in_seconds = value
                                self.time_since_last_query_in_seconds.value_namespace = name_space
                                self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "time-since-last-report-in-seconds"):
                                self.time_since_last_report_in_seconds = value
                                self.time_since_last_report_in_seconds.value_namespace = name_space
                                self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                            if(value_path == "total-active-groups"):
                                self.total_active_groups = value
                                self.total_active_groups.value_namespace = name_space
                                self.total_active_groups.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-id"):
                                self.vrf_id = value
                                self.vrf_id.value_namespace = name_space
                                self.vrf_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "vrf-state"):
                                self.vrf_state = value
                                self.vrf_state.value_namespace = name_space
                                self.vrf_state.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.join_group_count.is_set or
                            (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.join_group_count.yfilter != YFilter.not_set or
                            (self.igmp_interface_entry is not None and self.igmp_interface_entry.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ifrs-interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.join_group_count.is_set or self.join_group_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.join_group_count.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "igmp-interface-entry"):
                            if (self.igmp_interface_entry is None):
                                self.igmp_interface_entry = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                                self.igmp_interface_entry.parent = self
                                self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            return self.igmp_interface_entry

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "igmp-interface-entry" or name == "interface-name" or name == "join-group-count"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "join-group-count"):
                            self.join_group_count = value
                            self.join_group_count.value_namespace = name_space
                            self.join_group_count.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ifrs_interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ifrs_interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ifrs-interface"):
                        for c in self.ifrs_interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ifrs_interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ifrs-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TrafficCounters(Entity):
                """
                IGMP Message Traffic Counters
                
                .. attribute:: auxillary_data_length_errors
                
                	AuxDataLen errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bad_scope_errors
                
                	BadScope errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_errors
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_errors
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: get_packet_failure
                
                	Packet get failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_disabled_idb
                
                	Packet received on disabled idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_dvmrp
                
                	DVMRP packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_leaves
                
                	Leaves in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_martian_address
                
                	Packets received with Martian Address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_mtrace
                
                	Mtrace packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_assigned_vrf_id
                
                	Packets received with no assigned vrf id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb
                
                	Packets received without idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_platform_support_mtrace
                
                	mtrace packets without platform support
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_in_idb
                
                	Packets received on idb without VRF
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_mtrace
                
                	mtrace packets with no vrf associated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim
                
                	PIM packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_queries
                
                	Query packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_reports
                
                	Reports in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_address_errors
                
                	Invalid Source Address errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: miscellaneous_errors
                
                	Packets dropped for other reasons
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_dvmrp
                
                	DVMRP packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_leaves
                
                	Leaves out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_mtrace
                
                	Mtrace packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_no_parent_interface_handle
                
                	Failures setting 2nd ifhandle
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_pim
                
                	PIM packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_queries
                
                	Query packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_reports
                
                	Reports out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_input_errors
                
                	Incoming Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_output_errors
                
                	Outgoing Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_in
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_out
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_socket_errors
                
                	Socket errors on reception
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_errors
                
                	Socket errors on send
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"

                    self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                    self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                    self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_errors = YLeaf(YType.uint32, "format-errors")

                    self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                    self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                    self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                    self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                    self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                    self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                    self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                    self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                    self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                    self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                    self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                    self.input_pim = YLeaf(YType.uint32, "input-pim")

                    self.input_queries = YLeaf(YType.uint32, "input-queries")

                    self.input_reports = YLeaf(YType.uint32, "input-reports")

                    self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                    self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                    self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                    self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                    self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                    self.output_pim = YLeaf(YType.uint32, "output-pim")

                    self.output_queries = YLeaf(YType.uint32, "output-queries")

                    self.output_reports = YLeaf(YType.uint32, "output-reports")

                    self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                    self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                    self.packets_in = YLeaf(YType.uint32, "packets-in")

                    self.packets_out = YLeaf(YType.uint32, "packets-out")

                    self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                    self.socket_errors = YLeaf(YType.uint32, "socket-errors")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("auxillary_data_length_errors",
                                    "bad_scope_errors",
                                    "checksum_errors",
                                    "elapsed_time",
                                    "format_errors",
                                    "get_packet_failure",
                                    "input_disabled_idb",
                                    "input_dvmrp",
                                    "input_leaves",
                                    "input_martian_address",
                                    "input_mtrace",
                                    "input_no_assigned_vrf_id",
                                    "input_no_idb",
                                    "input_no_platform_support_mtrace",
                                    "input_no_vrf_in_idb",
                                    "input_no_vrf_mtrace",
                                    "input_pim",
                                    "input_queries",
                                    "input_reports",
                                    "invalid_source_address_errors",
                                    "miscellaneous_errors",
                                    "no_socket_connection",
                                    "output_dvmrp",
                                    "output_leaves",
                                    "output_mtrace",
                                    "output_no_parent_interface_handle",
                                    "output_pim",
                                    "output_queries",
                                    "output_reports",
                                    "packet_manager_input_errors",
                                    "packet_manager_output_errors",
                                    "packets_in",
                                    "packets_out",
                                    "receive_socket_errors",
                                    "socket_errors") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.TrafficCounters, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.TrafficCounters, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.auxillary_data_length_errors.is_set or
                        self.bad_scope_errors.is_set or
                        self.checksum_errors.is_set or
                        self.elapsed_time.is_set or
                        self.format_errors.is_set or
                        self.get_packet_failure.is_set or
                        self.input_disabled_idb.is_set or
                        self.input_dvmrp.is_set or
                        self.input_leaves.is_set or
                        self.input_martian_address.is_set or
                        self.input_mtrace.is_set or
                        self.input_no_assigned_vrf_id.is_set or
                        self.input_no_idb.is_set or
                        self.input_no_platform_support_mtrace.is_set or
                        self.input_no_vrf_in_idb.is_set or
                        self.input_no_vrf_mtrace.is_set or
                        self.input_pim.is_set or
                        self.input_queries.is_set or
                        self.input_reports.is_set or
                        self.invalid_source_address_errors.is_set or
                        self.miscellaneous_errors.is_set or
                        self.no_socket_connection.is_set or
                        self.output_dvmrp.is_set or
                        self.output_leaves.is_set or
                        self.output_mtrace.is_set or
                        self.output_no_parent_interface_handle.is_set or
                        self.output_pim.is_set or
                        self.output_queries.is_set or
                        self.output_reports.is_set or
                        self.packet_manager_input_errors.is_set or
                        self.packet_manager_output_errors.is_set or
                        self.packets_in.is_set or
                        self.packets_out.is_set or
                        self.receive_socket_errors.is_set or
                        self.socket_errors.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.auxillary_data_length_errors.yfilter != YFilter.not_set or
                        self.bad_scope_errors.yfilter != YFilter.not_set or
                        self.checksum_errors.yfilter != YFilter.not_set or
                        self.elapsed_time.yfilter != YFilter.not_set or
                        self.format_errors.yfilter != YFilter.not_set or
                        self.get_packet_failure.yfilter != YFilter.not_set or
                        self.input_disabled_idb.yfilter != YFilter.not_set or
                        self.input_dvmrp.yfilter != YFilter.not_set or
                        self.input_leaves.yfilter != YFilter.not_set or
                        self.input_martian_address.yfilter != YFilter.not_set or
                        self.input_mtrace.yfilter != YFilter.not_set or
                        self.input_no_assigned_vrf_id.yfilter != YFilter.not_set or
                        self.input_no_idb.yfilter != YFilter.not_set or
                        self.input_no_platform_support_mtrace.yfilter != YFilter.not_set or
                        self.input_no_vrf_in_idb.yfilter != YFilter.not_set or
                        self.input_no_vrf_mtrace.yfilter != YFilter.not_set or
                        self.input_pim.yfilter != YFilter.not_set or
                        self.input_queries.yfilter != YFilter.not_set or
                        self.input_reports.yfilter != YFilter.not_set or
                        self.invalid_source_address_errors.yfilter != YFilter.not_set or
                        self.miscellaneous_errors.yfilter != YFilter.not_set or
                        self.no_socket_connection.yfilter != YFilter.not_set or
                        self.output_dvmrp.yfilter != YFilter.not_set or
                        self.output_leaves.yfilter != YFilter.not_set or
                        self.output_mtrace.yfilter != YFilter.not_set or
                        self.output_no_parent_interface_handle.yfilter != YFilter.not_set or
                        self.output_pim.yfilter != YFilter.not_set or
                        self.output_queries.yfilter != YFilter.not_set or
                        self.output_reports.yfilter != YFilter.not_set or
                        self.packet_manager_input_errors.yfilter != YFilter.not_set or
                        self.packet_manager_output_errors.yfilter != YFilter.not_set or
                        self.packets_in.yfilter != YFilter.not_set or
                        self.packets_out.yfilter != YFilter.not_set or
                        self.receive_socket_errors.yfilter != YFilter.not_set or
                        self.socket_errors.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-counters" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.auxillary_data_length_errors.is_set or self.auxillary_data_length_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.auxillary_data_length_errors.get_name_leafdata())
                    if (self.bad_scope_errors.is_set or self.bad_scope_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bad_scope_errors.get_name_leafdata())
                    if (self.checksum_errors.is_set or self.checksum_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.checksum_errors.get_name_leafdata())
                    if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                    if (self.format_errors.is_set or self.format_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.format_errors.get_name_leafdata())
                    if (self.get_packet_failure.is_set or self.get_packet_failure.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.get_packet_failure.get_name_leafdata())
                    if (self.input_disabled_idb.is_set or self.input_disabled_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_disabled_idb.get_name_leafdata())
                    if (self.input_dvmrp.is_set or self.input_dvmrp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_dvmrp.get_name_leafdata())
                    if (self.input_leaves.is_set or self.input_leaves.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_leaves.get_name_leafdata())
                    if (self.input_martian_address.is_set or self.input_martian_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_martian_address.get_name_leafdata())
                    if (self.input_mtrace.is_set or self.input_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_mtrace.get_name_leafdata())
                    if (self.input_no_assigned_vrf_id.is_set or self.input_no_assigned_vrf_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_assigned_vrf_id.get_name_leafdata())
                    if (self.input_no_idb.is_set or self.input_no_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_idb.get_name_leafdata())
                    if (self.input_no_platform_support_mtrace.is_set or self.input_no_platform_support_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_platform_support_mtrace.get_name_leafdata())
                    if (self.input_no_vrf_in_idb.is_set or self.input_no_vrf_in_idb.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_in_idb.get_name_leafdata())
                    if (self.input_no_vrf_mtrace.is_set or self.input_no_vrf_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_no_vrf_mtrace.get_name_leafdata())
                    if (self.input_pim.is_set or self.input_pim.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_pim.get_name_leafdata())
                    if (self.input_queries.is_set or self.input_queries.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_queries.get_name_leafdata())
                    if (self.input_reports.is_set or self.input_reports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.input_reports.get_name_leafdata())
                    if (self.invalid_source_address_errors.is_set or self.invalid_source_address_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.invalid_source_address_errors.get_name_leafdata())
                    if (self.miscellaneous_errors.is_set or self.miscellaneous_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.miscellaneous_errors.get_name_leafdata())
                    if (self.no_socket_connection.is_set or self.no_socket_connection.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.no_socket_connection.get_name_leafdata())
                    if (self.output_dvmrp.is_set or self.output_dvmrp.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_dvmrp.get_name_leafdata())
                    if (self.output_leaves.is_set or self.output_leaves.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_leaves.get_name_leafdata())
                    if (self.output_mtrace.is_set or self.output_mtrace.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_mtrace.get_name_leafdata())
                    if (self.output_no_parent_interface_handle.is_set or self.output_no_parent_interface_handle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_no_parent_interface_handle.get_name_leafdata())
                    if (self.output_pim.is_set or self.output_pim.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_pim.get_name_leafdata())
                    if (self.output_queries.is_set or self.output_queries.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_queries.get_name_leafdata())
                    if (self.output_reports.is_set or self.output_reports.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_reports.get_name_leafdata())
                    if (self.packet_manager_input_errors.is_set or self.packet_manager_input_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_manager_input_errors.get_name_leafdata())
                    if (self.packet_manager_output_errors.is_set or self.packet_manager_output_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packet_manager_output_errors.get_name_leafdata())
                    if (self.packets_in.is_set or self.packets_in.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_in.get_name_leafdata())
                    if (self.packets_out.is_set or self.packets_out.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.packets_out.get_name_leafdata())
                    if (self.receive_socket_errors.is_set or self.receive_socket_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.receive_socket_errors.get_name_leafdata())
                    if (self.socket_errors.is_set or self.socket_errors.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.socket_errors.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "auxillary-data-length-errors" or name == "bad-scope-errors" or name == "checksum-errors" or name == "elapsed-time" or name == "format-errors" or name == "get-packet-failure" or name == "input-disabled-idb" or name == "input-dvmrp" or name == "input-leaves" or name == "input-martian-address" or name == "input-mtrace" or name == "input-no-assigned-vrf-id" or name == "input-no-idb" or name == "input-no-platform-support-mtrace" or name == "input-no-vrf-in-idb" or name == "input-no-vrf-mtrace" or name == "input-pim" or name == "input-queries" or name == "input-reports" or name == "invalid-source-address-errors" or name == "miscellaneous-errors" or name == "no-socket-connection" or name == "output-dvmrp" or name == "output-leaves" or name == "output-mtrace" or name == "output-no-parent-interface-handle" or name == "output-pim" or name == "output-queries" or name == "output-reports" or name == "packet-manager-input-errors" or name == "packet-manager-output-errors" or name == "packets-in" or name == "packets-out" or name == "receive-socket-errors" or name == "socket-errors"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "auxillary-data-length-errors"):
                        self.auxillary_data_length_errors = value
                        self.auxillary_data_length_errors.value_namespace = name_space
                        self.auxillary_data_length_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "bad-scope-errors"):
                        self.bad_scope_errors = value
                        self.bad_scope_errors.value_namespace = name_space
                        self.bad_scope_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "checksum-errors"):
                        self.checksum_errors = value
                        self.checksum_errors.value_namespace = name_space
                        self.checksum_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "elapsed-time"):
                        self.elapsed_time = value
                        self.elapsed_time.value_namespace = name_space
                        self.elapsed_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "format-errors"):
                        self.format_errors = value
                        self.format_errors.value_namespace = name_space
                        self.format_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "get-packet-failure"):
                        self.get_packet_failure = value
                        self.get_packet_failure.value_namespace = name_space
                        self.get_packet_failure.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-disabled-idb"):
                        self.input_disabled_idb = value
                        self.input_disabled_idb.value_namespace = name_space
                        self.input_disabled_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-dvmrp"):
                        self.input_dvmrp = value
                        self.input_dvmrp.value_namespace = name_space
                        self.input_dvmrp.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-leaves"):
                        self.input_leaves = value
                        self.input_leaves.value_namespace = name_space
                        self.input_leaves.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-martian-address"):
                        self.input_martian_address = value
                        self.input_martian_address.value_namespace = name_space
                        self.input_martian_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-mtrace"):
                        self.input_mtrace = value
                        self.input_mtrace.value_namespace = name_space
                        self.input_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-assigned-vrf-id"):
                        self.input_no_assigned_vrf_id = value
                        self.input_no_assigned_vrf_id.value_namespace = name_space
                        self.input_no_assigned_vrf_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-idb"):
                        self.input_no_idb = value
                        self.input_no_idb.value_namespace = name_space
                        self.input_no_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-platform-support-mtrace"):
                        self.input_no_platform_support_mtrace = value
                        self.input_no_platform_support_mtrace.value_namespace = name_space
                        self.input_no_platform_support_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-in-idb"):
                        self.input_no_vrf_in_idb = value
                        self.input_no_vrf_in_idb.value_namespace = name_space
                        self.input_no_vrf_in_idb.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-no-vrf-mtrace"):
                        self.input_no_vrf_mtrace = value
                        self.input_no_vrf_mtrace.value_namespace = name_space
                        self.input_no_vrf_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-pim"):
                        self.input_pim = value
                        self.input_pim.value_namespace = name_space
                        self.input_pim.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-queries"):
                        self.input_queries = value
                        self.input_queries.value_namespace = name_space
                        self.input_queries.value_namespace_prefix = name_space_prefix
                    if(value_path == "input-reports"):
                        self.input_reports = value
                        self.input_reports.value_namespace = name_space
                        self.input_reports.value_namespace_prefix = name_space_prefix
                    if(value_path == "invalid-source-address-errors"):
                        self.invalid_source_address_errors = value
                        self.invalid_source_address_errors.value_namespace = name_space
                        self.invalid_source_address_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "miscellaneous-errors"):
                        self.miscellaneous_errors = value
                        self.miscellaneous_errors.value_namespace = name_space
                        self.miscellaneous_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "no-socket-connection"):
                        self.no_socket_connection = value
                        self.no_socket_connection.value_namespace = name_space
                        self.no_socket_connection.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-dvmrp"):
                        self.output_dvmrp = value
                        self.output_dvmrp.value_namespace = name_space
                        self.output_dvmrp.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-leaves"):
                        self.output_leaves = value
                        self.output_leaves.value_namespace = name_space
                        self.output_leaves.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-mtrace"):
                        self.output_mtrace = value
                        self.output_mtrace.value_namespace = name_space
                        self.output_mtrace.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-no-parent-interface-handle"):
                        self.output_no_parent_interface_handle = value
                        self.output_no_parent_interface_handle.value_namespace = name_space
                        self.output_no_parent_interface_handle.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-pim"):
                        self.output_pim = value
                        self.output_pim.value_namespace = name_space
                        self.output_pim.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-queries"):
                        self.output_queries = value
                        self.output_queries.value_namespace = name_space
                        self.output_queries.value_namespace_prefix = name_space_prefix
                    if(value_path == "output-reports"):
                        self.output_reports = value
                        self.output_reports.value_namespace = name_space
                        self.output_reports.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-manager-input-errors"):
                        self.packet_manager_input_errors = value
                        self.packet_manager_input_errors.value_namespace = name_space
                        self.packet_manager_input_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "packet-manager-output-errors"):
                        self.packet_manager_output_errors = value
                        self.packet_manager_output_errors.value_namespace = name_space
                        self.packet_manager_output_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "packets-in"):
                        self.packets_in = value
                        self.packets_in.value_namespace = name_space
                        self.packets_in.value_namespace_prefix = name_space_prefix
                    if(value_path == "packets-out"):
                        self.packets_out = value
                        self.packets_out.value_namespace = name_space
                        self.packets_out.value_namespace_prefix = name_space_prefix
                    if(value_path == "receive-socket-errors"):
                        self.receive_socket_errors = value
                        self.receive_socket_errors.value_namespace = name_space
                        self.receive_socket_errors.value_namespace_prefix = name_space_prefix
                    if(value_path == "socket-errors"):
                        self.socket_errors = value
                        self.socket_errors.value_namespace = name_space
                        self.socket_errors.value_namespace_prefix = name_space_prefix


            class Groups(Entity):
                """
                IGMP Group Database Table
                
                .. attribute:: group
                
                	IGMP Group Entry Information
                	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Groups.Group>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.Groups, self).__init__()

                    self.yang_name = "groups"
                    self.yang_parent_name = "default-context"

                    self.group = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.Groups, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.Groups, self).__setattr__(name, value)


                class Group(Entity):
                    """
                    IGMP Group Entry Information
                    
                    .. attribute:: expiration_time
                    
                    	Expiration time in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: explicit_tracking_enabled
                    
                    	Is explicit tracking enabled
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_added
                    
                    	Joined
                    	**type**\:  bool
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: is_self_join
                    
                    	If local system is member of this group on this interface
                    	**type**\:  bool
                    
                    .. attribute:: is_suppressed
                    
                    	Suppressed
                    	**type**\:  bool
                    
                    .. attribute:: last_reporter
                    
                    	Last reporter address
                    	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Groups.Group.LastReporter>`
                    
                    .. attribute:: older_host_version1_timer
                    
                    	IGMP Hostversion1timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: older_host_version2_timer
                    
                    	IGMP Hostversion2timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_filter_mode
                    
                    	Filter mode
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: row_status
                    
                    	interface on or off for the group
                    	**type**\:  str
                    
                    	**length:** 0..16
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Groups.Group.SourceAddress>`
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.Groups.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "groups"

                        self.expiration_time = YLeaf(YType.int32, "expiration-time")

                        self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_added = YLeaf(YType.boolean, "is-added")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                        self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                        self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                        self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                        self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                        self.row_status = YLeaf(YType.str, "row-status")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.last_reporter = Igmp.Active.DefaultContext.Groups.Group.LastReporter()
                        self.last_reporter.parent = self
                        self._children_name_map["last_reporter"] = "last-reporter"
                        self._children_yang_names.add("last-reporter")

                        self.source_address = Igmp.Active.DefaultContext.Groups.Group.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("expiration_time",
                                        "explicit_tracking_enabled",
                                        "group_address",
                                        "interface_name",
                                        "interface_name_xr",
                                        "is_added",
                                        "is_low_memory",
                                        "is_self_join",
                                        "is_suppressed",
                                        "older_host_version1_timer",
                                        "older_host_version2_timer",
                                        "router_filter_mode",
                                        "row_status",
                                        "uptime") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.Groups.Group, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.Groups.Group, self).__setattr__(name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "group-address-xr" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class LastReporter(Entity):
                        """
                        Last reporter address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.Groups.Group.LastReporter, self).__init__()

                            self.yang_name = "last-reporter"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.Groups.Group.LastReporter, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.Groups.Group.LastReporter, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "last-reporter" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.Groups.Group.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "group"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.Groups.Group.SourceAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.Groups.Group.SourceAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "source-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/groups/group/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.expiration_time.is_set or
                            self.explicit_tracking_enabled.is_set or
                            self.group_address.is_set or
                            self.interface_name.is_set or
                            self.interface_name_xr.is_set or
                            self.is_added.is_set or
                            self.is_low_memory.is_set or
                            self.is_self_join.is_set or
                            self.is_suppressed.is_set or
                            self.older_host_version1_timer.is_set or
                            self.older_host_version2_timer.is_set or
                            self.router_filter_mode.is_set or
                            self.row_status.is_set or
                            self.uptime.is_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_data()) or
                            (self.last_reporter is not None and self.last_reporter.has_data()) or
                            (self.source_address is not None and self.source_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.expiration_time.yfilter != YFilter.not_set or
                            self.explicit_tracking_enabled.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_added.yfilter != YFilter.not_set or
                            self.is_low_memory.yfilter != YFilter.not_set or
                            self.is_self_join.yfilter != YFilter.not_set or
                            self.is_suppressed.yfilter != YFilter.not_set or
                            self.older_host_version1_timer.yfilter != YFilter.not_set or
                            self.older_host_version2_timer.yfilter != YFilter.not_set or
                            self.router_filter_mode.yfilter != YFilter.not_set or
                            self.row_status.yfilter != YFilter.not_set or
                            self.uptime.yfilter != YFilter.not_set or
                            (self.group_address_xr is not None and self.group_address_xr.has_operation()) or
                            (self.last_reporter is not None and self.last_reporter.has_operation()) or
                            (self.source_address is not None and self.source_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "group" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/groups/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiration_time.get_name_leafdata())
                        if (self.explicit_tracking_enabled.is_set or self.explicit_tracking_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.explicit_tracking_enabled.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_added.is_set or self.is_added.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_added.get_name_leafdata())
                        if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                        if (self.is_self_join.is_set or self.is_self_join.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_self_join.get_name_leafdata())
                        if (self.is_suppressed.is_set or self.is_suppressed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_suppressed.get_name_leafdata())
                        if (self.older_host_version1_timer.is_set or self.older_host_version1_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.older_host_version1_timer.get_name_leafdata())
                        if (self.older_host_version2_timer.is_set or self.older_host_version2_timer.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.older_host_version2_timer.get_name_leafdata())
                        if (self.router_filter_mode.is_set or self.router_filter_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_filter_mode.get_name_leafdata())
                        if (self.row_status.is_set or self.row_status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.row_status.get_name_leafdata())
                        if (self.uptime.is_set or self.uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.uptime.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "group-address-xr"):
                            if (self.group_address_xr is None):
                                self.group_address_xr = Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                            return self.group_address_xr

                        if (child_yang_name == "last-reporter"):
                            if (self.last_reporter is None):
                                self.last_reporter = Igmp.Active.DefaultContext.Groups.Group.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                            return self.last_reporter

                        if (child_yang_name == "source-address"):
                            if (self.source_address is None):
                                self.source_address = Igmp.Active.DefaultContext.Groups.Group.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                            return self.source_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "group-address-xr" or name == "last-reporter" or name == "source-address" or name == "expiration-time" or name == "explicit-tracking-enabled" or name == "group-address" or name == "interface-name" or name == "interface-name-xr" or name == "is-added" or name == "is-low-memory" or name == "is-self-join" or name == "is-suppressed" or name == "older-host-version1-timer" or name == "older-host-version2-timer" or name == "router-filter-mode" or name == "row-status" or name == "uptime"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "expiration-time"):
                            self.expiration_time = value
                            self.expiration_time.value_namespace = name_space
                            self.expiration_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "explicit-tracking-enabled"):
                            self.explicit_tracking_enabled = value
                            self.explicit_tracking_enabled.value_namespace = name_space
                            self.explicit_tracking_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-added"):
                            self.is_added = value
                            self.is_added.value_namespace = name_space
                            self.is_added.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-low-memory"):
                            self.is_low_memory = value
                            self.is_low_memory.value_namespace = name_space
                            self.is_low_memory.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-self-join"):
                            self.is_self_join = value
                            self.is_self_join.value_namespace = name_space
                            self.is_self_join.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-suppressed"):
                            self.is_suppressed = value
                            self.is_suppressed.value_namespace = name_space
                            self.is_suppressed.value_namespace_prefix = name_space_prefix
                        if(value_path == "older-host-version1-timer"):
                            self.older_host_version1_timer = value
                            self.older_host_version1_timer.value_namespace = name_space
                            self.older_host_version1_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "older-host-version2-timer"):
                            self.older_host_version2_timer = value
                            self.older_host_version2_timer.value_namespace = name_space
                            self.older_host_version2_timer.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-filter-mode"):
                            self.router_filter_mode = value
                            self.router_filter_mode.value_namespace = name_space
                            self.router_filter_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "row-status"):
                            self.row_status = value
                            self.row_status.value_namespace = name_space
                            self.row_status.value_namespace_prefix = name_space_prefix
                        if(value_path == "uptime"):
                            self.uptime = value
                            self.uptime.value_namespace = name_space
                            self.uptime.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.group:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.group:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "groups" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "group"):
                        for c in self.group:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.Groups.Group()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.group.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class GroupSummary(Entity):
                """
                IGMP Groups Summary
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groutes
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_low_memory
                
                	Node is running low on memory
                	**type**\:  bool
                
                .. attribute:: sg_routes
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.GroupSummary, self).__init__()

                    self.yang_name = "group-summary"
                    self.yang_parent_name = "default-context"

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.groutes = YLeaf(YType.uint32, "groutes")

                    self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                    self.sg_routes = YLeaf(YType.uint32, "sg-routes")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("group_count",
                                    "groutes",
                                    "is_low_memory",
                                    "sg_routes") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.GroupSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.GroupSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.group_count.is_set or
                        self.groutes.is_set or
                        self.is_low_memory.is_set or
                        self.sg_routes.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.group_count.yfilter != YFilter.not_set or
                        self.groutes.yfilter != YFilter.not_set or
                        self.is_low_memory.yfilter != YFilter.not_set or
                        self.sg_routes.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "group-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.group_count.is_set or self.group_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.group_count.get_name_leafdata())
                    if (self.groutes.is_set or self.groutes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.groutes.get_name_leafdata())
                    if (self.is_low_memory.is_set or self.is_low_memory.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_low_memory.get_name_leafdata())
                    if (self.sg_routes.is_set or self.sg_routes.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sg_routes.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "group-count" or name == "groutes" or name == "is-low-memory" or name == "sg-routes"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "group-count"):
                        self.group_count = value
                        self.group_count.value_namespace = name_space
                        self.group_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "groutes"):
                        self.groutes = value
                        self.groutes.value_namespace = name_space
                        self.groutes.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-low-memory"):
                        self.is_low_memory = value
                        self.is_low_memory.value_namespace = name_space
                        self.is_low_memory.value_namespace_prefix = name_space_prefix
                    if(value_path == "sg-routes"):
                        self.sg_routes = value
                        self.sg_routes.value_namespace = name_space
                        self.sg_routes.value_namespace_prefix = name_space_prefix


            class IfrsInterfaceSummary(Entity):
                """
                IGMP IFRS Interface summary
                
                .. attribute:: configuration_count
                
                	Configuration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Interface Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.IfrsInterfaceSummary, self).__init__()

                    self.yang_name = "ifrs-interface-summary"
                    self.yang_parent_name = "default-context"

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("configuration_count",
                                    "interface_count") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.IfrsInterfaceSummary, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.IfrsInterfaceSummary, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.configuration_count.is_set or
                        self.interface_count.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.configuration_count.yfilter != YFilter.not_set or
                        self.interface_count.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ifrs-interface-summary" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.configuration_count.is_set or self.configuration_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.configuration_count.get_name_leafdata())
                    if (self.interface_count.is_set or self.interface_count.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_count.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "configuration-count" or name == "interface-count"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "configuration-count"):
                        self.configuration_count = value
                        self.configuration_count.value_namespace = name_space
                        self.configuration_count.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-count"):
                        self.interface_count = value
                        self.interface_count.value_namespace = name_space
                        self.interface_count.value_namespace_prefix = name_space_prefix


            class GlobalInterfaceTable(Entity):
                """
                IGMP Global Interface 
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.GlobalInterfaceTable, self).__init__()

                    self.yang_name = "global-interface-table"
                    self.yang_parent_name = "default-context"

                    self.interface = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.GlobalInterfaceTable, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.GlobalInterfaceTable, self).__setattr__(name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "global-interface-table"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/global-interface-table/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-interface-table" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface"):
                        for c in self.interface:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SsmMapDetails(Entity):
                """
                SSM Map Detail
                
                .. attribute:: ssm_map_detail
                
                	SSM Map Detail Table information
                	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.SsmMapDetails, self).__init__()

                    self.yang_name = "ssm-map-details"
                    self.yang_parent_name = "default-context"

                    self.ssm_map_detail = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.SsmMapDetails, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.SsmMapDetails, self).__setattr__(name, value)


                class SsmMapDetail(Entity):
                    """
                    SSM Map Detail Table information
                    
                    .. attribute:: elapsed_time
                    
                    	Elapsed time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: expiration_time
                    
                    	Expiration Time in Seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: map_info
                    
                    	Basic Map Info
                    	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo>`
                    
                    .. attribute:: query_interval
                    
                    	Query interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response_pending
                    
                    	Response Pending
                    	**type**\:  bool
                    
                    .. attribute:: sources
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources>`
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail, self).__init__()

                        self.yang_name = "ssm-map-detail"
                        self.yang_parent_name = "ssm-map-details"

                        self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                        self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.query_interval = YLeaf(YType.uint32, "query-interval")

                        self.response_pending = YLeaf(YType.boolean, "response-pending")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.map_info = Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                        self.map_info.parent = self
                        self._children_name_map["map_info"] = "map-info"
                        self._children_yang_names.add("map-info")

                        self.sources = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("elapsed_time",
                                        "expiration_time",
                                        "group_address",
                                        "query_interval",
                                        "response_pending",
                                        "ssm_map_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail, self).__setattr__(name, value)


                    class MapInfo(Entity):
                        """
                        Basic Map Info
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                            self.yang_name = "map-info"
                            self.yang_parent_name = "ssm-map-detail"

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.group_address_xr = Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("map_type",
                                            "source_counts") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__setattr__(name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "map-info"

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("af_name",
                                                "ipv4_address",
                                                "ipv6_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.af_name.is_set or
                                    self.ipv4_address.is_set or
                                    self.ipv6_address.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.af_name.yfilter != YFilter.not_set or
                                    self.ipv4_address.yfilter != YFilter.not_set or
                                    self.ipv6_address.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "group-address-xr" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-map-details/ssm-map-detail/map-info/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.af_name.get_name_leafdata())
                                if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                                if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "af-name"):
                                    self.af_name = value
                                    self.af_name.value_namespace = name_space
                                    self.af_name.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv4-address"):
                                    self.ipv4_address = value
                                    self.ipv4_address.value_namespace = name_space
                                    self.ipv4_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "ipv6-address"):
                                    self.ipv6_address = value
                                    self.ipv6_address.value_namespace = name_space
                                    self.ipv6_address.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.map_type.is_set or
                                self.source_counts.is_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.map_type.yfilter != YFilter.not_set or
                                self.source_counts.yfilter != YFilter.not_set or
                                (self.group_address_xr is not None and self.group_address_xr.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "map-info" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-map-details/ssm-map-detail/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.map_type.is_set or self.map_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.map_type.get_name_leafdata())
                            if (self.source_counts.is_set or self.source_counts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_counts.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "group-address-xr"):
                                if (self.group_address_xr is None):
                                    self.group_address_xr = Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                    self.group_address_xr.parent = self
                                    self._children_name_map["group_address_xr"] = "group-address-xr"
                                return self.group_address_xr

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "group-address-xr" or name == "map-type" or name == "source-counts"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "map-type"):
                                self.map_type = value
                                self.map_type.value_namespace = name_space
                                self.map_type.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-counts"):
                                self.source_counts = value
                                self.source_counts.value_namespace = name_space
                                self.source_counts.value_namespace_prefix = name_space_prefix


                    class Sources(Entity):
                        """
                        List of sources
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                            self.yang_name = "sources"
                            self.yang_parent_name = "ssm-map-detail"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "sources" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-map-details/ssm-map-detail/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.sources:
                            if (c.has_data()):
                                return True
                        return (
                            self.elapsed_time.is_set or
                            self.expiration_time.is_set or
                            self.group_address.is_set or
                            self.query_interval.is_set or
                            self.response_pending.is_set or
                            self.ssm_map_type.is_set or
                            (self.map_info is not None and self.map_info.has_data()))

                    def has_operation(self):
                        for c in self.sources:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.elapsed_time.yfilter != YFilter.not_set or
                            self.expiration_time.yfilter != YFilter.not_set or
                            self.group_address.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.response_pending.yfilter != YFilter.not_set or
                            self.ssm_map_type.yfilter != YFilter.not_set or
                            (self.map_info is not None and self.map_info.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ssm-map-detail" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-map-details/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.elapsed_time.is_set or self.elapsed_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.elapsed_time.get_name_leafdata())
                        if (self.expiration_time.is_set or self.expiration_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.expiration_time.get_name_leafdata())
                        if (self.group_address.is_set or self.group_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_address.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.response_pending.is_set or self.response_pending.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response_pending.get_name_leafdata())
                        if (self.ssm_map_type.is_set or self.ssm_map_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ssm_map_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "map-info"):
                            if (self.map_info is None):
                                self.map_info = Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                                self.map_info.parent = self
                                self._children_name_map["map_info"] = "map-info"
                            return self.map_info

                        if (child_yang_name == "sources"):
                            for c in self.sources:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.sources.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "map-info" or name == "sources" or name == "elapsed-time" or name == "expiration-time" or name == "group-address" or name == "query-interval" or name == "response-pending" or name == "ssm-map-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "elapsed-time"):
                            self.elapsed_time = value
                            self.elapsed_time.value_namespace = name_space
                            self.elapsed_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "expiration-time"):
                            self.expiration_time = value
                            self.expiration_time.value_namespace = name_space
                            self.expiration_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-address"):
                            self.group_address = value
                            self.group_address.value_namespace = name_space
                            self.group_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "response-pending"):
                            self.response_pending = value
                            self.response_pending.value_namespace = name_space
                            self.response_pending.value_namespace_prefix = name_space_prefix
                        if(value_path == "ssm-map-type"):
                            self.ssm_map_type = value
                            self.ssm_map_type.value_namespace = name_space
                            self.ssm_map_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.ssm_map_detail:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.ssm_map_detail:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "ssm-map-details" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ssm-map-detail"):
                        for c in self.ssm_map_detail:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.ssm_map_detail.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ssm-map-detail"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class InterfaceStateOffs(Entity):
                """
                IGMP Interface state off
                
                .. attribute:: interface_state_off
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.InterfaceStateOffs, self).__init__()

                    self.yang_name = "interface-state-offs"
                    self.yang_parent_name = "default-context"

                    self.interface_state_off = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Igmp.Active.DefaultContext.InterfaceStateOffs, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Igmp.Active.DefaultContext.InterfaceStateOffs, self).__setattr__(name, value)


                class InterfaceStateOff(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                        self.yang_name = "interface-state-off"
                        self.yang_parent_name = "interface-state-offs"

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("interface_name",
                                        "configuration_mcast_vrf_error",
                                        "configuration_mcast_vrf_set",
                                        "configurationvrf_error",
                                        "configurationvrf_set",
                                        "group_joins",
                                        "group_leaves",
                                        "host_version",
                                        "igmp_version",
                                        "interface_name_xr",
                                        "is_configurationverify",
                                        "is_identity_present",
                                        "is_im_state_registered",
                                        "is_interface_up",
                                        "is_ip_enabled",
                                        "is_las_registered",
                                        "is_las_request",
                                        "is_querier",
                                        "is_router_enabled",
                                        "is_subscriber",
                                        "las_get_address_count",
                                        "las_ll_add_update_count",
                                        "las_ll_registration_count",
                                        "las_ll_remove_update_count",
                                        "las_null_update_count",
                                        "las_unregistration_count",
                                        "las_update_count",
                                        "last_member_query_interval",
                                        "location",
                                        "mte_tuple_count",
                                        "mte_vrf_id",
                                        "mtu",
                                        "parent_ifhandle",
                                        "prefix_length",
                                        "proxy_interface",
                                        "querier_uptime",
                                        "query_interval",
                                        "query_maximum_response_time",
                                        "query_timeout",
                                        "robustness",
                                        "router_uptime_in_seconds",
                                        "state",
                                        "subscriber_id",
                                        "subscriber_mode",
                                        "time_since_last_query_in_seconds",
                                        "time_since_last_report_in_seconds",
                                        "total_active_groups",
                                        "vrf_id",
                                        "vrf_state") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__setattr__(name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "querier-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-off"

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("af_name",
                                            "ipv4_address",
                                            "ipv6_address") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.af_name.is_set or
                                self.ipv4_address.is_set or
                                self.ipv6_address.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.af_name.yfilter != YFilter.not_set or
                                self.ipv4_address.yfilter != YFilter.not_set or
                                self.ipv6_address.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "subscriber-address" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.af_name.is_set or self.af_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.af_name.get_name_leafdata())
                            if (self.ipv4_address.is_set or self.ipv4_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv4_address.get_name_leafdata())
                            if (self.ipv6_address.is_set or self.ipv6_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ipv6_address.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "af-name" or name == "ipv4-address" or name == "ipv6-address"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "af-name"):
                                self.af_name = value
                                self.af_name.value_namespace = name_space
                                self.af_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv4-address"):
                                self.ipv4_address = value
                                self.ipv4_address.value_namespace = name_space
                                self.ipv4_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "ipv6-address"):
                                self.ipv6_address = value
                                self.ipv6_address.value_namespace = name_space
                                self.ipv6_address.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.interface_name.is_set or
                            self.configuration_mcast_vrf_error.is_set or
                            self.configuration_mcast_vrf_set.is_set or
                            self.configurationvrf_error.is_set or
                            self.configurationvrf_set.is_set or
                            self.group_joins.is_set or
                            self.group_leaves.is_set or
                            self.host_version.is_set or
                            self.igmp_version.is_set or
                            self.interface_name_xr.is_set or
                            self.is_configurationverify.is_set or
                            self.is_identity_present.is_set or
                            self.is_im_state_registered.is_set or
                            self.is_interface_up.is_set or
                            self.is_ip_enabled.is_set or
                            self.is_las_registered.is_set or
                            self.is_las_request.is_set or
                            self.is_querier.is_set or
                            self.is_router_enabled.is_set or
                            self.is_subscriber.is_set or
                            self.las_get_address_count.is_set or
                            self.las_ll_add_update_count.is_set or
                            self.las_ll_registration_count.is_set or
                            self.las_ll_remove_update_count.is_set or
                            self.las_null_update_count.is_set or
                            self.las_unregistration_count.is_set or
                            self.las_update_count.is_set or
                            self.last_member_query_interval.is_set or
                            self.location.is_set or
                            self.mte_tuple_count.is_set or
                            self.mte_vrf_id.is_set or
                            self.mtu.is_set or
                            self.parent_ifhandle.is_set or
                            self.prefix_length.is_set or
                            self.proxy_interface.is_set or
                            self.querier_uptime.is_set or
                            self.query_interval.is_set or
                            self.query_maximum_response_time.is_set or
                            self.query_timeout.is_set or
                            self.robustness.is_set or
                            self.router_uptime_in_seconds.is_set or
                            self.state.is_set or
                            self.subscriber_id.is_set or
                            self.subscriber_mode.is_set or
                            self.time_since_last_query_in_seconds.is_set or
                            self.time_since_last_report_in_seconds.is_set or
                            self.total_active_groups.is_set or
                            self.vrf_id.is_set or
                            self.vrf_state.is_set or
                            (self.address is not None and self.address.has_data()) or
                            (self.querier_address is not None and self.querier_address.has_data()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.interface_name.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_error.yfilter != YFilter.not_set or
                            self.configuration_mcast_vrf_set.yfilter != YFilter.not_set or
                            self.configurationvrf_error.yfilter != YFilter.not_set or
                            self.configurationvrf_set.yfilter != YFilter.not_set or
                            self.group_joins.yfilter != YFilter.not_set or
                            self.group_leaves.yfilter != YFilter.not_set or
                            self.host_version.yfilter != YFilter.not_set or
                            self.igmp_version.yfilter != YFilter.not_set or
                            self.interface_name_xr.yfilter != YFilter.not_set or
                            self.is_configurationverify.yfilter != YFilter.not_set or
                            self.is_identity_present.yfilter != YFilter.not_set or
                            self.is_im_state_registered.yfilter != YFilter.not_set or
                            self.is_interface_up.yfilter != YFilter.not_set or
                            self.is_ip_enabled.yfilter != YFilter.not_set or
                            self.is_las_registered.yfilter != YFilter.not_set or
                            self.is_las_request.yfilter != YFilter.not_set or
                            self.is_querier.yfilter != YFilter.not_set or
                            self.is_router_enabled.yfilter != YFilter.not_set or
                            self.is_subscriber.yfilter != YFilter.not_set or
                            self.las_get_address_count.yfilter != YFilter.not_set or
                            self.las_ll_add_update_count.yfilter != YFilter.not_set or
                            self.las_ll_registration_count.yfilter != YFilter.not_set or
                            self.las_ll_remove_update_count.yfilter != YFilter.not_set or
                            self.las_null_update_count.yfilter != YFilter.not_set or
                            self.las_unregistration_count.yfilter != YFilter.not_set or
                            self.las_update_count.yfilter != YFilter.not_set or
                            self.last_member_query_interval.yfilter != YFilter.not_set or
                            self.location.yfilter != YFilter.not_set or
                            self.mte_tuple_count.yfilter != YFilter.not_set or
                            self.mte_vrf_id.yfilter != YFilter.not_set or
                            self.mtu.yfilter != YFilter.not_set or
                            self.parent_ifhandle.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set or
                            self.proxy_interface.yfilter != YFilter.not_set or
                            self.querier_uptime.yfilter != YFilter.not_set or
                            self.query_interval.yfilter != YFilter.not_set or
                            self.query_maximum_response_time.yfilter != YFilter.not_set or
                            self.query_timeout.yfilter != YFilter.not_set or
                            self.robustness.yfilter != YFilter.not_set or
                            self.router_uptime_in_seconds.yfilter != YFilter.not_set or
                            self.state.yfilter != YFilter.not_set or
                            self.subscriber_id.yfilter != YFilter.not_set or
                            self.subscriber_mode.yfilter != YFilter.not_set or
                            self.time_since_last_query_in_seconds.yfilter != YFilter.not_set or
                            self.time_since_last_report_in_seconds.yfilter != YFilter.not_set or
                            self.total_active_groups.yfilter != YFilter.not_set or
                            self.vrf_id.yfilter != YFilter.not_set or
                            self.vrf_state.yfilter != YFilter.not_set or
                            (self.address is not None and self.address.has_operation()) or
                            (self.querier_address is not None and self.querier_address.has_operation()) or
                            (self.subscriber_address is not None and self.subscriber_address.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/interface-state-offs/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name.get_name_leafdata())
                        if (self.configuration_mcast_vrf_error.is_set or self.configuration_mcast_vrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_error.get_name_leafdata())
                        if (self.configuration_mcast_vrf_set.is_set or self.configuration_mcast_vrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configuration_mcast_vrf_set.get_name_leafdata())
                        if (self.configurationvrf_error.is_set or self.configurationvrf_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_error.get_name_leafdata())
                        if (self.configurationvrf_set.is_set or self.configurationvrf_set.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.configurationvrf_set.get_name_leafdata())
                        if (self.group_joins.is_set or self.group_joins.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_joins.get_name_leafdata())
                        if (self.group_leaves.is_set or self.group_leaves.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.group_leaves.get_name_leafdata())
                        if (self.host_version.is_set or self.host_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.host_version.get_name_leafdata())
                        if (self.igmp_version.is_set or self.igmp_version.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.igmp_version.get_name_leafdata())
                        if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                        if (self.is_configurationverify.is_set or self.is_configurationverify.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_configurationverify.get_name_leafdata())
                        if (self.is_identity_present.is_set or self.is_identity_present.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_identity_present.get_name_leafdata())
                        if (self.is_im_state_registered.is_set or self.is_im_state_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_im_state_registered.get_name_leafdata())
                        if (self.is_interface_up.is_set or self.is_interface_up.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_interface_up.get_name_leafdata())
                        if (self.is_ip_enabled.is_set or self.is_ip_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ip_enabled.get_name_leafdata())
                        if (self.is_las_registered.is_set or self.is_las_registered.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_registered.get_name_leafdata())
                        if (self.is_las_request.is_set or self.is_las_request.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_las_request.get_name_leafdata())
                        if (self.is_querier.is_set or self.is_querier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_querier.get_name_leafdata())
                        if (self.is_router_enabled.is_set or self.is_router_enabled.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_router_enabled.get_name_leafdata())
                        if (self.is_subscriber.is_set or self.is_subscriber.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_subscriber.get_name_leafdata())
                        if (self.las_get_address_count.is_set or self.las_get_address_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_get_address_count.get_name_leafdata())
                        if (self.las_ll_add_update_count.is_set or self.las_ll_add_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_add_update_count.get_name_leafdata())
                        if (self.las_ll_registration_count.is_set or self.las_ll_registration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_registration_count.get_name_leafdata())
                        if (self.las_ll_remove_update_count.is_set or self.las_ll_remove_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_ll_remove_update_count.get_name_leafdata())
                        if (self.las_null_update_count.is_set or self.las_null_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_null_update_count.get_name_leafdata())
                        if (self.las_unregistration_count.is_set or self.las_unregistration_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_unregistration_count.get_name_leafdata())
                        if (self.las_update_count.is_set or self.las_update_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.las_update_count.get_name_leafdata())
                        if (self.last_member_query_interval.is_set or self.last_member_query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.last_member_query_interval.get_name_leafdata())
                        if (self.location.is_set or self.location.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.location.get_name_leafdata())
                        if (self.mte_tuple_count.is_set or self.mte_tuple_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_tuple_count.get_name_leafdata())
                        if (self.mte_vrf_id.is_set or self.mte_vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mte_vrf_id.get_name_leafdata())
                        if (self.mtu.is_set or self.mtu.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.mtu.get_name_leafdata())
                        if (self.parent_ifhandle.is_set or self.parent_ifhandle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.parent_ifhandle.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())
                        if (self.proxy_interface.is_set or self.proxy_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.proxy_interface.get_name_leafdata())
                        if (self.querier_uptime.is_set or self.querier_uptime.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.querier_uptime.get_name_leafdata())
                        if (self.query_interval.is_set or self.query_interval.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_interval.get_name_leafdata())
                        if (self.query_maximum_response_time.is_set or self.query_maximum_response_time.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_maximum_response_time.get_name_leafdata())
                        if (self.query_timeout.is_set or self.query_timeout.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.query_timeout.get_name_leafdata())
                        if (self.robustness.is_set or self.robustness.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.robustness.get_name_leafdata())
                        if (self.router_uptime_in_seconds.is_set or self.router_uptime_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.router_uptime_in_seconds.get_name_leafdata())
                        if (self.state.is_set or self.state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.state.get_name_leafdata())
                        if (self.subscriber_id.is_set or self.subscriber_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_id.get_name_leafdata())
                        if (self.subscriber_mode.is_set or self.subscriber_mode.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.subscriber_mode.get_name_leafdata())
                        if (self.time_since_last_query_in_seconds.is_set or self.time_since_last_query_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_query_in_seconds.get_name_leafdata())
                        if (self.time_since_last_report_in_seconds.is_set or self.time_since_last_report_in_seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.time_since_last_report_in_seconds.get_name_leafdata())
                        if (self.total_active_groups.is_set or self.total_active_groups.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.total_active_groups.get_name_leafdata())
                        if (self.vrf_id.is_set or self.vrf_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_id.get_name_leafdata())
                        if (self.vrf_state.is_set or self.vrf_state.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.vrf_state.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "address"):
                            if (self.address is None):
                                self.address = Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                            return self.address

                        if (child_yang_name == "querier-address"):
                            if (self.querier_address is None):
                                self.querier_address = Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                            return self.querier_address

                        if (child_yang_name == "subscriber-address"):
                            if (self.subscriber_address is None):
                                self.subscriber_address = Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                            return self.subscriber_address

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "address" or name == "querier-address" or name == "subscriber-address" or name == "interface-name" or name == "configuration-mcast-vrf-error" or name == "configuration-mcast-vrf-set" or name == "configurationvrf-error" or name == "configurationvrf-set" or name == "group-joins" or name == "group-leaves" or name == "host-version" or name == "igmp-version" or name == "interface-name-xr" or name == "is-configurationverify" or name == "is-identity-present" or name == "is-im-state-registered" or name == "is-interface-up" or name == "is-ip-enabled" or name == "is-las-registered" or name == "is-las-request" or name == "is-querier" or name == "is-router-enabled" or name == "is-subscriber" or name == "las-get-address-count" or name == "las-ll-add-update-count" or name == "las-ll-registration-count" or name == "las-ll-remove-update-count" or name == "las-null-update-count" or name == "las-unregistration-count" or name == "las-update-count" or name == "last-member-query-interval" or name == "location" or name == "mte-tuple-count" or name == "mte-vrf-id" or name == "mtu" or name == "parent-ifhandle" or name == "prefix-length" or name == "proxy-interface" or name == "querier-uptime" or name == "query-interval" or name == "query-maximum-response-time" or name == "query-timeout" or name == "robustness" or name == "router-uptime-in-seconds" or name == "state" or name == "subscriber-id" or name == "subscriber-mode" or name == "time-since-last-query-in-seconds" or name == "time-since-last-report-in-seconds" or name == "total-active-groups" or name == "vrf-id" or name == "vrf-state"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "interface-name"):
                            self.interface_name = value
                            self.interface_name.value_namespace = name_space
                            self.interface_name.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-error"):
                            self.configuration_mcast_vrf_error = value
                            self.configuration_mcast_vrf_error.value_namespace = name_space
                            self.configuration_mcast_vrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configuration-mcast-vrf-set"):
                            self.configuration_mcast_vrf_set = value
                            self.configuration_mcast_vrf_set.value_namespace = name_space
                            self.configuration_mcast_vrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-error"):
                            self.configurationvrf_error = value
                            self.configurationvrf_error.value_namespace = name_space
                            self.configurationvrf_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "configurationvrf-set"):
                            self.configurationvrf_set = value
                            self.configurationvrf_set.value_namespace = name_space
                            self.configurationvrf_set.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-joins"):
                            self.group_joins = value
                            self.group_joins.value_namespace = name_space
                            self.group_joins.value_namespace_prefix = name_space_prefix
                        if(value_path == "group-leaves"):
                            self.group_leaves = value
                            self.group_leaves.value_namespace = name_space
                            self.group_leaves.value_namespace_prefix = name_space_prefix
                        if(value_path == "host-version"):
                            self.host_version = value
                            self.host_version.value_namespace = name_space
                            self.host_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "igmp-version"):
                            self.igmp_version = value
                            self.igmp_version.value_namespace = name_space
                            self.igmp_version.value_namespace_prefix = name_space_prefix
                        if(value_path == "interface-name-xr"):
                            self.interface_name_xr = value
                            self.interface_name_xr.value_namespace = name_space
                            self.interface_name_xr.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-configurationverify"):
                            self.is_configurationverify = value
                            self.is_configurationverify.value_namespace = name_space
                            self.is_configurationverify.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-identity-present"):
                            self.is_identity_present = value
                            self.is_identity_present.value_namespace = name_space
                            self.is_identity_present.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-im-state-registered"):
                            self.is_im_state_registered = value
                            self.is_im_state_registered.value_namespace = name_space
                            self.is_im_state_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-interface-up"):
                            self.is_interface_up = value
                            self.is_interface_up.value_namespace = name_space
                            self.is_interface_up.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ip-enabled"):
                            self.is_ip_enabled = value
                            self.is_ip_enabled.value_namespace = name_space
                            self.is_ip_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-registered"):
                            self.is_las_registered = value
                            self.is_las_registered.value_namespace = name_space
                            self.is_las_registered.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-las-request"):
                            self.is_las_request = value
                            self.is_las_request.value_namespace = name_space
                            self.is_las_request.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-querier"):
                            self.is_querier = value
                            self.is_querier.value_namespace = name_space
                            self.is_querier.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-router-enabled"):
                            self.is_router_enabled = value
                            self.is_router_enabled.value_namespace = name_space
                            self.is_router_enabled.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-subscriber"):
                            self.is_subscriber = value
                            self.is_subscriber.value_namespace = name_space
                            self.is_subscriber.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-get-address-count"):
                            self.las_get_address_count = value
                            self.las_get_address_count.value_namespace = name_space
                            self.las_get_address_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-add-update-count"):
                            self.las_ll_add_update_count = value
                            self.las_ll_add_update_count.value_namespace = name_space
                            self.las_ll_add_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-registration-count"):
                            self.las_ll_registration_count = value
                            self.las_ll_registration_count.value_namespace = name_space
                            self.las_ll_registration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-ll-remove-update-count"):
                            self.las_ll_remove_update_count = value
                            self.las_ll_remove_update_count.value_namespace = name_space
                            self.las_ll_remove_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-null-update-count"):
                            self.las_null_update_count = value
                            self.las_null_update_count.value_namespace = name_space
                            self.las_null_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-unregistration-count"):
                            self.las_unregistration_count = value
                            self.las_unregistration_count.value_namespace = name_space
                            self.las_unregistration_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "las-update-count"):
                            self.las_update_count = value
                            self.las_update_count.value_namespace = name_space
                            self.las_update_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "last-member-query-interval"):
                            self.last_member_query_interval = value
                            self.last_member_query_interval.value_namespace = name_space
                            self.last_member_query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "location"):
                            self.location = value
                            self.location.value_namespace = name_space
                            self.location.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-tuple-count"):
                            self.mte_tuple_count = value
                            self.mte_tuple_count.value_namespace = name_space
                            self.mte_tuple_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "mte-vrf-id"):
                            self.mte_vrf_id = value
                            self.mte_vrf_id.value_namespace = name_space
                            self.mte_vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "mtu"):
                            self.mtu = value
                            self.mtu.value_namespace = name_space
                            self.mtu.value_namespace_prefix = name_space_prefix
                        if(value_path == "parent-ifhandle"):
                            self.parent_ifhandle = value
                            self.parent_ifhandle.value_namespace = name_space
                            self.parent_ifhandle.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix
                        if(value_path == "proxy-interface"):
                            self.proxy_interface = value
                            self.proxy_interface.value_namespace = name_space
                            self.proxy_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "querier-uptime"):
                            self.querier_uptime = value
                            self.querier_uptime.value_namespace = name_space
                            self.querier_uptime.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-interval"):
                            self.query_interval = value
                            self.query_interval.value_namespace = name_space
                            self.query_interval.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-maximum-response-time"):
                            self.query_maximum_response_time = value
                            self.query_maximum_response_time.value_namespace = name_space
                            self.query_maximum_response_time.value_namespace_prefix = name_space_prefix
                        if(value_path == "query-timeout"):
                            self.query_timeout = value
                            self.query_timeout.value_namespace = name_space
                            self.query_timeout.value_namespace_prefix = name_space_prefix
                        if(value_path == "robustness"):
                            self.robustness = value
                            self.robustness.value_namespace = name_space
                            self.robustness.value_namespace_prefix = name_space_prefix
                        if(value_path == "router-uptime-in-seconds"):
                            self.router_uptime_in_seconds = value
                            self.router_uptime_in_seconds.value_namespace = name_space
                            self.router_uptime_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "state"):
                            self.state = value
                            self.state.value_namespace = name_space
                            self.state.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-id"):
                            self.subscriber_id = value
                            self.subscriber_id.value_namespace = name_space
                            self.subscriber_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "subscriber-mode"):
                            self.subscriber_mode = value
                            self.subscriber_mode.value_namespace = name_space
                            self.subscriber_mode.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-query-in-seconds"):
                            self.time_since_last_query_in_seconds = value
                            self.time_since_last_query_in_seconds.value_namespace = name_space
                            self.time_since_last_query_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "time-since-last-report-in-seconds"):
                            self.time_since_last_report_in_seconds = value
                            self.time_since_last_report_in_seconds.value_namespace = name_space
                            self.time_since_last_report_in_seconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "total-active-groups"):
                            self.total_active_groups = value
                            self.total_active_groups.value_namespace = name_space
                            self.total_active_groups.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-id"):
                            self.vrf_id = value
                            self.vrf_id.value_namespace = name_space
                            self.vrf_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "vrf-state"):
                            self.vrf_state = value
                            self.vrf_state.value_namespace = name_space
                            self.vrf_state.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.interface_state_off:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.interface_state_off:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-state-offs" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interface-state-off"):
                        for c in self.interface_state_off:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.interface_state_off.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-state-off"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.detail_groups is not None and self.detail_groups.has_data()) or
                    (self.explicit_groups is not None and self.explicit_groups.has_data()) or
                    (self.global_interface_table is not None and self.global_interface_table.has_data()) or
                    (self.group_summary is not None and self.group_summary.has_data()) or
                    (self.groups is not None and self.groups.has_data()) or
                    (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_data()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_data()) or
                    (self.interface_state_offs is not None and self.interface_state_offs.has_data()) or
                    (self.interface_state_ons is not None and self.interface_state_ons.has_data()) or
                    (self.interface_table is not None and self.interface_table.has_data()) or
                    (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_data()) or
                    (self.non_active_groups is not None and self.non_active_groups.has_data()) or
                    (self.ranges is not None and self.ranges.has_data()) or
                    (self.ssm_map_details is not None and self.ssm_map_details.has_data()) or
                    (self.ssm_maps is not None and self.ssm_maps.has_data()) or
                    (self.summary is not None and self.summary.has_data()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.detail_groups is not None and self.detail_groups.has_operation()) or
                    (self.explicit_groups is not None and self.explicit_groups.has_operation()) or
                    (self.global_interface_table is not None and self.global_interface_table.has_operation()) or
                    (self.group_summary is not None and self.group_summary.has_operation()) or
                    (self.groups is not None and self.groups.has_operation()) or
                    (self.ifrs_interface_summary is not None and self.ifrs_interface_summary.has_operation()) or
                    (self.ifrs_interfaces is not None and self.ifrs_interfaces.has_operation()) or
                    (self.interface_state_offs is not None and self.interface_state_offs.has_operation()) or
                    (self.interface_state_ons is not None and self.interface_state_ons.has_operation()) or
                    (self.interface_table is not None and self.interface_table.has_operation()) or
                    (self.interface_unicast_qos_adjusts is not None and self.interface_unicast_qos_adjusts.has_operation()) or
                    (self.non_active_groups is not None and self.non_active_groups.has_operation()) or
                    (self.ranges is not None and self.ranges.has_operation()) or
                    (self.ssm_map_details is not None and self.ssm_map_details.has_operation()) or
                    (self.ssm_maps is not None and self.ssm_maps.has_operation()) or
                    (self.summary is not None and self.summary.has_operation()) or
                    (self.traffic_counters is not None and self.traffic_counters.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "default-context" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "detail-groups"):
                    if (self.detail_groups is None):
                        self.detail_groups = Igmp.Active.DefaultContext.DetailGroups()
                        self.detail_groups.parent = self
                        self._children_name_map["detail_groups"] = "detail-groups"
                    return self.detail_groups

                if (child_yang_name == "explicit-groups"):
                    if (self.explicit_groups is None):
                        self.explicit_groups = Igmp.Active.DefaultContext.ExplicitGroups()
                        self.explicit_groups.parent = self
                        self._children_name_map["explicit_groups"] = "explicit-groups"
                    return self.explicit_groups

                if (child_yang_name == "global-interface-table"):
                    if (self.global_interface_table is None):
                        self.global_interface_table = Igmp.Active.DefaultContext.GlobalInterfaceTable()
                        self.global_interface_table.parent = self
                        self._children_name_map["global_interface_table"] = "global-interface-table"
                    return self.global_interface_table

                if (child_yang_name == "group-summary"):
                    if (self.group_summary is None):
                        self.group_summary = Igmp.Active.DefaultContext.GroupSummary()
                        self.group_summary.parent = self
                        self._children_name_map["group_summary"] = "group-summary"
                    return self.group_summary

                if (child_yang_name == "groups"):
                    if (self.groups is None):
                        self.groups = Igmp.Active.DefaultContext.Groups()
                        self.groups.parent = self
                        self._children_name_map["groups"] = "groups"
                    return self.groups

                if (child_yang_name == "ifrs-interface-summary"):
                    if (self.ifrs_interface_summary is None):
                        self.ifrs_interface_summary = Igmp.Active.DefaultContext.IfrsInterfaceSummary()
                        self.ifrs_interface_summary.parent = self
                        self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    return self.ifrs_interface_summary

                if (child_yang_name == "ifrs-interfaces"):
                    if (self.ifrs_interfaces is None):
                        self.ifrs_interfaces = Igmp.Active.DefaultContext.IfrsInterfaces()
                        self.ifrs_interfaces.parent = self
                        self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    return self.ifrs_interfaces

                if (child_yang_name == "interface-state-offs"):
                    if (self.interface_state_offs is None):
                        self.interface_state_offs = Igmp.Active.DefaultContext.InterfaceStateOffs()
                        self.interface_state_offs.parent = self
                        self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    return self.interface_state_offs

                if (child_yang_name == "interface-state-ons"):
                    if (self.interface_state_ons is None):
                        self.interface_state_ons = Igmp.Active.DefaultContext.InterfaceStateOns()
                        self.interface_state_ons.parent = self
                        self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    return self.interface_state_ons

                if (child_yang_name == "interface-table"):
                    if (self.interface_table is None):
                        self.interface_table = Igmp.Active.DefaultContext.InterfaceTable()
                        self.interface_table.parent = self
                        self._children_name_map["interface_table"] = "interface-table"
                    return self.interface_table

                if (child_yang_name == "interface-unicast-qos-adjusts"):
                    if (self.interface_unicast_qos_adjusts is None):
                        self.interface_unicast_qos_adjusts = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts()
                        self.interface_unicast_qos_adjusts.parent = self
                        self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    return self.interface_unicast_qos_adjusts

                if (child_yang_name == "non-active-groups"):
                    if (self.non_active_groups is None):
                        self.non_active_groups = Igmp.Active.DefaultContext.NonActiveGroups()
                        self.non_active_groups.parent = self
                        self._children_name_map["non_active_groups"] = "non-active-groups"
                    return self.non_active_groups

                if (child_yang_name == "ranges"):
                    if (self.ranges is None):
                        self.ranges = Igmp.Active.DefaultContext.Ranges()
                        self.ranges.parent = self
                        self._children_name_map["ranges"] = "ranges"
                    return self.ranges

                if (child_yang_name == "ssm-map-details"):
                    if (self.ssm_map_details is None):
                        self.ssm_map_details = Igmp.Active.DefaultContext.SsmMapDetails()
                        self.ssm_map_details.parent = self
                        self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    return self.ssm_map_details

                if (child_yang_name == "ssm-maps"):
                    if (self.ssm_maps is None):
                        self.ssm_maps = Igmp.Active.DefaultContext.SsmMaps()
                        self.ssm_maps.parent = self
                        self._children_name_map["ssm_maps"] = "ssm-maps"
                    return self.ssm_maps

                if (child_yang_name == "summary"):
                    if (self.summary is None):
                        self.summary = Igmp.Active.DefaultContext.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                    return self.summary

                if (child_yang_name == "traffic-counters"):
                    if (self.traffic_counters is None):
                        self.traffic_counters = Igmp.Active.DefaultContext.TrafficCounters()
                        self.traffic_counters.parent = self
                        self._children_name_map["traffic_counters"] = "traffic-counters"
                    return self.traffic_counters

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "detail-groups" or name == "explicit-groups" or name == "global-interface-table" or name == "group-summary" or name == "groups" or name == "ifrs-interface-summary" or name == "ifrs-interfaces" or name == "interface-state-offs" or name == "interface-state-ons" or name == "interface-table" or name == "interface-unicast-qos-adjusts" or name == "non-active-groups" or name == "ranges" or name == "ssm-map-details" or name == "ssm-maps" or name == "summary" or name == "traffic-counters"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.default_context is not None and self.default_context.has_data()) or
                (self.process is not None and self.process.has_data()) or
                (self.vrfs is not None and self.vrfs.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.default_context is not None and self.default_context.has_operation()) or
                (self.process is not None and self.process.has_operation()) or
                (self.vrfs is not None and self.vrfs.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "active" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "default-context"):
                if (self.default_context is None):
                    self.default_context = Igmp.Active.DefaultContext()
                    self.default_context.parent = self
                    self._children_name_map["default_context"] = "default-context"
                return self.default_context

            if (child_yang_name == "process"):
                if (self.process is None):
                    self.process = Igmp.Active.Process()
                    self.process.parent = self
                    self._children_name_map["process"] = "process"
                return self.process

            if (child_yang_name == "vrfs"):
                if (self.vrfs is None):
                    self.vrfs = Igmp.Active.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                return self.vrfs

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "default-context" or name == "process" or name == "vrfs"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.active is not None and self.active.has_data()) or
            (self.standby is not None and self.standby.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.active is not None and self.active.has_operation()) or
            (self.standby is not None and self.standby.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ipv4-igmp-oper:igmp" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "active"):
            if (self.active is None):
                self.active = Igmp.Active()
                self.active.parent = self
                self._children_name_map["active"] = "active"
            return self.active

        if (child_yang_name == "standby"):
            if (self.standby is None):
                self.standby = Igmp.Standby()
                self.standby.parent = self
                self._children_name_map["standby"] = "standby"
            return self.standby

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "active" or name == "standby"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Igmp()
        return self._top_entity

